=== modified file '.bzrignore'
--- .bzrignore	2008-07-29 20:42:35 +0000
+++ .bzrignore	2011-07-10 22:53:59 +0000
@@ -1,6 +1,12 @@
 ./dist
 ./loggerhead.egg-info
-./loggerhead.conf
 ./loggerhead.pid
 ./logs
 build
+*.log
+_trial_temp
+loggerhead-memprofile
+./docs/_build/
+tags
+.project
+.pydevproject

=== added file 'HACKING'
--- HACKING	1970-01-01 00:00:00 +0000
+++ HACKING	2011-02-10 23:05:31 +0000
@@ -0,0 +1,59 @@
+Loggerhead
+==========
+
+Overview
+--------
+
+This document attempts to give some hints for people that are wanting to work
+on Loggerhead.
+
+
+Testing
+-------
+
+You can run the loggerhead test suite as a bzr plugin. To run just the
+loggerhead tests::
+
+  bzr selftest -s bp.loggerhead
+
+
+Load Testing
+------------
+
+As a web service, Loggerhead will often be hit by multiple requests. We want
+to make sure that loggerhead can scale with many requests, without performing
+poorly or crashing under the load.
+
+There is a command ``bzr load-test-loggerhead`` that can be run to stress
+loggerhead. A script is given, describing what requests to make, against what
+URLs, and for what level of parallel activity.
+
+
+Load Testing Multiple Instances
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+One way that Launchpad provides both high availability and performance scaling
+is by running multiple instances of loggerhead, serving the same content. A
+proxy is then used to load balance the requests. This also allows us to shut
+down one instance for upgrading, without interupting service (requests are
+just routed to the other instance).
+
+However, multiple processes poses an even greater risk that caches will
+conflict. As such, it is useful to test that changes don't introduce coherency
+issues at load. ``bzr load-test-loggerhead`` can be configured with a script
+that will make requests against multiple loggerhead instances concurrently.
+
+To run multiple instances, it is often sufficient to just spawn multiple
+servers on different ports. For example::
+
+  $ bzr serve --http --port=8080 &
+  $ bzr serve --http --port=8081 &
+
+There is a simple example script already in the source tree::
+
+  $ bzr load-test-loggerhead load_test_scripts/multiple_instances.script
+
+
+
+.. vim: ft=rst tw=78
+

=== modified file 'MANIFEST.in'
--- MANIFEST.in	2008-06-22 18:04:15 +0000
+++ MANIFEST.in	2012-02-02 04:58:46 +0000
@@ -1,2 +1,6 @@
-include loggerhead.conf.example README.txt NEWS
+include NEWS
+include README.txt
+include apache-loggerhead.conf
+include bazaar.conf
+include loggerhead.conf.example
 recursive-include loggerhead/static *

=== modified file 'Makefile'
--- Makefile	2007-10-29 16:19:30 +0000
+++ Makefile	2011-03-14 08:47:03 +0000
@@ -8,5 +8,4 @@
 	rm -rf dist/
 
 check:
-	# XXX MichaelHudson 2007-10-29 bug=158361: We can't run the loggerhead
-	# tests in PQM yet :(
+	BZR_PLUGINS_AT=loggerhead@$$(pwd) bzr selftest -s bp.loggerhead

=== modified file 'NEWS'
--- NEWS	2008-07-31 05:41:42 +0000
+++ NEWS	2012-02-02 04:58:46 +0000
@@ -1,8 +1,289 @@
 What's changed in loggerhead?
 =============================
 
-1.6 [unreleased]
-----------------
+1.19 [????]
+-----------
+
+    - Add ``bzr load-test-loggerhead`` as a way to make sure loggerhead can
+      handle concurrent requests, etc. Scripts can be written that spawn
+      multiple threads, and issue concurrent requests.
+      (John Arbash Meinel)
+
+    - HEAD requests should not return body content. This is done by adding
+      another wsgi middleware that strips the body when the REQUEST_METHOD is
+      HEAD. Note that you have to add the middleware into your pipeline, and
+      it does not decrease the actual work done.
+      (John Arbash Meinel, #716201)
+
+    - If we get a HEAD request, there is no reason to expand the template, we
+      shouldn't be returning body content anyway.
+      (John Arbash Meinel, #716201, #716217)
+
+    - Merge the pqm changes back into trunk, after trunk was reverted to an old
+      revision. (John Arbash Meinel, #716152)
+
+    - Redirect ``/files/file.txt`` to ``/view/file.txt`` and ``/view/dir`` to
+      ``/files/dir``. (Jasper St. Pierre, #569358)
+
+    - Remove ``start-loggerhead`` and ``stop-loggerhead`` which were already
+      deprecated. (John Arbash Meinel)
+
+    - Show "Author(s)" as separate from "Committer". And label them
+      correctly. (John Arbash Meinel, #733015)
+
+    - The json module is no longer claimed to be supported as alternative for 
+      simplejson. (Jelmer Vernooij, #586611)
+
+    - Viewing the ``/changes`` page only iterates enough of the history to show
+      the actual revisions displayed, rather than walking the whole mainline.
+      Improves performance on projects with long histories like emacs.
+      (John Arbash Meinel)
+
+    - Fix support for displaying foreign revision ids.
+      (Jelmer Vernooij, #736026)
+
+    - Add hook 'controller' to BranchWSGIApp, allowing other bzr plugins
+      to provide custom branch-specific controllers. (Jelmer Vernooij, #585822)
+
+    - Add privacy notification code to loggerhead, allowing branches to be
+      marked as private and a notification ribbon to be displayed via
+      javascript on the view pages. (JC Sackett, #823471)
+
+    - Add a script and documentation for running under mod_wsgi.
+      (Stuart Colville, Toshio Kuratomi)
+
+
+1.18.1 [24Mar2011]
+------------------
+
+    - Fix escaping of filenames in revision views.
+      (William Grant, #740142)
+
+    - Add missing import to loggerhead.trace, allowing start-loggerhead
+      to run when a log.roll config option is set.
+      (Max Kanat-Alexander, #673999)
+
+
+1.18 [10Nov2010]
+----------------
+
+    - Syntax highlighting is no longer applied for files greater than 512K,
+      reducing codebrowse.launchpad.net overloading.
+      (Max Kanat-Alexander, #513044)
+
+    - Documentation added in the docs directory. README simplified
+      accordingly. (Tres Seaver).
+
+    - Show svn/git/hg revision ids in loggerhead revision view.
+      (Jelmer Vernooij)
+
+    - Fix .bzr/smart access to branches in shared repos. (You also need
+      a version of bzr with bug #348308 fixed.) (Andrew Bennetts)
+
+    - Support FastCGI, SCGI and AJP using flup. (Denis Martinez)
+
+    - Repository.get_revision_inventory() was removed in bzr 2.2; use
+      Repository.get_inventory() instead. (Matt Nordhoff, #528194)
+
+    - Ignore readonly+ prefix when checking if Loggerhead is serving a
+      local location. (Reported by Tres Seaver.) (Matt Nordhoff)
+
+    - Set Cache-Control and Expires headers on static pages.
+      (John Arbash Meinel)
+
+    - Generate relative links where possible (everywhere but HTTP
+      redirects and feed IDs). (Michael Hudson, Matt Nordhoff)
+
+    - Fix bad redirect when visiting "/download" or "/download/".
+      (Matt Nordhoff, #247992)
+
+1.17 [20Aug2009]
+----------------
+
+    - Add bug links in revision informations (Alexandre Garnier, #314052)
+
+    - Make sure that binary files aren't annotated. (Martin Albisetti,
+      #258848)
+
+    - Loggerhead now serves bzr branches over HTTP and exposes the URL
+      to branch them. Addresses bug #240577. (Jonathan Lange)
+
+    - Leading blank lines in commit messages no longer result in an
+      empty summary. (Colin Watson)
+
+    - Added optional syntax highlighting to annotate view using
+      python-pygments.  Partially addresses bug #306631. (Peter Bui)
+
+    - Convert newlines in commit messages to HTML line breaks for
+      annotate and changelog views.  Addresses bug #273688. (Peter
+      Bui)
+
+    - serve-branches now errors if run behind a proxy without
+      paste.deploy installed. (Michael Hudson)
+
+    - Loggerhead should now handle file and directory names that need
+      URL escaping without crashing.
+
+    - The start-loggerhead script properly sets the wsgi.url_scheme
+      from the server.webpath option. (neror, #260547)
+
+    - The revision page defaults to unified style again, and can
+      convert to a side-by-side view using JavaScript. (Michael Hudson)
+
+    - Clean up and improve performance of the annotate view. (Michael
+      Hudson)
+
+    - Finish converting JavaScript from MooTools to YUI 3. (Michael
+      Hudson)
+
+    - Improve compatibility with IE 6. (Michael Hudson)
+
+    - Leading blank lines in commit messages no longer result in an
+      empty summary. (Colin Watson)
+
+    - Clip long lines in side-by-side diff view. (Michael Hudson,
+      #334837)
+
+    - The user-confusing "next" and "previous" links now read "older"
+      and "newer" respectively. (Michael Hudson, #297930)
+
+    - The annotate view now contains line number anchors. (Michael
+      Hudson)
+
+    - Fix inventory pages using "//" in links. (Michael Hudson, #329668)
+
+    - Fix problems viewing files and directories containing spaces and
+      other funny characters. (Peter Bui)
+
+    - Changelog messages are now displayed with newlines preserved.
+      (Peter Bui, #273688)
+
+    - Offer a link to see the full file diffs for a file path. (Michael
+      Hudson, #333797)
+
+    - Fix annotate error caused by Pygments stripping trailing
+      whitespace. (Michael Hudson, #338762)
+
+    - Loggerhead can be installed as a Bazaar plugin and run by
+      'bzr serve --http'. (Martin Pool)
+
+    - Load parts of the changelog and revision pages via XMLHttpRequest
+      to improve performance. This adds a dependency on simplejson or
+      json. Partially addresses bug #253950. (Michael Hudson)
+
+    - Various improvements to the animation JavaScript. (Michael Hudson)
+
+    - Fix HTML content of source files being displayed unescaped when
+      Pygments was unavailable. (Michael Hudson, #344970)
+
+    - Fix serve-branches's path argument. (Michael Hudson, #353230)
+
+    - serve-branches now has an option, --use-cdn, to load YUI from
+      Yahoo!'s CDN. (Matt Nordhoff)
+
+    - Fix certain race conditions for loading bzr-search. (Robert
+      Collins, #334250)
+
+    - Fix errors when using serve-branches --log-folder or --user-dirs.
+      (It was calling config.get_option() incorrectly.) (Matt Nordhoff,
+      bug #361238)
+
+    - Move some caching from RAM to the disk, and other caching and
+      memory usage improvements. (Michael Hudson)
+
+    - Add a --cache-dir option to serve-branches to choose where to
+      place the SQL cache, and only create one temporary SQL dir per
+      process. (Matt Nordhoff, #358322)
+
+    - Replace homebrew memory profiling code with Dozer. (Paul Hummer)
+
+    - Use the branch's public_branch as the default suggested URL to
+      branch from (Matt Nordhoff, #369767)
+
+    - Fix a file descriptor leak (Matt Nordhoff, #370845)
+
+    - Use transport API internally, so it is possible to specify a remote
+      URL to serve-branches. (Jelmer Vernooij, #371787)
+
+    - Fix internal server errors when using start-loggerhead. (Matt
+      Nordhoff, #375948)
+
+    - Fix annotating non-UTF-8 files when Pygments is disabled. (Matt
+      Nordhoff, #376957)
+
+    - Fix 'bzr serve --http' errors. (Matt Nordhoff, #377551)
+
+    - Added the option to hide branches by setting http_serve = False
+      in locations.conf (Martin Albisetti)
+
+    - Fix serving branches over HTTP. (Matt Nordhoff, Jelmer Vernooij,
+      #380026)
+
+    - Install loggerhead as a bzr plugin by default (Jelmer Vernooij)
+
+    - Fix logging 404 Not Found responses (Matt Nordhoff, #381029)
+
+    - Bumped minimunm bzrlib version to 1.13 (Martin Albisetti)
+
+    - Make sure the Atom feeds (nearly) validate. (Matt Nordhoff, #247162)
+
+    - Support serving branches over HTTP using the smart server protocol.
+      (Jelmer Vernooij, #306853)
+
+    - Serving branch data was broken when --allow-writes was *not*
+      passed. (Michael Hudson, #388730)
+
+    - http_serve config values are interpreted more forgivingly.
+      (Michael Hudson)
+
+    - When specifying a remote url to serve-branches, do not share
+      connections between threads. (Michael Hudson, #390972)
+
+    - http_serve values from locations.conf are now applied to
+      non-branch .bzr data (e.g shared repositories). (Michael Hudson)
+
+    - tags are now displayed. (Cris Boylan, Alexandre Garnier, Michael
+      Hudson, #246739)
+
+    - Display Loggerhead's version number at the bottom of the page, and
+      add a <meta> generator tag also including the version numbers of
+      its dependencies. (Matt Nordhoff, #370155)
+
+
+1.10 [22Dec2008]
+----------------
+
+    - Add startup deamon script for Linux (Marius Kruger)
+
+    - Switch navigation from file_ids to paths. Fixes bugs #260363,
+      #269365 and #128926. (Martin Albisetti)
+
+    - Fix bug #258710 ("the /files page explodes in an empty branch").
+      Also minor improvements to the /files and /changes pages.
+      (Marius Kruger)
+
+    - Added --port, --host and --prefix options to serve-branches
+      script. (Martin Albisetti)
+
+    - Fixed broken template for project browsing with start-loggerhead
+      (Martin Albisetti)
+
+    - Added --reload options to restart the application when a python
+      file change. (Guillermo Gonzalez)
+
+    - Added error handling middleware. (Guillermo Gonzalez)
+
+    - Fix bug #243415 ("Tracebacks go to console but not log
+      file"). Also minor improvements to logging in serve-branches and
+      start-loggerhead. (Guillermo Gonzalez)
+
+1.6 [15Aug2008]
+----------------
+
+    - Download a diffs between revisions. (Martin Albisetti)
+
+    - Modified templates to make loggerhead's theme easier to
+      change. (Paul Hummer)
 
     - Default sqlite interface is now sqlite3. (Robert Collins)
 
@@ -13,12 +294,15 @@
     - Remove the .py extension requiered by the Debian Policy.
       (Jelmer Vernooij)
 
+    - New startup script serve-branches will serve Loggerhead without
+      the need of configuration, and allow you to browse through directories
+      and branches. (Michael Hudson)
+
     - Loggerhead is no longer a TurboGears application, but rather a
       WSGI application built using Paste (see http://wsgi.org/ and
-      http://pythonpaste.org/ for more about WSGI and Paste). XXX more.
+      http://pythonpaste.org/ for more about WSGI and Paste).
 
-    - zpt.cleaner_urls bug 138021 ("loggerhead should generate links
-      based on revision numbers and file paths").  XXX more.
+    - URLs now use revision numbers instead of revision ids (Martin Albisetti)
 
     - The scripts no longer insist on Python 2.4 -- loggerhead works
       fine with 2.5.

=== renamed file 'README.txt' => 'README'
--- README.txt	2008-07-26 17:53:10 +0000
+++ README	2010-04-23 01:30:29 +0000
@@ -1,104 +1,28 @@
-LOGGERHEAD
+Loggerhead
 ==========
 
-[ Version 1.6 for Bazaar 1.6 ]
-
-Loggerhead is a web viewer for Bazaar branches.  It can be used to
-navigate a branch history, annotate files, perform searches... all the
-usual things.
-
-
-GETTING STARTED
----------------
-
-Loggerhead depends on SimpleTAL for templating and Paste for the
-server.  So you need these installed -- on Ubuntu you want the
-'python-simpletal' and 'python-paste' packages installed.  You need
-version 1.2 or newer of Paste.
-
-Then simply run the 'serve-branches' with the branch you want to
-serve on the command line:
-
-    ./serve-branches ~/path/to/branch
-
-The script listens on port 8080 so head to http://localhost:8080/ in
-your browser to see the branch.  You can also pass a directory that
-contains branches to the script, and it will serve a very simple
-directory listing at other pages.
-
-You may update the Bazaar branches being viewed at any time.
-Loggerhead will notice and refresh, and Bazaar uses its own branch
-locking to prevent corruption.
-
-
-USING A CONFIG FILE
--------------------
-
-Previous versions of Loggerhead read their configuration from a config
-file.  This mode of operation is still supported by the
-'start-loggerhead' script.  A 'loggerhead.conf.example' file is
-included in the source which has comments explaining the various
-options.
-
-Loggerhead can then be started by running::
-
-    $ ./start-loggerhead
-
-This will run loggerhead in the background, listening on port 8080 by
-default.
-
-To stop Loggerhead, run::
-
-    $ ./stop-loggerhead
-
-In the configuration file you can configure projects, and branches per
-project.  The idea is that you could be publishing several (possibly
-unrelated) projects through the same loggerhead instance, and several
-branches for the same project.  See the "loggerhead.conf.example" file
-included with the source.
-
-A debug and access log are stored in the logs/ folder, relative to
-the location of the start-loggerhead script.
-
-
-SERVING LOGGERHEAD FROM BEHIND APACHE
--------------------------------------
-
-If you want to view Bazaar branches from your existing Apache
-installation, you'll need to configure Apache to proxy certain
-requests to Loggerhead.  Adding lines like this to you Apache
-configuration is one way to do this::
-
-    <Location "/branches/">
-        ProxyPass http://127.0.0.1:8080/
-        ProxyPassReverse http://127.0.0.1:8080/
-    </Location>
-
-If Paste Deploy is installed, the 'serve-branches' script can be
-run behind a proxy at the root of a site, but if you're running it at
-some path into the site, you'll need to add a 'prefix' argument to the
-PrefixMiddleware call in the script.  More flexible configuration
-should be added soon...
-
-
-FILES CHANGED CACHE
--------------------
-
-To speed up the display of the changelog view for large trees,
-loggerhead can be configured to cache the files changes between
-revisions.  Set the 'cachepath' value in the config file.
-
-
-SUPPORT
--------
-
-Loggerhead is loosely based on bazaar-webserve, which was loosely
-based on hgweb.  Discussion should take place on the bazaar-dev
-mailing list at bazaar@lists.canonical.com.  You can join the list at
-<https://lists.ubuntu.com/mailman/listinfo/bazaar>.  You don't need to
-subscribe to post, but your first post will be held briefly for manual
-moderation.
-
-Bugs are tracked on Launchpad; start at:
-
-    https://bugs.launchpad.net/loggerhead
+Overview
+--------
+
+Loggerhead is a web viewer for Bazaar branches. Its lets users do
+stuff like:
+
+* navigate through branch history
+* view the files in a given revision
+* annotate files (i.e. find out the origin of each line of a file)
+* perform searches.
+
+
+Documentation
+-------------
+
+See docs/index.rst for installation instructions and basic
+documentation.
+
+
+Licensing
+---------
+
+This software is (C) Copyright Canonical Limited 2006-10 under the
+GPL Version 2 or later. Please see the file COPYING.txt for the
+licence details.

=== added file '__init__.py'
--- __init__.py	1970-01-01 00:00:00 +0000
+++ __init__.py	2011-04-12 10:18:52 +0000
@@ -0,0 +1,122 @@
+# Copyright 2009, 2010, 2011 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+# This file allows loggerhead to be treated as a plugin for bzr.
+#
+# XXX: Because loggerhead already contains a loggerhead directory, much of the
+# code is going to appear loaded at bzrlib.plugins.loggerhead.loggerhead.
+# This seems like the easiest thing, because bzrlib wants the top-level plugin
+# directory to be the module, but when it's used as a library people expect
+# the source directory to contain a directory called loggerhead.  -- mbp
+# 20090123
+
+"""Loggerhead web viewer for Bazaar branches.
+
+This provides a new option "--http" to the "bzr serve" command, that
+starts a web server to browse the contents of a branch.
+"""
+
+import sys
+
+from info import (
+    bzr_plugin_version as version_info,
+    bzr_compatible_versions,
+    )
+
+if __name__ == 'bzrlib.plugins.loggerhead':
+    import bzrlib
+    from bzrlib.api import require_any_api
+    from bzrlib import commands
+
+    require_any_api(bzrlib, bzr_compatible_versions)
+
+    from bzrlib.transport import transport_server_registry
+
+    DEFAULT_HOST = '0.0.0.0'
+    DEFAULT_PORT = 8080
+    HELP = ('Loggerhead, a web-based code viewer and server. (default port: %d)' %
+            (DEFAULT_PORT,))
+
+    def _ensure_loggerhead_path():
+        """Ensure that you can 'import loggerhead' and get the root."""
+        # loggerhead internal code will try to 'import loggerhead', so
+        # let's put it on the path if we can't find it in the existing path
+        try:
+            import loggerhead.apps.transport
+        except ImportError:
+            import os.path, sys
+            sys.path.append(os.path.dirname(__file__))
+
+    def serve_http(transport, host=None, port=None, inet=None):
+        # TODO: if we supported inet to pass requests in and respond to them,
+        #       then it would be easier to test the full stack, but it probably
+        #       means routing around paste.httpserver.serve which probably
+        #       isn't testing the full stack
+        from paste.httpexceptions import HTTPExceptionHandler
+        from paste.httpserver import serve
+
+        _ensure_loggerhead_path()
+
+        from loggerhead.apps.http_head import HeadMiddleware
+        from loggerhead.apps.transport import BranchesFromTransportRoot
+        from loggerhead.config import LoggerheadConfig
+        from loggerhead.main import setup_logging
+
+        if host is None:
+            host = DEFAULT_HOST
+        if port is None:
+            port = DEFAULT_PORT
+        argv = ['--host', host, '--port', str(port), '--', transport.base]
+        if not transport.is_readonly():
+            argv.insert(0, '--allow-writes')
+        config = LoggerheadConfig(argv)
+        setup_logging(config, init_logging=False, log_file=sys.stderr)
+        app = BranchesFromTransportRoot(transport.base, config)
+        # Bug #758618, HeadMiddleware seems to break HTTPExceptionHandler from
+        # actually sending appropriate return codes to the client. Since nobody
+        # desperately needs HeadMiddleware right now, just ignoring it.
+        # app = HeadMiddleware(app)
+        app = HTTPExceptionHandler(app)
+        serve(app, host=host, port=port)
+
+    transport_server_registry.register('http', serve_http, help=HELP)
+
+    class cmd_load_test_loggerhead(commands.Command):
+        """Run a load test against a live loggerhead instance.
+
+        Pass in the name of a script file to run. See loggerhead/load_test.py
+        for a description of the file format.
+        """
+
+        takes_args = ["filename"]
+
+        def run(self, filename):
+            from bzrlib.plugins.loggerhead.loggerhead import load_test
+            script = load_test.run_script(filename)
+            for thread_id in sorted(script._threads):
+                worker = script._threads[thread_id][0]
+                for url, success, time in worker.stats:
+                    self.outf.write(' %5.3fs %s %s\n'
+                                    % (time, str(success)[0], url))
+
+    commands.register_command(cmd_load_test_loggerhead)
+
+    def load_tests(standard_tests, module, loader):
+        _ensure_loggerhead_path()
+        standard_tests.addTests(loader.loadTestsFromModuleNames(
+            ['bzrlib.plugins.loggerhead.loggerhead.tests']))
+        return standard_tests

=== added file 'apache-loggerhead.conf'
--- apache-loggerhead.conf	1970-01-01 00:00:00 +0000
+++ apache-loggerhead.conf	2010-04-18 17:55:33 +0000
@@ -0,0 +1,19 @@
+### If you receive MemoryError tracebacks setting up loggerhead under mod_wsgi,
+### read /usr/share/doc/loggerhead*/README for help
+Alias /bzr/static /usr/share/loggerhead/static
+RewriteEngine On
+RewriteRule ^/bzr$ /bzr/ [R]
+
+WSGIDaemonProcess loggerhead user=apache group=apache maximum-requests=1000 display-name=loggerhead processes=4 threads=1
+WSGISocketPrefix run/wsgi
+WSGIRestrictStdout On
+WSGIRestrictSignal Off
+
+WSGIScriptAlias /bzr /usr/bin/loggerhead.wsgi
+
+<Location /bzr>
+    WSGIProcessGroup loggerhead
+    Order deny,allow
+    Allow from all
+</Location>
+

=== added file 'bazaar.conf'
--- bazaar.conf	1970-01-01 00:00:00 +0000
+++ bazaar.conf	2010-04-18 14:41:23 +0000
@@ -0,0 +1,9 @@
+# directory to serve bzr branches from
+# Non-bzr directories under this path will also be visible in loggerhead
+#http_root_dir = '/var/www/bzr'
+
+# The url prefix for the bzr branches.
+http_user_prefix = '/bzr'
+
+# Directory to put cache files in
+http_sql_dir = '/var/cache/loggerhead'

=== added directory 'docs'
=== added file 'docs/Makefile'
--- docs/Makefile	1970-01-01 00:00:00 +0000
+++ docs/Makefile	2010-03-23 15:44:51 +0000
@@ -0,0 +1,89 @@
+# Makefile for Sphinx documentation
+#
+
+# You can set these variables from the command line.
+SPHINXOPTS    =
+SPHINXBUILD   = sphinx-build
+PAPER         =
+BUILDDIR      = _build
+
+# Internal variables.
+PAPEROPT_a4     = -D latex_paper_size=a4
+PAPEROPT_letter = -D latex_paper_size=letter
+ALLSPHINXOPTS   = -d $(BUILDDIR)/doctrees $(PAPEROPT_$(PAPER)) $(SPHINXOPTS) .
+
+.PHONY: help clean html dirhtml pickle json htmlhelp qthelp latex changes linkcheck doctest
+
+help:
+	@echo "Please use \`make <target>' where <target> is one of"
+	@echo "  html      to make standalone HTML files"
+	@echo "  dirhtml   to make HTML files named index.html in directories"
+	@echo "  pickle    to make pickle files"
+	@echo "  json      to make JSON files"
+	@echo "  htmlhelp  to make HTML files and a HTML help project"
+	@echo "  qthelp    to make HTML files and a qthelp project"
+	@echo "  latex     to make LaTeX files, you can set PAPER=a4 or PAPER=letter"
+	@echo "  changes   to make an overview of all changed/added/deprecated items"
+	@echo "  linkcheck to check all external links for integrity"
+	@echo "  doctest   to run all doctests embedded in the documentation (if enabled)"
+
+clean:
+	-rm -rf $(BUILDDIR)/*
+
+html:
+	$(SPHINXBUILD) -b html $(ALLSPHINXOPTS) $(BUILDDIR)/html
+	@echo
+	@echo "Build finished. The HTML pages are in $(BUILDDIR)/html."
+
+dirhtml:
+	$(SPHINXBUILD) -b dirhtml $(ALLSPHINXOPTS) $(BUILDDIR)/dirhtml
+	@echo
+	@echo "Build finished. The HTML pages are in $(BUILDDIR)/dirhtml."
+
+pickle:
+	$(SPHINXBUILD) -b pickle $(ALLSPHINXOPTS) $(BUILDDIR)/pickle
+	@echo
+	@echo "Build finished; now you can process the pickle files."
+
+json:
+	$(SPHINXBUILD) -b json $(ALLSPHINXOPTS) $(BUILDDIR)/json
+	@echo
+	@echo "Build finished; now you can process the JSON files."
+
+htmlhelp:
+	$(SPHINXBUILD) -b htmlhelp $(ALLSPHINXOPTS) $(BUILDDIR)/htmlhelp
+	@echo
+	@echo "Build finished; now you can run HTML Help Workshop with the" \
+	      ".hhp project file in $(BUILDDIR)/htmlhelp."
+
+qthelp:
+	$(SPHINXBUILD) -b qthelp $(ALLSPHINXOPTS) $(BUILDDIR)/qthelp
+	@echo
+	@echo "Build finished; now you can run "qcollectiongenerator" with the" \
+	      ".qhcp project file in $(BUILDDIR)/qthelp, like this:"
+	@echo "# qcollectiongenerator $(BUILDDIR)/qthelp/loggerhead.qhcp"
+	@echo "To view the help file:"
+	@echo "# assistant -collectionFile $(BUILDDIR)/qthelp/loggerhead.qhc"
+
+latex:
+	$(SPHINXBUILD) -b latex $(ALLSPHINXOPTS) $(BUILDDIR)/latex
+	@echo
+	@echo "Build finished; the LaTeX files are in $(BUILDDIR)/latex."
+	@echo "Run \`make all-pdf' or \`make all-ps' in that directory to" \
+	      "run these through (pdf)latex."
+
+changes:
+	$(SPHINXBUILD) -b changes $(ALLSPHINXOPTS) $(BUILDDIR)/changes
+	@echo
+	@echo "The overview file is in $(BUILDDIR)/changes."
+
+linkcheck:
+	$(SPHINXBUILD) -b linkcheck $(ALLSPHINXOPTS) $(BUILDDIR)/linkcheck
+	@echo
+	@echo "Link check complete; look for any errors in the above output " \
+	      "or in $(BUILDDIR)/linkcheck/output.txt."
+
+doctest:
+	$(SPHINXBUILD) -b doctest $(ALLSPHINXOPTS) $(BUILDDIR)/doctest
+	@echo "Testing of doctests in the sources finished, look at the " \
+	      "results in $(BUILDDIR)/doctest/output.txt."

=== added directory 'docs/_build'
=== added directory 'docs/_static'
=== added directory 'docs/_templates'
=== added file 'docs/conf.py'
--- docs/conf.py	1970-01-01 00:00:00 +0000
+++ docs/conf.py	2010-03-25 10:25:13 +0000
@@ -0,0 +1,194 @@
+# -*- coding: utf-8 -*-
+#
+# loggerhead documentation build configuration file, created by
+# sphinx-quickstart on Tue Mar 23 10:49:50 2010.
+#
+# This file is execfile()d with the current directory set to its containing dir.
+#
+# Note that not all possible configuration values are present in this
+# autogenerated file.
+#
+# All configuration values have a default; values that are commented out
+# serve to show the default.
+
+import sys, os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+#sys.path.append(os.path.abspath('.'))
+
+# -- General configuration -----------------------------------------------------
+
+# Add any Sphinx extension module names here, as strings. They can be extensions
+# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
+extensions = []
+
+# Add any paths that contain templates here, relative to this directory.
+templates_path = ['_templates']
+
+# The suffix of source filenames.
+source_suffix = '.rst'
+
+# The encoding of source files.
+#source_encoding = 'utf-8'
+
+# The master toctree document.
+master_doc = 'index'
+
+# General information about the project.
+project = u'Loggerhead'
+copyright = u'2010, Loggerhead team (https://launchpad.net/~loggerhead-team)'
+
+# The version info for the project you're documenting, acts as replacement for
+# |version| and |release|, also used in various other places throughout the
+# built documents.
+#
+# The short X.Y version.
+version = '1.17'
+# The full version, including alpha/beta/rc tags.
+release = '1.17'
+
+# The language for content autogenerated by Sphinx. Refer to documentation
+# for a list of supported languages.
+#language = None
+
+# There are two options for replacing |today|: either, you set today to some
+# non-false value, then it is used:
+#today = ''
+# Else, today_fmt is used as the format for a strftime call.
+#today_fmt = '%B %d, %Y'
+
+# List of documents that shouldn't be included in the build.
+#unused_docs = []
+
+# List of directories, relative to source directory, that shouldn't be searched
+# for source files.
+exclude_trees = ['_build']
+
+# The reST default role (used for this markup: `text`) to use for all documents.
+#default_role = None
+
+# If true, '()' will be appended to :func: etc. cross-reference text.
+#add_function_parentheses = True
+
+# If true, the current module name will be prepended to all description
+# unit titles (such as .. function::).
+#add_module_names = True
+
+# If true, sectionauthor and moduleauthor directives will be shown in the
+# output. They are ignored by default.
+#show_authors = False
+
+# The name of the Pygments (syntax highlighting) style to use.
+pygments_style = 'sphinx'
+
+# A list of ignored prefixes for module index sorting.
+#modindex_common_prefix = []
+
+
+# -- Options for HTML output ---------------------------------------------------
+
+# The theme to use for HTML and HTML Help pages.  Major themes that come with
+# Sphinx are currently 'default' and 'sphinxdoc'.
+html_theme = 'default'
+
+# Theme options are theme-specific and customize the look and feel of a theme
+# further.  For a list of options available for each theme, see the
+# documentation.
+#html_theme_options = {}
+
+# Add any paths that contain custom themes here, relative to this directory.
+#html_theme_path = []
+
+# The name for this set of Sphinx documents.  If None, it defaults to
+# "<project> v<release> documentation".
+#html_title = None
+
+# A shorter title for the navigation bar.  Default is the same as html_title.
+#html_short_title = None
+
+# The name of an image file (relative to this directory) to place at the top
+# of the sidebar.
+#html_logo = None
+
+# The name of an image file (within the static path) to use as favicon of the
+# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
+# pixels large.
+#html_favicon = None
+
+# Add any paths that contain custom static files (such as style sheets) here,
+# relative to this directory. They are copied after the builtin static files,
+# so a file named "default.css" will overwrite the builtin "default.css".
+html_static_path = ['_static']
+
+# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
+# using the given strftime format.
+#html_last_updated_fmt = '%b %d, %Y'
+
+# If true, SmartyPants will be used to convert quotes and dashes to
+# typographically correct entities.
+#html_use_smartypants = True
+
+# Custom sidebar templates, maps document names to template names.
+#html_sidebars = {}
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+#html_additional_pages = {}
+
+# If false, no module index is generated.
+#html_use_modindex = True
+
+# If false, no index is generated.
+#html_use_index = True
+
+# If true, the index is split into individual pages for each letter.
+#html_split_index = False
+
+# If true, links to the reST sources are added to the pages.
+#html_show_sourcelink = True
+
+# If true, an OpenSearch description file will be output, and all pages will
+# contain a <link> tag referring to it.  The value of this option must be the
+# base URL from which the finished HTML is served.
+#html_use_opensearch = ''
+
+# If nonempty, this is the file name suffix for HTML files (e.g. ".xhtml").
+#html_file_suffix = ''
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'loggerheaddoc'
+
+
+# -- Options for LaTeX output --------------------------------------------------
+
+# The paper size ('letter' or 'a4').
+#latex_paper_size = 'letter'
+
+# The font size ('10pt', '11pt' or '12pt').
+#latex_font_size = '10pt'
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass [howto/manual]).
+latex_documents = [
+  ('index', 'loggerhead.tex', u'Loggerhead Documentation',
+   u'Loggerhead team (https://launchpad.net/\\textasciitilde{}loggerhead-team)', 'manual'),
+]
+
+# The name of an image file (relative to this directory) to place at the top of
+# the title page.
+#latex_logo = None
+
+# For "manual" documents, if this is true, then toplevel headings are parts,
+# not chapters.
+#latex_use_parts = False
+
+# Additional stuff for the LaTeX preamble.
+#latex_preamble = ''
+
+# Documents to append as an appendix to all manuals.
+#latex_appendices = []
+
+# If false, no module index is generated.
+#latex_use_modindex = True

=== added file 'docs/index.rst'
--- docs/index.rst	1970-01-01 00:00:00 +0000
+++ docs/index.rst	2012-02-02 04:58:46 +0000
@@ -0,0 +1,264 @@
+Loggerhead:  A web viewer for ``bzr`` branches
+==============================================
+
+Loggerhead is a web viewer for projects in Bazaar. It can be used to navigate 
+a branch history, annotate files, view patches, perform searches, etc.
+Loggerhead is heavily based on `bazaar-webserve
+<https://launchpad.net/bzr-webserve>`_, which was, in turn, loosely
+based on `hgweb <http://mercurial.selenic.com/wiki/HgWebDirStepByStep>`_.
+
+
+Getting Started
+---------------
+
+Loggerhead depends on the following Python libraries.:
+
+- SimpleTAL for templating.
+
+- simplejson for producing JSON data.
+
+- Paste for the server. (You need version 1.2 or newer of Paste).
+
+- Paste Deploy  (optional, needed when proxying through Apache).
+
+- flup (optional, needed to use FastCGI, SCGI or AJP).
+
+
+Installing Dependencies Using Ubuntu Packages
+#############################################
+
+.. code-block:: sh
+
+   $ sudo apt-get install python-simpletal
+   $ sudo apt-get install python-simplejson
+   $ sudo apt-get install python-paste
+   $ sudo apt-get install python-pastedeploy
+   $ sudo apt-get install python-flup
+
+Installing Dependencies Using :command:`easy_install`
+#####################################################
+
+.. code-block:: sh
+
+   $ easy_install \
+     -f http://www.owlfish.com/software/simpleTAL/py2compatible/download.html \
+     SimpleTAL
+   $ easy_install simplejson
+   $ easy_install Paste
+   $ easy_install PasteDeploy
+   $ easy_install flup
+
+
+Running the Standalone Loggerhead Server
+----------------------------------------
+
+After installing all the dependencies, you should be able to run
+:command:`serve-branches` with the branch you want to serve on the
+command line:
+
+.. code-block:: sh
+
+    ./serve-branches ~/path/to/branch
+
+By default, the script listens on port 8080, so head to
+http://localhost:8080/ in your browser to see the branch.
+
+You can also pass a directory that contains branches to the script,
+and it will serve a very simple directory listing at other pages.
+
+You may update the Bazaar branches being viewed at any time.
+Loggerhead will notice and refresh, and Bazaar uses its own branch
+locking to prevent corruption.
+
+See :doc:`serve-branches` for all command line options.
+
+Running Loggerhead as a Daemon
+------------------------------
+
+To run Loggerhead as a linux daemon:
+
+1) Copy the ``loggerheadd`` scipt to ``/etc/init.d``
+
+.. code-block:: sh
+
+   $ sudo cp ./loggerheadd /etc/init.d
+
+2) Edit the file to configure where your Loggerhead is installed, and which
+   serve-branches options you would like.
+
+.. code-block:: sh
+
+   $ sudo vim /etc/init.d/loggerheadd
+
+3) Register the service
+
+.. code-block:: sh
+
+   # on upstart based systems like Ubuntu run: 
+   $ sudo update-rc.d loggerheadd defaults
+
+   # on Sysvinit based systems like Centos or SuSE run:
+   $ sudo chkconfig --add loggerheadd
+
+
+Using Loggerhead as a Bazaar Plugin
+------------------------------------
+
+This branch contains experimental support for using Loggerhead as a Bazaar
+plugin.  To use it, place the top-level Loggerhead directory (the one
+containing COPYING.txt) at ``~/.bazaar/plugins/loggerhead``.  E.g.:
+
+.. code-block:: sh
+
+   $ bzr branch lp:loggerhead ~/.bazaar/plugins/loggerhead
+   $ cd ~/myproject
+   $ bzr serve --http
+
+
+Using a Config File
+-------------------
+
+To hide branches from being displayed, add to ``~/.bazaar/locations.conf``,
+under the branch's section:
+
+.. code-block:: ini
+
+    [/path/to/branch]
+    http_serve = False
+
+More configuration options to come soon.
+
+
+Serving Loggerhead behind Apache
+--------------------------------
+
+If you want to view Bazaar branches from your existing Apache
+installation, you'll need to configure Apache to proxy certain
+requests to Loggerhead.  Adding lines like this to your Apache
+configuration is one way to do this:
+
+.. code-block:: apache
+
+    <Location "/branches/">
+        ProxyPass http://127.0.0.1:8080/branches/
+        ProxyPassReverse http://127.0.0.1:8080/branches/
+    </Location>
+
+If Paste Deploy is installed, the :command:`serve-branches` script can be
+run behind a proxy at the root of a site, but if you're running it at
+some path into the site, you'll need to specify it using
+``--prefix=/some_path``.
+
+Serving Loggerhead with mod_wsgi
+--------------------------------
+
+A second method for using Loggerhead with apache is to have apache itself
+execute Loggerhead via mod_wsgi.  You need to add configuration for apache and
+for bazaar to make this work.  Example config files are in the Loggerhead doc
+directory as apache-loggerhead.conf and bazaar.conf.  You can copy them into
+place and use them as a starting point following these directions:
+
+1) Install mod_wsgi.  On Ubuntu and other Debian derived distros::
+
+    sudo apt-get install libapache2-mod-wsgi
+
+   On Fedora-derived distros::
+
+    su -c yum install mod_wsgi
+
+2) Copy the bazaar.conf file where apache will find it (May be done for you if
+   you installed Loggerhead from a distribution package)::
+
+    # install -d -o apache -g apache -m 0755 /etc/loggerhead
+    # cp -p /usr/share/doc/loggerhead*/bazaar.conf /etc/loggerhead/
+    # ln -s /etc/loggerhead /var/www/.bazaar
+
+3) Create the cache directory (May be done for you if you installed Loggerhead
+   from a distribution package)::
+
+    # install -d -o apache -g apache -m 0700 /var/cache/loggerhead/
+
+4) Edit /etc/loggerhead/bazaar.conf.  You need to set http_root_dir to the filesystem
+   path that you will find your bzr branches under.  Note that normal
+   directories under that path will also be visible in Loggerhead.
+
+5) Install the apache conf file::
+
+     # cp -p /usr/share/doc/loggerhead*/apache-loggerhead.conf /etc/httpd/conf.d/loggerhead.conf
+
+6) Edit /etc/httpd/conf.d/loggerhead.conf to point to the url you desire to
+   serve Loggerhead on.  This should match with the setting for
+   http_user_prefix in bazaar.conf
+
+7) Restart apache and you should be able to start browsing
+
+.. note:: If you have SELinux enabled on your system you may need to allow
+   apache to execute files in temporary directories.  You will get a
+   MemoryError traceback from python if this is the case.  This is because of
+   the way that python ctypes interacts with libffi.  To rectify this, you may
+   have to do several things, such as mounting tmpdirs so programs can be
+   executed on them and setting this SELinux boolean::
+
+       setsebool httpd_tmp_exec on
+
+   This bug has information about how python and/or Linux distros might solve
+   this issue permanently and links to bugs which diagnose the root cause.
+   https://bugzilla.redhat.com/show_bug.cgi?id=582009
+
+Search
+------
+
+Search is currently supported by using the bzr-search plugin (available
+at: https://launchpad.net/bzr-search ).
+
+You need to have the plugin installed and each branch indexed to allow
+searching on branches.
+
+Command-Line Reference
+----------------------
+
+.. toctree::
+   :maxdepth: 2
+
+   serve-branches
+
+
+Support
+-------
+
+Discussion should take place on the bazaar-dev mailing list at
+mailto:bazaar@lists.canonical.com.  You can join the list at
+<https://lists.ubuntu.com/mailman/listinfo/bazaar>.  You don't need to
+subscribe to post, but your first post will be held briefly for manual
+moderation.
+
+Bugs, support questions and merge proposals are tracked on Launchpad, e.g:
+
+    https://bugs.launchpad.net/loggerhead
+
+
+Hacking
+-------
+
+To run Loggerhead tests, you will need to install the package ``python-nose``,
+and run its :command:`nosetests` script in the Loggerhead directory:
+
+.. code-block:: sh
+
+    nosetests
+
+
+License
+-------
+
+GNU GPLv2 or later.
+
+See Also
+--------
+
+https://launchpad.net/loggerhead
+
+Index
+=====
+
+- :ref:`genindex`

=== added file 'docs/make.bat'
--- docs/make.bat	1970-01-01 00:00:00 +0000
+++ docs/make.bat	2010-03-23 15:44:51 +0000
@@ -0,0 +1,113 @@
+@ECHO OFF
+
+REM Command file for Sphinx documentation
+
+set SPHINXBUILD=sphinx-build
+set BUILDDIR=_build
+set ALLSPHINXOPTS=-d %BUILDDIR%/doctrees %SPHINXOPTS% .
+if NOT "%PAPER%" == "" (
+	set ALLSPHINXOPTS=-D latex_paper_size=%PAPER% %ALLSPHINXOPTS%
+)
+
+if "%1" == "" goto help
+
+if "%1" == "help" (
+	:help
+	echo.Please use `make ^<target^>` where ^<target^> is one of
+	echo.  html      to make standalone HTML files
+	echo.  dirhtml   to make HTML files named index.html in directories
+	echo.  pickle    to make pickle files
+	echo.  json      to make JSON files
+	echo.  htmlhelp  to make HTML files and a HTML help project
+	echo.  qthelp    to make HTML files and a qthelp project
+	echo.  latex     to make LaTeX files, you can set PAPER=a4 or PAPER=letter
+	echo.  changes   to make an overview over all changed/added/deprecated items
+	echo.  linkcheck to check all external links for integrity
+	echo.  doctest   to run all doctests embedded in the documentation if enabled
+	goto end
+)
+
+if "%1" == "clean" (
+	for /d %%i in (%BUILDDIR%\*) do rmdir /q /s %%i
+	del /q /s %BUILDDIR%\*
+	goto end
+)
+
+if "%1" == "html" (
+	%SPHINXBUILD% -b html %ALLSPHINXOPTS% %BUILDDIR%/html
+	echo.
+	echo.Build finished. The HTML pages are in %BUILDDIR%/html.
+	goto end
+)
+
+if "%1" == "dirhtml" (
+	%SPHINXBUILD% -b dirhtml %ALLSPHINXOPTS% %BUILDDIR%/dirhtml
+	echo.
+	echo.Build finished. The HTML pages are in %BUILDDIR%/dirhtml.
+	goto end
+)
+
+if "%1" == "pickle" (
+	%SPHINXBUILD% -b pickle %ALLSPHINXOPTS% %BUILDDIR%/pickle
+	echo.
+	echo.Build finished; now you can process the pickle files.
+	goto end
+)
+
+if "%1" == "json" (
+	%SPHINXBUILD% -b json %ALLSPHINXOPTS% %BUILDDIR%/json
+	echo.
+	echo.Build finished; now you can process the JSON files.
+	goto end
+)
+
+if "%1" == "htmlhelp" (
+	%SPHINXBUILD% -b htmlhelp %ALLSPHINXOPTS% %BUILDDIR%/htmlhelp
+	echo.
+	echo.Build finished; now you can run HTML Help Workshop with the ^
+.hhp project file in %BUILDDIR%/htmlhelp.
+	goto end
+)
+
+if "%1" == "qthelp" (
+	%SPHINXBUILD% -b qthelp %ALLSPHINXOPTS% %BUILDDIR%/qthelp
+	echo.
+	echo.Build finished; now you can run "qcollectiongenerator" with the ^
+.qhcp project file in %BUILDDIR%/qthelp, like this:
+	echo.^> qcollectiongenerator %BUILDDIR%\qthelp\loggerhead.qhcp
+	echo.To view the help file:
+	echo.^> assistant -collectionFile %BUILDDIR%\qthelp\loggerhead.ghc
+	goto end
+)
+
+if "%1" == "latex" (
+	%SPHINXBUILD% -b latex %ALLSPHINXOPTS% %BUILDDIR%/latex
+	echo.
+	echo.Build finished; the LaTeX files are in %BUILDDIR%/latex.
+	goto end
+)
+
+if "%1" == "changes" (
+	%SPHINXBUILD% -b changes %ALLSPHINXOPTS% %BUILDDIR%/changes
+	echo.
+	echo.The overview file is in %BUILDDIR%/changes.
+	goto end
+)
+
+if "%1" == "linkcheck" (
+	%SPHINXBUILD% -b linkcheck %ALLSPHINXOPTS% %BUILDDIR%/linkcheck
+	echo.
+	echo.Link check complete; look for any errors in the above output ^
+or in %BUILDDIR%/linkcheck/output.txt.
+	goto end
+)
+
+if "%1" == "doctest" (
+	%SPHINXBUILD% -b doctest %ALLSPHINXOPTS% %BUILDDIR%/doctest
+	echo.
+	echo.Testing of doctests in the sources finished, look at the ^
+results in %BUILDDIR%/doctest/output.txt.
+	goto end
+)
+
+:end

=== added file 'docs/serve-branches.rst'
--- docs/serve-branches.rst	1970-01-01 00:00:00 +0000
+++ docs/serve-branches.rst	2010-03-25 10:32:47 +0000
@@ -0,0 +1,116 @@
+:command:`serve-branches`
+=========================
+
+The :command:`serve-branches` script runs a standalone Loggerhead server in
+the foreground.
+
+.. program:: serve-branches
+
+Usage
+-----
+
+.. code-block:: sh
+
+   serve-branches [OPTIONS] <target directory>
+
+Options
+-------
+
+.. cmdoption:: --user-dirs
+
+    Serve user directories as ``~user`` (requires ``--trunk-dir``).
+
+    If both options are set, then for requests where the CGI ``PATH_INFO``
+    starts with "/~<name>", serve branches under the <name> directory.
+
+.. cmdoption:: --trunk-dir=DIR
+
+    The directory that contains the trunk branches (requires ``--user-dirs``).
+
+    If both options are set, then for requests where the CGI ``PATH_INFO``
+    does not start with "/~<name>", serve branches under DIR.
+
+.. cmdoption:: --port
+
+    Listen on the given port.
+    
+    Defaults to 8080.
+
+.. cmdoption:: --host
+
+    Listen on the interface corresponding to the given IP. 
+    
+    Defaults to listening on all interfaces, i.e., "0.0.0.0".
+
+.. cmdoption:: --protocol
+
+    Serve the application using the specified protocol.
+    
+    Can be one of: "http", "scgi", "fcgi", "ajp" (defaults to "http").
+
+.. cmdoption:: --prefix
+
+    Set the supplied value as the CGI ``SCRIPT_NAME`` for the application.
+
+    This option is intended for use when serving Loggerhead behind a
+    reverse proxy, with Loggerhead being "mounted" at a directory below
+    the root.  E.g., if the reverse proxy translates requests for
+    ``http://example.com/loggerhead`` onto the standalone Loggerhead process,
+    that process should be run with ``--prefix=/loggerhead``.
+
+.. cmdoption:: --log-folder=LOG_FOLDER
+
+    The directory in which to place Loggerhead's log files.
+    
+    Defaults to the current directory.
+
+.. cmdoption:: --cache-dir=SQL_CACHE_DIR
+
+    The directory in which to place the SQL cache.
+
+    Defaults to the current directory.
+
+.. cmdoption:: --use-cdn
+   
+    Serve YUI javascript libraries from Yahoo!'s CDN.
+
+.. cmdoption:: --allow-writes
+   
+    Allow writing to the Bazaar server.
+    
+    Setting this option keeps Loggerhead from adding a 'readonly+' prefix
+    to the base URL of the branch.  The only effect of suppressing this prefix
+    is to make visible the display of instructions for checking out the
+    'public_branch' URL for the branch being browsed.
+
+.. cmdoption:: -h, --help
+
+    Print the help message and exit
+
+.. cmdoption:: --version
+
+    Print the software version and exit.
+
+Debugging Options
+-----------------
+
+The following options are only useful when developing / debugging Loggerhead
+itself.
+
+.. cmdoption:: --profile
+   
+    Generate per-request callgrind profile data.
+    
+    Data for each request is written to a file ``%d-stats.callgrind``,
+    where ``%d`` is replaced by the sequence number of the request.
+
+.. cmdoption:: --memory-profile
+
+    Profile the memory usage using the `Dozer
+    <http://pypi.python.org/pypi/Dozer>`_ middleware.
+
+.. cmdoption:: --reload
+
+    Restart the application when any of its python file change.
+    
+    This option should only used for development purposes.

=== added file 'info.py'
--- info.py	1970-01-01 00:00:00 +0000
+++ info.py	2011-11-23 08:33:12 +0000
@@ -0,0 +1,15 @@
+#!/usr/bin/env python
+# API Info for loggerhead
+
+bzr_plugin_name = "loggerhead"
+
+bzr_plugin_version = (1, 18, 1)  # Keep in sync with loggerhead/__init__.py
+
+bzr_compatible_versions = [
+    (1, 17, 0), (1, 18, 0), (2, 0, 0), (2, 1, 0), (2, 2, 0), (2, 3, 0),
+    (2, 4, 0), (2, 5, 0),
+    ]
+
+bzr_minimum_version = bzr_compatible_versions[0]
+
+bzr_maximum_version = bzr_compatible_versions[-1]

=== added directory 'load_test_scripts'
=== added file 'load_test_scripts/multiple_instances.script'
--- load_test_scripts/multiple_instances.script	1970-01-01 00:00:00 +0000
+++ load_test_scripts/multiple_instances.script	2011-02-10 01:00:32 +0000
@@ -0,0 +1,19 @@
+{
+    "comment": "Connect to multiple loggerhead instances and make requests on each. One should be on :8080, one should be on :8081. Multiple threads will place requests on each.",
+    "parameters": {"base_url": "http://localhost"},
+    "requests": [
+        {"thread": "1", "relpath": ":8080/changes"},
+        {"thread": "2", "relpath": ":8080/files"},
+        {"thread": "3", "relpath": ":8081/files"},
+        {"thread": "4", "relpath": ":8081/changes"},
+        {"thread": "1", "relpath": ":8080/changes"},
+        {"thread": "2", "relpath": ":8080/files"},
+        {"thread": "3", "relpath": ":8081/files"},
+        {"thread": "4", "relpath": ":8081/changes"},
+        {"thread": "1", "relpath": ":8080/changes"},
+        {"thread": "2", "relpath": ":8080/files"},
+        {"thread": "3", "relpath": ":8081/files"},
+        {"thread": "4", "relpath": ":8081/changes"}
+    ]
+}
+

=== added file 'load_test_scripts/simple.script'
--- load_test_scripts/simple.script	1970-01-01 00:00:00 +0000
+++ load_test_scripts/simple.script	2011-02-10 01:00:32 +0000
@@ -0,0 +1,9 @@
+{
+    "comment": "A fairly trivial load test script. It just loads the main two pages from a loggerhead install running directly on a branch.",
+    "parameters": {"base_url": "http://localhost:8080"},
+    "requests": [
+        {"relpath": "/changes"},
+        {"relpath": "/files"}
+    ]
+}
+

=== removed file 'loggerhead.conf.example'
--- loggerhead.conf.example	2008-07-22 00:40:03 +0000
+++ loggerhead.conf.example	1970-01-01 00:00:00 +0000
@@ -1,76 +0,0 @@
-
-# use this to change the server's port
-#server.socket_port = 8080
-
-# use this if you're mapping loggerhead within apache via proxy
-#server.webpath = 'http://example.com/branches'
-
-# use this if you want loggerhead to listen to another interface than 127.0.0.1
-# server.socket_host = 'your_hostname_or_ip'
-
-# where's bzrlib?
-# (you only need this if you don't install bzr.)
-#bzrpath = '/Users/robey/code/bzr/bzr'
-
-# if you want a special title on the front page, set it here:
-title = 'branches in loggerhead'
-
-# the access and debug logs can be set up to roll 'daily', 'weekly', or 'never':
-log.roll = 'weekly'
-
-# group branches by project:
-[bazaar]
-
-    # name of this project
-    name = 'bazaar'
-    
-    # for the top browsing page, you can include a description, in raw HTML.
-    #description = 'Bazaar is a <i>revision control system</i>.'
-
-    # should we cache files changed? (recommended for large trees)
-    # this will be a folder containing one file.  if the folder doesn't
-    # exist, it'll be created.
-    #
-    # all branches in this project will share the same cache, which is usually
-    # what you want if they share a repository.  if not, you can also specify
-    # this per-branch.
-    cachepath = '/Users/robey/code/bzr/.bzr/loggerhead-files'
-
-    # each branch is in a sub-folder of the website, and the config
-    # key describes that folder name:
-    [[bzr.dev]]
-
-        # where is the bazaar branch located?
-        folder = '/Users/robey/code/bzr/bzr.dev'
-
-        # (optional) is there a friendier name for the branch that i should
-        # use on the web pages?
-        # you can also define this using the branch's nickname.
-        #branch_name = 'bazaar-dev'
-
-        # (optional) short description for the top-level page
-        # you can also define this using the "description" config key in the
-        # branch's 'branch.conf'.
-        description = "bazaar vcs development branch"
-
-        # (optional) public branch url for the top-level page
-        # you can also define this using the "public_url" config key in the
-        # branch's 'branch.conf'.
-        url = 'http://bazaar-ng.org/bzr/bzr.dev'
-
-
-# here's an example of an auto-published folder:
-[paramiko]
-    name = 'paramiko'
-    cachepath = '/Users/robey/code/paramiko/.bzr/loggerhead-files'
-    
-    # if an auto_publish_folder is given, any bazaar branches discovered in
-    # that folder will be published.  using each branch's 'branch.conf' to
-    # provide optional descriptions and public urls is a nice way to avoid
-    # having to do much configuration here.
-    auto_publish_folder = '/Users/robey/code/paramiko'
-    
-    # if all of the branches under an auto_publish_folder are exported to
-    # the same (base) public url, you can specify that url prefix here, and
-    # each discovered branch's public url will be generated.
-    url_prefix = 'http://www.example.com/code/paramiko'

=== added file 'loggerhead.wsgi'
--- loggerhead.wsgi	1970-01-01 00:00:00 +0000
+++ loggerhead.wsgi	2010-04-18 17:58:04 +0000
@@ -0,0 +1,50 @@
+#!/usr/bin/python -tt
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+import sys
+import os
+import pwd
+sys.path.insert(0, os.path.dirname(__file__))
+
+from paste.httpexceptions import HTTPExceptionHandler
+from loggerhead.apps.transport import BranchesFromTransportRoot
+from loggerhead.apps.error import ErrorHandlerApp
+from loggerhead.config import LoggerheadConfig
+from bzrlib import config as bzrconfig
+from paste.deploy.config import PrefixMiddleware
+from bzrlib.plugin import load_plugins
+
+class NotConfiguredError(Exception):
+    pass
+
+
+load_plugins()
+config = LoggerheadConfig()
+prefix = config.get_option('user_prefix') or ''
+# Note we could use LoggerheadConfig here if it didn't fail when a
+# config option is not also a commandline option
+root_dir = bzrconfig.GlobalConfig().get_user_option('http_root_dir')
+if not root_dir:
+    raise NotConfiguredError('You must have a ~/.bazaar/bazaar.conf file for'
+            ' %(user)s with http_root_dir set to the base directory you want'
+            ' to serve bazaar repositories from' %
+            {'user': pwd.getpwuid(os.geteuid()).pw_name})
+prefix = prefix.encode('utf-8', 'ignore')
+root_dir = root_dir.encode('utf-8', 'ignore')
+app = BranchesFromTransportRoot(root_dir, config)
+app = PrefixMiddleware(app, prefix=prefix)
+app = HTTPExceptionHandler(app)
+application = ErrorHandlerApp(app)

=== removed file 'loggerhead/TODO'
--- loggerhead/TODO	2007-05-21 06:19:31 +0000
+++ loggerhead/TODO	1970-01-01 00:00:00 +0000
@@ -1,20 +0,0 @@
-
-* problem: given a folder, find all revisions where items inside that
-  folder have changed.
-    -- stumper.  maybe ask on bazaar-dev ML?
-    -- aaron bentley says this is a general problem.
-
-* potentially do a 'bzr pull' on a branch on an interval timer
-
-* browse view: sort by name, last change?
-
-* something is leaking on www.lag.net/branches
-
-* download tar archive of revision?
-
-* nicholas allen suggested the ability to change the # of context lines
-  in diffs (probably something inside bzrlib) and also the ability to see
-  an entire file in diff format
-
-* setup.py install doesn't work
-

=== modified file 'loggerhead/__init__.py'
--- loggerhead/__init__.py	2008-07-29 22:00:33 +0000
+++ loggerhead/__init__.py	2011-11-23 08:33:12 +0000
@@ -1,3 +1,6 @@
+#
+# Copyright (C) 2008, 2009 Canonical Ltd.
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -12,6 +15,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-"""Just a simple container to turn this into a python package."""
-__version__ = '1.6'
-required_bzrlib = (1, 6)
+"""A simple container to turn this into a python package.
+
+We also check the versions of some dependencies.
+"""
+
+import pkg_resources
+
+__version__ = '1.18.1'  # Keep in sync with ../info.py.
+required_bzrlib = (1, 17)
+
+pkg_resources.get_distribution('Paste>=1.6')
+try:
+    pkg_resources.get_distribution('PasteDeploy>=1.3')
+except pkg_resources.DistributionNotFound:
+    # No paste.deploy is OK, but an old paste.deploy is bad.
+    pass

=== modified file 'loggerhead/apps/__init__.py'
--- loggerhead/apps/__init__.py	2008-07-01 04:01:31 +0000
+++ loggerhead/apps/__init__.py	2010-04-30 21:30:18 +0000
@@ -4,9 +4,17 @@
 
 from paste import urlparser, fileapp
 
+from loggerhead.util import convert_file_errors
+
 static = os.path.join(
     os.path.dirname(os.path.dirname(__file__)), 'static')
 
-static_app = urlparser.make_static(None, static)
-
-favicon_app = fileapp.FileApp(os.path.join(static, 'images', 'favicon.ico'))
+# Static things can be cached for half a day, we could probably make this
+# longer, except for just before rollout times.
+static_app = urlparser.make_static(None, static, cache_max_age=12*60*60)
+
+favicon_app = convert_file_errors(fileapp.FileApp(
+    os.path.join(static, 'images', 'favicon.ico')))
+
+robots_app = convert_file_errors(fileapp.FileApp(
+    os.path.join(static, 'robots.txt')))

=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2008-08-05 05:17:47 +0000
+++ loggerhead/apps/branch.py	2011-11-23 08:18:35 +0000
@@ -1,54 +1,98 @@
+# Copyright (C) 2008-2011 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 """The WSGI application for serving a Bazaar branch."""
 
 import logging
 import urllib
+import sys
 
 import bzrlib.branch
+import bzrlib.errors
+from bzrlib.hooks import Hooks
 import bzrlib.lru_cache
 
 from paste import request
 from paste import httpexceptions
 
 from loggerhead.apps import static_app
+from loggerhead.controllers.annotate_ui import AnnotateUI
+from loggerhead.controllers.view_ui import ViewUI
+from loggerhead.controllers.atom_ui import AtomUI
 from loggerhead.controllers.changelog_ui import ChangeLogUI
+from loggerhead.controllers.diff_ui import DiffUI
+from loggerhead.controllers.download_ui import DownloadUI, DownloadTarballUI
+from loggerhead.controllers.filediff_ui import FileDiffUI
 from loggerhead.controllers.inventory_ui import InventoryUI
-from loggerhead.controllers.annotate_ui import AnnotateUI
 from loggerhead.controllers.revision_ui import RevisionUI
-from loggerhead.controllers.atom_ui import AtomUI
-from loggerhead.controllers.download_ui import DownloadUI
+from loggerhead.controllers.revlog_ui import RevLogUI
 from loggerhead.controllers.search_ui import SearchUI
 from loggerhead.history import History
 from loggerhead import util
 
 
+_DEFAULT = object()
+
 class BranchWSGIApp(object):
 
     def __init__(self, branch, friendly_name=None, config={},
-                 graph_cache=None, branch_link=None):
+                 graph_cache=None, branch_link=None, is_root=False,
+                 served_url=_DEFAULT, use_cdn=False, private=False,
+                 export_tarballs=True):
+        """Create branch-publishing WSGI app.
+
+        :param export_tarballs: If true, allow downloading snapshots of revisions
+            as tarballs.
+        """
         self.branch = branch
         self._config = config
         self.friendly_name = friendly_name
         self.branch_link = branch_link  # Currently only used in Launchpad
         self.log = logging.getLogger('loggerhead.%s' % (friendly_name,))
         if graph_cache is None:
-            graph_cache = bzrlib.lru_cache.LRUCache()
+            graph_cache = bzrlib.lru_cache.LRUCache(10)
         self.graph_cache = graph_cache
+        self.is_root = is_root
+        self.served_url = served_url
+        self.use_cdn = use_cdn
+        self.private = private
+        self.export_tarballs = export_tarballs
+
+    def public_private_css(self):
+        if self.private:
+            return "private"
+        else:
+            return "public"
 
     def get_history(self):
-        _history = History(self.branch, self.graph_cache)
+        revinfo_disk_cache = None
         cache_path = self._config.get('cachepath', None)
         if cache_path is not None:
             # Only import the cache if we're going to use it.
             # This makes sqlite optional
             try:
-                from loggerhead.changecache import FileChangeCache
+                from loggerhead.changecache import RevInfoDiskCache
             except ImportError:
                 self.log.debug("Couldn't load python-sqlite,"
                                " continuing without using a cache")
             else:
-                _history.use_file_cache(
-                    FileChangeCache(_history, cache_path))
-        return _history
+                revinfo_disk_cache = RevInfoDiskCache(cache_path)
+        return History(
+            self.branch, self.graph_cache,
+            revinfo_disk_cache=revinfo_disk_cache, cache_key=self.friendly_name)
 
     def url(self, *args, **kw):
         if isinstance(args[0], list):
@@ -56,12 +100,17 @@
         qs = []
         for k, v in kw.iteritems():
             if v is not None:
-                qs.append('%s=%s'%(k, urllib.quote(v)))
+                qs.append('%s=%s' % (k, urllib.quote(v)))
         qs = '&'.join(qs)
-        return request.construct_url(
-            self._environ, script_name=self._url_base,
-            path_info='/'.join(args),
-            querystring=qs)
+        path_info = urllib.quote(
+            unicode('/'.join(args)).encode('utf-8'), safe='/~:')
+        if qs:
+            path_info += '?' + qs
+        return self._url_base + path_info
+
+    def absolute_url(self, *args, **kw):
+        rel_url = self.url(*args, **kw)
+        return request.resolve_relative_url(rel_url, self._environ)
 
     def context_url(self, *args, **kw):
         kw = util.get_context(**kw)
@@ -70,42 +119,105 @@
     def static_url(self, path):
         return self._static_url_base + path
 
+    def yui_url(self, path):
+        if self.use_cdn:
+            base = 'http://yui.yahooapis.com/3.0.0pr2/build/'
+        else:
+            base = self.static_url('/static/javascript/yui/build/')
+        return base + path
+
     controllers_dict = {
+        '+filediff': FileDiffUI,
+        '+revlog': RevLogUI,
         'annotate': AnnotateUI,
+        'atom': AtomUI,
         'changes': ChangeLogUI,
+        'diff': DiffUI,
+        'download': DownloadUI,
         'files': InventoryUI,
         'revision': RevisionUI,
-        'download': DownloadUI,
-        'atom': AtomUI,
         'search': SearchUI,
+        'view': ViewUI,
+        'tarball': DownloadTarballUI,
         }
 
     def last_updated(self):
         h = self.get_history()
-        change = h.get_changes([ h.last_revid ])[0]
+        change = h.get_changes([h.last_revid])[0]
         return change.date
 
-    def branch_url(self):
+    def public_branch_url(self):
         return self.branch.get_config().get_user_option('public_branch')
 
-    def app(self, environ, start_response):
+    def lookup_app(self, environ):
+        # Check again if the branch is blocked from being served, this is
+        # mostly for tests. It's already checked in apps/transport.py
+        if self.branch.get_config().get_user_option('http_serve') == 'False':
+            raise httpexceptions.HTTPNotFound()
         self._url_base = environ['SCRIPT_NAME']
         self._static_url_base = environ.get('loggerhead.static.url')
         if self._static_url_base is None:
             self._static_url_base = self._url_base
         self._environ = environ
+        if self.served_url is _DEFAULT:
+            public_branch = self.public_branch_url()
+            if public_branch is not None:
+                self.served_url = public_branch
+            else:
+                # Loggerhead only supports serving .bzr/ on local branches, so
+                # we shouldn't suggest something that won't work.
+                try:
+                    util.local_path_from_url(self.branch.base)
+                    self.served_url = self.url([])
+                except bzrlib.errors.InvalidURL:
+                    self.served_url = None
+        for hook in self.hooks['controller']:
+            controller = hook(self, environ)
+            if controller is not None:
+                return controller
         path = request.path_info_pop(environ)
         if not path:
             raise httpexceptions.HTTPMovedPermanently(
-                self._url_base + '/changes')
+                self.absolute_url('/changes'))
         if path == 'static':
-            return static_app(environ, start_response)
+            return static_app
+        elif path == '+json':
+            environ['loggerhead.as_json'] = True
+            path = request.path_info_pop(environ)
         cls = self.controllers_dict.get(path)
-        if cls is None:
-            raise httpexceptions.HTTPNotFound()
+        if cls is not None:
+            return cls(self, self.get_history)
+        raise httpexceptions.HTTPNotFound()
+
+    def app(self, environ, start_response):
         self.branch.lock_read()
         try:
-            c = cls(self, self.get_history())
-            return c(environ, start_response)
+            try:
+                c = self.lookup_app(environ)
+                return c(environ, start_response)
+            except:
+                environ['exc_info'] = sys.exc_info()
+                environ['branch'] = self
+                raise
         finally:
             self.branch.unlock()
+
+
+class BranchWSGIAppHooks(Hooks):
+    """A dictionary mapping hook name to a list of callables for WSGI app branch hooks.
+    """
+
+    def __init__(self):
+        """Create the default hooks.
+        """
+        Hooks.__init__(self, "bzrlib.plugins.loggerhead.apps.branch",
+            "BranchWSGIApp.hooks")
+        self.add_hook('controller',
+            "Invoked when looking for the controller to use for a "
+            "branch subpage. The api signature is (branch_app, environ)."
+            "If a hook can provide a controller, it should return one, "
+            "as a standard WSGI app. If it can't provide a controller, "
+            "it should return None", (1, 19))
+
+
+BranchWSGIApp.hooks = BranchWSGIAppHooks()

=== removed file 'loggerhead/apps/config.py'
--- loggerhead/apps/config.py	2008-07-01 04:01:31 +0000
+++ loggerhead/apps/config.py	1970-01-01 00:00:00 +0000
@@ -1,219 +0,0 @@
-"""A server that uses a loggerhead.conf file.
-
-We recreate the branch discovery and url scheme of the old branchview
-code.  It's all a bit horrible really.
-"""
-
-import logging
-import os
-import posixpath
-
-import bzrlib.lru_cache
-
-from configobj import ConfigObj
-
-from paste.request import path_info_pop
-from paste import httpexceptions
-from paste.wsgiwrappers import WSGIResponse
-
-from loggerhead.apps.branch import BranchWSGIApp
-from loggerhead.apps import favicon_app, static_app
-from loggerhead.templatefunctions import templatefunctions
-from loggerhead.zptsupport import load_template
-from loggerhead import util
-
-log = logging.getLogger("loggerhead.controllers")
-
-from loggerhead.history import is_branch
-
-class Project(object):
-    """A project contains the branches.
-
-    There is some complication because we don't want to hold on to the
-    branches when they are not being browsed."""
-
-    def __init__(self, name, config, root_config, graph_cache):
-        self.name = name
-        self.friendly_name = config.get('name', name)
-        self.description = config.get('description', '')
-        self.long_description = config.get('long_description', '')
-        self._config = config
-        self._root_config = root_config
-        self.graph_cache = graph_cache
-
-        self.view_names = []
-        self.view_data_by_name = {}
-        for view_name in config.sections:
-            log.debug('Configuring (project %s) branch %s...', name, view_name)
-            self._add_view(
-                view_name, config[view_name], config[view_name].get('folder'))
-
-        self._auto_folder = config.get('auto_publish_folder', None)
-        self._auto_list = []
-        if self._auto_folder is not None:
-            self._recheck_auto_folders()
-
-    def _recheck_auto_folders(self):
-        if self._auto_folder is None:
-            return
-        auto_list = []
-        # scan a folder for bazaar branches, and add them automatically
-        for path, folders, filenames in os.walk(self._auto_folder):
-            for folder in folders:
-                folder = os.path.join(path, folder)
-                if is_branch(folder):
-                    auto_list.append(folder)
-        auto_list.sort()
-        if auto_list == self._auto_list:
-            # nothing has changed; do nothing.
-            return
-
-        # rebuild views:
-        self.view_names = []
-        log.debug('Rescanning auto-folder for project %s ...', self.name)
-        for folder in auto_list:
-            view_name = os.path.basename(folder)
-            log.debug('Auto-configuring (project %s) branch %s...', self.name, view_name)
-            self._add_view(view_name, ConfigObj(), folder)
-        self._auto_list = auto_list
-
-    def _get_branch_url(self, view, view_config, folder):
-        url = view_config.get('url', None)
-        if url is not None:
-            return url
-        url = self._config.get('url_prefix', None)
-        if url is not None:
-            return posixpath.join(url, folder) + '/'
-        return None
-
-    def _get_description(self, view, view_config, history):
-        description = view_config.get('description', None)
-        if description is not None:
-            return description
-        description = history._branch.get_config().get_user_option('description')
-        return description
-
-    def _add_view(self, view_name, view_config, folder):
-        b = bzrlib.branch.Branch.open(folder)
-        view = BranchWSGIApp(b, view_name, view_config, self.graph_cache)
-        b.lock_read()
-        try:
-            history = view.get_history()
-            friendly_name = view_config.get('branch_name', None)
-            if friendly_name is None:
-                friendly_name = history.get_config().get_nickname()
-                if friendly_name is None:
-                    friendly_name = view_name
-            self.view_data_by_name[view_name] = {
-                'branch_path': folder,
-                'args': (view_name, view_config, self.graph_cache),
-                'description': self._get_description(view, view_config, history),
-                '_src_folder': folder,
-                '_view_config': view_config,
-                'friendly_name': friendly_name,
-                'name': view_name,
-                }
-            branch_url = self._get_branch_url(view, view_config, view_name)
-            if branch_url is not None:
-                self.view_data_by_name[view_name]['branch_url'] = branch_url
-            self.view_names.append(view_name)
-        finally:
-            b.unlock()
-
-    def view_named(self, name):
-        view_data = self.view_data_by_name.get(name)
-        if view_data is None:
-            return None
-        view_data = view_data.copy()
-        branch_path = view_data.pop('branch_path')
-        args = view_data.pop('args')
-        b = bzrlib.branch.Branch.open(branch_path)
-        b.lock_read()
-        view = BranchWSGIApp(b, *args)
-        for k in view_data:
-            setattr(view, k, view_data[k])
-        return view
-
-    def call(self, environ, start_response):
-        segment = path_info_pop(environ)
-        if not segment:
-            raise httpexceptions.HTTPNotFound()
-        else:
-            view = self.view_named(segment)
-            if view is None:
-                raise httpexceptions.HTTPNotFound()
-            try:
-                return view.app(environ, start_response)
-            finally:
-                view.branch.unlock()
-
-
-class Root(object):
-    """The root of the server -- renders as the browse view,
-    dispatches to Project above for each 'project'."""
-
-    def __init__(self, config):
-        self.projects = []
-        self.config = config
-        self.projects_by_name = {}
-        graph_cache = bzrlib.lru_cache.LRUCache()
-        for project_name in self.config.sections:
-            project = Project(
-                project_name, self.config[project_name], self.config, graph_cache)
-            self.projects.append(project)
-            self.projects_by_name[project_name] = project
-
-    def browse(self, response):
-        # This is insanely complicated because we want to open and
-        # lock all the branches, render the view and then unlock the
-        # branches again.
-        for p in self.projects:
-            p._recheck_auto_folders()
-        class branch(object):
-            @staticmethod
-            def static_url(path):
-                return self._static_url_base + path
-        views_by_project = {}
-        all_views = []
-        try:
-            for p in self.projects:
-                views_by_project[p] = []
-                for vn in p.view_names:
-                    v = p.view_named(vn)
-                    all_views.append(v)
-                    views_by_project[p].append(v)
-            vals = {
-                'projects': self.projects,
-                'util': util,
-                'title': self.config.get('title', None),
-                'branch': branch,
-                'views_by_project': views_by_project,
-            }
-            vals.update(templatefunctions)
-            response.headers['Content-Type'] = 'text/html'
-            template = load_template('loggerhead.templates.browse')
-            template.expand_into(response, **vals)
-        finally:
-            for v in all_views:
-                v.branch.unlock()
-
-    def __call__(self, environ, start_response):
-        self._static_url_base = environ['loggerhead.static.url'] = \
-                                environ['SCRIPT_NAME']
-        segment = path_info_pop(environ)
-        if segment is None:
-            raise httpexceptions.HTTPMovedPermanently(
-                environ['SCRIPT_NAME'] + '/')
-        elif segment == '':
-            response = WSGIResponse()
-            self.browse(response)
-            return response(environ, start_response)
-        elif segment == 'static':
-            return static_app(environ, start_response)
-        elif segment == 'favicon.ico':
-            return favicon_app(environ, start_response)
-        else:
-            project = self.projects_by_name.get(segment)
-            if project is None:
-                raise httpexceptions.HTTPNotFound()
-            return project.call(environ, start_response)

=== added file 'loggerhead/apps/error.py'
--- loggerhead/apps/error.py	1970-01-01 00:00:00 +0000
+++ loggerhead/apps/error.py	2009-10-17 08:47:38 +0000
@@ -0,0 +1,58 @@
+# Copyright (C) 2008  Guillermo Gonzalez <guillo.gonzo@gmail.com>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+from loggerhead.controllers.error_ui import ErrorUI
+
+
+class ErrorHandlerApp(object):
+    """Class for WSGI error logging middleware."""
+
+    msg = " %s.%s: %s \n"
+
+    def __init__(self, application, **kwargs):
+        self.application = application
+
+    def __call__(self, environ, start_response):
+        try:
+            return self.application(environ, start_response)
+        except:
+            # test if exc_info has been set, in the case that
+            # the error is caused before BranchWSGGIApp middleware
+            if 'exc_info' in environ.keys() and 'branch' in environ.keys():
+                # Log and/or report any application errors
+                return self.handle_error(environ, start_response)
+            else:
+                # simply propagate the error, this is logged
+                # by paste.httpexceptions.TransLogger middleware
+                raise
+
+    def handle_error(self, environ, start_response):
+        """Exception hanlder."""
+        self.log_error(environ)
+        return errapp(environ, start_response)
+
+    def log_error(self, environ):
+        exc_type, exc_object, exc_tb = environ['exc_info']
+        logger = environ['branch'].log
+        logger.exception(self.msg, exc_type.__module__,
+                              exc_type.__name__, exc_object)
+
+
+def errapp(environ, start_response):
+    """Default (and trivial) error handling WSGI application."""
+    c = ErrorUI(environ['branch'], environ['exc_info'])
+    return c(environ, start_response)

=== added file 'loggerhead/apps/http_head.py'
--- loggerhead/apps/http_head.py	1970-01-01 00:00:00 +0000
+++ loggerhead/apps/http_head.py	2011-02-10 02:33:15 +0000
@@ -0,0 +1,62 @@
+# Copyright (C) 2011 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+"""WSGI apps tend to return body content as part of a HEAD request.
+
+We should definitely not do that.
+"""
+
+class HeadMiddleware(object):
+    """When we get a HEAD request, we should not return body content.
+
+    WSGI defaults to just generating everything, and not paying attention to
+    whether it is a GET or a HEAD request. It does that because of potential
+    issues getting the Headers correct.
+
+    This middleware works by just omitting the body if the request method is
+    HEAD.
+    """
+
+    def __init__(self, app):
+        self._wrapped_app = app
+        self._real_environ = None
+        self._real_start_response = None
+        self._real_writer = None
+
+    def noop_write(self, chunk):
+        """We intentionally ignore all body content that is returned."""
+        pass
+
+    def start_response(self, status, response_headers, exc_info=None):
+        if exc_info is None:
+            self._real_writer = self._real_start_response(status,
+                response_headers)
+        else:
+            self._real_writer = self._real_start_response(status,
+                response_headers, exc_info)
+        return self.noop_write
+
+    def __call__(self, environ, start_response):
+        self._real_environ = environ
+        self._real_start_response = start_response
+        if environ.get('REQUEST_METHOD', 'GET') == 'HEAD':
+            result = self._wrapped_app(environ, self.start_response)
+            for chunk in result:
+                pass
+        else:
+            result = self._wrapped_app(environ, start_response)
+            for chunk in result:
+                yield chunk

=== renamed file 'loggerhead/apps/filesystem.py' => 'loggerhead/apps/transport.py'
--- loggerhead/apps/filesystem.py	2008-08-05 05:11:33 +0000
+++ loggerhead/apps/transport.py	2011-03-16 14:43:36 +0000
@@ -1,108 +1,199 @@
-"""Serve branches at urls that mimic the file system layout."""
-
-import os
-import tempfile
-
-from bzrlib import branch, errors, lru_cache
+# Copyright (C) 2008-2011 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+"""Serve branches at urls that mimic a transport's file system layout."""
+
+import threading
+
+from bzrlib import branch, errors, lru_cache, urlutils
+from bzrlib.config import LocationConfig
+from bzrlib.smart import request
+from bzrlib.transport import get_transport
+from bzrlib.transport.http import wsgi
 
 from paste.request import path_info_pop
 from paste import httpexceptions
+from paste import urlparser
 
+from loggerhead import util
 from loggerhead.apps.branch import BranchWSGIApp
-from loggerhead.apps import favicon_app, static_app
+from loggerhead.apps import favicon_app, robots_app, static_app
 from loggerhead.controllers.directory_ui import DirectoryUI
 
-sql_dir = tempfile.mkdtemp(prefix='loggerhead-cache-')
-
-
-class BranchesFromFileSystemServer(object):
-    def __init__(self, path, root, name=None):
-        self.path = path
+# TODO: Use bzrlib.ui.bool_from_string(), added in bzr 1.18
+_bools = {
+    'yes': True, 'no': False,
+    'on': True, 'off': False,
+    '1': True, '0': False,
+    'true': True, 'false': False,
+    }
+
+class BranchesFromTransportServer(object):
+
+    def __init__(self, transport, root, name=None):
+        self.transport = transport
         self.root = root
         self.name = name
+        self._config = root._config
 
     def app_for_branch(self, branch):
         if not self.name:
-            name = branch.nick
+            name = branch._get_nick(local=True)
+            is_root = True
         else:
             name = self.name
+            is_root = False
         branch_app = BranchWSGIApp(
-            branch, name, {'cachepath': sql_dir}, self.root.graph_cache)
+            branch,
+            name,
+            {'cachepath': self._config.SQL_DIR},
+            self.root.graph_cache,
+            is_root=is_root,
+            use_cdn=self._config.get_option('use_cdn'),
+            )
         return branch_app.app
 
     def app_for_non_branch(self, environ):
         segment = path_info_pop(environ)
         if segment is None:
-            raise httpexceptions.HTTPMovedPermanently(
-                environ['SCRIPT_NAME'] + '/')
+            raise httpexceptions.HTTPMovedPermanently.relative_redirect(
+                environ['SCRIPT_NAME'] + '/', environ)
         elif segment == '':
             if self.name:
                 name = self.name
             else:
                 name = '/'
-            return DirectoryUI(environ['loggerhead.static.url'], self.path, name)
+            return DirectoryUI(
+                environ['loggerhead.static.url'], self.transport, name)
         else:
-            new_path = os.path.join(self.path, segment)
+            new_transport = self.transport.clone(segment)
             if self.name:
-                new_name = os.path.join(self.name, segment)
+                new_name = urlutils.join(self.name, segment)
             else:
                 new_name = '/' + segment
-            return BranchesFromFileSystemServer(new_path, self.root, new_name)
-
-    def __call__(self, environ, start_response):
-        if not os.path.isdir(self.path):
+            return BranchesFromTransportServer(new_transport, self.root, new_name)
+
+    def app_for_bazaar_data(self, relpath):
+        if relpath == '/.bzr/smart':
+            root_transport = get_transport_for_thread(self.root.base)
+            wsgi_app = wsgi.SmartWSGIApp(root_transport)
+            return wsgi.RelpathSetter(wsgi_app, '', 'loggerhead.path_info')
+        else:
+            # TODO: Use something here that uses the transport API
+            # rather than relying on the local filesystem API.
+            base = self.transport.base
+            try:
+                path = util.local_path_from_url(base)
+            except errors.InvalidURL:
+                raise httpexceptions.HTTPNotFound()
+            else:
+                return urlparser.make_static(None, path)
+
+    def check_serveable(self, config):
+        value = config.get_user_option('http_serve')
+        if value is None:
+            return
+        elif not _bools.get(value.lower(), True):
             raise httpexceptions.HTTPNotFound()
+
+    def __call__(self, environ, start_response):
+        path = environ['PATH_INFO']
         try:
-            b = branch.Branch.open(self.path)
+            b = branch.Branch.open_from_transport(self.transport)
         except errors.NotBranchError:
+            if path.startswith('/.bzr'):
+                self.check_serveable(LocationConfig(self.transport.base))
+                return self.app_for_bazaar_data(path)(environ, start_response)
+            if not self.transport.listable() or not self.transport.has('.'):
+                raise httpexceptions.HTTPNotFound()
             return self.app_for_non_branch(environ)(environ, start_response)
         else:
-            return self.app_for_branch(b)(environ, start_response)
-
-
-class BranchesFromFileSystemRoot(object):
-
-    def __init__(self, folder):
-        self.graph_cache = lru_cache.LRUCache()
-        self.folder = folder
+            self.check_serveable(b.get_config())
+            if path.startswith('/.bzr'):
+                return self.app_for_bazaar_data(path)(environ, start_response)
+            else:
+                return self.app_for_branch(b)(environ, start_response)
+
+
+_transport_store = threading.local()
+
+def get_transport_for_thread(base):
+    thread_transports = getattr(_transport_store, 'transports', None)
+    if thread_transports is None:
+        thread_transports = _transport_store.transports = {}
+    if base in thread_transports:
+        return thread_transports[base]
+    transport = get_transport(base)
+    thread_transports[base] = transport
+    return transport
+
+
+class BranchesFromTransportRoot(object):
+
+    def __init__(self, base, config):
+        self.graph_cache = lru_cache.LRUCache(10)
+        self.base = base
+        self._config = config
 
     def __call__(self, environ, start_response):
         environ['loggerhead.static.url'] = environ['SCRIPT_NAME']
+        environ['loggerhead.path_info'] = environ['PATH_INFO']
         if environ['PATH_INFO'].startswith('/static/'):
             segment = path_info_pop(environ)
             assert segment == 'static'
             return static_app(environ, start_response)
         elif environ['PATH_INFO'] == '/favicon.ico':
             return favicon_app(environ, start_response)
+        elif environ['PATH_INFO'] == '/robots.txt':
+            return robots_app(environ, start_response)
         else:
-            return BranchesFromFileSystemServer(
-                self.folder, self)(environ, start_response)
-
-
-class UserBranchesFromFileSystemRoot(object):
-
-    def __init__(self, folder, trunk_dir):
-        self.graph_cache = lru_cache.LRUCache()
-        self.folder = folder
-        self.trunk_dir = trunk_dir
+            transport = get_transport_for_thread(self.base)
+            return BranchesFromTransportServer(
+                transport, self)(environ, start_response)
+
+
+class UserBranchesFromTransportRoot(object):
+
+    def __init__(self, base, config):
+        self.graph_cache = lru_cache.LRUCache(10)
+        self.base = base
+        self._config = config
+        self.trunk_dir = config.get_option('trunk_dir')
 
     def __call__(self, environ, start_response):
         environ['loggerhead.static.url'] = environ['SCRIPT_NAME']
-        path_info= environ['PATH_INFO']
+        environ['loggerhead.path_info'] = environ['PATH_INFO']
+        path_info = environ['PATH_INFO']
         if path_info.startswith('/static/'):
             segment = path_info_pop(environ)
             assert segment == 'static'
             return static_app(environ, start_response)
         elif path_info == '/favicon.ico':
             return favicon_app(environ, start_response)
+        elif environ['PATH_INFO'] == '/robots.txt':
+            return robots_app(environ, start_response)
         else:
+            transport = get_transport_for_thread(self.base)
             # segments starting with ~ are user branches
             if path_info.startswith('/~'):
                 segment = path_info_pop(environ)
-                new_path = os.path.join(self.folder, segment[1:])
-                return BranchesFromFileSystemServer(
-                    new_path, self, segment)(environ, start_response)
+                return BranchesFromTransportServer(
+                    transport.clone(segment[1:]), self, segment)(
+                    environ, start_response)
             else:
-                new_path = os.path.join(self.folder, self.trunk_dir)
-                return BranchesFromFileSystemServer(
-                    new_path, self)(environ, start_response)
+                return BranchesFromTransportServer(
+                    transport.clone(self.trunk_dir), self)(
+                    environ, start_response)

=== modified file 'loggerhead/changecache.py'
--- loggerhead/changecache.py	2008-07-31 05:41:42 +0000
+++ loggerhead/changecache.py	2011-08-17 11:04:00 +0000
@@ -17,99 +17,124 @@
 #
 
 """
-a cache for chewed-up "change" data structures, which are basically just a
-different way of storing a revision.  the cache improves lookup times 10x
-over bazaar's xml revision structure, though, so currently still worth doing.
+a cache for chewed-up 'file change' data structures, which are basically just
+a different way of storing a revision delta.  the cache improves lookup times
+10x over bazaar's xml revision structure, though, so currently still worth
+doing.
 
 once a revision is committed in bazaar, it never changes, so once we have
 cached a change, it's good forever.
 """
 
 import cPickle
+import marshal
 import os
-
-from loggerhead import util
-from loggerhead.lockfile import LockFile
-
-with_lock = util.with_lock('_lock', 'ChangeCache')
-
-SQLITE_INTERFACE = os.environ.get('SQLITE_INTERFACE', 'sqlite3')
-
-if SQLITE_INTERFACE == 'sqlite3':
+import tempfile
+import zlib
+
+try:
     from sqlite3 import dbapi2
-    _param_marker = '?'
-
-_select_stmt = ("select data from revisiondata where revid = ?"
-                ).replace('?', _param_marker)
-_insert_stmt = ("insert into revisiondata (revid, data) "
-                "values (?, ?)").replace('?', _param_marker)
-
-
-
+except ImportError:
+    from pysqlite2 import dbapi2
+
+# We take an optimistic approach to concurrency here: we might do work twice
+# in the case of races, but not crash or corrupt data.
+
+def safe_init_db(filename, init_sql):
+    # To avoid races around creating the database, we create the db in
+    # a temporary file and rename it into the ultimate location.
+    fd, temp_path = tempfile.mkstemp(dir=os.path.dirname(filename))
+    os.close(fd)
+    con = dbapi2.connect(temp_path)
+    cur = con.cursor()
+    cur.execute(init_sql)
+    con.commit()
+    con.close()
+    os.rename(temp_path, filename)
 
 class FakeShelf(object):
+
     def __init__(self, filename):
         create_table = not os.path.exists(filename)
+        if create_table:
+            safe_init_db(
+                filename, "create table RevisionData "
+                "(revid binary primary key, data binary)")
         self.connection = dbapi2.connect(filename)
         self.cursor = self.connection.cursor()
-        if create_table:
-            self._create_table()
-    def _create_table(self):
-        self.cursor.execute(
+
+    def _create_table(self, filename):
+        con = dbapi2.connect(filename)
+        cur = con.cursor()
+        cur.execute(
             "create table RevisionData "
             "(revid binary primary key, data binary)")
-        self.connection.commit()
+        con.commit()
+        con.close()
+
     def _serialize(self, obj):
-        r = dbapi2.Binary(cPickle.dumps(obj, protocol=2))
-        return r
+        return dbapi2.Binary(cPickle.dumps(obj, protocol=2))
+
     def _unserialize(self, data):
         return cPickle.loads(str(data))
+
     def get(self, revid):
-        self.cursor.execute(_select_stmt, (revid,))
+        self.cursor.execute(
+            "select data from revisiondata where revid = ?", (revid, ))
         filechange = self.cursor.fetchone()
         if filechange is None:
             return None
         else:
             return self._unserialize(filechange[0])
-    def add(self, revid_obj_pairs):
-        for  (r, d) in revid_obj_pairs:
-            self.cursor.execute(_insert_stmt, (r, self._serialize(d)))
-        self.connection.commit()
-
-
-class FileChangeCache(object):
-    def __init__(self, history, cache_path):
-        self.history = history
-
+
+    def add(self, revid, object):
+        try:
+            self.cursor.execute(
+                "insert into revisiondata (revid, data) values (?, ?)",
+                (revid, self._serialize(object)))
+            self.connection.commit()
+        except dbapi2.IntegrityError:
+            # If another thread or process attempted to set the same key, we
+            # assume it set it to the same value and carry on with our day.
+            pass
+
+
+class RevInfoDiskCache(object):
+    """Like `RevInfoMemoryCache` but backed in a sqlite DB."""
+
+    def __init__(self, cache_path):
         if not os.path.exists(cache_path):
             os.mkdir(cache_path)
-
-        self._changes_filename = os.path.join(cache_path, 'filechanges.sql')
-
-        # use a lockfile since the cache folder could be shared across
-        # different processes.
-        self._lock = LockFile(os.path.join(cache_path, 'filechange-lock'))
-
-    @with_lock
-    def get_file_changes(self, entries):
-        out = []
-        missing_entries = []
-        missing_entry_indices = []
-        cache = FakeShelf(self._changes_filename)
-        for entry in entries:
-            changes = cache.get(entry.revid)
-            if changes is not None:
-                out.append(changes)
-            else:
-                missing_entries.append(entry)
-                missing_entry_indices.append(len(out))
-                out.append(None)
-        if missing_entries:
-            missing_changes = self.history.get_file_changes_uncached(missing_entries)
-            revid_changes_pairs = []
-            for i, entry, changes in zip(
-                missing_entry_indices, missing_entries, missing_changes):
-                revid_changes_pairs.append((entry.revid, changes))
-                out[i] = changes
-            cache.add(revid_changes_pairs)
-        return out
+        filename = os.path.join(cache_path, 'revinfo.sql')
+        create_table = not os.path.exists(filename)
+        if create_table:
+            safe_init_db(
+                filename, "create table Data "
+                "(key binary primary key, revid binary, data binary)")
+        self.connection = dbapi2.connect(filename)
+        self.cursor = self.connection.cursor()
+
+    def get(self, key, revid):
+        self.cursor.execute(
+            "select revid, data from data where key = ?", (dbapi2.Binary(key),))
+        row = self.cursor.fetchone()
+        if row is None:
+            return None
+        elif str(row[0]) != revid:
+            return None
+        else:
+            return marshal.loads(zlib.decompress(row[1]))
+
+    def set(self, key, revid, data):
+        try:
+            self.cursor.execute(
+                'delete from data where key = ?', (dbapi2.Binary(key), ))
+            blob = zlib.compress(marshal.dumps(data))
+            self.cursor.execute(
+                "insert into data (key, revid, data) values (?, ?, ?)",
+                map(dbapi2.Binary, [key, revid, blob]))
+            self.connection.commit()
+        except dbapi2.IntegrityError:
+            # If another thread or process attempted to set the same key, we
+            # don't care too much -- it's only a cache after all!
+            pass

=== added file 'loggerhead/config.py'
--- loggerhead/config.py	1970-01-01 00:00:00 +0000
+++ loggerhead/config.py	2011-07-07 19:09:11 +0000
@@ -0,0 +1,149 @@
+#
+# Copyright (C) 2008, 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+"""Configuration tools for Loggerhead."""
+
+from optparse import OptionParser
+import sys
+import tempfile
+
+from bzrlib import config
+
+_temporary_sql_dir = None
+
+def _get_temporary_sql_dir():
+    global _temporary_sql_dir
+    if _temporary_sql_dir is None:
+        _temporary_sql_dir = tempfile.mkdtemp(prefix='loggerhead-cache-')
+    return _temporary_sql_dir
+
+def command_line_parser():
+    parser = OptionParser("%prog [options] <path>")
+    parser.set_defaults(
+        user_dirs=False,
+        show_version=False,
+        log_folder=None,
+        use_cdn=False,
+        sql_dir=None,
+        allow_writes=False,
+        export_tarballs=True,
+        )
+    parser.add_option("--user-dirs", action="store_true",
+                      help="Serve user directories as ~user.")
+    parser.add_option("--trunk-dir", metavar="DIR",
+                      help="The directory that contains the trunk branches.")
+    parser.add_option("--port", dest="user_port",
+                      help=("Port Loggerhead should listen on "
+                            "(defaults to 8080)."))
+    parser.add_option("--host", dest="user_host",
+                      help="Host Loggerhead should listen on.")
+    parser.add_option("--protocol", dest="protocol",
+                      help=("Protocol to use: http, scgi, fcgi, ajp"
+                           "(defaults to http)."))
+    parser.add_option("--log-level", default=None, action='callback',
+                      callback=_optparse_level_to_int_level,
+                      type="string",
+                      help="Set the verbosity of logging. Can either"
+                           " be set to a numeric or string"
+                           " (eg, 10=debug, 30=warning)")
+    parser.add_option("--memory-profile", action="store_true",
+                      help="Profile the memory usage using Dozer.")
+    parser.add_option("--prefix", dest="user_prefix",
+                      help="Specify host prefix.")
+    parser.add_option("--profile", action="store_true",
+                      help="Generate callgrind profile data to "
+                        "%d-stats.callgrind on each request.")
+    parser.add_option("--reload", action="store_true",
+                      help="Restarts the application when changing python"
+                           " files. Only used for development purposes.")
+    parser.add_option("--log-folder",
+                      help="The directory to place log files in.")
+    parser.add_option("--version", action="store_true", dest="show_version",
+                      help="Print the software version and exit")
+    parser.add_option("--use-cdn", action="store_true", dest="use_cdn",
+                      help="Serve YUI from Yahoo!'s CDN")
+    parser.add_option("--cache-dir", dest="sql_dir",
+                      help="The directory to place the SQL cache in")
+    parser.add_option("--allow-writes", action="store_true",
+                      help="Allow writing to the Bazaar server.")
+    parser.add_option("--export-tarballs", action="store_true",
+                      help="Allow exporting revisions to tarballs.")
+    return parser
+
+
+_log_levels = {
+    'debug': 10,
+    'info': 20,
+    'warning': 30,
+    'error': 40,
+    'critical': 50,
+}
+
+def _optparse_level_to_int_level(option, opt_str, value, parser):
+    parser.values.log_level = _level_to_int_level(value)
+
+
+def _level_to_int_level(value):
+    """Convert a string level to an integer value."""
+    if value is None:
+        return None
+    try:
+        return int(value)
+    except ValueError:
+        pass
+    return _log_levels[value.lower()]
+
+
+class LoggerheadConfig(object):
+    """A configuration object."""
+
+    def __init__(self, argv=None):
+        if argv is None:
+            argv = sys.argv[1:]
+        self._parser = command_line_parser()
+        self._options, self._args = self._parser.parse_args(argv)
+
+        sql_dir = self.get_option('sql_dir')
+        if sql_dir is None:
+            sql_dir = _get_temporary_sql_dir()
+        self.SQL_DIR = sql_dir
+
+    def get_option(self, option):
+        """Get the value for the config option, either
+        from ~/.bazaar/bazaar.conf or from the command line.
+        All loggerhead-specific settings start with 'http_'
+        """
+        global_config = config.GlobalConfig().get_user_option('http_'+option)
+        cmd_config = getattr(self._options, option)
+        if global_config is not None and (
+            cmd_config is None or cmd_config is False):
+            return global_config
+        else:
+            return cmd_config
+
+    def get_log_level(self):
+        opt = self.get_option('log_level')
+        return _level_to_int_level(opt)
+
+    def get_arg(self, index):
+        """Get an arg from the arg list."""
+        return self._args[index]
+
+    def print_help(self):
+        """Wrapper around OptionParser.print_help."""
+        return self._parser.print_help()
+
+    @property
+    def arg_count(self):
+        """Return the number of args from the option parser."""
+        return len(self._args)

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2008-07-22 00:40:03 +0000
+++ loggerhead/controllers/__init__.py	2011-07-07 19:09:11 +0000
@@ -1,4 +1,5 @@
 #
+# Copyright (C) 2008  Canonical Ltd.
 # Copyright (C) 2006  Robey Pointer <robey@lag.net>
 # Copyright (C) 2006  Goffredo Baroncelli <kreijack@inwind.it>
 #
@@ -16,15 +17,18 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import re
+import bzrlib.errors
+import simplejson
 import time
 
+from paste.httpexceptions import HTTPNotFound, HTTPSeeOther
 from paste.request import path_info_pop, parse_querystring
 
 from loggerhead import util
 from loggerhead.templatefunctions import templatefunctions
 from loggerhead.zptsupport import load_template
 
+
 class BufferingWriter(object):
 
     def __init__(self, writefunc, buf_limit):
@@ -32,15 +36,10 @@
         self.buf = []
         self.buflen = 0
         self.writefunc = writefunc
-        self.bytes_saved = 0
         self.buf_limit = buf_limit
 
     def flush(self):
-        chunk = ''.join(self.buf)
-        chunk = re.sub(r'\s*\n\s*', '\n', chunk)
-        chunk = re.sub(r'[ \t]+', ' ', chunk)
-        self.bytes_saved += self.buflen - len(chunk)
-        self.writefunc(chunk)
+        self.writefunc(''.join(self.buf))
         self.buf = []
         self.buflen = 0
 
@@ -51,47 +50,93 @@
         if self.buflen > self.buf_limit:
             self.flush()
 
+
 class TemplatedBranchView(object):
 
     template_path = None
+    supports_json = False
 
-    def __init__(self, branch, history):
+    def __init__(self, branch, history_callable):
         self._branch = branch
-        self._history = history
+        self._history_callable = history_callable
+        self.__history = None
         self.log = branch.log
 
-    def __call__(self, environ, start_response):
-        z = time.time()
-        h = self._history
-        kw = dict(parse_querystring(environ))
-        util.set_context(kw)
+    @property
+    def _history(self):
+        if self.__history is not None:
+            return self.__history
+        self.__history = self._history_callable()
+        return self.__history
+
+    def parse_args(self, environ):
+        kwargs = dict(parse_querystring(environ))
+        util.set_context(kwargs)
         args = []
-        while 1:
+        while True:
             arg = path_info_pop(environ)
             if arg is None:
                 break
             args.append(arg)
 
-        vals = {
+        path = None
+        if len(args) > 1:
+            path = unicode('/'.join(args[1:]), 'utf-8')
+        self.args = args
+        self.kwargs = kwargs
+        return path
+
+    def add_template_values(self, values):
+        values.update({
+            'static_url': self._branch.static_url,
             'branch': self._branch,
             'util': util,
-            'history': h,
             'url': self._branch.context_url,
-        }
-        vals.update(templatefunctions)
+        })
+        values.update(templatefunctions)
+
+    def __call__(self, environ, start_response):
+        z = time.time()
+        if environ.get('loggerhead.as_json') and not self.supports_json:
+            raise HTTPNotFound
+        path = self.parse_args(environ)
         headers = {}
-        vals.update(self.get_values(h, args, kw, headers))
+        values = self.get_values(path, self.kwargs, headers)
 
-        self.log.info('Getting information for %s: %r secs' % (
-            self.__class__.__name__, time.time() - z,))
-        if 'Content-Type' not in headers:
+        self.log.info('Getting information for %s: %.3f secs' % (
+            self.__class__.__name__, time.time() - z))
+        if environ.get('loggerhead.as_json'):
+            headers['Content-Type'] = 'application/json'
+        elif 'Content-Type' not in headers:
             headers['Content-Type'] = 'text/html'
         writer = start_response("200 OK", headers.items())
-        template = load_template(self.template_path)
+        if environ.get('REQUEST_METHOD') == 'HEAD':
+            # No content for a HEAD request
+            return []
         z = time.time()
         w = BufferingWriter(writer, 8192)
-        template.expand_into(w, **vals)
+        if environ.get('loggerhead.as_json'):
+            w.write(simplejson.dumps(values,
+                default=util.convert_to_json_ready))
+        else:
+            self.add_template_values(values)
+            template = load_template(self.template_path)
+            template.expand_into(w, **values)
         w.flush()
-        self.log.info('Rendering %s: %r secs, %s bytes, %s (%2.1f%%) bytes saved' % (
-            self.__class__.__name__, time.time() - z, w.bytes, w.bytes_saved, 100.0*w.bytes_saved/w.bytes))
+        self.log.info(
+            'Rendering %s: %.3f secs, %s bytes' % (
+                self.__class__.__name__, time.time() - z, w.bytes))
         return []
+
+    def get_revid(self):
+        h = self._history
+        if h is None:
+            return None
+        if len(self.args) > 0 and self.args != ['']:
+            try:
+                revid = h.fix_revid(self.args[0])
+            except bzrlib.errors.NoSuchRevision:
+                raise HTTPNotFound;
+        else:
+            revid = h.last_revid
+        return revid

=== added file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	1970-01-01 00:00:00 +0000
+++ loggerhead/controllers/annotate_ui.py	2011-08-09 14:06:49 +0000
@@ -0,0 +1,78 @@
+#
+# Copyright (C) 2010 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+import itertools
+
+from loggerhead.controllers.view_ui import ViewUI
+from loggerhead import util
+
+class AnnotateUI(ViewUI):
+
+    def annotate_file(self, info):
+        file_id = info['file_id']
+        revid = info['change'].revid
+        
+        tree = self.tree_for(file_id, revid)
+        
+        change_cache = {}
+        last_line_revid = None
+        last_lineno = None
+        message = ""
+
+        revisions = {}
+
+        lineno = 0
+        for (line_revid, text), lineno in zip(tree.annotate_iter(file_id), itertools.count(1)):
+            if line_revid != last_line_revid:
+                last_line_revid = line_revid
+
+                change = change_cache.get(line_revid, None)
+                if change is None:
+                    change = self._history.get_changes([line_revid])[0]
+                    change_cache[line_revid] = change
+
+                try:
+                    message = change.comment.splitlines()[0]
+                except IndexError:
+                    # Comment not present for this revision
+                    message = ""
+
+                if last_lineno:
+                    # The revspan is of lines between the last revision and this one.
+                    # We set the one for the previous revision when we're creating the current revision.
+                    revisions[last_lineno].revspan = lineno - last_lineno
+
+                revisions[lineno] = util.Container(change=change, message=message)
+
+                last_lineno = lineno
+                last_line_revid = line_revid
+
+        # Zero-size file. Return empty revisions.
+        if last_lineno is None:
+            return revisions
+
+        # We never set a revspan for the last revision during the loop above, so set it here.
+        revisions[last_lineno].revspan = lineno - last_lineno + 1
+
+        return revisions
+            
+    def get_values(self, path, kwargs, headers):
+        values = super(AnnotateUI, self).get_values(path, kwargs, headers)
+        values['annotated'] = self.annotate_file(values)
+        
+        return values

=== modified file 'loggerhead/controllers/atom_ui.py'
--- loggerhead/controllers/atom_ui.py	2008-07-22 00:40:03 +0000
+++ loggerhead/controllers/atom_ui.py	2009-07-07 23:52:24 +0000
@@ -24,14 +24,16 @@
 
     template_path = 'loggerhead.templates.atom'
 
-    def get_values(self, h, args, kw, headers):
+    def get_values(self, path, kwargs, headers):
+        history = self._history
         pagesize = int(20)#self._branch.config.get('pagesize', '20'))
 
-        revid_list = h.get_file_view(h.last_revid, None)
-        entries = list(h.get_changes(list(revid_list)[:pagesize]))
+        revid_list = history.get_file_view(history.last_revid, None)
+        entries = list(history.get_changes(list(revid_list)[:pagesize]))
 
         headers['Content-Type'] = 'application/atom+xml'
         return {
             'changes': entries,
-            'updated': entries[0].date.isoformat() + 'Z',
+            'updated': entries[0].utc_date.isoformat(),
+            'history': self._history,
         }

=== modified file 'loggerhead/controllers/changelog_ui.py'
--- loggerhead/controllers/changelog_ui.py	2008-07-22 00:40:03 +0000
+++ loggerhead/controllers/changelog_ui.py	2011-03-12 13:25:52 +0000
@@ -1,4 +1,5 @@
 #
+# Copyright (C) 2008, 2009 Canonical Ltd.
 # Copyright (C) 2006  Robey Pointer <robey@lag.net>
 # Copyright (C) 2006  Goffredo Baroncelli <kreijack@inwind.it>
 #
@@ -17,6 +18,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
+import urllib
+
+import simplejson
+
 from paste.httpexceptions import HTTPServerError
 
 from loggerhead import util
@@ -27,23 +32,24 @@
 
     template_path = 'loggerhead.templates.changelog'
 
-    def get_values(self, h, args, kw, headers):
-        if args:
-            revid = h.fix_revid(args[0])
-        else:
-            revid = None
-
-        filter_file_id = kw.get('filter_file_id', None)
-        query = kw.get('q', None)
-        start_revid = h.fix_revid(kw.get('start_revid', None))
+    def get_values(self, path, kwargs, headers):
+        history = self._history
+        revid = self.get_revid()
+        filter_file_id = kwargs.get('filter_file_id', None)
+        query = kwargs.get('q', None)
+        start_revid = history.fix_revid(kwargs.get('start_revid', None))
         orig_start_revid = start_revid
         pagesize = 20#int(config.get('pagesize', '20'))
         search_failed = False
 
+        if filter_file_id is None and path is not None:
+            filter_file_id = history.get_file_id(revid, path)
+
         try:
-            revid, start_revid, revid_list = h.get_view(
-                revid, start_revid, filter_file_id, query)
-            util.set_context(kw)
+            revid, start_revid, revid_list = history.get_view(
+                revid, start_revid, filter_file_id, query,
+                extra_rev_count=pagesize+1)
+            util.set_context(kwargs)
 
             if (query is not None) and (len(revid_list) == 0):
                 search_failed = True
@@ -57,8 +63,11 @@
                     i = None
                 scan_list = revid_list[i:]
             change_list = scan_list[:pagesize]
-            changes = list(h.get_changes(change_list))
-            h.add_changes(changes)
+            changes = list(history.get_changes(change_list))
+            data = {}
+            for i, c in enumerate(changes):
+                c.index = i
+                data[str(i)] = urllib.quote(urllib.quote(c.revid, safe=''))
         except:
             self.log.exception('Exception fetching changes')
             raise HTTPServerError('Could not fetch changes')
@@ -66,38 +75,39 @@
         navigation = util.Container(
             pagesize=pagesize, revid=revid, start_revid=start_revid,
             revid_list=revid_list, filter_file_id=filter_file_id,
-            scan_url='/changes', branch=self._branch, feed=True, history=h)
+            scan_url='/changes', branch=self._branch, feed=True, history=history)
         if query is not None:
             navigation.query = query
         util.fill_in_navigation(navigation)
 
-        # add parent & merge-point branch-nick info, in case it's useful
-        h.get_branch_nicks(changes)
-
-        # does every change on this page have the same committer?  if so,
-        # tell the template to show committer info in the "details block"
-        # instead of on each line.
-        all_same_author = True
-
-        if changes:
-            author = changes[0].author
-            for e in changes[1:]:
-                if e.author != author:
-                    all_same_author = False
-                    break
+        # Directory Breadcrumbs
+        directory_breadcrumbs = (
+            util.directory_breadcrumbs(
+                self._branch.friendly_name,
+                self._branch.is_root,
+                'changes'))
+
+        show_tag_col = False
+        for change in changes:
+            if change.tags is not None:
+                show_tag_col = True
+                break
 
         return {
             'branch': self._branch,
             'changes': changes,
+            'show_tag_col': show_tag_col,
+            'data': simplejson.dumps(data),
             'util': util,
-            'history': h,
+            'history': history,
             'revid': revid,
             'navigation': navigation,
             'filter_file_id': filter_file_id,
             'start_revid': start_revid,
-            'viewing_from': (orig_start_revid is not None) and (orig_start_revid != h.last_revid),
+            'viewing_from': (orig_start_revid is not None) and
+                            (orig_start_revid != history.last_revid),
             'query': query,
             'search_failed': search_failed,
-            'all_same_author': all_same_author,
             'url': self._branch.context_url,
+            'directory_breadcrumbs': directory_breadcrumbs,
         }

=== added file 'loggerhead/controllers/diff_ui.py'
--- loggerhead/controllers/diff_ui.py	1970-01-01 00:00:00 +0000
+++ loggerhead/controllers/diff_ui.py	2011-06-28 16:51:55 +0000
@@ -0,0 +1,79 @@
+# Copyright (C) 2008-2011 Canonical Ltd.
+#                     (Authored by Martin Albisetti <argentina@gmail.com>)
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+from cStringIO import StringIO
+import time
+
+from paste.request import path_info_pop
+
+from bzrlib.diff import show_diff_trees
+from bzrlib.revision import NULL_REVISION
+
+from loggerhead.controllers import TemplatedBranchView
+
+
+class DiffUI(TemplatedBranchView):
+    """Class to output a diff for a single file or revisions."""
+
+    def __call__(self, environ, start_response):
+        # /diff/<rev_id>/<rev_id>
+        """Default method called from /diff URL."""
+        z = time.time()
+
+        args = []
+        while True:
+            arg = path_info_pop(environ)
+            if arg is None:
+                break
+            args.append(arg)
+
+        revid_from = args[0]
+        # Convert a revno to a revid if we get a revno
+        revid_from = self._history.fix_revid(revid_from)
+        change = self._history.get_changes([revid_from])[0]
+
+        if len(args) == 2:
+            revid_to = self._history.fix_revid(args[1])
+        elif len(change.parents) == 0:
+            revid_to = NULL_REVISION
+        else:
+            revid_to = change.parents[0].revid
+
+        repo = self._branch.branch.repository
+        revtree1 = repo.revision_tree(revid_to)
+        revtree2 = repo.revision_tree(revid_from)
+
+        diff_content_stream = StringIO()
+        show_diff_trees(revtree1, revtree2, diff_content_stream,
+                        old_label='', new_label='')
+
+        content = diff_content_stream.getvalue()
+
+        self.log.info('/diff %r:%r in %r secs' % (revid_from, revid_to,
+                                                  time.time() - z))
+
+        revno1 = self._history.get_revno(revid_from)
+        revno2 = self._history.get_revno(revid_to)
+        filename = '%s_%s.diff' % (revno1, revno2)
+        headers = [
+            ('Content-Type', 'application/octet-stream'),
+            ('Content-Length', str(len(content))),
+            ('Content-Disposition', 'attachment; filename=%s' % (filename,)),
+            ]
+        start_response('200 OK', headers)
+        return [content]

=== modified file 'loggerhead/controllers/directory_ui.py'
--- loggerhead/controllers/directory_ui.py	2008-08-04 21:22:16 +0000
+++ loggerhead/controllers/directory_ui.py	2009-10-17 06:35:33 +0000
@@ -18,20 +18,29 @@
 
 import datetime
 import logging
-import os
-
-from bzrlib import branch
-
+import stat
+
+from bzrlib import branch, errors
+
+from loggerhead import util
 from loggerhead.controllers import TemplatedBranchView
 
+
 class DirEntry(object):
+
     def __init__(self, dirname, parity, branch):
         self.dirname = dirname
         self.parity = parity
         self.branch = branch
         if branch is not None:
-            self.last_change =  datetime.datetime.fromtimestamp(
-                branch.repository.get_revision(branch.last_revision()).timestamp)
+            # If a branch is empty, bzr raises an exception when trying this
+            try:
+                self.last_change = datetime.datetime.fromtimestamp(
+                    branch.repository.get_revision(
+                        branch.last_revision()).timestamp)
+            except:
+                self.last_change = None
+
 
 class DirectoryUI(TemplatedBranchView):
     """
@@ -39,35 +48,48 @@
 
     template_path = 'loggerhead.templates.directory'
 
-    def __init__(self, static_url_base, path, name):
+    def __init__(self, static_url_base, transport, name):
+
         class _branch(object):
             context_url = 1
+
+            @staticmethod
+            def static_url(path):
+                return self._static_url_base + path
         self._branch = _branch
-        self._history = None
-        self._path = path
+        self._history_callable = lambda: None
         self._name = name
         self._static_url_base = static_url_base
+        self.transport = transport
         self.log = logging.getLogger('')
 
-    def get_values(self, h, args, kwargs, response):
-        listing = [d for d in os.listdir(self._path)
-                   if not d.startswith('.')
-                   and os.path.isdir(os.path.join(self._path, d))]
+    def get_values(self, path, kwargs, response):
+        listing = [d for d in self.transport.list_dir('.')
+                   if not d.startswith('.')]
         listing.sort(key=lambda x: x.lower())
         dirs = []
         parity = 0
-        def static_url(path):
-            return self._static_url_base + path
         for d in listing:
-            p = os.path.join(self._path, d)
             try:
-                b = branch.Branch.open(p)
+                b = branch.Branch.open_from_transport(self.transport.clone(d))
+                if b.get_config().get_user_option('http_serve') == 'False':
+                    continue
             except:
+                try:
+                    if not stat.S_ISDIR(self.transport.stat(d).st_mode):
+                        continue
+                except errors.NoSuchFile:
+                    continue
                 b = None
             dirs.append(DirEntry(d, parity, b))
             parity = 1 - parity
+        # Create breadcrumb trail
+        directory_breadcrumbs = util.directory_breadcrumbs(
+                self._name,
+                False,
+                'directory')
         return {
             'dirs': dirs,
             'name': self._name,
-            'static_url': static_url,
+            'directory_breadcrumbs': directory_breadcrumbs,
             }

=== modified file 'loggerhead/controllers/download_ui.py'
--- loggerhead/controllers/download_ui.py	2008-07-01 02:38:56 +0000
+++ loggerhead/controllers/download_ui.py	2011-11-25 01:41:07 +0000
@@ -19,49 +19,89 @@
 
 import logging
 import mimetypes
-import time
+import os
+import urllib
 
 from paste import httpexceptions
 from paste.request import path_info_pop
 
+from loggerhead.controllers import TemplatedBranchView
+from loggerhead.exporter import export_archive
+
 log = logging.getLogger("loggerhead.controllers")
 
 
-class DownloadUI (object):
-
-    def __init__(self, branch, history):
-        self._branch = branch
-        self._history = history
-        self.log = branch.log
-
-    def __call__(self, environ, start_response):
-        # /download/<rev_id>/<file_id>/[filename]
-        z = time.time()
-
-        h = self._history
-
+class DownloadUI (TemplatedBranchView):
+
+    def encode_filename(self, filename):
+
+        return urllib.quote(filename.encode('utf-8'))
+
+    def get_args(self, environ):
         args = []
-        while 1:
+        while True:
             arg = path_info_pop(environ)
             if arg is None:
                 break
             args.append(arg)
+        return args
 
+    def __call__(self, environ, start_response):
+        # /download/<rev_id>/<file_id>/[filename]
+        h = self._history
+        args = self.get_args(environ)
         if len(args) < 2:
-            raise httpexceptions.HTTPMovedPermanently(self._branch.url('../changes'))
-
+            raise httpexceptions.HTTPMovedPermanently(
+                self._branch.absolute_url('/changes'))
         revid = h.fix_revid(args[0])
         file_id = args[1]
         path, filename, content = h.get_file(file_id, revid)
         mime_type, encoding = mimetypes.guess_type(filename)
         if mime_type is None:
             mime_type = 'application/octet-stream'
-
-        self.log.info('/download %s @ %s (%d bytes)', path, h.get_revno(revid), len(content))
+        self.log.info('/download %s @ %s (%d bytes)',
+                      path,
+                      h.get_revno(revid),
+                      len(content))
+        encoded_filename = self.encode_filename(filename)
         headers = [
             ('Content-Type', mime_type),
-            ('Content-Length', len(content)),
-            ('Content-Disposition', 'attachment; filename=%s'%(filename,)),
+            ('Content-Length', str(len(content))),
+            ('Content-Disposition',
+             "attachment; filename*=utf-8''%s" % (encoded_filename,)),
             ]
         start_response('200 OK', headers)
         return [content]
+
+
+class DownloadTarballUI(DownloadUI):
+
+    def __call__(self, environ, start_response):
+        """Stream a tarball from a bazaar branch."""
+        # Tried to re-use code from downloadui, not very successful
+        if not self._branch.export_tarballs:
+            raise httpexceptions.HTTPForbidden(
+                "Tarball downloads are not allowed")
+        archive_format = "tgz"
+        history = self._history
+        self.args = self.get_args(environ)
+        if len(self.args):
+            revid = history.fix_revid(self.args[0])
+            version_part = '-r' + self.args[0]
+        else:
+            revid = self.get_revid()
+            version_part = ''
+        # XXX: Perhaps some better suggestion based on the URL or path?
+        #
+        # TODO: Perhaps set the tarball suggested mtime to the revision
+        # mtime.
+        root = self._branch.friendly_name or 'branch'
+        encoded_filename = self.encode_filename(
+            root + version_part + '.' + archive_format)
+        headers = [
+            ('Content-Type', 'application/octet-stream'),
+            ('Content-Disposition',
+                "attachment; filename*=utf-8''%s" % (encoded_filename,)),
+            ]
+        start_response('200 OK', headers)
+        return export_archive(history, root, revid, archive_format)

=== added file 'loggerhead/controllers/error_ui.py'
--- loggerhead/controllers/error_ui.py	1970-01-01 00:00:00 +0000
+++ loggerhead/controllers/error_ui.py	2009-10-17 08:47:38 +0000
@@ -0,0 +1,46 @@
+#
+# Copyright (C) 2008  Guillermo Gonzalez <guillo.gonzo@gmail.com>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+from StringIO import StringIO
+import traceback
+
+from loggerhead.controllers import TemplatedBranchView
+from loggerhead import util
+
+
+class ErrorUI(TemplatedBranchView):
+
+    template_path = 'loggerhead.templates.error'
+
+    def __init__(self, branch, exc_info):
+        super(ErrorUI, self).__init__(branch, lambda: None)
+        self.exc_info = exc_info
+
+    def get_values(self, path, kwargs, response):
+        exc_type, exc_object, exc_tb = self.exc_info
+        description = StringIO()
+        traceback.print_exception(exc_type, exc_object, None, file=description)
+        directory_breadcrumbs = util.directory_breadcrumbs(
+            self._branch.friendly_name, self._branch.is_root, 'changes')
+        return {
+            'branch': self._branch,
+            'error_title': ('An unexpected error occurred while'
+                            'processing the request:'),
+            'error_description': description.getvalue(),
+            'directory_breadcrumbs': directory_breadcrumbs,
+        }

=== added file 'loggerhead/controllers/filediff_ui.py'
--- loggerhead/controllers/filediff_ui.py	1970-01-01 00:00:00 +0000
+++ loggerhead/controllers/filediff_ui.py	2011-06-27 15:05:06 +0000
@@ -0,0 +1,92 @@
+from StringIO import StringIO
+import urllib
+
+from bzrlib import diff
+from bzrlib import errors
+from bzrlib import osutils
+
+from loggerhead import util
+from loggerhead.controllers import TemplatedBranchView
+
+def _process_diff(difftext):
+    chunks = []
+    chunk = None
+    for line in difftext.splitlines():
+        if len(line) == 0:
+            continue
+        if line.startswith('+++ ') or line.startswith('--- '):
+            continue
+        if line.startswith('@@ '):
+            # new chunk
+            if chunk is not None:
+                chunks.append(chunk)
+            chunk = util.Container()
+            chunk.diff = []
+            split_lines = line.split(' ')[1:3]
+            lines = [int(x.split(',')[0][1:]) for x in split_lines]
+            old_lineno = lines[0]
+            new_lineno = lines[1]
+        elif line.startswith(' '):
+            chunk.diff.append(util.Container(old_lineno=old_lineno,
+                                             new_lineno=new_lineno,
+                                             type='context',
+                                             line=line[1:]))
+            old_lineno += 1
+            new_lineno += 1
+        elif line.startswith('+'):
+            chunk.diff.append(util.Container(old_lineno=None,
+                                             new_lineno=new_lineno,
+                                             type='insert', line=line[1:]))
+            new_lineno += 1
+        elif line.startswith('-'):
+            chunk.diff.append(util.Container(old_lineno=old_lineno,
+                                             new_lineno=None,
+                                             type='delete', line=line[1:]))
+            old_lineno += 1
+        else:
+            chunk.diff.append(util.Container(old_lineno=None,
+                                             new_lineno=None,
+                                             type='unknown',
+                                             line=repr(line)))
+    if chunk is not None:
+        chunks.append(chunk)
+    return chunks
+
+
+def diff_chunks_for_file(repository, file_id, compare_revid, revid):
+    lines = {}
+    args = []
+    for r in (compare_revid, revid):
+        if r == 'null:':
+            lines[r] = []
+        else:
+            args.append((file_id, r, r))
+    for r, bytes_iter in repository.iter_files_bytes(args):
+        lines[r] = osutils.split_lines(''.join(bytes_iter))
+    buffer = StringIO()
+    try:
+        diff.internal_diff('', lines[compare_revid], '', lines[revid], buffer)
+    except errors.BinaryFile:
+        difftext = ''
+    else:
+        difftext = buffer.getvalue()
+
+    return _process_diff(difftext)
+
+
+class FileDiffUI(TemplatedBranchView):
+
+    template_path = 'loggerhead.templates.filediff'
+    supports_json = True
+
+    def get_values(self, path, kwargs, headers):
+        revid = urllib.unquote(self.args[0])
+        compare_revid = urllib.unquote(self.args[1])
+        file_id = urllib.unquote(self.args[2])
+
+        chunks = diff_chunks_for_file(
+            self._history._branch.repository, file_id, compare_revid, revid)
+
+        return {
+            'chunks': chunks,
+        }

=== modified file 'loggerhead/controllers/inventory_ui.py'
--- loggerhead/controllers/inventory_ui.py	2008-07-23 21:41:49 +0000
+++ loggerhead/controllers/inventory_ui.py	2011-06-27 16:30:57 +0000
@@ -1,4 +1,5 @@
 #
+# Copyright (C) 2008  Canonical Ltd.
 # Copyright (C) 2006  Robey Pointer <robey@lag.net>
 # Copyright (C) 2006  Goffredo Baroncelli <kreijack@inwind.it>
 #
@@ -19,76 +20,173 @@
 
 import logging
 import posixpath
-
-from paste.httpexceptions import HTTPServerError
+import urllib
+
+from paste.httpexceptions import HTTPNotFound, HTTPMovedPermanently
+
+from bzrlib import errors
+from bzrlib.revision import is_null as is_null_rev
 
 from loggerhead import util
 from loggerhead.controllers import TemplatedBranchView
 
 
-log = logging.getLogger("loggerhead.controllers")
 
 def dirname(path):
-    while path.endswith('/'):
-        path = path[:-1]
-    path = posixpath.dirname(path)
+    if path is not None:
+        path = path.rstrip('/')
+        path = urllib.quote(posixpath.dirname(path))
     return path
 
 
 class InventoryUI(TemplatedBranchView):
 
     template_path = 'loggerhead.templates.inventory'
-
-    def get_values(self, h, args, kw, headers):
-        if len(args) > 0:
-            revid = h.fix_revid(args[0])
-        else:
-            revid = h.last_revid
-
+    supports_json = True
+
+    def get_filelist(self, inv, path, sort_type, revno_url):
+        """
+        return the list of all files (and their attributes) within a given
+        path subtree.
+
+        @param inv: The inventory.
+        @param path: The path of a directory within the inventory.
+        @param sort_type: How to sort the results... XXX.
+        """
+        file_id = inv.path2id(path)
+        dir_ie = inv[file_id]
+        file_list = []
+
+        if dir_ie.kind != 'directory':
+            raise HTTPMovedPermanently(self._branch.context_url(['/view', revno_url, path]))
+
+        revid_set = set()
+
+        for filename, entry in dir_ie.children.iteritems():
+            revid_set.add(entry.revision)
+
+        change_dict = {}
+        for change in self._history.get_changes(list(revid_set)):
+            change_dict[change.revid] = change
+
+        for filename, entry in dir_ie.children.iteritems():
+            pathname = filename
+            if entry.kind == 'directory':
+                pathname += '/'
+            if path == '':
+                absolutepath = pathname
+            else:
+                absolutepath = path + '/' + pathname
+            revid = entry.revision
+
+            # TODO: For the JSON rendering, this inlines the "change" aka
+            # revision information attached to each file. Consider either
+            # pulling this out as a separate changes dict, or possibly just
+            # including the revision id and having a separate request to get
+            # back the revision info.
+            file = util.Container(
+                filename=filename, executable=entry.executable,
+                kind=entry.kind, absolutepath=absolutepath,
+                file_id=entry.file_id, size=entry.text_size, revid=revid,
+                change=change_dict[revid])
+            file_list.append(file)
+
+        if sort_type == 'filename':
+            file_list.sort(key=lambda x: x.filename.lower()) # case-insensitive
+        elif sort_type == 'size':
+            file_list.sort(key=lambda x: x.size)
+        elif sort_type == 'date':
+            file_list.sort(key=lambda x: x.change.date)
+
+        # Always sort directories first.
+        file_list.sort(key=lambda x: x.kind != 'directory')
+
+        return file_list
+
+    def get_values(self, path, kwargs, headers):
+        history = self._history
+        branch = history._branch
         try:
-            inv = h.get_inventory(revid)
-        except:
-            self.log.exception('Exception fetching changes')
-            raise HTTPServerError('Could not fetch changes')
-
-        file_id = kw.get('file_id', inv.root.file_id)
-        start_revid = kw.get('start_revid', None)
-        sort_type = kw.get('sort', None)
-
-        # no navbar for revisions
-        navigation = util.Container()
-
-        change = h.get_changes([ revid ])[0]
-        # add parent & merge-point branch-nick info, in case it's useful
-        h.get_branch_nicks([ change ])
-
-        path = inv.id2path(file_id)
-        if not path.startswith('/'):
-            path = '/' + path
-        idpath = inv.get_idpath(file_id)
-        if len(idpath) > 1:
+            revid = self.get_revid()
+            rev_tree = branch.repository.revision_tree(revid)
+        except errors.NoSuchRevision:
+            raise HTTPNotFound()
+
+        file_id = kwargs.get('file_id', None)
+        start_revid = kwargs.get('start_revid', None)
+        sort_type = kwargs.get('sort', 'filename')
+
+        if path is not None:
+            path = path.rstrip('/')
+            file_id = rev_tree.path2id(path)
+            if file_id is None:
+                raise HTTPNotFound()
+        else:
+            if file_id is None:
+                path = ''
+            else:
+                try:
+                    path = rev_tree.id2path(file_id)
+                except errors.NoSuchId:
+                    raise HTTPNotFound()
+
+        # Are we at the top of the tree
+        if path in ['/', '']:
+            updir = None
+        else:
             updir = dirname(path)
-            updir_file_id = idpath[-2]
+
+        if not is_null_rev(revid):
+            change = history.get_changes([ revid ])[0]
+            # If we're looking at the tip, use head: in the URL instead
+            if revid == branch.last_revision():
+                revno_url = 'head:'
+            else:
+                revno_url = history.get_revno(revid)
+            history.add_branch_nicks(change)
+            filelist = self.get_filelist(rev_tree.inventory, path, sort_type, revno_url)
+
         else:
+            start_revid = None
+            change = None
+            path = "/"
             updir = None
-            updir_file_id = None
-        if updir == '/':
-            updir_file_id = None
+            revno_url = 'head:'
+            filelist = []
 
         return {
-            'branch': self._branch,
-            'util': util,
             'revid': revid,
+            'revno_url': revno_url,
             'change': change,
-            'file_id': file_id,
             'path': path,
             'updir': updir,
-            'updir_file_id': updir_file_id,
-            'filelist': h.get_filelist(inv, file_id, sort_type),
-            'history': h,
-            'posixpath': posixpath,
-            'navigation': navigation,
-            'url': self._branch.context_url,
+            'filelist': filelist,
             'start_revid': start_revid,
+        }
+
+    def add_template_values(self, values):
+        super(InventoryUI, self).add_template_values(values)
+        # Directory Breadcrumbs
+        directory_breadcrumbs = util.directory_breadcrumbs(
+                self._branch.friendly_name,
+                self._branch.is_root,
+                'files')
+
+        path = values['path']
+        revid = values['revid']
+        # no navbar for revisions
+        navigation = util.Container()
+
+        if is_null_rev(revid):
+            branch_breadcrumbs = []
+        else:
+            # Create breadcrumb trail for the path within the branch
+            branch = self._history._branch
+            rev_tree = branch.repository.revision_tree(revid)
+            branch_breadcrumbs = util.branch_breadcrumbs(path, rev_tree, 'files')
+        values.update({
             'fileview_active': True,
-        }
+            'directory_breadcrumbs': directory_breadcrumbs,
+            'branch_breadcrumbs': branch_breadcrumbs,
+            'navigation': navigation,
+        })

=== modified file 'loggerhead/controllers/revision_ui.py'
--- loggerhead/controllers/revision_ui.py	2008-07-22 00:40:03 +0000
+++ loggerhead/controllers/revision_ui.py	2011-11-23 08:18:35 +0000
@@ -17,76 +17,144 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
+import simplejson
+import urllib
+
 from paste.httpexceptions import HTTPServerError
 
 from loggerhead import util
 from loggerhead.controllers import TemplatedBranchView
+from loggerhead.controllers.filediff_ui import diff_chunks_for_file
 
 
 DEFAULT_LINE_COUNT_LIMIT = 3000
 
+def dq(p):
+    return urllib.quote(urllib.quote(p, safe=''))
+
 
 class RevisionUI(TemplatedBranchView):
 
     template_path = 'loggerhead.templates.revision'
-
-    def get_values(self, h, args, kw, headers):
-
-        if len(args) > 0:
-            revid = h.fix_revid(args[0])
-        else:
-            revid = None
-
-        filter_file_id = kw.get('filter_file_id', None)
-        start_revid = h.fix_revid(kw.get('start_revid', None))
-        query = kw.get('q', None)
-        remember = h.fix_revid(kw.get('remember', None))
-        compare_revid = h.fix_revid(kw.get('compare_revid', None))
-
+    supports_json = True
+
+    def get_values(self, path, kwargs, headers):
+        h = self._history
+        revid = self.get_revid()
+
+        filter_file_id = kwargs.get('filter_file_id', None)
+        start_revid = h.fix_revid(kwargs.get('start_revid', None))
+        query = kwargs.get('q', None)
+        compare_revid = h.fix_revid(kwargs.get('compare_revid', None))
+
+        # TODO: This try/except looks to date before real exception handling
+        # and should be removed
         try:
-            revid, start_revid, revid_list = h.get_view(revid, start_revid, filter_file_id, query)
+            revid, start_revid, revid_list = h.get_view(revid,
+                                                        start_revid,
+                                                        filter_file_id,
+                                                        query)
         except:
             self.log.exception('Exception fetching changes')
             raise HTTPServerError('Could not fetch changes')
-
+        # XXX: Some concern about namespace collisions. These are only stored
+        # here so they can be expanded into the template later. Should probably
+        # be stored in a specific dict/etc.
+        self.revid_list = revid_list
+        self.compare_revid = compare_revid
+        self.path = path
+        kwargs['start_revid'] = start_revid
+
+        change = h.get_changes([revid])[0]
+
+        if compare_revid is None:
+            file_changes = h.get_file_changes(change)
+        else:
+            file_changes = h.file_changes_for_revision_ids(
+                compare_revid, change.revid)
+
+        h.add_branch_nicks(change)
+
+        if '.' in change.revno:
+            # Walk "up" though the merge-sorted graph until we find a
+            # revision with merge depth 0: this is the revision that merged
+            # this one to mainline.
+            ri = self._history._rev_info
+            i = self._history._rev_indices[change.revid]
+            while ri[i][0][2] > 0:
+                i -= 1
+            merged_in = ri[i][0][3]
+        else:
+            merged_in = None
+
+        return {
+            'revid': revid,
+            'change': change,
+            'file_changes': file_changes,
+            'merged_in': merged_in,
+        }
+
+    def add_template_values(self, values):
+        super(RevisionUI, self).add_template_values(values)
+        remember = self._history.fix_revid(self.kwargs.get('remember', None))
+        query = self.kwargs.get('q', None)
+        filter_file_id = self.kwargs.get('filter_file_id', None)
+        start_revid = self.kwargs['start_revid']
         navigation = util.Container(
-            revid_list=revid_list, revid=revid, start_revid=start_revid,
+            revid_list=self.revid_list, revid=values['revid'],
+            start_revid=start_revid,
             filter_file_id=filter_file_id, pagesize=1,
-            scan_url='/revision', branch=self._branch, feed=True, history=h)
+            scan_url='/revision', branch=self._branch, feed=True,
+            history=self._history)
         if query is not None:
             navigation.query = query
         util.fill_in_navigation(navigation)
-
-        change = h.get_change_with_diff(revid, compare_revid)
-        # add parent & merge-point branch-nick info, in case it's useful
-        h.get_branch_nicks([ change ])
-
-        line_count_limit = DEFAULT_LINE_COUNT_LIMIT
-        line_count = 0
-        for file in change.changes.modified:
-            for chunk in file.chunks:
-                line_count += len(chunk.diff)
-
-        # let's make side-by-side diff be the default
-        side_by_side = not kw.get('unified', False)
-        if side_by_side:
-            h.add_side_by_side([ change ])
-
-        return {
-            'branch': self._branch,
-            'revid': revid,
-            'change': change,
-            'start_revid': start_revid,
+        path = self.path
+        if path in ('', '/'):
+            path = None
+
+
+        file_changes = values['file_changes']
+        link_data = {}
+        path_to_id = {}
+        if path:
+            items = [x for x in file_changes.text_changes if x.filename == path]
+            if len(items) > 0:
+                item = items[0]
+                diff_chunks = diff_chunks_for_file(
+                    self._history._branch.repository, item.file_id,
+                    item.old_revision, item.new_revision)
+            else:
+                diff_chunks = None
+        else:
+            diff_chunks = None
+            for i, item in enumerate(file_changes.text_changes):
+                item.index = i
+                link_data['diff-' + str(i)] = '%s/%s/%s' % (
+                    dq(item.new_revision), dq(item.old_revision), dq(item.file_id))
+                path_to_id[item.filename] = 'diff-' + str(i)
+
+        # Directory Breadcrumbs
+        directory_breadcrumbs = (
+            util.directory_breadcrumbs(
+                self._branch.friendly_name,
+                self._branch.is_root,
+                'changes'))
+        can_export = self._branch.export_tarballs
+
+        values.update({
+            'history': self._history,
+            'link_data': simplejson.dumps(link_data),
+            'json_specific_path': simplejson.dumps(path),
+            'path_to_id': simplejson.dumps(path_to_id),
+            'directory_breadcrumbs': directory_breadcrumbs,
+            'navigation': navigation,
+            'remember': remember,
+            'compare_revid': self.compare_revid,
             'filter_file_id': filter_file_id,
-            'util': util,
-            'history': h,
-            'navigation': navigation,
+            'diff_chunks': diff_chunks,
             'query': query,
-            'remember': remember,
-            'compare_revid': compare_revid,
-            'side_by_side': side_by_side,
-            'url': self._branch.context_url,
-            'line_count': line_count,
-            'line_count_limit': line_count_limit,
-            'show_plain_diffs': line_count > line_count_limit,
-        }
+            'can_export': can_export,
+            'specific_path': path,
+            'start_revid': start_revid,
+        })

=== added file 'loggerhead/controllers/revlog_ui.py'
--- loggerhead/controllers/revlog_ui.py	1970-01-01 00:00:00 +0000
+++ loggerhead/controllers/revlog_ui.py	2011-06-27 15:05:06 +0000
@@ -0,0 +1,24 @@
+import urllib
+
+from loggerhead.controllers import TemplatedBranchView
+
+
+class RevLogUI(TemplatedBranchView):
+
+    template_path = 'loggerhead.templates.revlog'
+    supports_json = True
+
+    def get_values(self, path, kwargs, headers):
+        history = self._history
+
+        revid = urllib.unquote(self.args[0])
+
+        change = history.get_changes([revid])[0]
+        file_changes = history.get_file_changes(change)
+        history.add_branch_nicks(change)
+
+        return {
+            'entry': change,
+            'file_changes': file_changes,
+            'revid': revid,
+        }

=== modified file 'loggerhead/controllers/search_ui.py'
--- loggerhead/controllers/search_ui.py	2008-07-26 17:41:49 +0000
+++ loggerhead/controllers/search_ui.py	2008-12-05 18:52:44 +0000
@@ -16,22 +16,19 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-from paste.httpexceptions import HTTPServerError
-from loggerhead import history
-from loggerhead import util
 from loggerhead.controllers import TemplatedBranchView
 from loggerhead import search
 
 
 class SearchUI(TemplatedBranchView):
     """
-    
+
     Class to output progressive search result terms.
     """
 
     template_path = 'loggerhead.templates.search'
 
-    def get_values(self, h, args, kwargs, response):
+    def get_values(self, path, kwargs, response):
         """
         Default method called from the search box as /search URL
 
@@ -41,11 +38,11 @@
         terms = []
         query = kwargs['query']
         if len(query) > 0:
-            terms = search.search_revisions(h._branch, query, True)
+            terms = search.search_revisions(self._branch.branch, query, True)
             if terms is not None:
                 terms = [term[0] for term in terms]
             else:
                 # Should show a 'search is not available' etc box.
                 terms = []
 
-        return {'terms':terms}
+        return {'terms': terms}

=== renamed file 'loggerhead/controllers/annotate_ui.py' => 'loggerhead/controllers/view_ui.py'
--- loggerhead/controllers/annotate_ui.py	2008-07-23 21:41:49 +0000
+++ loggerhead/controllers/view_ui.py	2011-09-08 00:33:28 +0000
@@ -18,57 +18,123 @@
 #
 
 import os
-import posixpath
-
-from paste.httpexceptions import HTTPBadRequest
+import time
+
+import bzrlib.errors
+import bzrlib.textfile
+import bzrlib.osutils
+
+from paste.httpexceptions import HTTPBadRequest, HTTPServerError, HTTPMovedPermanently
 
 from loggerhead.controllers import TemplatedBranchView
+try:
+    from loggerhead.highlight import highlight
+except ImportError:
+    highlight = None
 from loggerhead import util
 
 
-def dirname(path):
-    while path.endswith('/'):
-        path = path[:-1]
-    path = posixpath.dirname(path)
-    return path
-
-class AnnotateUI (TemplatedBranchView):
-
-    template_path = 'loggerhead.templates.annotate'
-
-    def get_values(self, h, args, kw, headers):
-        if len(args) > 0:
-            revid = h.fix_revid(args[0])
+class ViewUI(TemplatedBranchView):
+
+    template_path = 'loggerhead.templates.view'
+    
+    def tree_for(self, file_id, revid):
+        file_revid = self._history.get_inventory(revid)[file_id].revision
+        return self._history._branch.repository.revision_tree(file_revid)
+
+    def text_lines(self, file_id, revid):
+        file_name = os.path.basename(self._history.get_path(revid, file_id))
+        
+        tree = self.tree_for(file_id, revid)
+        file_text = tree.get_file_text(file_id)
+        encoding = 'utf-8'
+        try:
+            file_text = file_text.decode(encoding)
+        except UnicodeDecodeError:
+            encoding = 'iso-8859-15'
+            file_text = file_text.decode(encoding)
+
+        file_lines = bzrlib.osutils.split_lines(file_text)
+        # This can throw bzrlib.errors.BinaryFile (which our caller catches).
+        bzrlib.textfile.check_text_lines(file_lines)
+        
+        if highlight is not None:
+            hl_lines = highlight(file_name, file_text, encoding)
+            # highlight strips off extra newlines at the end of the file.
+            extra_lines = len(file_lines) - len(hl_lines)
+            hl_lines.extend([u''] * extra_lines)
         else:
-            revid = h.last_revid
-
-        path = None
-        if len(args) > 1:
-            path = '/'.join(args[1:])
-            if not path.startswith('/'):
-                path = '/' + path
-
-        file_id = kw.get('file_id', None)
+            hl_lines = map(util.html_escape, file_lines)
+        
+        return hl_lines;
+
+    def file_contents(self, file_id, revid):
+        try:
+            file_lines = self.text_lines(file_id, revid)
+        except bzrlib.errors.BinaryFile:
+            # bail out; this isn't displayable text
+            return ['(This is a binary file.)']
+
+        return file_lines
+
+    def get_values(self, path, kwargs, headers):
+        history = self._history
+        branch = history._branch
+        revid = self.get_revid()
+        revid = history.fix_revid(revid)
+        file_id = kwargs.get('file_id', None)
         if (file_id is None) and (path is None):
-            raise HTTPBadRequest('No file_id or filename provided to annotate')
+            raise HTTPBadRequest('No file_id or filename '
+                                 'provided to view')
 
         if file_id is None:
-            file_id = h.get_file_id(revid, path)
+            file_id = history.get_file_id(revid, path)
 
         # no navbar for revisions
         navigation = util.Container()
 
         if path is None:
-            path = h.get_path(revid, file_id)
+            path = history.get_path(revid, file_id)
         filename = os.path.basename(path)
 
+        change = history.get_changes([ revid ])[0]
+        # If we're looking at the tip, use head: in the URL instead
+        if revid == branch.last_revision():
+            revno_url = 'head:'
+        else:
+            revno_url = history.get_revno(revid)
+
+        # Directory Breadcrumbs
+        directory_breadcrumbs = (
+            util.directory_breadcrumbs(
+                self._branch.friendly_name,
+                self._branch.is_root,
+                'files'))
+
+        # Create breadcrumb trail for the path within the branch
+        try:
+            inv = history.get_inventory(revid)
+        except:
+            self.log.exception('Exception fetching changes')
+            raise HTTPServerError('Could not fetch changes')
+        branch_breadcrumbs = util.branch_breadcrumbs(path, inv, 'files')
+
+        if inv[file_id].kind == "directory":
+            raise HTTPMovedPermanently(self._branch.context_url(['/files', revno_url, path]))
+
         return {
-            'revid': revid,
+            # In AnnotateUI, "annotated" is a dictionary mapping lines to changes.
+            # We exploit the fact that bool({}) is False when checking whether
+            # we're in "annotated" mode.
+            'annotated': {},
+            'revno_url': revno_url,
             'file_id': file_id,
-            'path': path,
+            'file_path': path,
             'filename': filename,
             'navigation': navigation,
-            'change': h.get_changes([ revid ])[0],
-            'contents': list(h.annotate_file(file_id, revid)),
+            'change': change,
+            'contents':  self.file_contents(file_id, revid),
             'fileview_active': True,
+            'directory_breadcrumbs': directory_breadcrumbs,
+            'branch_breadcrumbs': branch_breadcrumbs,
         }

=== modified file 'loggerhead/daemon.py'
--- loggerhead/daemon.py	2008-07-26 14:52:44 +0000
+++ loggerhead/daemon.py	2009-05-13 14:03:48 +0000
@@ -25,7 +25,7 @@
         try:
             pid = os.fork()     # Fork a second child.
         except OSError, e:
-            raise Exception, "%s [%d]" % (e.strerror, e.errno)
+            raise Exception("%s [%d]" % (e.strerror, e.errno))
 
         if pid == 0:  # The second child.
             os.chdir(WORKDIR)
@@ -54,7 +54,6 @@
 
     f = open(pidfile, 'w')
     f.write('%d\n' % (os.getpid(),))
-    f.write('%s\n' % (home,))
     f.close()
 
 

=== added file 'loggerhead/exporter.py'
--- loggerhead/exporter.py	1970-01-01 00:00:00 +0000
+++ loggerhead/exporter.py	2011-11-24 07:46:41 +0000
@@ -0,0 +1,60 @@
+# Copyright (C) 2011 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+"""Exports an archive from a bazaar branch"""
+
+from bzrlib.export import get_export_generator
+
+
+class ExporterFileObject(object):
+    """Shim that accumulates temporarily written out data.
+
+    There are python tarfile classes that want to write to a file like object.
+    We want to stream data.  But wsgi assumes it can pull data from the
+    handler, rather than having bytes pushed.
+
+    So this class holds the data temporarily, until it is pulled.  It 
+    should never buffer everything because as soon as a chunk is produced, 
+    wsgi will be given the chance to take it.
+    """
+
+    def __init__(self):
+        self._buffer = []
+
+    def write(self, s):
+        self._buffer.append(s)
+
+    def get_buffer(self):
+        try:
+            return ''.join(self._buffer)
+        finally:
+            self._buffer = []
+
+    def close(self):
+        pass
+
+
+def export_archive(history, root, revid, archive_format):
+    """Export tree contents to an archive
+
+    :param history: Instance of history to export
+    :param root: Root location inside the archive.
+    :param revid: Revision to export
+    :param archive_format: Format of the archive, eg 'tar.gz'.
+    """
+    fileobj = ExporterFileObject()
+    tree = history._branch.repository.revision_tree(revid)
+    for _ in get_export_generator(tree=tree, root=root, fileobj=fileobj,
+        format=archive_format):
+        yield fileobj.get_buffer()
+    # Might have additonal contents written
+    yield fileobj.get_buffer()

=== added file 'loggerhead/highlight.py'
--- loggerhead/highlight.py	1970-01-01 00:00:00 +0000
+++ loggerhead/highlight.py	2010-12-01 08:30:02 +0000
@@ -0,0 +1,55 @@
+#
+# Copyright (C) 2009  Peter Bui <pnutzh4x0r@gmail.com>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+import bzrlib.osutils
+import cgi
+
+from pygments import highlight as _highlight_func
+from pygments.lexers import guess_lexer, guess_lexer_for_filename, TextLexer
+from pygments.formatters import HtmlFormatter
+from pygments.util import ClassNotFound
+
+DEFAULT_PYGMENT_STYLE = 'colorful'
+
+# Trying to highlight very large files using pygments was killing
+# loggerhead on launchpad.net, because pygments isn't very fast.
+# So we only highlight files if they're 512K or smaller.
+MAX_HIGHLIGHT_SIZE = 512000;
+
+def highlight(path, text, encoding, style=DEFAULT_PYGMENT_STYLE):
+    """
+    Returns a list of highlighted (i.e. HTML formatted) strings.
+    """
+
+    if len(text) > MAX_HIGHLIGHT_SIZE:
+        return map(cgi.escape,  bzrlib.osutils.split_lines(text))
+
+    formatter = HtmlFormatter(style=style, nowrap=True, classprefix='pyg-')
+
+    try:
+        lexer = guess_lexer_for_filename(path, text[:1024], encoding=encoding)
+    except (ClassNotFound, ValueError):
+        try:
+            lexer = guess_lexer(text[:1024], encoding=encoding)
+        except (ClassNotFound, ValueError):
+            lexer = TextLexer(encoding=encoding)
+
+    hl_lines = _highlight_func(text, lexer, formatter)
+    hl_lines = bzrlib.osutils.split_lines(hl_lines)
+
+    return hl_lines

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2008-07-26 17:53:10 +0000
+++ loggerhead/history.py	2012-01-23 21:10:46 +0000
@@ -1,5 +1,4 @@
-#
-# Copyright (C) 2008  Canonical Ltd. 
+# Copyright (C) 2006-2011 Canonical Ltd.
 #                     (Authored by Martin Albisetti <argentina@gmail.com>)
 # Copyright (C) 2006  Robey Pointer <robey@lag.net>
 # Copyright (C) 2006  Goffredo Baroncelli <kreijack@inwind.it>
@@ -34,93 +33,19 @@
 import re
 import textwrap
 import threading
-import time
-from StringIO import StringIO
+import tarfile
+
+from bzrlib import tag
+import bzrlib.branch
+import bzrlib.delta
+import bzrlib.errors
+import bzrlib.foreign
+import bzrlib.revision
 
 from loggerhead import search
 from loggerhead import util
 from loggerhead.wholehistory import compute_whole_history_data
 
-import bzrlib
-import bzrlib.branch
-import bzrlib.diff
-import bzrlib.errors
-import bzrlib.progress
-import bzrlib.revision
-import bzrlib.tsort
-import bzrlib.ui
-
-# bzrlib's UIFactory is not thread-safe
-uihack = threading.local()
-
-class ThreadSafeUIFactory (bzrlib.ui.SilentUIFactory):
-    def nested_progress_bar(self):
-        if getattr(uihack, '_progress_bar_stack', None) is None:
-            uihack._progress_bar_stack = bzrlib.progress.ProgressBarStack(klass=bzrlib.progress.DummyProgress)
-        return uihack._progress_bar_stack.get_nested()
-
-bzrlib.ui.ui_factory = ThreadSafeUIFactory()
-
-
-def _process_side_by_side_buffers(line_list, delete_list, insert_list):
-    while len(delete_list) < len(insert_list):
-        delete_list.append((None, '', 'context'))
-    while len(insert_list) < len(delete_list):
-        insert_list.append((None, '', 'context'))
-    while len(delete_list) > 0:
-        d = delete_list.pop(0)
-        i = insert_list.pop(0)
-        line_list.append(util.Container(old_lineno=d[0], new_lineno=i[0],
-                                        old_line=d[1], new_line=i[1],
-                                        old_type=d[2], new_type=i[2]))
-
-
-def _make_side_by_side(chunk_list):
-    """
-    turn a normal unified-style diff (post-processed by parse_delta) into a
-    side-by-side diff structure.  the new structure is::
-
-        chunks: list(
-            diff: list(
-                old_lineno: int,
-                new_lineno: int,
-                old_line: str,
-                new_line: str,
-                type: str('context' or 'changed'),
-            )
-        )
-    """
-    out_chunk_list = []
-    for chunk in chunk_list:
-        line_list = []
-        wrap_char = '<wbr/>'
-        delete_list, insert_list = [], []
-        for line in chunk.diff:
-            # Add <wbr/> every X characters so we can wrap properly
-            wrap_line = re.findall(r'.{%d}|.+$' % 78, line.line)
-            wrap_lines = [util.html_clean(_line) for _line in wrap_line]
-            wrapped_line = wrap_char.join(wrap_lines)
-
-            if line.type == 'context':
-                if len(delete_list) or len(insert_list):
-                    _process_side_by_side_buffers(line_list, delete_list, 
-                                                  insert_list)
-                    delete_list, insert_list = [], []
-                line_list.append(util.Container(old_lineno=line.old_lineno, 
-                                                new_lineno=line.new_lineno,
-                                                old_line=wrapped_line, 
-                                                new_line=wrapped_line,
-                                                old_type=line.type, 
-                                                new_type=line.type))
-            elif line.type == 'delete':
-                delete_list.append((line.old_lineno, wrapped_line, line.type))
-            elif line.type == 'insert':
-                insert_list.append((line.new_lineno, wrapped_line, line.type))
-        if len(delete_list) or len(insert_list):
-            _process_side_by_side_buffers(line_list, delete_list, insert_list)
-        out_chunk_list.append(util.Container(diff=line_list))
-    return out_chunk_list
-
 
 def is_branch(folder):
     try:
@@ -137,7 +62,7 @@
     module (Robey, the original author of this code, apparently favored this
     style of message).
     """
-    message = message.splitlines()
+    message = message.lstrip().splitlines()
 
     if len(message) == 1:
         message = textwrap.wrap(message[0])
@@ -164,8 +89,6 @@
     return path
 
 
-
-# from bzrlib
 class _RevListToTimestamps(object):
     """This takes a list of revisions, and allows you to bisect by date"""
 
@@ -177,13 +100,112 @@
 
     def __getitem__(self, index):
         """Get the date of the index'd item"""
-        return datetime.datetime.fromtimestamp(self.repository.get_revision(self.revid_list[index]).timestamp)
+        return datetime.datetime.fromtimestamp(self.repository.get_revision(
+                   self.revid_list[index]).timestamp)
 
     def __len__(self):
         return len(self.revid_list)
 
-
-class History (object):
+class FileChangeReporter(object):
+
+    def __init__(self, old_inv, new_inv):
+        self.added = []
+        self.modified = []
+        self.renamed = []
+        self.removed = []
+        self.text_changes = []
+        self.old_inv = old_inv
+        self.new_inv = new_inv
+
+    def revid(self, inv, file_id):
+        try:
+            return inv[file_id].revision
+        except bzrlib.errors.NoSuchId:
+            return 'null:'
+
+    def report(self, file_id, paths, versioned, renamed, modified,
+               exe_change, kind):
+        if modified not in ('unchanged', 'kind changed'):
+            if versioned == 'removed':
+                filename = rich_filename(paths[0], kind[0])
+            else:
+                filename = rich_filename(paths[1], kind[1])
+            self.text_changes.append(util.Container(
+                filename=filename, file_id=file_id,
+                old_revision=self.revid(self.old_inv, file_id),
+                new_revision=self.revid(self.new_inv, file_id)))
+        if versioned == 'added':
+            self.added.append(util.Container(
+                filename=rich_filename(paths[1], kind), kind=kind[1]))
+        elif versioned == 'removed':
+            self.removed.append(util.Container(
+                filename=rich_filename(paths[0], kind), kind=kind[0]))
+        elif renamed:
+            self.renamed.append(util.Container(
+                old_filename=rich_filename(paths[0], kind[0]),
+                new_filename=rich_filename(paths[1], kind[1]),
+                text_modified=modified == 'modified', exe_change=exe_change))
+        else:
+            self.modified.append(util.Container(
+                filename=rich_filename(paths[1], kind),
+                text_modified=modified == 'modified', exe_change=exe_change))
+
+# The lru_cache is not thread-safe, so we need a lock around it for
+# all threads.
+rev_info_memory_cache_lock = threading.RLock()
+
+class RevInfoMemoryCache(object):
+    """A store that validates values against the revids they were stored with.
+
+    We use a unique key for each branch.
+
+    The reason for not just using the revid as the key is so that when a new
+    value is provided for a branch, we replace the old value used for the
+    branch.
+
+    There is another implementation of the same interface in
+    loggerhead.changecache.RevInfoDiskCache.
+    """
+
+    def __init__(self, cache):
+        self._cache = cache
+
+    def get(self, key, revid):
+        """Return the data associated with `key`, subject to a revid check.
+
+        If a value was stored under `key`, with the same revid, return it.
+        Otherwise return None.
+        """
+        rev_info_memory_cache_lock.acquire()
+        try:
+            cached = self._cache.get(key)
+        finally:
+            rev_info_memory_cache_lock.release()
+        if cached is None:
+            return None
+        stored_revid, data = cached
+        if revid == stored_revid:
+            return data
+        else:
+            return None
+
+    def set(self, key, revid, data):
+        """Store `data` under `key`, to be checked against `revid` on get().
+        """
+        rev_info_memory_cache_lock.acquire()
+        try:
+            self._cache[key] = (revid, data)
+        finally:
+            rev_info_memory_cache_lock.release()
+
+# Used to store locks that prevent multiple threads from building a 
+# revision graph for the same branch at the same time, because that can
+# cause severe performance issues that are so bad that the system seems
+# to hang.
+revision_graph_locks = {}
+revision_graph_check_lock = threading.Lock()
+
+class History(object):
     """Decorate a branch to provide information for rendering.
 
     History objects are expected to be short lived -- when serving a request
@@ -191,29 +213,89 @@
     around it, serve the request, throw the History object away, unlock the
     branch and throw it away.
 
-    :ivar _file_change_cache: xx
+    :ivar _rev_info: A list of information about revisions.  This is by far
+        the most cryptic data structure in loggerhead.  At the top level, it
+        is a list of 3-tuples [(merge-info, where-merged, parents)].
+        `merge-info` is (seq, revid, merge_depth, revno_str, end_of_merge) --
+        like a merged sorted list, but the revno is stringified.
+        `where-merged` is a tuple of revisions that have this revision as a
+        non-lefthand parent.  Finally, `parents` is just the usual list of
+        parents of this revision.
+    :ivar _rev_indices: A dictionary mapping each revision id to the index of
+        the information about it in _rev_info.
+    :ivar _revno_revid: A dictionary mapping stringified revnos to revision
+        ids.
     """
 
-    def __init__(self, branch, whole_history_data_cache):
+    def _load_whole_history_data(self, caches, cache_key):
+        """Set the attributes relating to the whole history of the branch.
+
+        :param caches: a list of caches with interfaces like
+            `RevInfoMemoryCache` and be ordered from fastest to slowest.
+        :param cache_key: the key to use with the caches.
+        """
+        self._rev_indices = None
+        self._rev_info = None
+
+        missed_caches = []
+        def update_missed_caches():
+            for cache in missed_caches:
+                cache.set(cache_key, self.last_revid, self._rev_info)
+
+        # Theoretically, it's possible for two threads to race in creating
+        # the Lock() object for their branch, so we put a lock around
+        # creating the per-branch Lock().
+        revision_graph_check_lock.acquire()
+        try:
+            if cache_key not in revision_graph_locks:
+                revision_graph_locks[cache_key] = threading.Lock()
+        finally:
+            revision_graph_check_lock.release()
+
+        revision_graph_locks[cache_key].acquire()
+        try:
+            for cache in caches:
+                data = cache.get(cache_key, self.last_revid)
+                if data is not None:
+                    self._rev_info = data
+                    update_missed_caches()
+                    break
+                else:
+                    missed_caches.append(cache)
+            else:
+                whole_history_data = compute_whole_history_data(self._branch)
+                self._rev_info, self._rev_indices = whole_history_data
+                update_missed_caches()
+        finally:
+            revision_graph_locks[cache_key].release()
+
+        if self._rev_indices is not None:
+            self._revno_revid = {}
+            for ((_, revid, _, revno_str, _), _, _) in self._rev_info:
+                self._revno_revid[revno_str] = revid
+        else:
+            self._revno_revid = {}
+            self._rev_indices = {}
+            for ((seq, revid, _, revno_str, _), _, _) in self._rev_info:
+                self._rev_indices[revid] = seq
+                self._revno_revid[revno_str] = revid
+
+    def __init__(self, branch, whole_history_data_cache,
+                 revinfo_disk_cache=None, cache_key=None):
         assert branch.is_locked(), (
             "Can only construct a History object with a read-locked branch.")
-        self._file_change_cache = None
         self._branch = branch
-        self.log = logging.getLogger('loggerhead.%s' % (branch.nick,))
+        self._branch_tags = None
+        self._inventory_cache = {}
+        self._branch_nick = self._branch.get_config().get_nickname()
+        self.log = logging.getLogger('loggerhead.%s' % (self._branch_nick,))
 
         self.last_revid = branch.last_revision()
 
-        whole_history_data = whole_history_data_cache.get(self.last_revid)
-        if whole_history_data is None:
-            whole_history_data = compute_whole_history_data(branch)
-            whole_history_data_cache[self.last_revid] = whole_history_data
-
-        (self._revision_graph, self._full_history, self._revision_info,
-         self._revno_revid, self._merge_sort, self._where_merged
-         ) = whole_history_data
-
-    def use_file_cache(self, cache):
-        self._file_change_cache = cache
+        caches = [RevInfoMemoryCache(whole_history_data_cache)]
+        if revinfo_disk_cache:
+            caches.append(revinfo_disk_cache)
+        self._load_whole_history_data(caches, cache_key)
 
     @property
     def has_revisions(self):
@@ -223,11 +305,12 @@
         return self._branch.get_config()
 
     def get_revno(self, revid):
-        if revid not in self._revision_info:
+        if revid not in self._rev_indices:
             # ghost parent?
             return 'unknown'
-        seq, revid, merge_depth, revno_str, end_of_merge = self._revision_info[revid]
-        return revno_str
+        seq = self._rev_indices[revid]
+        revno = self._rev_info[seq][0][3]
+        return revno
 
     def get_revids_from(self, revid_list, start_revid):
         """
@@ -235,43 +318,68 @@
         revid in revid_list.
         """
         if revid_list is None:
-            revid_list = self._full_history
+            # Just yield the mainline, starting at start_revid
+            revid = start_revid
+            is_null = bzrlib.revision.is_null
+            while not is_null(revid):
+                yield revid
+                parents = self._rev_info[self._rev_indices[revid]][2]
+                if not parents:
+                    return
+                revid = parents[0]
+            return
         revid_set = set(revid_list)
         revid = start_revid
+
         def introduced_revisions(revid):
             r = set([revid])
-            seq, revid, md, revno, end_of_merge = self._revision_info[revid]
+            seq = self._rev_indices[revid]
+            md = self._rev_info[seq][0][2]
             i = seq + 1
-            while i < len(self._merge_sort) and self._merge_sort[i][2] > md:
-                r.add(self._merge_sort[i][1])
+            while i < len(self._rev_info) and self._rev_info[i][0][2] > md:
+                r.add(self._rev_info[i][0][1])
                 i += 1
             return r
-        while 1:
+        while revid_set:
             if bzrlib.revision.is_null(revid):
                 return
-            if introduced_revisions(revid) & revid_set:
+            rev_introduced = introduced_revisions(revid)
+            matching = rev_introduced.intersection(revid_set)
+            if matching:
+                # We don't need to look for these anymore.
+                revid_set.difference_update(matching)
                 yield revid
-            parents = self._revision_graph[revid]
+            parents = self._rev_info[self._rev_indices[revid]][2]
             if len(parents) == 0:
                 return
             revid = parents[0]
 
     def get_short_revision_history_by_fileid(self, file_id):
-        # wow.  is this really the only way we can get this list?  by
-        # man-handling the weave store directly? :-0
         # FIXME: would be awesome if we could get, for a folder, the list of
-        # revisions where items within that folder changed.
-        possible_keys = [(file_id, revid) for revid in self._full_history]
-        existing_keys = self._branch.repository.texts.get_parent_map(possible_keys)
-        return [revid for _, revid in existing_keys.iterkeys()]
+        # revisions where items within that folder changed.i
+        possible_keys = [(file_id, revid) for revid in self._rev_indices]
+        get_parent_map = self._branch.repository.texts.get_parent_map
+        # We chunk the requests as this works better with GraphIndex.
+        # See _filter_revisions_touching_file_id in bzrlib/log.py
+        # for more information.
+        revids = []
+        chunk_size = 1000
+        for start in xrange(0, len(possible_keys), chunk_size):
+            next_keys = possible_keys[start:start + chunk_size]
+            revids += [k[1] for k in get_parent_map(next_keys)]
+        del possible_keys, next_keys
+        return revids
 
     def get_revision_history_since(self, revid_list, date):
         # if a user asks for revisions starting at 01-sep, they mean inclusive,
         # so start at midnight on 02-sep.
         date = date + datetime.timedelta(days=1)
-        # our revid list is sorted in REVERSE date order, so go thru some hoops here...
+        # our revid list is sorted in REVERSE date order,
+        # so go thru some hoops here...
         revid_list.reverse()
-        index = bisect.bisect(_RevListToTimestamps(revid_list, self._branch.repository), date)
+        index = bisect.bisect(_RevListToTimestamps(revid_list,
+                                                   self._branch.repository),
+                              date)
         if index == 0:
             return []
         revid_list.reverse()
@@ -283,7 +391,8 @@
         given a "quick-search" query, try a few obvious possible meanings:
 
             - revision id or # ("128.1.3")
-            - date (US style "mm/dd/yy", earth style "dd-mm-yy", or iso style "yyyy-mm-dd")
+            - date (US style "mm/dd/yy", earth style "dd-mm-yy", or \
+iso style "yyyy-mm-dd")
             - comment text as a fallback
 
         and return a revid list that matches.
@@ -292,30 +401,38 @@
         # all the relevant changes (time-consuming) only to return a list of
         # revids which will be used to fetch a set of changes again.
 
-        # if they entered a revid, just jump straight there; ignore the passed-in revid_list
+        # if they entered a revid, just jump straight there;
+        # ignore the passed-in revid_list
         revid = self.fix_revid(query)
         if revid is not None:
             if isinstance(revid, unicode):
                 revid = revid.encode('utf-8')
-            changes = self.get_changes([ revid ])
+            changes = self.get_changes([revid])
             if (changes is not None) and (len(changes) > 0):
-                return [ revid ]
+                return [revid]
 
         date = None
         m = self.us_date_re.match(query)
         if m is not None:
-            date = datetime.datetime(util.fix_year(int(m.group(3))), int(m.group(1)), int(m.group(2)))
+            date = datetime.datetime(util.fix_year(int(m.group(3))),
+                                     int(m.group(1)),
+                                     int(m.group(2)))
         else:
             m = self.earth_date_re.match(query)
             if m is not None:
-                date = datetime.datetime(util.fix_year(int(m.group(3))), int(m.group(2)), int(m.group(1)))
+                date = datetime.datetime(util.fix_year(int(m.group(3))),
+                                         int(m.group(2)),
+                                         int(m.group(1)))
             else:
                 m = self.iso_date_re.match(query)
                 if m is not None:
-                    date = datetime.datetime(util.fix_year(int(m.group(1))), int(m.group(2)), int(m.group(3)))
+                    date = datetime.datetime(util.fix_year(int(m.group(1))),
+                                             int(m.group(2)),
+                                             int(m.group(3)))
         if date is not None:
             if revid_list is None:
-                # if no limit to the query was given, search only the direct-parent path.
+                # if no limit to the query was given,
+                # search only the direct-parent path.
                 revid_list = list(self.get_revids_from(None, self.last_revid))
             return self.get_revision_history_since(revid_list, date)
 
@@ -333,8 +450,11 @@
             return revid
         if revid == 'head:':
             return self.last_revid
-        if self.revno_re.match(revid):
-            revid = self._revno_revid[revid]
+        try:
+            if self.revno_re.match(revid):
+                revid = self._revno_revid[revid]
+        except KeyError:
+            raise bzrlib.errors.NoSuchRevision(self._branch_nick, revid)
         return revid
 
     def get_file_view(self, revid, file_id):
@@ -348,15 +468,41 @@
         if revid is None:
             revid = self.last_revid
         if file_id is not None:
-            # since revid is 'start_revid', possibly should start the path
-            # tracing from revid... FIXME
-            revlist = list(self.get_short_revision_history_by_fileid(file_id))
-            revlist = list(self.get_revids_from(revlist, revid))
+            revlist = list(
+                self.get_short_revision_history_by_fileid(file_id))
+            revlist = self.get_revids_from(revlist, revid)
         else:
-            revlist = list(self.get_revids_from(None, revid))
+            revlist = self.get_revids_from(None, revid)
         return revlist
 
-    def get_view(self, revid, start_revid, file_id, query=None):
+    @staticmethod
+    def _iterate_sufficiently(iterable, stop_at, extra_rev_count):
+        """Return a list of iterable.
+
+        If extra_rev_count is None, fully consume iterable.
+        Otherwise, stop at 'stop_at' + extra_rev_count.
+
+        Example:
+          iterate until you find stop_at, then iterate 10 more times.
+        """
+        if extra_rev_count is None:
+            return list(iterable)
+        result = []
+        found = False
+        for n in iterable:
+            result.append(n)
+            if n == stop_at:
+                found = True
+                break
+        if found:
+            for count, n in enumerate(iterable):
+                if count >= extra_rev_count:
+                    break
+                result.append(n)
+        return result
+
+    def get_view(self, revid, start_revid, file_id, query=None,
+                 extra_rev_count=None):
         """
         use the URL parameters (revid, start_revid, file_id, and query) to
         determine the revision list we're viewing (start_revid, file_id, query)
@@ -367,6 +513,10 @@
               file.
             - if a start_revid is given, we're viewing the branch from a
               specific revision up the tree.
+            - if extra_rev_count is given, find the view from start_revid =>
+              revid, and continue an additional 'extra_rev_count'. If not
+              given, then revid_list will contain the full history of
+              start_revid
 
         these may be combined to view revisions for a specific file, from
         a specific revision, with a specific search query.
@@ -385,12 +535,16 @@
 
         if query is None:
             revid_list = self.get_file_view(start_revid, file_id)
+            revid_list = self._iterate_sufficiently(revid_list, revid,
+                                                    extra_rev_count)
             if revid is None:
                 revid = start_revid
             if revid not in revid_list:
                 # if the given revid is not in the revlist, use a revlist that
                 # starts at the given revid.
                 revid_list = self.get_file_view(revid, file_id)
+                revid_list = self._iterate_sufficiently(revid_list, revid,
+                                                        extra_rev_count)
                 start_revid = revid
             return revid, start_revid, revid_list
 
@@ -411,12 +565,15 @@
             return None, None, []
 
     def get_inventory(self, revid):
-        return self._branch.repository.get_revision_inventory(revid)
+        if revid not in self._inventory_cache:
+            self._inventory_cache[revid] = (
+                self._branch.repository.get_inventory(revid))
+        return self._inventory_cache[revid]
 
     def get_path(self, revid, file_id):
         if (file_id is None) or (file_id == ''):
             return ''
-        path = self._branch.repository.get_revision_inventory(revid).id2path(file_id)
+        path = self.get_inventory(revid).id2path(file_id)
         if (len(path) > 0) and not path.startswith('/'):
             path = '/' + path
         return path
@@ -424,7 +581,7 @@
     def get_file_id(self, revid, path):
         if (len(path) > 0) and not path.startswith('/'):
             path = '/' + path
-        return self._branch.repository.get_revision_inventory(revid).path2id(path)
+        return self.get_inventory(revid).path2id(path)
 
     def get_merge_point_list(self, revid):
         """
@@ -435,10 +592,10 @@
 
         merge_point = []
         while True:
-            children = self._where_merged.get(revid, [])
+            children = self._rev_info[self._rev_indices[revid]][1]
             nexts = []
             for child in children:
-                child_parents = self._revision_graph[child]
+                child_parents = self._rev_info[self._rev_indices[child]][2]
                 if child_parents[0] == revid:
                     nexts.append(child)
                 else:
@@ -464,40 +621,37 @@
             revnol = revno.split(".")
             revnos = ".".join(revnol[:-2])
             revnolast = int(revnol[-1])
-            if d.has_key(revnos):
+            if revnos in d:
                 m = d[revnos][0]
                 if revnolast < m:
-                    d[revnos] = ( revnolast, revid )
+                    d[revnos] = (revnolast, revid)
             else:
-                d[revnos] = ( revnolast, revid )
-
-        return [ d[revnos][1] for revnos in d.keys() ]
-
-    def get_branch_nicks(self, changes):
+                d[revnos] = (revnolast, revid)
+
+        return [revid for (_, revid) in d.itervalues()]
+
+    def add_branch_nicks(self, change):
         """
-        given a list of changes from L{get_changes}, fill in the branch nicks
-        on all parents and merge points.
+        given a 'change', fill in the branch nicks on all parents and merge
+        points.
         """
         fetch_set = set()
-        for change in changes:
-            for p in change.parents:
-                fetch_set.add(p.revid)
-            for p in change.merge_points:
-                fetch_set.add(p.revid)
+        for p in change.parents:
+            fetch_set.add(p.revid)
+        for p in change.merge_points:
+            fetch_set.add(p.revid)
         p_changes = self.get_changes(list(fetch_set))
         p_change_dict = dict([(c.revid, c) for c in p_changes])
-        for change in changes:
-            # arch-converted branches may not have merged branch info :(
-            for p in change.parents:
-                if p.revid in p_change_dict:
-                    p.branch_nick = p_change_dict[p.revid].branch_nick
-                else:
-                    p.branch_nick = '(missing)'
-            for p in change.merge_points:
-                if p.revid in p_change_dict:
-                    p.branch_nick = p_change_dict[p.revid].branch_nick
-                else:
-                    p.branch_nick = '(missing)'
+        for p in change.parents:
+            if p.revid in p_change_dict:
+                p.branch_nick = p_change_dict[p.revid].branch_nick
+            else:
+                p.branch_nick = '(missing)'
+        for p in change.merge_points:
+            if p.revid in p_change_dict:
+                p.branch_nick = p_change_dict[p.revid].branch_nick
+            else:
+                p.branch_nick = '(missing)'
 
     def get_changes(self, revid_list):
         """Return a list of changes objects for the given revids.
@@ -511,10 +665,13 @@
         # some data needs to be recalculated each time, because it may
         # change as new revisions are added.
         for change in changes:
-            merge_revids = self.simplify_merge_point_list(self.get_merge_point_list(change.revid))
-            change.merge_points = [util.Container(revid=r, revno=self.get_revno(r)) for r in merge_revids]
+            merge_revids = self.simplify_merge_point_list(
+                               self.get_merge_point_list(change.revid))
+            change.merge_points = [
+                util.Container(revid=r,
+                revno=self.get_revno(r)) for r in merge_revids]
             if len(change.parents) > 0:
-                change.parents = [util.Container(revid=r, 
+                change.parents = [util.Container(revid=r,
                     revno=self.get_revno(r)) for r in change.parents]
             change.revno = self.get_revno(change.revid)
 
@@ -529,7 +686,8 @@
         # FIXME: deprecated method in getting a null revision
         revid_list = filter(lambda revid: not bzrlib.revision.is_null(revid),
                             revid_list)
-        parent_map = self._branch.repository.get_graph().get_parent_map(revid_list)
+        parent_map = self._branch.repository.get_graph().get_parent_map(
+                         revid_list)
         # We need to return the answer in the same order as the input,
         # less any ghosts.
         present_revids = [revid for revid in revid_list
@@ -538,95 +696,73 @@
 
         return [self._change_from_revision(rev) for rev in rev_list]
 
-    def _get_deltas_for_revisions_with_trees(self, revisions):
-        """Produce a list of revision deltas.
-
-        Note that the input is a sequence of REVISIONS, not revision_ids.
-        Trees will be held in memory until the generator exits.
-        Each delta is relative to the revision's lefthand predecessor.
-        (This is copied from bzrlib.)
-        """
-        required_trees = set()
-        for revision in revisions:
-            required_trees.add(revision.revid)
-            required_trees.update([p.revid for p in revision.parents[:1]])
-        trees = dict((t.get_revision_id(), t) for
-                     t in self._branch.repository.revision_trees(required_trees))
-        ret = []
-        self._branch.repository.lock_read()
-        try:
-            for revision in revisions:
-                if not revision.parents:
-                    old_tree = self._branch.repository.revision_tree(
-                        bzrlib.revision.NULL_REVISION)
-                else:
-                    old_tree = trees[revision.parents[0].revid]
-                tree = trees[revision.revid]
-                ret.append(tree.changes_from(old_tree))
-            return ret
-        finally:
-            self._branch.repository.unlock()
-
     def _change_from_revision(self, revision):
         """
         Given a bzrlib Revision, return a processed "change" for use in
         templates.
         """
-        commit_time = datetime.datetime.fromtimestamp(revision.timestamp)
-
-        parents = [util.Container(revid=r, revno=self.get_revno(r)) for r in revision.parent_ids]
-
         message, short_message = clean_message(revision.message)
 
+        if self._branch_tags is None:
+            self._branch_tags = self._branch.tags.get_reverse_tag_dict()
+
+        revtags = None
+        if revision.revision_id in self._branch_tags:
+          # tag.sort_* functions expect (tag, data) pairs, so we generate them,
+          # and then strip them
+          tags = [(t, None) for t in self._branch_tags[revision.revision_id]]
+          sort_func = getattr(tag, 'sort_natural', None)
+          if sort_func is None:
+              tags.sort()
+          else:
+              sort_func(self._branch, tags)
+          revtags = u', '.join([t[0] for t in tags])
+
         entry = {
             'revid': revision.revision_id,
-            'date': commit_time,
-            'author': revision.get_apparent_author(),
+            'date': datetime.datetime.fromtimestamp(revision.timestamp),
+            'utc_date': datetime.datetime.utcfromtimestamp(revision.timestamp),
+            'committer': revision.committer,
+            'authors': revision.get_apparent_authors(),
             'branch_nick': revision.properties.get('branch-nick', None),
             'short_comment': short_message,
             'comment': revision.message,
             'comment_clean': [util.html_clean(s) for s in message],
             'parents': revision.parent_ids,
+            'bugs': [bug.split()[0] for bug in revision.properties.get('bugs', '').splitlines()],
+            'tags': revtags,
         }
+        if isinstance(revision, bzrlib.foreign.ForeignRevision):
+            foreign_revid, mapping = (
+                revision.foreign_revid, revision.mapping)
+        elif ":" in revision.revision_id:
+            try:
+                foreign_revid, mapping = \
+                    bzrlib.foreign.foreign_vcs_registry.parse_revision_id(
+                        revision.revision_id)
+            except bzrlib.errors.InvalidRevisionId:
+                foreign_revid = None
+                mapping = None
+        else:
+            foreign_revid = None
+        if foreign_revid is not None:
+            entry["foreign_vcs"] = mapping.vcs.abbreviation
+            entry["foreign_revid"] = mapping.vcs.show_foreign_revid(foreign_revid)
         return util.Container(entry)
 
-    def get_file_changes_uncached(self, entries):
-        delta_list = self._get_deltas_for_revisions_with_trees(entries)
-
-        return [self.parse_delta(delta) for delta in delta_list]
-
-    def get_file_changes(self, entries):
-        if self._file_change_cache is None:
-            return self.get_file_changes_uncached(entries)
+    def get_file_changes(self, entry):
+        if entry.parents:
+            old_revid = entry.parents[0].revid
         else:
-            return self._file_change_cache.get_file_changes(entries)
-
-    def add_changes(self, entries):
-        changes_list = self.get_file_changes(entries)
-
-        for entry, changes in zip(entries, changes_list):
-            entry.changes = changes
-
-    def get_change_with_diff(self, revid, compare_revid=None):
-        change = self.get_changes([revid])[0]
-
-        if compare_revid is None:
-            if change.parents:
-                compare_revid = change.parents[0].revid
-            else:
-                compare_revid = 'null:'
-
-        rev_tree1 = self._branch.repository.revision_tree(compare_revid)
-        rev_tree2 = self._branch.repository.revision_tree(revid)
-        delta = rev_tree2.changes_from(rev_tree1)
-
-        change.changes = self.parse_delta(delta)
-        change.changes.modified = self._parse_diffs(rev_tree1, rev_tree2, delta)
-
-        return change
+            old_revid = bzrlib.revision.NULL_REVISION
+        return self.file_changes_for_revision_ids(old_revid, entry.revid)
+
+    def add_changes(self, entry):
+        changes = self.get_file_changes(entry)
+        entry.changes = changes
 
     def get_file(self, file_id, revid):
-        "returns (path, filename, data)"
+        """Returns (path, filename, file contents)"""
         inv = self.get_inventory(revid)
         inv_entry = inv[file_id]
         rev_tree = self._branch.repository.revision_tree(inv_entry.revision)
@@ -635,95 +771,7 @@
             path = '/' + path
         return path, inv_entry.name, rev_tree.get_file_text(file_id)
 
-    def _parse_diffs(self, old_tree, new_tree, delta):
-        """
-        Return a list of processed diffs, in the format::
-
-            list(
-                filename: str,
-                file_id: str,
-                chunks: list(
-                    diff: list(
-                        old_lineno: int,
-                        new_lineno: int,
-                        type: str('context', 'delete', or 'insert'),
-                        line: str,
-                    ),
-                ),
-            )
-        """
-        process = []
-        out = []
-
-        for old_path, new_path, fid, kind, text_modified, meta_modified in delta.renamed:
-            if text_modified:
-                process.append((old_path, new_path, fid, kind))
-        for path, fid, kind, text_modified, meta_modified in delta.modified:
-            process.append((path, path, fid, kind))
-
-        for old_path, new_path, fid, kind in process:
-            old_lines = old_tree.get_file_lines(fid)
-            new_lines = new_tree.get_file_lines(fid)
-            buffer = StringIO()
-            if old_lines != new_lines:
-                try:
-                    bzrlib.diff.internal_diff(old_path, old_lines,
-                                              new_path, new_lines, buffer)
-                except bzrlib.errors.BinaryFile:
-                    diff = ''
-                else:
-                    diff = buffer.getvalue()
-            else:
-                diff = ''
-            out.append(util.Container(filename=rich_filename(new_path, kind), file_id=fid, chunks=self._process_diff(diff), raw_diff=diff))
-
-        return out
-
-    def _process_diff(self, diff):
-        # doesn't really need to be a method; could be static.
-        chunks = []
-        chunk = None
-        for line in diff.splitlines():
-            if len(line) == 0:
-                continue
-            if line.startswith('+++ ') or line.startswith('--- '):
-                continue
-            if line.startswith('@@ '):
-                # new chunk
-                if chunk is not None:
-                    chunks.append(chunk)
-                chunk = util.Container()
-                chunk.diff = []
-                lines = [int(x.split(',')[0][1:]) for x in line.split(' ')[1:3]]
-                old_lineno = lines[0]
-                new_lineno = lines[1]
-            elif line.startswith(' '):
-                chunk.diff.append(util.Container(old_lineno=old_lineno, 
-                                                 new_lineno=new_lineno,
-                                                 type='context', 
-                                                 line=line[1:]))
-                old_lineno += 1
-                new_lineno += 1
-            elif line.startswith('+'):
-                chunk.diff.append(util.Container(old_lineno=None, 
-                                                 new_lineno=new_lineno,
-                                                 type='insert', line=line[1:]))
-                new_lineno += 1
-            elif line.startswith('-'):
-                chunk.diff.append(util.Container(old_lineno=old_lineno, 
-                                                 new_lineno=None,
-                                                 type='delete', line=line[1:]))
-                old_lineno += 1
-            else:
-                chunk.diff.append(util.Container(old_lineno=None, 
-                                                 new_lineno=None,
-                                                 type='unknown', 
-                                                 line=repr(line)))
-        if chunk is not None:
-            chunks.append(chunk)
-        return chunks
-
-    def parse_delta(self, delta):
+    def file_changes_for_revision_ids(self, old_revid, new_revid):
         """
         Return a nested data structure containing the changes in a delta::
 
@@ -733,125 +781,27 @@
             modified: list(
                 filename: str,
                 file_id: str,
-            )
-        """
-        added = []
-        modified = []
-        renamed = []
-        removed = []
-
-        for path, fid, kind in delta.added:
-            added.append((rich_filename(path, kind), fid))
-
-        for path, fid, kind, text_modified, meta_modified in delta.modified:
-            modified.append(util.Container(filename=rich_filename(path, kind), file_id=fid))
-
-        for old_path, new_path, fid, kind, text_modified, meta_modified in delta.renamed:
-            renamed.append((rich_filename(old_path, kind), rich_filename(new_path, kind), fid))
-            if meta_modified or text_modified:
-                modified.append(util.Container(filename=rich_filename(new_path, kind), file_id=fid))
-
-        for path, fid, kind in delta.removed:
-            removed.append((rich_filename(path, kind), fid))
-
-        return util.Container(added=added, renamed=renamed, removed=removed, modified=modified)
-
-    @staticmethod
-    def add_side_by_side(changes):
-        # FIXME: this is a rotten API.
-        for change in changes:
-            for m in change.changes.modified:
-                m.sbs_chunks = _make_side_by_side(m.chunks)
-
-    def get_filelist(self, inv, file_id, sort_type=None):
-        """
-        return the list of all files (and their attributes) within a given
-        path subtree.
-        """
-
-        dir_ie = inv[file_id]
-        path = inv.id2path(file_id)
-        file_list = []
-
-        revid_set = set()
-
-        for filename, entry in dir_ie.children.iteritems():
-            revid_set.add(entry.revision)
-
-        change_dict = {}
-        for change in self.get_changes(list(revid_set)):
-            change_dict[change.revid] = change
-
-        for filename, entry in dir_ie.children.iteritems():
-            pathname = filename
-            if entry.kind == 'directory':
-                pathname += '/'
-
-            revid = entry.revision
-
-            file = util.Container(
-                filename=filename, executable=entry.executable, kind=entry.kind,
-                pathname=pathname, file_id=entry.file_id, size=entry.text_size,
-                revid=revid, change=change_dict[revid])
-            file_list.append(file)
-
-        if sort_type == 'filename' or sort_type is None:
-            file_list.sort(key=lambda x: x.filename.lower()) # case-insensitive
-        elif sort_type == 'size':
-            file_list.sort(key=lambda x: x.size)
-        elif sort_type == 'date':
-            file_list.sort(key=lambda x: x.change.date)
-        
-        # Always sort by kind to get directories first
-        file_list.sort(key=lambda x: x.kind != 'directory')
-
-        parity = 0
-        for file in file_list:
-            file.parity = parity
-            parity ^= 1
-
-        return file_list
-
-
-    _BADCHARS_RE = re.compile(ur'[\x00-\x08\x0b\x0e-\x1f]')
-
-    def annotate_file(self, file_id, revid):
-        z = time.time()
-        lineno = 1
-        parity = 0
-
-        file_revid = self.get_inventory(revid)[file_id].revision
-        oldvalues = None
-        tree = self._branch.repository.revision_tree(file_revid)
-        revid_set = set()
-
-        for line_revid, text in tree.annotate_iter(file_id):
-            revid_set.add(line_revid)
-            if self._BADCHARS_RE.match(text):
-                # bail out; this isn't displayable text
-                yield util.Container(parity=0, lineno=1, status='same',
-                                     text='(This is a binary file.)',
-                                     change=util.Container())
-                return
-        change_cache = dict([(c.revid, c) \
-                for c in self.get_changes(list(revid_set))])
-
-        last_line_revid = None
-        for line_revid, text in tree.annotate_iter(file_id):
-            if line_revid == last_line_revid:
-                # remember which lines have a new revno and which don't
-                status = 'same'
-            else:
-                status = 'changed'
-                parity ^= 1
-                last_line_revid = line_revid
-                change = change_cache[line_revid]
-                trunc_revno = change.revno
-                if len(trunc_revno) > 10:
-                    trunc_revno = trunc_revno[:9] + '...'
-
-            yield util.Container(parity=parity, lineno=lineno, status=status,
-                                 change=change, text=util.fixed_width(text))
-            lineno += 1
-
-        self.log.debug('annotate: %r secs' % (time.time() - z,))
+            ),
+            text_changes: list((filename, file_id)),
+        """
+        repo = self._branch.repository
+        if (bzrlib.revision.is_null(old_revid) or
+            bzrlib.revision.is_null(new_revid) or
+            old_revid == new_revid):
+            old_tree, new_tree = map(
+                repo.revision_tree, [old_revid, new_revid])
+        else:
+            old_tree, new_tree = repo.revision_trees([old_revid, new_revid])
+
+        reporter = FileChangeReporter(old_tree.inventory, new_tree.inventory)
+
+        bzrlib.delta.report_changes(new_tree.iter_changes(old_tree), reporter)
+
+        return util.Container(
+            added=sorted(reporter.added, key=lambda x: x.filename),
+            renamed=sorted(reporter.renamed, key=lambda x: x.new_filename),
+            removed=sorted(reporter.removed, key=lambda x: x.filename),
+            modified=sorted(reporter.modified, key=lambda x: x.filename),
+            text_changes=sorted(reporter.text_changes,
+                                key=lambda x: x.filename))
+

=== added file 'loggerhead/load_test.py'
--- loggerhead/load_test.py	1970-01-01 00:00:00 +0000
+++ loggerhead/load_test.py	2011-03-02 14:07:21 +0000
@@ -0,0 +1,230 @@
+# Copyright 2011 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Code to do some load testing against a loggerhead instance.
+
+This is basically meant to take a list of actions to take, and run it against a
+real host, and see how the results respond.::
+
+    {"parameters": {
+         "base_url": "http://localhost:8080",
+     },
+     "requests": [
+        {"thread": "1", "relpath": "/changes"},
+        {"thread": "1", "relpath": "/changes"},
+        {"thread": "1", "relpath": "/changes"},
+        {"thread": "1", "relpath": "/changes"}
+     ],
+    }
+
+All threads have a Queue length of 1. When a third request for a given thread
+is seen, no more requests are queued until that thread finishes its current
+job. So this results in all requests being issued sequentially::
+
+        {"thread": "1", "relpath": "/changes"},
+        {"thread": "1", "relpath": "/changes"},
+        {"thread": "1", "relpath": "/changes"},
+        {"thread": "1", "relpath": "/changes"}
+
+While this would cause all requests to be sent in parallel:
+
+        {"thread": "1", "relpath": "/changes"},
+        {"thread": "2", "relpath": "/changes"},
+        {"thread": "3", "relpath": "/changes"},
+        {"thread": "4", "relpath": "/changes"}
+
+This should keep 2 threads pipelined with activity, as long as they finish in
+approximately the same speed. We'll start the first thread running, and the
+second thread, and queue up both with a second request once the first finishes.
+When we get to the third request for thread "1", we block on queuing up more
+work until the first thread 1 request has finished.
+        {"thread": "1", "relpath": "/changes"},
+        {"thread": "2", "relpath": "/changes"},
+        {"thread": "1", "relpath": "/changes"},
+        {"thread": "2", "relpath": "/changes"},
+        {"thread": "1", "relpath": "/changes"},
+        {"thread": "2", "relpath": "/changes"}
+
+There is not currently a way to say "run all these requests keeping exactly 2
+threads active". Though if you know the load pattern, you could approximate
+this.
+"""
+
+import threading
+import time
+import Queue
+
+import simplejson
+
+from bzrlib import (
+    errors,
+    transport,
+    urlutils,
+    )
+
+# This code will be doing multi-threaded requests against bzrlib.transport
+# code. We want to make sure to load everything ahead of time, so we don't get
+# lazy-import failures
+_ = transport.get_transport('http://example.com')
+
+
+class RequestDescription(object):
+    """Describes info about a request."""
+
+    def __init__(self, descrip_dict):
+        self.thread = descrip_dict.get('thread', '1')
+        self.relpath = descrip_dict['relpath']
+
+
+class RequestWorker(object):
+    """Process requests in a worker thread."""
+
+    _timer = time.time
+
+    def __init__(self, identifier, blocking_time=1.0, _queue_size=1):
+        self.identifier = identifier
+        self.queue = Queue.Queue(_queue_size)
+        self.start_time = self.end_time = None
+        self.stats = []
+        self.blocking_time = blocking_time
+
+    def step_next(self):
+        url = self.queue.get(True, self.blocking_time)
+        if url == '<noop>':
+            # This is usually an indicator that we want to stop, so just skip
+            # this one.
+            self.queue.task_done()
+            return
+        self.start_time = self._timer()
+        success = self.process(url)
+        self.end_time = self._timer()
+        self.update_stats(url, success)
+        self.queue.task_done()
+
+    def run(self, stop_event):
+        while not stop_event.isSet():
+            try:
+                self.step_next()
+            except Queue.Empty:
+                pass
+
+    def process(self, url):
+        base, path = urlutils.split(url)
+        t = transport.get_transport(base)
+        try:
+            # TODO: We should probably look into using some part of
+            #       blocking_timeout to decide when to stop trying to read
+            #       content
+            content = t.get_bytes(path)
+        except (errors.TransportError, errors.NoSuchFile):
+            return False
+        return True
+
+    def update_stats(self, url, success):
+        self.stats.append((url, success, self.end_time - self.start_time))
+
+
+class ActionScript(object):
+    """This tracks the actions that we want to perform."""
+
+    _worker_class = RequestWorker
+    _default_base_url = 'http://localhost:8080'
+    _default_blocking_timeout = 60.0
+
+    def __init__(self):
+        self.base_url = self._default_base_url
+        self.blocking_timeout = self._default_blocking_timeout
+        self._requests = []
+        self._threads = {}
+        self.stop_event = threading.Event()
+
+    @classmethod
+    def parse(cls, content):
+        script = cls()
+        json_dict = simplejson.loads(content)
+        if 'parameters' not in json_dict:
+            raise ValueError('Missing "parameters" section')
+        if 'requests' not in json_dict:
+            raise ValueError('Missing "requests" section')
+        param_dict = json_dict['parameters']
+        request_list = json_dict['requests']
+        base_url = param_dict.get('base_url', None)
+        if base_url is not None:
+            script.base_url = base_url
+        blocking_timeout = param_dict.get('blocking_timeout', None)
+        if blocking_timeout is not None:
+            script.blocking_timeout = blocking_timeout
+        for request_dict in request_list:
+            script.add_request(request_dict)
+        return script
+
+    def add_request(self, request_dict):
+        request = RequestDescription(request_dict)
+        self._requests.append(request)
+
+    def _get_worker(self, thread_id):
+        if thread_id in self._threads:
+            return self._threads[thread_id][0]
+        handler = self._worker_class(thread_id,
+                                     blocking_time=self.blocking_timeout/10.0)
+
+        t = threading.Thread(target=handler.run, args=(self.stop_event,),
+                             name='Thread-%s' % (thread_id,))
+        self._threads[thread_id] = (handler, t)
+        t.start()
+        return handler
+
+    def finish_queues(self):
+        """Wait for all queues of all children to finish."""
+        for h, t in self._threads.itervalues():
+            h.queue.join()
+
+    def stop_and_join(self):
+        """Stop all running workers, and return.
+
+        This will stop even if workers still have work items.
+        """
+        self.stop_event.set()
+        for h, t in self._threads.itervalues():
+            # Signal the queue that it should stop blocking, we don't have to
+            # wait for the queue to empty, because we may see stop_event before
+            # we see the <noop>
+            h.queue.put('<noop>')
+            # And join the controlling thread
+            for i in range(10):
+                t.join(self.blocking_timeout / 10.0)
+                if not t.isAlive():
+                    break
+
+    def _full_url(self, relpath):
+        return self.base_url + relpath
+
+    def run(self):
+        self.stop_event.clear()
+        for request in self._requests:
+            full_url = self._full_url(request.relpath)
+            worker = self._get_worker(request.thread)
+            worker.queue.put(full_url, True, self.blocking_timeout)
+        self.finish_queues()
+        self.stop_and_join()
+
+
+def run_script(filename):
+    with open(filename, 'rb') as f:
+        content = f.read()
+    script = ActionScript.parse(content)
+    script.run()
+    return script

=== removed file 'loggerhead/lockfile.py'
--- loggerhead/lockfile.py	2008-02-27 03:36:09 +0000
+++ loggerhead/lockfile.py	1970-01-01 00:00:00 +0000
@@ -1,82 +0,0 @@
-#
-# Copyright (C) 2006  Robey Pointer <robey@lag.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-import os
-import threading
-import time
-
-from loggerhead import util
-
-
-with_lock = util.with_lock('_tlock', 'LockFile')
-
-MAX_STALE_TIME = 5 * 60
-
-
-class LockFile (object):
-    """
-    simple lockfile implementation that mimics the API of threading.Lock, so
-    it can be used interchangably.  it's actually a reentrant lock, so the
-    lock may be acquired multiple times by the same thread, as long as it's
-    released an equal number of times.  unlike threading.Lock, this lock can
-    be used across processes.
-
-    this uses os.open(O_CREAT|O_EXCL), which apparently works even on windows,
-    but will not work over NFS, if anyone still uses that.  so don't put the
-    cache folder on an NFS server...
-    """
-
-    def __init__(self, filename):
-        self._filename = filename
-        # thread lock to maintain internal consistency
-        self._tlock = threading.Lock()
-        self._count = 0
-        if os.path.exists(filename):
-            # remove stale locks left over from a previous run
-            if time.time() - os.stat(filename).st_mtime > MAX_STALE_TIME:
-                os.remove(filename)
-
-    @with_lock
-    def _try_acquire(self):
-        if self._count > 0:
-            self._count += 1
-            return True
-        try:
-            fd = os.open(self._filename, os.O_WRONLY | os.O_CREAT | os.O_EXCL, 0600)
-            os.close(fd)
-            self._count += 1
-            return True
-        except OSError:
-            return False
-
-    def acquire(self):
-        # try over and over, sleeping on exponential backoff with an upper limit of about 5 seconds
-        pause = 0.1
-        #max_pause = 5.0
-        max_pause = 0.1
-        while True:
-            if self._try_acquire():
-                return
-            time.sleep(pause)
-            pause = min(pause * 2.0, max_pause)
-
-    @with_lock
-    def release(self):
-        self._count -= 1
-        if self._count == 0:
-            os.remove(self._filename)

=== modified file 'loggerhead/lsprof.py'
--- loggerhead/lsprof.py	2008-07-26 14:52:44 +0000
+++ loggerhead/lsprof.py	2009-07-07 23:52:24 +0000
@@ -26,7 +26,7 @@
 
 
 def profile(f, *args, **kwds):
-    """XXX docstring"""
+    """FIXME: docstring"""
     global _g_threadmap
     p = Profiler()
     p.enable(subcalls=True)
@@ -47,16 +47,16 @@
 
 
 class Stats(object):
-    """XXX docstring"""
+    """FIXME: docstring"""
 
     def __init__(self, data, threads):
         self.data = data
         self.threads = threads
 
     def sort(self, crit="inlinetime"):
-        """XXX docstring"""
+        """FIXME: docstring"""
         if crit not in profiler_entry.__dict__:
-            raise ValueError, "Can't sort by %s" % crit
+            raise ValueError("Can't sort by %s" % crit)
         self.data.sort(lambda b, a: cmp(getattr(a, crit),
                                         getattr(b, crit)))
         for e in self.data:
@@ -65,7 +65,7 @@
                                               getattr(b, crit)))
 
     def pprint(self, top=None, file=None):
-        """XXX docstring"""
+        """FIXME: docstring"""
         if file is None:
             file = sys.stdout
         d = self.data
@@ -73,7 +73,6 @@
             d = d[:top]
         cols = "% 12s %12s %11.4f %11.4f   %s\n"
         hcols = "% 12s %12s %12s %12s %s\n"
-        cols2 = "+%12s %12s %11.4f %11.4f +  %s\n"
         file.write(hcols % ("CallCount", "Recursive", "Total(ms)",
                             "Inline(ms)", "module:lineno(function)"))
         for e in d:
@@ -93,12 +92,12 @@
         for i in range(len(self.data)):
             e = self.data[i]
             if not isinstance(e.code, str):
-                self.data[i] = type(e)((label(e.code),) + e[1:])
+                self.data[i] = type(e)((label(e.code)) + e[1:])
             if e.calls:
                 for j in range(len(e.calls)):
                     se = e.calls[j]
                     if not isinstance(se.code, str):
-                        e.calls[j] = type(se)((label(se.code),) + se[1:])
+                        e.calls[j] = type(se)((label(se.code)) + se[1:])
         for s in self.threads.values():
             s.freeze()
 
@@ -125,15 +124,15 @@
         for entry in self.data:
             totaltime = int(entry.totaltime * 1000)
             max_cost = max(max_cost, totaltime)
-        print >> self.out_file, 'summary: %d' % (max_cost,)
+        print >> self.out_file, 'summary: %d' % (max_cost)
 
     def _entry(self, entry):
         out_file = self.out_file
         code = entry.code
         inlinetime = int(entry.inlinetime * 1000)
         #print >> out_file, 'ob=%s' % (code.co_filename,)
-        print >> out_file, 'fi=%s' % (code.co_filename,)
-        print >> out_file, 'fn=%s' % (label(code, True),)
+        print >> out_file, 'fi=%s' % (code.co_filename)
+        print >> out_file, 'fn=%s' % (label(code, True))
         print >> out_file, '%d %d' % (code.co_firstlineno, inlinetime)
         # recursive calls are counted in entry.calls
         if entry.calls:
@@ -149,8 +148,8 @@
         code = subentry.code
         totaltime = int(subentry.totaltime * 1000)
         #print >> out_file, 'cob=%s' % (code.co_filename,)
-        print >> out_file, 'cfn=%s' % (label(code, True),)
-        print >> out_file, 'cfi=%s' % (code.co_filename,)
+        print >> out_file, 'cfn=%s' % (label(code, True))
+        print >> out_file, 'cfi=%s' % (code.co_filename)
         print >> out_file, 'calls=%d %d' % (
             subentry.callcount, code.co_firstlineno)
         print >> out_file, '%d %d' % (lineno, totaltime)
@@ -158,6 +157,7 @@
 
 _fn2mod = {}
 
+
 def label(code, calltree=False):
     if isinstance(code, str):
         return code

=== renamed file 'serve-branches' => 'loggerhead/main.py' (properties changed: +x to -x)
--- serve-branches	2008-08-01 04:42:14 +0000
+++ loggerhead/main.py	2011-03-16 11:39:27 +0000
@@ -1,4 +1,6 @@
-#!/usr/bin/env python
+#
+# Copyright (C) 2008, 2009 Canonical Ltd
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -19,78 +21,169 @@
 import os
 import sys
 
-from optparse import OptionParser
+from bzrlib.plugin import load_plugins
 
 from paste import httpserver
-from paste.httpexceptions import HTTPExceptionHandler
+from paste.httpexceptions import HTTPExceptionHandler, HTTPInternalServerError
 from paste.translogger import TransLogger
 
 from loggerhead import __version__
-from loggerhead.apps.filesystem import (
-    BranchesFromFileSystemRoot, UserBranchesFromFileSystemRoot)
-
-
-def command_line_parser():
-    parser = OptionParser("%prog [options] <path>")
-    parser.set_defaults(
-        user_dirs=False,
-        show_version=False,
-        )
-    parser.add_option("--user-dirs", action="store_true", dest="user_dirs",
-                      help="Serve user directories as ~user.")
-    parser.add_option("--trunk-dir", metavar="DIR",
-                      help="The directory that contains the trunk branches.")
-    parser.add_option("--version", action="store_true", dest="show_version",
-                      help="Print the software version and exit")
-    return parser
-
-
-def main(args):
-    logging.basicConfig()
-    logging.getLogger().setLevel(logging.DEBUG)
-
-    parser = command_line_parser()
-    (options, args) = parser.parse_args(sys.argv[1:])
-
-    if options.show_version:
-        print "loggerhead %s" % __version__
+from loggerhead.apps.transport import (
+    BranchesFromTransportRoot, UserBranchesFromTransportRoot)
+from loggerhead.config import LoggerheadConfig
+from loggerhead.util import Reloader
+from loggerhead.apps.error import ErrorHandlerApp
+
+
+def get_config_and_path(args):
+    config = LoggerheadConfig(args)
+
+    if config.get_option('show_version'):
+        print "loggerhead %s" % (__version__,)
         sys.exit(0)
 
-    if len(args) > 1:
-        parser.print_help()
-        sys.exit(1)
-    elif len(args) == 1:
-        [path] = args
-    else:
-        path = '.'
-
-    if not os.path.isdir(path):
-        print "%s is not a directory" % path
-        sys.exit(1)
-
-    if options.trunk_dir and not options.user_dirs:
+    if config.arg_count > 1:
+        config.print_help()
+        sys.exit(1)
+    elif config.arg_count == 1:
+        base = config.get_arg(0)
+    else:
+        base = '.'
+
+    if not config.get_option('allow_writes'):
+        base = 'readonly+' + base
+
+    return config, base
+
+
+def setup_logging(config, init_logging=True, log_file=None):
+    log_level = config.get_log_level()
+    if init_logging:
+        logging.basicConfig()
+        if log_level is not None:
+            logging.getLogger('').setLevel(log_level)
+    logger = logging.getLogger('loggerhead')
+    if log_level is not None:
+        logger.setLevel(log_level)
+    if log_file is not None:
+        handler = logging.StreamHandler(log_file)
+    else:
+        if config.get_option('log_folder'):
+            logfile_path = os.path.join(
+                config.get_option('log_folder'), 'serve-branches.log')
+        else:
+            logfile_path = 'serve-branches.log'
+        handler = logging.FileHandler(logfile_path, 'a')
+        formatter = logging.Formatter('%(asctime)s %(levelname)-8s %(name)s:'
+                                      ' %(message)s')
+        handler.setFormatter(formatter)
+    # We set the handler to accept all messages, the *logger* won't emit them
+    # if it is configured to suppress it
+    handler.setLevel(logging.DEBUG)
+    logger.addHandler(handler)
+    def _restrict_logging(logger_name):
+        logger = logging.getLogger(logger_name)
+        if logger.getEffectiveLevel() < logging.INFO:
+            logger.setLevel(logging.INFO)
+    # simpleTAL is *very* verbose in DEBUG mode, which is otherwise the
+    # default. So quiet it up a bit.
+    _restrict_logging('simpleTAL')
+    _restrict_logging('simpleTALES')
+    return logger
+
+
+def make_app_for_config_and_path(config, base):
+    if config.get_option('trunk_dir') and not config.get_option('user_dirs'):
         print "--trunk-dir is only valid with --user-dirs"
         sys.exit(1)
 
-    if options.user_dirs:
-        if not options.trunk_dir:
+    if config.get_option('reload'):
+        if Reloader.is_installed():
+            Reloader.install()
+        else:
+            return Reloader.restart_with_reloader()
+
+    if config.get_option('user_dirs'):
+        if not config.get_option('trunk_dir'):
             print "You didn't specify a directory for the trunk directories."
             sys.exit(1)
-        app = UserBranchesFromFileSystemRoot(path, options.trunk_dir)
-    else:
-        app = BranchesFromFileSystemRoot(path)
-    app = HTTPExceptionHandler(app)
-    app = TransLogger(app)
+        app = UserBranchesFromTransportRoot(base, config)
+    else:
+        app = BranchesFromTransportRoot(base, config)
+
+    setup_logging(config)
+
+    if config.get_option('profile'):
+        from loggerhead.middleware.profile import LSProfMiddleware
+        app = LSProfMiddleware(app)
+    if config.get_option('memory_profile'):
+        from dozer import Dozer
+        app = Dozer(app)
+
+    if not config.get_option('user_prefix'):
+        prefix = '/'
+    else:
+        prefix = config.get_option('user_prefix')
+        if not prefix.startswith('/'):
+            prefix = '/' + prefix
 
     try:
         from paste.deploy.config import PrefixMiddleware
     except ImportError:
-        pass
-    else:
-        app = PrefixMiddleware(app)
-
-    httpserver.serve(app, host='0.0.0.0', port='8080')
-
-
-if __name__ == "__main__":
-    main(sys.argv)
+        cant_proxy_correctly_message = (
+            'Unsupported configuration: PasteDeploy not available, but '
+            'loggerhead appears to be behind a proxy.')
+        def check_not_proxied(app):
+            def wrapped(environ, start_response):
+                if 'HTTP_X_FORWARDED_SERVER' in environ:
+                    exc = HTTPInternalServerError()
+                    exc.explanation = cant_proxy_correctly_message
+                    raise exc
+                return app(environ, start_response)
+            return wrapped
+        app = check_not_proxied(app)
+    else:
+        app = PrefixMiddleware(app, prefix=prefix)
+
+    app = HTTPExceptionHandler(app)
+    app = ErrorHandlerApp(app)
+    app = TransLogger(app, logger=logging.getLogger('loggerhead'))
+
+    return app
+
+
+def main(args):
+    load_plugins()
+
+    config, path = get_config_and_path(args)
+
+    app = make_app_for_config_and_path(config, path)
+
+    if not config.get_option('user_port'):
+        port = '8080'
+    else:
+        port = config.get_option('user_port')
+
+    if not config.get_option('user_host'):
+        host = '0.0.0.0'
+    else:
+        host = config.get_option('user_host')
+
+    if not config.get_option('protocol'):
+        protocol = 'http'
+    else:
+        protocol = config.get_option('protocol')
+
+    if protocol == 'http':
+        httpserver.serve(app, host=host, port=port)
+    else:
+        if protocol == 'fcgi':
+            from flup.server.fcgi import WSGIServer
+        elif protocol == 'scgi':
+            from flup.server.scgi import WSGIServer
+        elif protocol == 'ajp':
+            from flup.server.ajp import WSGIServer
+        else:
+            print 'Unknown protocol: %s.' % (protocol)
+            sys.exit(1)
+        WSGIServer(app, bindAddress=(host, int(port))).run()

=== added directory 'loggerhead/middleware'
=== added file 'loggerhead/middleware/__init__.py'
=== added file 'loggerhead/middleware/profile.py'
--- loggerhead/middleware/profile.py	1970-01-01 00:00:00 +0000
+++ loggerhead/middleware/profile.py	2009-10-17 08:47:38 +0000
@@ -0,0 +1,33 @@
+"""Profiling middleware for Paste."""
+
+import threading
+
+from bzrlib.lsprof import profile
+
+
+class LSProfMiddleware(object):
+    """Paste middleware for profiling with lsprof."""
+
+    def __init__(self, app, global_conf=None):
+        self.app = app
+        self.lock = threading.Lock()
+        self.__count = 0
+
+    def __run_app(self, environ, start_response):
+        app_iter = self.app(environ, start_response)
+        try:
+            return list(app_iter)
+        finally:
+            if getattr(app_iter, 'close', None):
+                app_iter.close()
+
+    def __call__(self, environ, start_response):
+        """Run a request."""
+        self.lock.acquire()
+        try:
+            ret, stats = profile(self.__run_app, environ, start_response)
+            self.__count += 1
+            stats.save("%d-stats.callgrind" % (self.__count,), format="callgrind")
+            return ret
+        finally:
+            self.lock.release()

=== modified file 'loggerhead/search.py'
--- loggerhead/search.py	2008-07-26 17:41:49 +0000
+++ loggerhead/search.py	2009-04-17 03:38:04 +0000
@@ -17,25 +17,31 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-import sets
-import os
-try:
-    from bzrlib.plugins.search import errors
-    from bzrlib.plugins.search import index as _mod_index
-    from bzrlib.plugins.search.index import FileTextHit, RevisionHit
-except ImportError:
-    _mod_index = None
+
+_mod_index = None
+def import_search():
+    global errors, _mod_index, FileTextHit, RevisionHit
+    if _mod_index is not None:
+        return
+    try:
+        from bzrlib.plugins.search import errors
+        from bzrlib.plugins.search import index as _mod_index
+        from bzrlib.plugins.search.index import FileTextHit, RevisionHit
+    except ImportError:
+        _mod_index = None
+
 
 def search_revisions(branch, query_list, suggest=False):
     """
     Search using bzr-search plugin to find revisions matching the query.
     This can either suggest query terms, or revision ids.
-    
+
     param branch: branch object to search in
     param query_list: string to search
     param suggest: Optional flag to request suggestions instead of results
     return: A list for results, either revision ids or terms
     """
+    import_search()
     if _mod_index is None:
         return None # None indicates could-not-search
     try:
@@ -59,6 +65,6 @@
                     revid_list.append(result.text_key[1])
                 elif isinstance(result, RevisionHit):
                     revid_list.append(result.revision_key[0])
-            return list(sets.Set(revid_list))
+            return list(set(revid_list))
     finally:
         index._branch.unlock()

=== modified file 'loggerhead/static/css/diff.css'
--- loggerhead/static/css/diff.css	2008-07-24 22:07:40 +0000
+++ loggerhead/static/css/diff.css	2011-02-18 05:41:17 +0000
@@ -1,137 +1,113 @@
 /*Info Box*/
-#infoContainer {
-	width:970px;
-	padding:10px 10px 0px 10px;
-	margin:0px 0px 10px 0px;
-	color:#666;
-	background:#fcfcfc url(../images/bg_infobox.gif) repeat-y top right;
-	border:1px solid #b7b7b7;
-}
+.infoContainer {
+    width: 970px;
+    padding: 10px 10px 0 10px;
+    margin: 0 0 10px 0;
+    color: #666;
+    background: #fcfcfc url(../images/bg_infobox.gif) repeat-y top right;
+    border: 1px solid #b7b7b7;
+    }
 ul#list-files {
-	float:right;
-	width:460px;
-	list-style:none;
-	margin:0px;
-	padding:0px;
-	font:normal 11px/normal sans-serif;
-	color:#000;
-}
+    float: right;
+    width: 460px;
+    font-size: 77%;
+    color: #000;
+    }
 ul#list-files li {
-	width:440px;
-	padding:2px 0px 2px 20px;
-	margin:0px 0px 2px 8px;
-	background:url(../images/ico_file.gif) 2px 0px no-repeat;
-}
+    width: 440px;
+    padding: 2px 0 2px 20px;
+    margin: 0 0 2px 8px;
+    background: url(../images/ico_file.gif) 2px 0 no-repeat;
+    }
 ul#list-files li.desc {
     margin-left: 0;
-	background:url(../images/ico_description.gif) 0px 0px no-repeat;
-}
+    background: url(../images/ico_description.gif) 0 0 no-repeat;
+    }
 #infTxt {
-	float:left;
-	width:493px;
-	margin:0px 0px 5px 0px;
-}
-.information, .comiter, .timer, .mfrom, .mto, .revid {
-	clear:both;
-	margin:0px;
-	padding:0px 0px 2px 18px;
-	font:normal 11px/1.3 sans-serif;
-	color:#666;
-	background:url(../images/ico_description.gif) no-repeat top left;
-}
-.revid {
-    padding:1px 0px 0px 18px;
-    margin:0px 10px 5px 0px;
-}
-.comiter, .mfrom, .mto {
-	color:#000;
-	padding:1px 0px 0px 18px;
-	margin:0px 10px 5px 0px;
-	float:left;
-	display:inline;
-	background:url(../images/ico_committer.gif) no-repeat 2px 0px;
-}
-.timer {
-	margin:0px 10px 5px 0px;
-	padding:1px 0px 0px 18px;
-	float:left;
-	clear:none;
-	display:inline;
-	background:url(../images/ico_time.gif) no-repeat top left;
-}
-.mfrom {
-	background:url(../images/ico_mergefrom.gif) no-repeat top left;
-}
-.mto {
-	background:url(../images/ico_mergeto.gif) no-repeat top left;
-}
-/**/
-#loggerheadCont p.expand, #loggerheadCont p.expand a, #loggerheadCont p.expand a:link, #loggerheadCont p.expand a:visited, #loggerheadCont p.expand a:hover {
-	color:#0f6b97;
-	text-decoration:none;
-	margin-right:10px;
-	float:left;	
-}
-#loggerheadCont p.codin, #loggerheadCont p.codin a, #loggerheadCont p.codin a:link, #loggerheadCont p.codin a:visited, #loggerheadCont p.codin a:hover {
-	color:#000;
-	font-size:12px;
-	text-decoration:none;
-	margin-right:10px;
-	float:left;	
-}
+    float: left;
+    width: 493px;
+    margin: 0 0 5px 0;
+    font-size:  77%;
+    color: #666;
+    }
 /*Diff Boxes*/
 .diffBox {
-	width:100%;
-	padding:6px 0%;
-	background:#eef6fa;
-	border:1px solid #d2d2d2;
-	margin:10px 0px 0px 0px;
-}
+    width: 100%;
+    padding: 6px 0;
+    background: #eef6fa;
+    border: 1px solid #d2d2d2;
+    margin: 10px 0 0 0;
+    }
 .diffBox img {
-	vertical-align:middle;
-}
-.diffBox a, .diffBox a:link, .diffBox a:visited, .diffBox a:hover {
-	text-decoration:none;
-}
+    vertical-align: middle;
+    }
+.diffBox a {
+    text-decoration: none;
+    }
 .diff {
-    margin: 2em 0 2em 0;
-}
-.lineNumber {
-	float:left;
-	width:2%;
-	padding:0px 1%; 
-	border-right:1px solid #d5d5d5;
-	border-left:1px solid #d5d5d5;
-	color:#000;
-	background:#f8fbfd;
-	font:normal 12px/1.8 monospace;
-	text-align:right;
-}
-.lineCode, .removecode, .addcode {
-	float:left;
-	width:43%;
-	padding:0px 1%; 
-	color:#000;
-	background:#fff;
-	font:normal 12px/1.8 monospace;
-}
-.delete, .insert {
-	display:block;
-	background:#ff7f7f;
-}
-.insert {
-	background:#92ed92;
-}
+    margin: 2em 0;
+    }
+.diffinfo {
+    overflow: hidden;
+    }
+.lineNumber {
+    width: 2%;
+    border-width: 0 1px;
+    border-style: solid;
+    border-color: #d5d5d5;
+    background: #f8fbfd;
+    text-align: right;
+    }
+.unified .lineNumber.second {
+    border-left: 0;
+    }
+.code,
+.lineNumber {
+    float: left;
+    padding: 0 1%;
+    color: #000;
+    font-size: 85%;
+    font-family: 'UbuntuBeta Mono', 'Ubuntu Mono', monospace;
+    line-height: 180%;
+    }
+.blank {
+    float: left;
+    padding: 0 1%;
+    }
+.unified .code {
+    width: 89%;
+    }
+.sbs .code,
+.blank {
+    width: 43%;
+    overflow: hidden;
+    }
+.unified .insert-row .lineNumber.first {
+    background: #c9ffc9;
+    }
+.unified .delete-row .lineNumber.second {
+    background: #ffbfbf;
+    }
+.code.insert,
+.insert-row .lineNumber.second,
+.both-row .lineNumber.second {
+    background: #92ed92;
+    }
+.code.delete,
+.delete-row .lineNumber.first,
+.both-row .lineNumber.first {
+    background: #ff7f7f;
+    }
 .separate {
     height: 2em;
     background: #e3e3e3;
-}
+    }
 ul#pages {
-	margin-top:10px;
-}
+    margin-top: 10px;
+    }
 /*Foot Links*/
 #loggerheadCont p.lpandbzr {
-	float:left;
-	padding:3px 0px 0px 0px;
-	margin-top:10px;
-}
+    float: left;
+    padding: 3px 0 0 0;
+    margin-top: 10px;
+    }

=== modified file 'loggerhead/static/css/files.css'
--- loggerhead/static/css/files.css	2008-07-24 00:47:13 +0000
+++ loggerhead/static/css/files.css	2011-02-18 05:41:17 +0000
@@ -1,49 +1,5 @@
-/*Info Box*/
-#infoContainer {
-	width:900px;
-	padding:10px 10px 0px 10px;
-	margin:0px 0px 10px 0px;
-	color:#666;
-	background:#fcfcfc;
-	border:1px solid #b7b7b7;
-}
-.information, .comiter, .timer, .mfrom, .mto, .revid {
-	float:left;
-	margin:0px 10px 5px 0px;
-	padding:0px 0px 2px 18px;
-	font:normal 11px/1.3 sans-serif;
-	color:#666;
-	background:url(../images/ico_description.gif) no-repeat top left;
-}
-.revid {
-    float:left;
-    padding:1px 0px 0px 18px;
-    margin:0px 10px 5px 0px;
-}
-.comiter, .mfrom, .mto {
-	color:#000;
-	padding:1px 0px 0px 18px;
-	margin:0px 10px 5px 0px;
-	float:left;
-	display:inline;
-	background:url(../images/ico_committer.gif) no-repeat 2px 0px;
-}
-.timer {
-	margin:0px 10px 5px 0px;
-	padding:1px 0px 0px 18px;
-	float:left;
-	clear:none;
-	display:inline;
-	background:url(../images/ico_time.gif) no-repeat top left;
-}
-.mfrom {
-	background:url(../images/ico_mergefrom.gif) no-repeat top left;
-}
-.mto {
-	background:url(../images/ico_mergetop.gif) no-repeat top left;
-}
-.information {
-    clear:both;
-    width:100%;
-    position:relative;
-}
+#infTxt {
+    font-size: 77%;
+    color: #666;
+    margin-bottom: 10px;
+    }

=== modified file 'loggerhead/static/css/global.css'
--- loggerhead/static/css/global.css	2008-08-05 06:17:12 +0000
+++ loggerhead/static/css/global.css	2011-11-23 17:21:39 +0000
@@ -1,321 +1,410 @@
+/*
+    CSS Structure
+    - Reset and Generic Styles
+    - Header & Navigation
+        - Loggerhead Menu Tabs
+        - Sub-menu Tabs
+        - Breadcrumbs
+    - Search & RSS 
+    - General Content
+    - Log Table
+    - Revision List
+    - Pagination
+    - Footer
+*/
+
+
+/* =========================
+   Reset and Generic Styles
+*/
+body, img, form, tr, ul, li, h1, h2, h3, h4, p, table {
+    padding: 0;
+    margin: 0;
+    }
+body, html, table {
+    font-size: 93%;
+    }
 body {
-	padding:0px;
-	margin:0px;
-	font:normal 12px/normal sans-serif;
-	color:#666;
-	background:#fff;
-}
-a, a:link, a:visited, a:hover {
-	color:#0f597f;
-	text-decoration:none;
-	font-weight:normal;
-	outline:none;
-}
+    font-weight: normal;
+    font-family: UbuntuBeta, Ubuntu, 'Bitstream Vera Sans', 'DejaVu Sans', Tahoma, sans-serif;
+    color: #000;
+    background: #fff;
+    }
+a {
+    color: #03A;
+    text-decoration: none;
+    }
+a:hover {
+    text-decoration: underline;
+    }
 img {
-	padding:0px;
-	margin:0px;
-	border:0px;
-	outline:none;
-}
-form {
-  margin: 0;
-  padding: 0;
-}
-tr td {
-  vertical-align: top;
-}
+    border: 0;
+    outline: none;
+    }
 .clear {
-	clear:both;
-	font-size:0px;
-	height:0px;
-}
-.fr {float:right;}
-.fl {float:left;}
-
+    clear: both;
+    font-size: 0;
+    height: 0;
+    }
+.fr {
+    float: right;
+    }
+.fl {
+    float: left;
+    }
 ul {
-    list-style:none;
+    list-style: none;
+    }
+table {
+    caption-side: top;
+    width: 100%;
+    border: none;
+    border-spacing: 0;
+    border-collapse: collapse;
+    }
+tr td {
+    vertical-align: top;
+    }
+th, td {
+    border-color: #D2D2D2;
+    }
+th {
+    text-align: left;
+    color: #5A5A5A;
+    padding: 4px 8px;
+    border-width: 1px;
+    border-style: solid;
+    }
+td {
+    padding: 4px 4px;
+    border-width: 0 0 1px 0;
+    border-style: dotted;
+    }
+h1 {
+    font-size:138.5%;
+    padding: 10px 0 5px 0;
+    }
+h2 {
+    font-size: 123.1%;
+    padding: 10px 0 5px 0;
+    }
+p {
+    padding: 5px 0;
+    }
+p img {
+    vertical-align: middle;
+    }
+
+
+/* =========================
+   Header & Navigation
+*/
+
+.black-link {
+    border-bottom: 1px solid #D2D2D2;
+    padding: 6px 1% 8px 1%;
+    font-size: 85%;
 }
 
-/* Loggerhead Menu tabs */
+/* Branch Title */
+h1.branch-name {
+    font-size: 131%;
+    padding: 0;
+    margin: 20px 0 0 1%;
+    }
+
+/* Loggerhead Menu Tabs */
 ul#menuTabs {
-	width:98%;
-	height:33px;
-	list-style:none;
-	color:#fff;
-	background:#fff url(../images/bg_menuTabs.gif) bottom repeat-x;
-	margin:0px;
-	padding:12px 0px 0px 2%;
-}
-ul#menuTabs li a:link, ul#menuTabs li a:visited {
-	float:left;
-	width:93px;
-	padding:10px 0px 0px 0px;
-	height:23px;
-	font:normal 14px/1.5 sans-serif;
-	text-align:center;
-	color:#fff;
-	text-decoration:none;
-	background:#ad2001 url(../images/bg_Tabs.gif) bottom center;
-}
+    height: 33px;
+    color: #fff;
+    margin: 0;
+    padding: 15px 20px 0 1%;
+    }
 ul#menuTabs li {
-	float:left;
-	color:#fff;
-	background:#f00 url(../images/bg_Tabs.gif) bottom center;
-}
+    float: left;
+    padding: 0 7px 0 0;
+    }
+ul#menuTabs li a {
+    padding: 3px 6px;
+    color: #000;
+    }
 ul#menuTabs li a:hover {
-	float:left;
-	color:#000;
-	background:#666 url(../images/bg_Tabs.gif) top center;
-	text-decoration:none;
-}
-ul#menuTabs li a#on:link, ul#menuTabs li a#on:visited, ul#menuTabs a#on:hover {
-	float:left;
-	color:#000;
-	background:#666 url(../images/bg_Tabs.gif) top center;
-	text-decoration:none;
-}
-/*Sub menu tabs*/
+    background-color: #f3f3f3;
+    text-decoration: none;
+    }
+ul#menuTabs li a#on {
+    font-weight: bold;
+    color: #fff;
+    background-color: #747474;
+    }
+
+/* Sub-menu Tabs */
 ul#submenuTabs {
-	width:100%;
-	height:24px;
-	list-style:none;
-	color:#fff;
-	background:#fff;
-	margin:0px;
-	padding:10px 0%;
-}
-ul#submenuTabs li a:link, ul#submenuTabs li a:visited {
-	float:left;
-	display:inline;
-	height:22px;
-	padding:2px 15px 0px 15px;
-	font:normal 14px/1.5 sans-serif;
-	text-align:center;
-	color:#fff;
-	text-decoration:none;
-	background:#2f40a5;
-}
+    height: 24px;
+    margin-bottom: 10px;
+    }
 ul#submenuTabs li {
-	float:left;
-	display:inline;
-	margin-left:1px;
-	color:#fff;
-	background:#2f40a5;
-}
-ul#submenuTabs li a:hover {
-	float:left;
-	display:inline;
-	color:#fff;
-	background:#2f40a5;
-	text-decoration:underline;
-}
-ul#submenuTabs li#first a, ul#submenuTabs li#first a:link, ul#submenuTabs li#first a:visited, ul#submenuTabs li#first a:hover {
-	background:#2f40a5 url(../images/bg_submenuTabs.gif) top left no-repeat;
-}
-ul#submenuTabs li#last a, ul#submenuTabs li#last a:link, ul#submenuTabs li#last a:visited, ul#submenuTabs li#last a:hover {
-	background:#2f40a5 url(../images/bg_submenuTabs.gif) bottom right no-repeat;
-}
-
-/* Search & RSS */
-#finderBox {
-	width:300px;
-	float:right;
-	padding:0px;
-}
-#finderBox label {
-	float:left;
-	display:inline;
-	width:100px;
-	font:normal 12px/normal sans-serif;
-	text-align:right;
-	color:#000;
-	padding:5px 5px 0px 0px;
-}
-#finderBox input {
-	float:left;
-	font:normal 12px/normal sans-serif;
-	color:#666;
-	display:inline;
-	width:130px;
-	padding:3px;
-	background:#fff url(../images/bg_search_input.gif) 110px 3px no-repeat;
-	border:1px solid #e9e9e9;
-}
-#search_terms {
-    display:none;
-    border:solid 1px black;
-    width:180px;
-    overflow:auto;
-    background: #fff;
-}
-.rssfeed {
-	float:left;
-	display:inline;
-	padding:0px 0px 0px 10px;
-}
-
-/* General Content */
+    float: left;
+    display: inline;
+    margin-right: 20px;
+    }
+ul#submenuTabs li a {
+    float: left;
+    display: inline;
+    height: 22px;
+    line-height: 22px;
+    padding: 0 0 0 18px;
+    background: transparent url(../images/ico_description.gif) no-repeat center left;
+    }
+
+/* Breadcrumbs */
+#breadcrumbs {
+    font-size: 77%;
+    margin-bottom: 10px;
+    }
+
+#branch-info {
+    padding: 10px;
+    margin: 0 0 10px 0;
+    color: #666;
+    background: #fcfcfc;
+    border: 1px solid #b7b7b7;
+    }
+
+
+/* =========================
+   General Content
+*/
 #loggerheadCont {
-	width:98%;
-	padding:10px 1%;
-	color:#242424;
-	background:#fff;
-}
-#loggerheadCont h1 {
-	font-size:18px;
-	color:#666;
-	margin:0px;
-	padding:10px 0px 5px 0px;
-}
-#loggerheadCont h1 span {
-    color:#889ea9;
-}
-#loggerheadCont p {
-	color:#000;
-	margin:0px;
-	padding:5px 0px;
-}
-#loggerheadCont p.expand, #loggerheadCont p.expand a, #loggerheadCont p.expand a:link, #loggerheadCont p.expand a:visited, #loggerheadCont p.expand a:hover {
-	color:#000;
-	text-decoration:none;	
-}
-#loggerheadCont p img {
-	vertical-align:middle;
-}
-.link {
-	padding:0px 11px 0px 0px;
-	margin:0px 2px 0px 0px;
-	font-weight:bold;
-}
-.revnolink a, .revnolink a:visited, .revnolink a:link, .revnolink a:hover {
-	color:#CC6600;
-	text-decoration:none;		
-}
-
-/*Log Table*/
+    width: 98%;
+    padding: 0 1% 10px 1%;
+    }
+
+
+/* =========================
+   Log Table
+*/
 #logentries {
-	caption-side:top;
-	width:99%;
-	margin:0px auto 10px auto;
-	padding:0px;
-	background:#fff;
-	border:none;
-	border-spacing:0px;
-	border-collapse:collapse;
-}
-.logheader {
-	background:#fff;
-	font:bold 14px/normal sans-serif;
-	padding:0px;
-	margin:0px;
-}
-.blueRow0, .blueRow1 {
-	background:#eef6fa;
-	font:normal 14px/normal sans-serif;	
-	padding:0px;
-	margin:0px;
-}
-.blueRow1 {
-	background:#f8fbfd;
-}
-.revisionnumber, .expandcell, .diffcell, .downloadcell, .revnro, .expcell, .diffr, .downr, .allicones {
-	padding:4px 0px;
-	width:42px;
-	text-align:center;
-	border:1px solid #d2d2d2;
-}
-.expandcell, .expcell {
-	width:28px;	
-}
-.summarycell, .authorcell, .datecell, .timedate{
-  padding: 4px 8px;
-  border: 1px solid #d2d2d2;
-}
-.icocell {
-  width: 18px;
-}
-.datecell, .date {
-  width: 180px;
-}
-.timedate, .timedate2 {
-	width:80px;
-}
-.downloadcell, .downr {
-	width:47px;
-}
-.revnro, .expcell, .diffr, .summcell, .autcell, .icocell, .date, .downr, .allicones, .timedate2 {
-  border: 0;
-  padding: 4px 4px;
-  border-bottom:1px solid #d2d2d2;
-}
+    margin-bottom: 10px;
+    clear: left;
+    }
+p.expand, p.codin {
+    margin-right: 10px;
+    float: left;
+    }
+p.expand a, p.codin a {
+    color: #000;
+    text-decoration: none;
+    }
+.show_if_js {
+    display: none;
+    }
+
+/* th and td styles */
+th.revisionnumber,
+th.expandcell,
+th.diffcell,
+th.downloadcell {
+    padding-left: 0;
+    padding-right: 0;
+    text-align: center;
+    }
+th.diffcell,
+th.revisionnumber {
+    width: 42px;
+    }
+th.expandcell,
+td.expcell {
+    width: 10px;
+    }
+td.icocell {
+    width: 18px;
+    }
+th.authorcell,
+td.autcell,
+th.tagscell,
+td.tagcell {
+    width: 240px;
+    }
+th.datecell,
+td.date {
+    width: 180px;
+    }
+th.timedate,
+td.timedate2 {
+    width: 80px;
+    }
+th.downloadcell,
+td.downr {
+    width: 47px;
+    }
+
+
+/* =========================
+   Revision List
+*/
+.revision_log {
+    overflow: hidden;
+    }
 .revisioninfo {
-    margin-top:4px;
-}
+    margin-top: 4px;
+    }
 ul.expandrev {
-	list-style:none;
-	font:normal 11px/normal sans-serif;
-	color:#000;
-}
+    font-size: 85%;
+    }
 ul.expandrev li {
-	padding:2px 0px 2px 20px;
-	margin:0px 0px 2px 0px;
-}
+    padding: 2px 0 2px 20px;
+    margin: 0 0 2px 0;
+    }
 ul.expandrev li.mfrom {
-	background:url(../images/ico_mergefrom.gif) 0px 0px no-repeat;
-}
+    background: url(../images/ico_mergefrom.gif) 0 0 no-repeat;
+    }
 ul.expandrev li.mto {
-	background:url(../images/ico_mergeto.gif) 0px 0px no-repeat;
-}
+    background: url(../images/ico_mergeto.gif) 0 0 no-repeat;
+    }
 ul.expandrev li.committerli {
-	background:url(../images/ico_committer.gif) 2px 0px no-repeat;
-}
+    background: url(../images/ico_committer.gif) 2px 0 no-repeat;
+    }
 ul.expandrev li.desc {
-	background:url(../images/ico_description.gif) 0px 0px no-repeat;
-	color:#666;
-}
+    background: url(../images/ico_description.gif) 0 0 no-repeat;
+    color: #666;
+    }
 ul.expandrev li.files {
-	background:url(../images/ico_file.gif) 2px 0px no-repeat;
+    background: url(../images/ico_file.gif) 2px 0 no-repeat;
     margin-left: 8px;
-}
-
-/* Navigation */
-ul {border:0; margin:0; padding:0;}
-
+    }
+.revnolink a {
+    color: #000;
+    }
+
+
+/* =========================
+   Pagination
+*/
 ul#pages {
-	float:right;
-}
+    float: right;
+    }
 #pages li {
-	border:0; margin:0; padding:0;
-	font-size:12px;
-	list-style:none;
-	float:left;
-	display:inline;
-}
-#pages a {
-	border:solid 1px #DDDDDD;
-	margin-right:2px;
-}
-#pages .next a, #pages .previous a {
-	font-weight:bold;
-	border:solid 1px #fff;
-}
-#pages .active {
-	color:#f37b06;
-	font-weight:bold;
-	display:block;
-	float:left;
-	padding:4px 6px;
-}
-#pages a:link, #pages a:visited {
-	color:#f37b06;
-	display:block;
-	float:left;
-	padding:3px 6px;
-	text-decoration:none;
-}
-#pages .next a {
-	color:#0f6b97;
-}
-#pages a:hover {
-	border:solid 1px #666666;
-}		
+    font-size: 77%;
+    font-weight: bold;
+    float: left;
+    display: inline;
+    padding: 3px 6px;
+    margin-right: 2px;
+    }
+
+
+/* =========================
+   Search & RSS
+*/
+#finderBox {
+    width: 300px;
+    float: right;
+    padding: 10px 0 0 0;
+    }
+#finderBox label,
+#finderBox input {
+    float: left;
+    font-weight: normal;
+    font-size: 12px;
+    }
+#finderBox label {
+    display: inline;
+    width: 100px;
+    text-align: right;
+    color: #000;
+    padding: 5px 5px 0 0;
+    }
+#finderBox input {
+    color: #666;
+    display: inline;
+    width: 130px;
+    padding: 3px;
+    background: #fff url(../images/bg_search_input.gif) 110px 3px no-repeat;
+    border: 1px solid #e9e9e9;
+    }
+#search_terms {
+    display: none;
+    border: solid 1px black;
+    width: 180px;
+    overflow: auto;
+    background: #fff;
+    }
+.rssfeed {
+    float: left;
+    display: inline;
+    padding: 0 0 0 10px;
+    }
+
+
+/* =========================
+   Footer
+*/
+#footer {
+    font-size: 77%;
+    }
+
+    
+/* ====================
+   Global notifications
+*/
+/* Move the content down so the notification banner doesn't hide any content. */
+body.global-notification-visible {
+    padding-top: 40px;
+    }
+body.global-notification-visible .login-logout {
+    top: 45px;
+    }
+.notification-private {
+    background-image: url(/static/images/notification-private.png); /* sprite-ref: icon-sprites */
+    background-repeat: no-repeat;
+    }
+.global-notification {
+    position: fixed;
+    z-index: 10;
+    top: 0;
+    left: 0;
+    right: 0;
+    padding: 8px 20px;
+    /* Define colour for browsers that don't support transparency */
+    background-color: #8d1f1f;
+    /* Set transparent background for browsers that support it */
+    background-color: rgba(125,0,0,0.9);
+    color: #fff;
+    text-shadow: 0 -1px 0 #631616;
+    font-size: 14px;
+    line-height: 21px;
+    font-weight: bold;
+    -moz-box-shadow: 0 0 5px #333;
+    -webkit-box-shadow: 0 0 5px #333;
+    box-shadow: 0 0 5px #333;
+    }
+.global-notification .sprite.notification-private {
+    float: left;
+    display: inline-block;
+    height: 21px;
+    width: 20px;
+    margin-right: 10px;
+    padding: 0;
+    }
+.global-notification-close, .global-notification-close:active,
+.global-notification-close:visited {
+    color: #e47a7a;
+    }
+.global-notification-close {
+    display: block;
+    position: absolute;
+    top: 11px;
+    right: 20px;
+    font-size: 12px;
+    font-weight: normal;
+    line-height: 14px;
+    }
+.global-notification-close .sprite.notification-close {
+    float: right;
+    display: block;
+    height: 9px;
+    width: 8px;
+    margin: 3px 0 0 7px;
+    padding: 0;
+    }

=== added file 'loggerhead/static/css/highlight.css'
--- loggerhead/static/css/highlight.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/css/highlight.css	2009-03-01 20:16:18 +0000
@@ -0,0 +1,59 @@
+.pyg-c { color: #808080 } /* Comment */
+.pyg-err { color: #F00000; background-color: #F0A0A0 } /* Error */
+.pyg-k { color: #008000; font-weight: bold } /* Keyword */
+.pyg-o { color: #303030 } /* Operator */
+.pyg-cm { color: #808080 } /* Comment.Multiline */
+.pyg-cp { color: #507090 } /* Comment.Preproc */
+.pyg-c1 { color: #808080 } /* Comment.Single */
+.pyg-cs { color: #cc0000; font-weight: bold } /* Comment.Special */
+.pyg-gd { color: #A00000 } /* Generic.Deleted */
+.pyg-ge { font-style: italic } /* Generic.Emph */
+.pyg-gr { color: #FF0000 } /* Generic.Error */
+.pyg-gh { color: #000080; font-weight: bold } /* Generic.Heading */
+.pyg-gi { color: #00A000 } /* Generic.Inserted */
+.pyg-go { color: #808080 } /* Generic.Output */
+.pyg-gp { color: #c65d09; font-weight: bold } /* Generic.Prompt */
+.pyg-gs { font-weight: bold } /* Generic.Strong */
+.pyg-gu { color: #800080; font-weight: bold } /* Generic.Subheading */
+.pyg-gt { color: #0040D0 } /* Generic.Traceback */
+.pyg-kc { color: #008000; font-weight: bold } /* Keyword.Constant */
+.pyg-kd { color: #008000; font-weight: bold } /* Keyword.Declaration */
+.pyg-kp { color: #003080; font-weight: bold } /* Keyword.Pseudo */
+.pyg-kr { color: #008000; font-weight: bold } /* Keyword.Reserved */
+.pyg-kt { color: #303090; font-weight: bold } /* Keyword.Type */
+.pyg-m { color: #6000E0; font-weight: bold } /* Literal.Number */
+.pyg-s { background-color: #fff0f0 } /* Literal.String */
+.pyg-na { color: #0000C0 } /* Name.Attribute */
+.pyg-nb { color: #007020 } /* Name.Builtin */
+.pyg-nc { color: #B00060; font-weight: bold } /* Name.Class */
+.pyg-no { color: #003060; font-weight: bold } /* Name.Constant */
+.pyg-nd { color: #505050; font-weight: bold } /* Name.Decorator */
+.pyg-ni { color: #800000; font-weight: bold } /* Name.Entity */
+.pyg-ne { color: #F00000; font-weight: bold } /* Name.Exception */
+.pyg-nf { color: #0060B0; font-weight: bold } /* Name.Function */
+.pyg-nl { color: #907000; font-weight: bold } /* Name.Label */
+.pyg-nn { color: #0e84b5; font-weight: bold } /* Name.Namespace */
+.pyg-nt { color: #007000 } /* Name.Tag */
+.pyg-nv { color: #906030 } /* Name.Variable */
+.pyg-ow { color: #000000; font-weight: bold } /* Operator.Word */
+.pyg-w { color: #bbbbbb } /* Text.Whitespace */
+.pyg-mf { color: #6000E0; font-weight: bold } /* Literal.Number.Float */
+.pyg-mh { color: #005080; font-weight: bold } /* Literal.Number.Hex */
+.pyg-mi { color: #0000D0; font-weight: bold } /* Literal.Number.Integer */
+.pyg-mo { color: #4000E0; font-weight: bold } /* Literal.Number.Oct */
+.pyg-sb { background-color: #fff0f0 } /* Literal.String.Backtick */
+.pyg-sc { color: #0040D0 } /* Literal.String.Char */
+.pyg-sd { color: #D04020 } /* Literal.String.Doc */
+.pyg-s2 { background-color: #fff0f0 } /* Literal.String.Double */
+.pyg-se { color: #606060; font-weight: bold; background-color: #fff0f0 } /* Literal.String.Escape */
+.pyg-sh { background-color: #fff0f0 } /* Literal.String.Heredoc */
+.pyg-si { background-color: #e0e0e0 } /* Literal.String.Interpol */
+.pyg-sx { color: #D02000; background-color: #fff0f0 } /* Literal.String.Other */
+.pyg-sr { color: #000000; background-color: #fff0ff } /* Literal.String.Regex */
+.pyg-s1 { background-color: #fff0f0 } /* Literal.String.Single */
+.pyg-ss { color: #A06000 } /* Literal.String.Symbol */
+.pyg-bp { color: #007020 } /* Name.Builtin.Pseudo */
+.pyg-vc { color: #306090 } /* Name.Variable.Class */
+.pyg-vg { color: #d07000; font-weight: bold } /* Name.Variable.Global */
+.pyg-vi { color: #3030B0 } /* Name.Variable.Instance */
+.pyg-il { color: #0000D0; font-weight: bold } /* Literal.Number.Integer.Long */

=== renamed file 'loggerhead/static/css/annotate.css' => 'loggerhead/static/css/view.css'
--- loggerhead/static/css/annotate.css	2008-08-05 19:44:50 +0000
+++ loggerhead/static/css/view.css	2011-04-22 17:22:26 +0000
@@ -1,27 +1,47 @@
 /*table*/
-.annoLineTit, .annoLine, .annoRevTit, .annoRev, .annoComm, .annoCommTit, .annoContTit, .annoCont {
-	width:45px;
-	border:1px solid #d2d2d2;
-}
-.annoLine, .annoRev, .annoComm, .annoCont {
-	border:none;	
-}
-.annoLine {
-	width:37px;
-}
-.annoContTit, .annoCont {
-	width:auto;
-}
-.annoRevTit, .annoRev {
-	width:70px;
-	text-align:center;
-}
-.annoComm, .annoCommTit {
-	width:200px;
-}
-.annoLine, .annoCont {
-	font:normal 12px/normal monospace;
-}
-.annoLine {
-	text-align:right;
+#logentries,
+.viewRev,
+.viewLine {
+    border: 1px solid #d2d2d2;
+}
+.viewRev {
+    border-right: none;
+    white-space: nowrap;
+    width: 1px;
+    padding: .3em .6em;
+}
+.viewComm,
+.viewCont {
+    border: none;
+    }
+.viewLine {
+    border-style: none solid none none;
+    width: 20px;
+    padding-left: .6em;
+    padding-right: .2em;
+    }
+.viewLine.first {
+    border-style: solid solid none none;
+}
+.viewCont {
+    padding-left: .4em;
+    }
+.viewLine,
+.viewCont {
+    font-size: 116%;
+    font-family: 'UbuntuBeta Mono', 'Ubuntu Mono', monospace;
+    line-height: 108%;
+    whitespace: pre;
+    }
+.viewCont pre {
+    margin: 0;
+    }
+.viewLine {
+    text-align: center;
+    }
+.viewLine {
+    font-size: 93%;
+    }
+.viewAuthors {
+    color: #999999;
 }

=== added directory 'loggerhead/static/downloads'
=== modified file 'loggerhead/static/images/bg_Tabs.gif'
Binary files loggerhead/static/images/bg_Tabs.gif and loggerhead/static/images/bg_Tabs.gif differ
=== modified file 'loggerhead/static/images/bg_menuTabs.gif'
Binary files loggerhead/static/images/bg_menuTabs.gif and loggerhead/static/images/bg_menuTabs.gif differ
=== modified file 'loggerhead/static/images/bg_submenuTabs.gif'
Binary files loggerhead/static/images/bg_submenuTabs.gif and loggerhead/static/images/bg_submenuTabs.gif differ
=== added file 'loggerhead/static/images/favicon.png'
Binary files loggerhead/static/images/favicon.png and loggerhead/static/images/favicon.png differ
=== added file 'loggerhead/static/images/ico_bug.png'
Binary files loggerhead/static/images/ico_bug.png and loggerhead/static/images/ico_bug.png differ
=== added file 'loggerhead/static/images/ico_tag.gif'
Binary files loggerhead/static/images/ico_tag.gif and loggerhead/static/images/ico_tag.gif differ
=== added file 'loggerhead/static/images/notification-private.png'
Binary files loggerhead/static/images/notification-private.png and loggerhead/static/images/notification-private.png differ
=== added file 'loggerhead/static/images/spinner.gif'
Binary files loggerhead/static/images/spinner.gif and loggerhead/static/images/spinner.gif differ
=== added file 'loggerhead/static/javascript/changelog.js'
--- loggerhead/static/javascript/changelog.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/changelog.js	2009-03-31 21:11:38 +0000
@@ -0,0 +1,76 @@
+function toggle_expand_all(action)
+{
+  var revlogs = Y.all('.revision_log');
+  if (revlogs == null) return;
+  revlogs.each(
+    function(item, i)
+    {
+      var collapsable = item.collapsable;
+      if(action == 'close')
+      {
+        Y.get('#expand_all').setStyle('display','block');
+        Y.get('#collapse_all').setStyle('display','none');
+        collapsable.close();
+      }
+      else if(action == 'open')
+      {
+        Y.get('#expand_all').setStyle('display','none');
+        Y.get('#collapse_all').setStyle('display','block');
+        collapsable.open();
+      }
+    });
+}
+
+Y.on(
+  'click',
+  function (event) {
+    event.preventDefault();
+    toggle_expand_all('open');
+  },
+  '#expand_all a'
+);
+
+Y.on(
+  'click',
+  function (event) {
+    event.preventDefault();
+    toggle_expand_all('close');
+  },
+  '#collapse_all a'
+);
+
+Y.on(
+  "domready", function () {
+    Y.all(".show_if_js").removeClass("show_if_js");
+  });
+
+Y.on(
+  'domready',
+  function()
+  {
+    var revlogs = Y.all('.revision_log');
+    if (revlogs == null) return;
+    revlogs.each(
+      function(item, i)
+      {
+        var revid = revids[item.get('id').replace('log-', '')];
+        var collapsable = new Collapsable(
+          {
+            expand_icon: item.query('.expand_icon'),
+            open_node: item.query('.long_description'),
+            close_node: item.query('.short_description'),
+            source: global_path + '+revlog/' + revid,
+            loading: item.query('.loading'),
+            is_open: false
+          });
+
+        item.query('.expand_revisioninfo a').on(
+          'click',
+          function(e) {
+            e.preventDefault();
+            collapsable.toggle();
+          });
+        item.collapsable = collapsable;
+      });
+
+  });

=== modified file 'loggerhead/static/javascript/custom.js'
--- loggerhead/static/javascript/custom.js	2008-07-22 00:40:03 +0000
+++ loggerhead/static/javascript/custom.js	2011-10-26 16:06:54 +0000
@@ -1,236 +1,368 @@
+Y = YUI().use("base", "node", "io-base", "anim");
+
 var global_timeout_id = null;
 var global_search_request = null;
 
-window.addEvent('domready', function() 
-{
-    var search_box = $('q');
-    search_box.addEvents(
+Y.on(
+  'domready',
+  function()
+  {
+    var search_box = Y.get('#q');
+    if (!Y.Lang.isNull(search_box))
     {
-        keyup: function()
-        {
-            if($('q').value == '')
-            {
-                $('search_terms').setStyle('display','none');
-            }
-            else
-            {
-	            if (null != global_timeout_id)
-	            {
-	                clearTimeout(global_timeout_id);
-	            }
-                    global_timeout_id = setTimeout('$("q").fireEvent("search",$("q").value)',200);
-            }
-        },
-
-        search: function(query)
-        {
-            url = global_path + 'search?query=' + query;
-	
-            if ($defined(global_search_request))
-            {
-                global_search_request.cancel();
-            }
-            global_search_request = new Request({'url':url,'method':'get','onComplete':cool_search});
-            global_search_request.send('');
-	        var posicion = search_box.getPosition();
-	        var size     = search_box.getSize();
-
-	        $('search_terms').setStyle('position','absolute');
-	        $('search_terms').setStyle('left',posicion.x);
-	        $('search_terms').setStyle('top',posicion.y + size.y);
-	        $('search_terms').setStyle('display','block');
-	        $('search_terms').set('html','Loading...');
-
-            new Request({'url':url,'method':'get','onComplete':cool_search}).send('');
-
-
+      function get_suggestions() {
+        var query = search_box.get('value');
+        var url = global_path + 'search?query=' + query;
+
+        if (!Y.Lang.isNull(global_search_request))
+        {
+          global_search_request.abort();
         }
-    });
-});
-
-function cool_search(response)
+        global_search_request = Y.io(
+          url,
+          {
+            on: {complete: cool_search},
+            arguments: [query]
+          }
+        );
+
+        var region = search_box.get('region');
+        var current_query = search_box.get('value');
+
+        Y.get('#search_terms').setStyle('display', 'block');
+        Y.get('#search_terms').setStyle('position', 'absolute');
+        Y.get('#search_terms').setStyle('left', region.left);
+        Y.get('#search_terms').setStyle('top', region.bottom);
+        Y.get('#search_terms').set('innerHTML','Loading...');
+      }
+      search_box.on(
+        "keyup",
+        function(event)
+        {
+          if(search_box.get('value') == '')
+          {
+            Y.get('#search_terms').setStyle('display', 'none');
+          }
+          else
+          {
+            if (null != global_timeout_id)
+            {
+              clearTimeout(global_timeout_id);
+            }
+            global_timeout_id = setTimeout(get_suggestions, 200);
+          }
+        });
+    }
+  });
+
+function cool_search(tid, response, query)
 {
-	var posicion = $('q').getPosition();
-	var size     = $('q').getSize();
-	$('search_terms').set('html',response);
-	$('search_terms').setStyle('display','block');
-	$('search_terms').setStyle('position','absolute');
-	$('search_terms').setStyle('left',posicion.x);
-	$('search_terms').setStyle('top',posicion.y + size.y);
+  var q = Y.get('#q');
+  var region = q.get('region');
+  var current_query = q.get('value');
+  if (current_query == query)
+  {
+    Y.get('#search_terms').set('innerHTML', response.responseText);
+    Y.get('#search_terms').setStyle('display', 'block');
+    Y.get('#search_terms').setStyle('position', 'absolute');
+    Y.get('#search_terms').setStyle('left', region.left);
+    Y.get('#search_terms').setStyle('top', region.bottom);
+  }
 }
 
 function hide_search()
 {
-    hide_div = setTimeout("$('search_terms').setStyle('display','none')", 300);
-}
-var Colapsable = new Class({
-    initialize: function(item,expand_icon,open_content,close_content,is_open)
-    {
-        this.is_open = false;
-        if ($defined(is_open))
-        {
-            this.is_open = is_open;
-        }
-        this.item = item;
-        item.set('colapsable',this);
-        this.open_content  = open_content;
-        this.close_content = close_content;
-        this.expand_icon   = expand_icon;
-
-        var expander = new Fx.Slide(this.item, { duration: 200 } );
-        if (!this.is_open)
-        {
-            expander.hide();
-            if ($defined(this.expand_icon))
-            {
-                this.expand_icon.set('src',this.expand_icon.title);
-            }
-        }
-        else
-        {
-            if ($defined(this.expand_icon))
-            {
-                this.expand_icon.set('src',this.expand_icon.alt);
-            }
-        }
-    },
-
-    open: function()
-    {
-        this.item.setStyle('display', 'block');
-        var expander = this.item.get('slide');
-        expander.slideIn();
-        if ($defined(this.open_content))
-        {
-            for (var i=0;i<this.open_content.length;++i)
-            {
-                this.open_content[i].setStyle('display','block');
-            }
-		}
-		
-        if ($defined(this.close_content))
-        {
-            for (var i=0;i<this.close_content.length;++i)
-            {
-                this.close_content[i].setStyle('display','none');
-            }
-        }
-
-        if ($defined(this.expand_icon))
-        {
-            this.expand_icon.set('src',this.expand_icon.alt);
-        }
-        this.is_open = true;
-    },
-
-    close: function()
-    {
-        var expander = this.item.get('slide');
-        expander.slideOut();
-        if ($defined(this.open_content))
-        {
-            for (var i=0;i<this.open_content.length;++i)
-            {
-                this.open_content[i].setStyle('display','none');
-            }
-        }
-
-        if ($defined(this.close_content))
-        {
-            for (var i=0;i<this.close_content.length;++i)
-            {
-                this.close_content[i].setStyle('display','block');
-            }
-        }
-        if ($defined(this.expand_icon))
-        {
-            this.expand_icon.set('src',this.expand_icon.title);
-        }
-        this.is_open = false;
-    },
-
-    isOpen : function()
-    {
-        return this.is_open;
-    },
-
-    toggle: function()
-    {
-        if (this.isOpen())
-        {
-            this.close();
-        }
-        else
-        {
-            this.open();
-        }
-    }
-    });
-
-
-window.addEvent('domready', function()
-{
-    $$('.revision_log').each(function(item, i)
-    {
-        var item_slide = item.getElement('.revisioninfo');
-        var open_content  = new Array();
-        var close_content = new Array();
-        open_content.push(item.getElement('.long_description'));
-        close_content.push(item.getElement('.short_description'));
-        var expand_icon = item.getElement('.expand_icon');
-        var colapsable = new Colapsable(item_slide,expand_icon,open_content,close_content);
-        
-        item.getElement('.expand_revisioninfo').addEvent('click',function(){colapsable.toggle();});
-        item.colapsable = colapsable;
-    });
-
-    $$('.diffBox').each(function(item, i)
-    {
-        var item_slide = item.getNext('.diffinfo');
-        var expand_icon = item.getElement( '.expand_diff' );
-        var colapsable = new Colapsable(item_slide,expand_icon,null,null,true);
-        item.getElement( '.expand_diff' ).addEvent( 'click', function(){colapsable.toggle();});
-        item.colapsable=colapsable;
-    });
+  setTimeout("Y.get('#search_terms').setStyle('display','none')", 300);
+}
+
+function Collapsable(config)
+{
+  this.is_open = config.is_open;
+  this.open_node = config.open_node;
+  this.close_node = config.close_node;
+  this.expand_icon = config.expand_icon;
+  this.source = config.source;
+  this.loading = config.loading;
+  this.node_process = config.node_process;
+  this.container = null;
+  this.anim = null;
+  this._loading = false;
+}
+
+function get_height(node) {
+  node.setStyle('position', 'absolute');
+  node.setStyle('top', -1000000000);
+  node.setStyle('display', 'block');
+  var height = node.get('region').height;
+  node.setStyle('display', 'none');
+  node.setStyle('position', 'static');
+  node.setStyle('top', 'auto');
+  return height;
+}
+
+Collapsable.prototype._animate = function (callback)
+{
+  if (this.anim) this.anim.stop();
+
+  this.anim = new Y.Anim(
+    {
+      node: this.container,
+      from: {
+        marginBottom: this.container.getStyle('marginBottom')
+      },
+      to: {
+        marginBottom: 0
+      },
+      duration: 0.2
+    });
+
+  this.anim.run();
+  this.anim.on('end', this.animComplete, this, callback);
+}
+
+Collapsable.prototype._load_finished = function(tid, res, args)
+{
+  var l = res.responseText.split('\n');
+  l.splice(0, 1);
+  var newNode = Y.Node.create(l.join(''));
+  if (this.node_process)
+    this.node_process(newNode);
+  this.source = null;
+  newNode.setStyle('display', 'none');
+  this.loading.ancestor().insertBefore(newNode, this.loading);
+  var delta = this.loading.get('region').height - get_height(newNode);
+  newNode.setStyle('display', 'block');
+  this.container.setStyle('marginBottom', parseFloat(this.container.getStyle('marginBottom')) + delta);
+  this.loading.ancestor().removeChild(this.loading);
+  this._animate(args[0]);
+};
+
+Collapsable.prototype._ensure_container = function(callback)
+{
+  if (this.container == null) {
+    this.container = Y.Node.create('<div></div>');
+    if (this.closed_node) {
+      this.closed_node.ancestor().replaceChild(
+        this.container, this.closed_node);
+      this.container.appendChild(this.closed_node);
+      if (this.open_node) {
+        this.container.appendChild(this.open_node);
+      }
+    }
+    else {
+      this.open_node.ancestor().replaceChild(
+        this.container, this.open_node);
+      this.container.appendChild(this.open_node);
+    }
+    var outer = Y.Node.create('<div style="overflow:hidden;"></div>');
+    this.container.ancestor().replaceChild(outer, this.container);
+    outer.appendChild(this.container);
+  }
+}
+
+/* What happens when you click open.
+ *
+ * 1. The arrow flips to the expanded position.
+ *
+ * 2. If necessary, the div which will be running the animation is
+ * created and the open/closed content stuffed into it (and has height
+ * set to the height of the closed content).
+ *
+ * 3. The open content is shown and the closed content is closed.
+ *
+ * 4. The animation to expose all of the open content is started.
+ *
+ * 5. If we have to do ajax to load content, start the request.
+ *
+ * 6. When the request completes, parse the content into a node, run
+ * the node_process callback over it and replace the spinner (assumed
+ * to be appropriately contained in the open node) with the new node.
+ *
+ * 7. If the animation showing the open content has not completed,
+ * stop it.
+ *
+ * 8. Start a new animation to show the rest of the new content.
+ */
+
+Collapsable.prototype.open = function(callback)
+{
+  this.expand_icon.set('src', expanded_icon_path);
+
+  this._ensure_container();
+
+  var open_height = get_height(this.open_node);
+
+  var close_height;
+  if (this.close_node) {
+    close_height = this.close_node.get('region').height;
+  }
+  else {
+    close_height = 0;
+  }
+
+  this.container.setStyle('marginBottom', close_height - open_height);
+  if (this.close_node) {
+    this.close_node.setStyle('display', 'none');
+  }
+  this.open_node.setStyle('display', 'block');
+
+  this._animate(callback);
+
+  if (this.source) {
+    Y.io(
+      this.source,
+      {
+        on: {complete: this._load_finished},
+        arguments: [callback],
+        context: this
+      });
+    return;
+  }
+
+};
+
+Collapsable.prototype.animComplete = function(evt, callback)
+{
+  this.anim = null;
+  if (this._loading) return;
+  if (callback) callback();
+  this.is_open = true;
+};
+
+Collapsable.prototype.close = function()
+{
+  this._ensure_container();
+
+  var open_height = this.open_node.get('region').height;
+
+  var close_height;
+  if (this.close_node) {
+    close_height = get_height(this.close_node);
+  }
+  else {
+    close_height = 0;
+  }
+
+  var anim = new Y.Anim(
+    {
+      node: this.container,
+      from: {
+        marginBottom: 0
+      },
+      to: {
+        marginBottom: close_height - open_height
+      },
+      duration: 0.2
+    });
+  anim.on("end", this.closeComplete, this);
+  anim.run();
+};
+
+Collapsable.prototype.closeComplete = function () {
+  this.open_node.setStyle('display', 'none');
+  if (this.close_node) {
+    this.close_node.setStyle('display', 'block');
+  }
+  this.container.setStyle('marginBottom', 0);
+  this.expand_icon.set('src', collapsed_icon_path);
+  this.is_open = false;
+};
+
+Collapsable.prototype.toggle = function()
+{
+  if (this.is_open)
+  {
+    this.close();
+  }
+  else
+  {
+    this.open();
+  }
+};
+
+var notification_node = null;
+/*
+ * Display privacy notifications
+ *
+ * This should be called after the page has loaded e.g. on 'domready'.
+ */
+function setup_privacy_notification(config) {
+    if (notification_node !== null) {
+        return;
+    }
+    var notification_text = 'The information on this page is private';
+    var hidden = true;
+    var target_id = "loggerheadCont";
+    if (config !== undefined) {
+        if (config.notification_text !== undefined) {
+            notification_text = config.notification_text;
+        }
+        if (config.hidden !== undefined) {
+            hidden = config.hidden;
+        }
+        if (config.target_id !== undefined) {
+            target_id = config.target_id;
+        }
+    }
+    var id_selector = "#" + target_id;
+    var main = Y.get(id_selector);
+    notification_node = Y.Node.create('<div></div>')
+        .addClass('global-notification');
+    if (hidden) {
+        notification_node.addClass('hidden');
+    }
+    var notification_span = Y.Node.create('<span></span>')
+        .addClass('sprite')
+        .addClass('notification-private');
+    notification_node.set('innerHTML', notification_text);
+    main.appendChild(notification_node);
+    notification_node.appendChild(notification_span);
+};
+
+function display_privacy_notification() {
+    /* Set a temporary class on the body for the feature flag,
+     this is because we have no way to use feature flags in
+     css directly. This should be removed if the feature
+     is accepted. */
+    var body = Y.get('body');
+    body.addClass('feature-flag-bugs-private-notification-enabled');
+    // Set the visible flag so that the content moves down.
+    body.addClass('global-notification-visible');
+
+    setup_privacy_notification();
+    var global_notification = Y.get('.global-notification');
+    if (global_notification.hasClass('hidden')) {
+        global_notification.addClass('transparent');
+        global_notification.removeClass('hidden');
+
+        var fade_in = new Y.Anim({
+            node: global_notification,
+            to: {opacity: 1},
+            duration: 0.3
+        });
+        var body_space = new Y.Anim({
+            node: 'body',
+            to: {'paddingTop': '40px'},
+            duration: 0.2,
+            easing: Y.Easing.easeOut
+        });
+        var black_link_space = new Y.Anim({
+            node: '.black-link',
+            to: {'top': '45px'},
+            duration: 0.2,
+            easing: Y.Easing.easeOut
+        });
+
+        fade_in.run();
+        body_space.run();
+        black_link_space.run();
+    }
+};
+
+Y.on('domready', function() {
+    var body = Y.get('body');
+    if (body.hasClass('private')) {
+        setup_privacy_notification();
+        display_privacy_notification();
+    }
 });
-
-function toggle_expand_all(action)
-{
-    $$('.revision_log').each(function(item, i)
-    {
-    	var colapsable = item.colapsable;
-        if(action == 'close')
-        {
-            $('expand_all').setStyle('display','block');
-            $('collapse_all').setStyle('display','none');
-            colapsable.close();
-        }
-        else if(action == 'open')
-        {
-            $('expand_all').setStyle('display','none');
-            $('collapse_all').setStyle('display','block');
-            colapsable.open();
-        }
-    });
-}
-
-function toggle_expand_all_revisionview(action)
-{
-    $$('.diffBox').each(function(item, i)
-    {
-    	var colapsable = item.colapsable;
-        if(action == 'close')
-        {
-            $('expand_all').setStyle('display','block');
-            $('collapse_all').setStyle('display','none');
-            colapsable.close();
-        }
-        else if(action == 'open')
-        {
-            $('expand_all').setStyle('display','none');
-            $('collapse_all').setStyle('display','block');
-            colapsable.open();
-        }
-    });
-}
-

=== added file 'loggerhead/static/javascript/diff.js'
--- loggerhead/static/javascript/diff.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/diff.js	2009-03-31 21:11:38 +0000
@@ -0,0 +1,204 @@
+var unified = true;
+
+function make_unified(chunk) {
+  var pending_added = [];
+  function flush_adds(before) {
+    for (var i = 0; i < pending_added.length; i++) {
+      before.ancestor().insertBefore(pending_added[i], before);
+    }
+    pending_added.length = 0;
+  }
+  chunk.get('children').filter(".pseudorow").each(
+    function (line) {
+      if (line.hasClass("context-row")) {
+        flush_adds(line);
+        line.removeChild(line.query('.code'));
+      }
+      else if (line.hasClass("both-row")) {
+        var added_line = line.create('<div class="pseudorow insert-row"><div class="lineNumber first">&nbsp;</div><div class="clear">&nbsp;</div></div>');
+        var clear = added_line.query('.clear');
+        added_line.insertBefore(line.query('.lineNumber.second'), clear);
+        added_line.insertBefore(line.query('.code.insert'), clear);
+        pending_added[pending_added.length] = added_line;
+        line.insertBefore(line.create('<div class="lineNumber second">&nbsp;</div>'), line.query('.code.delete'));
+        line.replaceClass("both-row", "delete-row");
+      }
+      else if (line.hasClass("insert-row")) {
+        flush_adds(line);
+        line.removeChild(line.query('.blank'));
+      }
+      else if (line.hasClass("delete-row")) {
+        line.removeChild(line.query('.blank'));
+        line.insertBefore(line.query('.lineNumber.second'), line.query('.code.delete'));
+      }
+    });
+  flush_adds(null);
+  chunk.replaceClass('sbs', 'unified');
+}
+
+function make_sbs(chunk) {
+  var added = [];
+  var removed = [];
+  function clear_bufs(before) {
+    if (!added.length && !removed.length) return;
+    var common = Math.min(added.length, removed.length);
+    for (var i = 0; i < common; i++) {
+      var a = added[i];
+      var r = removed[i];
+      a.ancestor().removeChild(a);
+      r.removeChild(r.query('.lineNumber.second'));
+      r.insertBefore(a.query('.lineNumber.second'), r.query('.clear'));
+      r.insertBefore(a.query('.code.insert'), r.query('.clear'));
+      r.replaceClass('removed-row', 'both-row');
+    }
+    if (added.length > removed.length) {
+      for (var j = common; j < added.length; j++) {
+        a = added[j];
+        a.insertBefore(a.create('<div class="blank">&nbsp;</div>'), a.query('.lineNumber.second'));
+      }
+    }
+    else if (added.length < removed.length) {
+      for (var j = common; j < removed.length; j++) {
+        r = removed[j];
+        r.insertBefore(r.query('.code.delete'), r.query('.lineNumber.second'));
+        r.insertBefore(r.create('<div class="blank">&nbsp;</div>'), r.query('.clear'));
+      }
+    }
+    added.length = 0;
+    removed.length = 0;
+  }
+  chunk.get('children').filter(".pseudorow").each(
+    function (line) {
+      if (line.hasClass("context-row")) {
+        clear_bufs(line);
+        line.insertBefore(line.query('.code').cloneNode(true), line.query(".second"));
+      }
+      else if (line.hasClass("insert-row")) {
+        added[added.length] = line;
+      }
+      else if (line.hasClass("delete-row")) {
+        removed[removed.length] = line;
+      }
+    });
+  clear_bufs(null);
+  chunk.replaceClass('unified', 'sbs');
+
+}
+
+function toggle_unified_sbs(event) {
+  event.preventDefault();
+  var pts = Y.all(".pseudotable");
+  if (unified) {
+    pts && pts.each(make_sbs);
+    unified = false;
+    Y.get("#toggle_unified_sbs").set('innerHTML', "Show unified diffs");
+  }
+  else {
+    pts && pts.each(make_unified);
+    unified = true;
+    Y.get("#toggle_unified_sbs").set('innerHTML', "Show diffs side-by-side");
+  }
+}
+
+Y.on("click", toggle_unified_sbs, '#toggle_unified_sbs');
+
+function toggle_expand_all_revisionview(action)
+{
+  var diffs = Y.all('.diff');
+  if (diffs == null) return;
+  diffs.each(
+    function(item, i)
+    {
+      var collapsable = item.collapsable;
+      if(action == 'close')
+      {
+        Y.get('#expand_all').setStyle('display','block');
+        Y.get('#collapse_all').setStyle('display','none');
+        collapsable.close();
+      }
+      else if(action == 'open')
+      {
+        Y.get('#expand_all').setStyle('display','none');
+        Y.get('#collapse_all').setStyle('display','block');
+        collapsable.open();
+      }
+    });
+}
+
+Y.on(
+  'click',
+  function (event) {
+    event.preventDefault();
+    toggle_expand_all_revisionview('open');
+  },
+  '#expand_all a'
+);
+
+Y.on(
+  'click',
+  function (event) {
+    event.preventDefault();
+    toggle_expand_all_revisionview('close');
+  },
+  '#collapse_all a'
+);
+
+function node_process(node) {
+  if (!unified) {
+    node.get('children').filter('.pseudotable').each(make_sbs);
+  }
+}
+
+function zoom_to_diff (path) {
+  var collapsable = Y.get('#' + path_to_id[path]).collapsable;
+  if (!collapsable.is_open) {
+    collapsable.open(
+      function () {
+        window.location.hash = '#' + path;
+      });
+  }
+}
+
+Y.on(
+  "domready", function () {
+    Y.all(".show_if_js").removeClass("show_if_js");
+    if (!specific_path) {
+      Y.all("#list-files a").on(
+        'click',
+        function (e) {
+          e.preventDefault();
+          var path = decodeURIComponent(e.target.get('href').split('#')[1]);
+          window.location.hash = '#' + path;
+          zoom_to_diff(path);
+        });
+    }
+    var diffs = Y.all('.diff');
+    if (diffs == null) return;
+    diffs.each(
+      function(item, i)
+      {
+        var source_url = null;
+        if (!specific_path)
+          source_url = global_path + '+filediff/' + link_data[item.get('id')];
+        item.query('.the-link').on(
+          'click',
+          function(e) {
+            e.preventDefault();
+            collapsable.toggle();
+          });
+        var collapsable = new Collapsable(
+          {
+            expand_icon: item.query('.expand_diff'),
+            open_node: item.query('.diffinfo'),
+            close_node: null,
+            source: source_url,
+            is_open: specific_path != null,
+            loading: item.query('.loading'),
+            node_process: node_process
+          });
+       item.collapsable=collapsable;
+       });
+    if (window.location.hash && !specific_path) {
+      zoom_to_diff(window.location.hash.substring(1));
+    }
+  });

=== removed file 'loggerhead/static/javascript/mootools-1.2-core.js'
--- loggerhead/static/javascript/mootools-1.2-core.js	2008-06-13 23:50:23 +0000
+++ loggerhead/static/javascript/mootools-1.2-core.js	1970-01-01 00:00:00 +0000
@@ -1,333 +0,0 @@
-//MooTools, <http://mootools.net>, My Object Oriented (JavaScript) Tools. Copyright (c) 2006-2008 Valerio Proietti, <http://mad4milk.net>, MIT Style License.
-
-var MooTools={version:"1.2.0",build:""};var Native=function(J){J=J||{};var F=J.afterImplement||function(){};var G=J.generics;G=(G!==false);var H=J.legacy;
-var E=J.initialize;var B=J.protect;var A=J.name;var C=E||H;C.constructor=Native;C.$family={name:"native"};if(H&&E){C.prototype=H.prototype;}C.prototype.constructor=C;
-if(A){var D=A.toLowerCase();C.prototype.$family={name:D};Native.typize(C,D);}var I=function(M,K,N,L){if(!B||L||!M.prototype[K]){M.prototype[K]=N;}if(G){Native.genericize(M,K,B);
-}F.call(M,K,N);return M;};C.implement=function(L,K,N){if(typeof L=="string"){return I(this,L,K,N);}for(var M in L){I(this,M,L[M],K);}return this;};C.alias=function(M,K,N){if(typeof M=="string"){M=this.prototype[M];
-if(M){I(this,K,M,N);}}else{for(var L in M){this.alias(L,M[L],K);}}return this;};return C;};Native.implement=function(D,C){for(var B=0,A=D.length;B<A;B++){D[B].implement(C);
-}};Native.genericize=function(B,C,A){if((!A||!B[C])&&typeof B.prototype[C]=="function"){B[C]=function(){var D=Array.prototype.slice.call(arguments);return B.prototype[C].apply(D.shift(),D);
-};}};Native.typize=function(A,B){if(!A.type){A.type=function(C){return($type(C)===B);};}};Native.alias=function(E,B,A,F){for(var D=0,C=E.length;D<C;D++){E[D].alias(B,A,F);
-}};(function(B){for(var A in B){Native.typize(B[A],A);}})({"boolean":Boolean,"native":Native,object:Object});(function(B){for(var A in B){new Native({name:A,initialize:B[A],protect:true});
-}})({String:String,Function:Function,Number:Number,Array:Array,RegExp:RegExp,Date:Date});(function(B,A){for(var C=A.length;C--;C){Native.genericize(B,A[C],true);
-}return arguments.callee;})(Array,["pop","push","reverse","shift","sort","splice","unshift","concat","join","slice","toString","valueOf","indexOf","lastIndexOf"])(String,["charAt","charCodeAt","concat","indexOf","lastIndexOf","match","replace","search","slice","split","substr","substring","toLowerCase","toUpperCase","valueOf"]);
-function $chk(A){return !!(A||A===0);}function $clear(A){clearTimeout(A);clearInterval(A);return null;}function $defined(A){return(A!=undefined);}function $empty(){}function $arguments(A){return function(){return arguments[A];
-};}function $lambda(A){return(typeof A=="function")?A:function(){return A;};}function $extend(C,A){for(var B in (A||{})){C[B]=A[B];}return C;}function $unlink(C){var B;
-switch($type(C)){case"object":B={};for(var E in C){B[E]=$unlink(C[E]);}break;case"hash":B=$unlink(C.getClean());break;case"array":B=[];for(var D=0,A=C.length;
-D<A;D++){B[D]=$unlink(C[D]);}break;default:return C;}return B;}function $merge(){var E={};for(var D=0,A=arguments.length;D<A;D++){var B=arguments[D];if($type(B)!="object"){continue;
-}for(var C in B){var G=B[C],F=E[C];E[C]=(F&&$type(G)=="object"&&$type(F)=="object")?$merge(F,G):$unlink(G);}}return E;}function $pick(){for(var B=0,A=arguments.length;
-B<A;B++){if(arguments[B]!=undefined){return arguments[B];}}return null;}function $random(B,A){return Math.floor(Math.random()*(A-B+1)+B);}function $splat(B){var A=$type(B);
-return(A)?((A!="array"&&A!="arguments")?[B]:B):[];}var $time=Date.now||function(){return new Date().getTime();};function $try(){for(var B=0,A=arguments.length;
-B<A;B++){try{return arguments[B]();}catch(C){}}return null;}function $type(A){if(A==undefined){return false;}if(A.$family){return(A.$family.name=="number"&&!isFinite(A))?false:A.$family.name;
-}if(A.nodeName){switch(A.nodeType){case 1:return"element";case 3:return(/\S/).test(A.nodeValue)?"textnode":"whitespace";}}else{if(typeof A.length=="number"){if(A.callee){return"arguments";
-}else{if(A.item){return"collection";}}}}return typeof A;}var Hash=new Native({name:"Hash",initialize:function(A){if($type(A)=="hash"){A=$unlink(A.getClean());
-}for(var B in A){this[B]=A[B];}return this;}});Hash.implement({getLength:function(){var B=0;for(var A in this){if(this.hasOwnProperty(A)){B++;}}return B;
-},forEach:function(B,C){for(var A in this){if(this.hasOwnProperty(A)){B.call(C,this[A],A,this);}}},getClean:function(){var B={};for(var A in this){if(this.hasOwnProperty(A)){B[A]=this[A];
-}}return B;}});Hash.alias("forEach","each");function $H(A){return new Hash(A);}Array.implement({forEach:function(C,D){for(var B=0,A=this.length;B<A;B++){C.call(D,this[B],B,this);
-}}});Array.alias("forEach","each");function $A(C){if(C.item){var D=[];for(var B=0,A=C.length;B<A;B++){D[B]=C[B];}return D;}return Array.prototype.slice.call(C);
-}function $each(C,B,D){var A=$type(C);((A=="arguments"||A=="collection"||A=="array")?Array:Hash).each(C,B,D);}var Browser=new Hash({Engine:{name:"unknown",version:""},Platform:{name:(navigator.platform.match(/mac|win|linux/i)||["other"])[0].toLowerCase()},Features:{xpath:!!(document.evaluate),air:!!(window.runtime)},Plugins:{}});
-if(window.opera){Browser.Engine={name:"presto",version:(document.getElementsByClassName)?950:925};}else{if(window.ActiveXObject){Browser.Engine={name:"trident",version:(window.XMLHttpRequest)?5:4};
-}else{if(!navigator.taintEnabled){Browser.Engine={name:"webkit",version:(Browser.Features.xpath)?420:419};}else{if(document.getBoxObjectFor!=null){Browser.Engine={name:"gecko",version:(document.getElementsByClassName)?19:18};
-}}}}Browser.Engine[Browser.Engine.name]=Browser.Engine[Browser.Engine.name+Browser.Engine.version]=true;if(window.orientation!=undefined){Browser.Platform.name="ipod";
-}Browser.Platform[Browser.Platform.name]=true;Browser.Request=function(){return $try(function(){return new XMLHttpRequest();},function(){return new ActiveXObject("MSXML2.XMLHTTP");
-});};Browser.Features.xhr=!!(Browser.Request());Browser.Plugins.Flash=(function(){var A=($try(function(){return navigator.plugins["Shockwave Flash"].description;
-},function(){return new ActiveXObject("ShockwaveFlash.ShockwaveFlash").GetVariable("$version");})||"0 r0").match(/\d+/g);return{version:parseInt(A[0]||0+"."+A[1]||0),build:parseInt(A[2]||0)};
-})();function $exec(B){if(!B){return B;}if(window.execScript){window.execScript(B);}else{var A=document.createElement("script");A.setAttribute("type","text/javascript");
-A.text=B;document.head.appendChild(A);document.head.removeChild(A);}return B;}Native.UID=1;var $uid=(Browser.Engine.trident)?function(A){return(A.uid||(A.uid=[Native.UID++]))[0];
-}:function(A){return A.uid||(A.uid=Native.UID++);};var Window=new Native({name:"Window",legacy:(Browser.Engine.trident)?null:window.Window,initialize:function(A){$uid(A);
-if(!A.Element){A.Element=$empty;if(Browser.Engine.webkit){A.document.createElement("iframe");}A.Element.prototype=(Browser.Engine.webkit)?window["[[DOMElement.prototype]]"]:{};
-}return $extend(A,Window.Prototype);},afterImplement:function(B,A){window[B]=Window.Prototype[B]=A;}});Window.Prototype={$family:{name:"window"}};new Window(window);
-var Document=new Native({name:"Document",legacy:(Browser.Engine.trident)?null:window.Document,initialize:function(A){$uid(A);A.head=A.getElementsByTagName("head")[0];
-A.html=A.getElementsByTagName("html")[0];A.window=A.defaultView||A.parentWindow;if(Browser.Engine.trident4){$try(function(){A.execCommand("BackgroundImageCache",false,true);
-});}return $extend(A,Document.Prototype);},afterImplement:function(B,A){document[B]=Document.Prototype[B]=A;}});Document.Prototype={$family:{name:"document"}};
-new Document(document);Array.implement({every:function(C,D){for(var B=0,A=this.length;B<A;B++){if(!C.call(D,this[B],B,this)){return false;}}return true;
-},filter:function(D,E){var C=[];for(var B=0,A=this.length;B<A;B++){if(D.call(E,this[B],B,this)){C.push(this[B]);}}return C;},clean:function(){return this.filter($defined);
-},indexOf:function(C,D){var A=this.length;for(var B=(D<0)?Math.max(0,A+D):D||0;B<A;B++){if(this[B]===C){return B;}}return -1;},map:function(D,E){var C=[];
-for(var B=0,A=this.length;B<A;B++){C[B]=D.call(E,this[B],B,this);}return C;},some:function(C,D){for(var B=0,A=this.length;B<A;B++){if(C.call(D,this[B],B,this)){return true;
-}}return false;},associate:function(C){var D={},B=Math.min(this.length,C.length);for(var A=0;A<B;A++){D[C[A]]=this[A];}return D;},link:function(C){var A={};
-for(var E=0,B=this.length;E<B;E++){for(var D in C){if(C[D](this[E])){A[D]=this[E];delete C[D];break;}}}return A;},contains:function(A,B){return this.indexOf(A,B)!=-1;
-},extend:function(C){for(var B=0,A=C.length;B<A;B++){this.push(C[B]);}return this;},getLast:function(){return(this.length)?this[this.length-1]:null;},getRandom:function(){return(this.length)?this[$random(0,this.length-1)]:null;
-},include:function(A){if(!this.contains(A)){this.push(A);}return this;},combine:function(C){for(var B=0,A=C.length;B<A;B++){this.include(C[B]);}return this;
-},erase:function(B){for(var A=this.length;A--;A){if(this[A]===B){this.splice(A,1);}}return this;},empty:function(){this.length=0;return this;},flatten:function(){var D=[];
-for(var B=0,A=this.length;B<A;B++){var C=$type(this[B]);if(!C){continue;}D=D.concat((C=="array"||C=="collection"||C=="arguments")?Array.flatten(this[B]):this[B]);
-}return D;},hexToRgb:function(B){if(this.length!=3){return null;}var A=this.map(function(C){if(C.length==1){C+=C;}return C.toInt(16);});return(B)?A:"rgb("+A+")";
-},rgbToHex:function(D){if(this.length<3){return null;}if(this.length==4&&this[3]==0&&!D){return"transparent";}var B=[];for(var A=0;A<3;A++){var C=(this[A]-0).toString(16);
-B.push((C.length==1)?"0"+C:C);}return(D)?B:"#"+B.join("");}});Function.implement({extend:function(A){for(var B in A){this[B]=A[B];}return this;},create:function(B){var A=this;
-B=B||{};return function(D){var C=B.arguments;C=(C!=undefined)?$splat(C):Array.slice(arguments,(B.event)?1:0);if(B.event){C=[D||window.event].extend(C);
-}var E=function(){return A.apply(B.bind||null,C);};if(B.delay){return setTimeout(E,B.delay);}if(B.periodical){return setInterval(E,B.periodical);}if(B.attempt){return $try(E);
-}return E();};},pass:function(A,B){return this.create({arguments:A,bind:B});},attempt:function(A,B){return this.create({arguments:A,bind:B,attempt:true})();
-},bind:function(B,A){return this.create({bind:B,arguments:A});},bindWithEvent:function(B,A){return this.create({bind:B,event:true,arguments:A});},delay:function(B,C,A){return this.create({delay:B,bind:C,arguments:A})();
-},periodical:function(A,C,B){return this.create({periodical:A,bind:C,arguments:B})();},run:function(A,B){return this.apply(B,$splat(A));}});Number.implement({limit:function(B,A){return Math.min(A,Math.max(B,this));
-},round:function(A){A=Math.pow(10,A||0);return Math.round(this*A)/A;},times:function(B,C){for(var A=0;A<this;A++){B.call(C,A,this);}},toFloat:function(){return parseFloat(this);
-},toInt:function(A){return parseInt(this,A||10);}});Number.alias("times","each");(function(B){var A={};B.each(function(C){if(!Number[C]){A[C]=function(){return Math[C].apply(null,[this].concat($A(arguments)));
-};}});Number.implement(A);})(["abs","acos","asin","atan","atan2","ceil","cos","exp","floor","log","max","min","pow","sin","sqrt","tan"]);String.implement({test:function(A,B){return((typeof A=="string")?new RegExp(A,B):A).test(this);
-},contains:function(A,B){return(B)?(B+this+B).indexOf(B+A+B)>-1:this.indexOf(A)>-1;},trim:function(){return this.replace(/^\s+|\s+$/g,"");},clean:function(){return this.replace(/\s+/g," ").trim();
-},camelCase:function(){return this.replace(/-\D/g,function(A){return A.charAt(1).toUpperCase();});},hyphenate:function(){return this.replace(/[A-Z]/g,function(A){return("-"+A.charAt(0).toLowerCase());
-});},capitalize:function(){return this.replace(/\b[a-z]/g,function(A){return A.toUpperCase();});},escapeRegExp:function(){return this.replace(/([-.*+?^${}()|[\]\/\\])/g,"\\$1");
-},toInt:function(A){return parseInt(this,A||10);},toFloat:function(){return parseFloat(this);},hexToRgb:function(B){var A=this.match(/^#?(\w{1,2})(\w{1,2})(\w{1,2})$/);
-return(A)?A.slice(1).hexToRgb(B):null;},rgbToHex:function(B){var A=this.match(/\d{1,3}/g);return(A)?A.rgbToHex(B):null;},stripScripts:function(B){var A="";
-var C=this.replace(/<script[^>]*>([\s\S]*?)<\/script>/gi,function(){A+=arguments[1]+"\n";return"";});if(B===true){$exec(A);}else{if($type(B)=="function"){B(A,C);
-}}return C;},substitute:function(A,B){return this.replace(B||(/\\?\{([^}]+)\}/g),function(D,C){if(D.charAt(0)=="\\"){return D.slice(1);}return(A[C]!=undefined)?A[C]:"";
-});}});Hash.implement({has:Object.prototype.hasOwnProperty,keyOf:function(B){for(var A in this){if(this.hasOwnProperty(A)&&this[A]===B){return A;}}return null;
-},hasValue:function(A){return(Hash.keyOf(this,A)!==null);},extend:function(A){Hash.each(A,function(C,B){Hash.set(this,B,C);},this);return this;},combine:function(A){Hash.each(A,function(C,B){Hash.include(this,B,C);
-},this);return this;},erase:function(A){if(this.hasOwnProperty(A)){delete this[A];}return this;},get:function(A){return(this.hasOwnProperty(A))?this[A]:null;
-},set:function(A,B){if(!this[A]||this.hasOwnProperty(A)){this[A]=B;}return this;},empty:function(){Hash.each(this,function(B,A){delete this[A];},this);
-return this;},include:function(B,C){var A=this[B];if(A==undefined){this[B]=C;}return this;},map:function(B,C){var A=new Hash;Hash.each(this,function(E,D){A.set(D,B.call(C,E,D,this));
-},this);return A;},filter:function(B,C){var A=new Hash;Hash.each(this,function(E,D){if(B.call(C,E,D,this)){A.set(D,E);}},this);return A;},every:function(B,C){for(var A in this){if(this.hasOwnProperty(A)&&!B.call(C,this[A],A)){return false;
-}}return true;},some:function(B,C){for(var A in this){if(this.hasOwnProperty(A)&&B.call(C,this[A],A)){return true;}}return false;},getKeys:function(){var A=[];
-Hash.each(this,function(C,B){A.push(B);});return A;},getValues:function(){var A=[];Hash.each(this,function(B){A.push(B);});return A;},toQueryString:function(A){var B=[];
-Hash.each(this,function(F,E){if(A){E=A+"["+E+"]";}var D;switch($type(F)){case"object":D=Hash.toQueryString(F,E);break;case"array":var C={};F.each(function(H,G){C[G]=H;
-});D=Hash.toQueryString(C,E);break;default:D=E+"="+encodeURIComponent(F);}if(F!=undefined){B.push(D);}});return B.join("&");}});Hash.alias({keyOf:"indexOf",hasValue:"contains"});
-var Event=new Native({name:"Event",initialize:function(A,F){F=F||window;var K=F.document;A=A||F.event;if(A.$extended){return A;}this.$extended=true;var J=A.type;
-var G=A.target||A.srcElement;while(G&&G.nodeType==3){G=G.parentNode;}if(J.test(/key/)){var B=A.which||A.keyCode;var M=Event.Keys.keyOf(B);if(J=="keydown"){var D=B-111;
-if(D>0&&D<13){M="f"+D;}}M=M||String.fromCharCode(B).toLowerCase();}else{if(J.match(/(click|mouse|menu)/i)){K=(!K.compatMode||K.compatMode=="CSS1Compat")?K.html:K.body;
-var I={x:A.pageX||A.clientX+K.scrollLeft,y:A.pageY||A.clientY+K.scrollTop};var C={x:(A.pageX)?A.pageX-F.pageXOffset:A.clientX,y:(A.pageY)?A.pageY-F.pageYOffset:A.clientY};
-if(J.match(/DOMMouseScroll|mousewheel/)){var H=(A.wheelDelta)?A.wheelDelta/120:-(A.detail||0)/3;}var E=(A.which==3)||(A.button==2);var L=null;if(J.match(/over|out/)){switch(J){case"mouseover":L=A.relatedTarget||A.fromElement;
-break;case"mouseout":L=A.relatedTarget||A.toElement;}if(!(function(){while(L&&L.nodeType==3){L=L.parentNode;}return true;}).create({attempt:Browser.Engine.gecko})()){L=false;
-}}}}return $extend(this,{event:A,type:J,page:I,client:C,rightClick:E,wheel:H,relatedTarget:L,target:G,code:B,key:M,shift:A.shiftKey,control:A.ctrlKey,alt:A.altKey,meta:A.metaKey});
-}});Event.Keys=new Hash({enter:13,up:38,down:40,left:37,right:39,esc:27,space:32,backspace:8,tab:9,"delete":46});Event.implement({stop:function(){return this.stopPropagation().preventDefault();
-},stopPropagation:function(){if(this.event.stopPropagation){this.event.stopPropagation();}else{this.event.cancelBubble=true;}return this;},preventDefault:function(){if(this.event.preventDefault){this.event.preventDefault();
-}else{this.event.returnValue=false;}return this;}});var Class=new Native({name:"Class",initialize:function(B){B=B||{};var A=function(E){for(var D in this){this[D]=$unlink(this[D]);
-}for(var F in Class.Mutators){if(!this[F]){continue;}Class.Mutators[F](this,this[F]);delete this[F];}this.constructor=A;if(E===$empty){return this;}var C=(this.initialize)?this.initialize.apply(this,arguments):this;
-if(this.options&&this.options.initialize){this.options.initialize.call(this);}return C;};$extend(A,this);A.constructor=Class;A.prototype=B;return A;}});
-Class.implement({implement:function(){Class.Mutators.Implements(this.prototype,Array.slice(arguments));return this;}});Class.Mutators={Implements:function(A,B){$splat(B).each(function(C){$extend(A,($type(C)=="class")?new C($empty):C);
-});},Extends:function(self,klass){var instance=new klass($empty);delete instance.parent;delete instance.parentOf;for(var key in instance){var current=self[key],previous=instance[key];
-if(current==undefined){self[key]=previous;continue;}var ctype=$type(current),ptype=$type(previous);if(ctype!=ptype){continue;}switch(ctype){case"function":if(!arguments.callee.caller){self[key]=eval("("+String(current).replace(/\bthis\.parent\(\s*(\))?/g,function(full,close){return"arguments.callee._parent_.call(this"+(close||", ");
-})+")");}self[key]._parent_=previous;break;case"object":self[key]=$merge(previous,current);}}self.parent=function(){return arguments.callee.caller._parent_.apply(this,arguments);
-};self.parentOf=function(descendant){return descendant._parent_.apply(this,Array.slice(arguments,1));};}};var Chain=new Class({chain:function(){this.$chain=(this.$chain||[]).extend(arguments);
-return this;},callChain:function(){return(this.$chain&&this.$chain.length)?this.$chain.shift().apply(this,arguments):false;},clearChain:function(){if(this.$chain){this.$chain.empty();
-}return this;}});var Events=new Class({addEvent:function(C,B,A){C=Events.removeOn(C);if(B!=$empty){this.$events=this.$events||{};this.$events[C]=this.$events[C]||[];
-this.$events[C].include(B);if(A){B.internal=true;}}return this;},addEvents:function(A){for(var B in A){this.addEvent(B,A[B]);}return this;},fireEvent:function(C,B,A){C=Events.removeOn(C);
-if(!this.$events||!this.$events[C]){return this;}this.$events[C].each(function(D){D.create({bind:this,delay:A,"arguments":B})();},this);return this;},removeEvent:function(B,A){B=Events.removeOn(B);
-if(!this.$events||!this.$events[B]){return this;}if(!A.internal){this.$events[B].erase(A);}return this;},removeEvents:function(C){for(var D in this.$events){if(C&&C!=D){continue;
-}var B=this.$events[D];for(var A=B.length;A--;A){this.removeEvent(D,B[A]);}}return this;}});Events.removeOn=function(A){return A.replace(/^on([A-Z])/,function(B,C){return C.toLowerCase();
-});};var Options=new Class({setOptions:function(){this.options=$merge.run([this.options].extend(arguments));if(!this.addEvent){return this;}for(var A in this.options){if($type(this.options[A])!="function"||!(/^on[A-Z]/).test(A)){continue;
-}this.addEvent(A,this.options[A]);delete this.options[A];}return this;}});Document.implement({newElement:function(A,B){if(Browser.Engine.trident&&B){["name","type","checked"].each(function(C){if(!B[C]){return ;
-}A+=" "+C+'="'+B[C]+'"';if(C!="checked"){delete B[C];}});A="<"+A+">";}return $.element(this.createElement(A)).set(B);},newTextNode:function(A){return this.createTextNode(A);
-},getDocument:function(){return this;},getWindow:function(){return this.defaultView||this.parentWindow;},purge:function(){var C=this.getElementsByTagName("*");
-for(var B=0,A=C.length;B<A;B++){Browser.freeMem(C[B]);}}});var Element=new Native({name:"Element",legacy:window.Element,initialize:function(A,B){var C=Element.Constructors.get(A);
-if(C){return C(B);}if(typeof A=="string"){return document.newElement(A,B);}return $(A).set(B);},afterImplement:function(A,B){if(!Array[A]){Elements.implement(A,Elements.multi(A));
-}Element.Prototype[A]=B;}});Element.Prototype={$family:{name:"element"}};Element.Constructors=new Hash;var IFrame=new Native({name:"IFrame",generics:false,initialize:function(){var E=Array.link(arguments,{properties:Object.type,iframe:$defined});
-var C=E.properties||{};var B=$(E.iframe)||false;var D=C.onload||$empty;delete C.onload;C.id=C.name=$pick(C.id,C.name,B.id,B.name,"IFrame_"+$time());B=new Element(B||"iframe",C);
-var A=function(){var F=$try(function(){return B.contentWindow.location.host;});if(F&&F==window.location.host){var H=new Window(B.contentWindow);var G=new Document(B.contentWindow.document);
-$extend(H.Element.prototype,Element.Prototype);}D.call(B.contentWindow,B.contentWindow.document);};(!window.frames[C.id])?B.addListener("load",A):A();return B;
-}});var Elements=new Native({initialize:function(F,B){B=$extend({ddup:true,cash:true},B);F=F||[];if(B.ddup||B.cash){var G={},E=[];for(var C=0,A=F.length;
-C<A;C++){var D=$.element(F[C],!B.cash);if(B.ddup){if(G[D.uid]){continue;}G[D.uid]=true;}E.push(D);}F=E;}return(B.cash)?$extend(F,this):F;}});Elements.implement({filter:function(A,B){if(!A){return this;
-}return new Elements(Array.filter(this,(typeof A=="string")?function(C){return C.match(A);}:A,B));}});Elements.multi=function(A){return function(){var B=[];
-var F=true;for(var D=0,C=this.length;D<C;D++){var E=this[D][A].apply(this[D],arguments);B.push(E);if(F){F=($type(E)=="element");}}return(F)?new Elements(B):B;
-};};Window.implement({$:function(B,C){if(B&&B.$family&&B.uid){return B;}var A=$type(B);return($[A])?$[A](B,C,this.document):null;},$$:function(A){if(arguments.length==1&&typeof A=="string"){return this.document.getElements(A);
-}var F=[];var C=Array.flatten(arguments);for(var D=0,B=C.length;D<B;D++){var E=C[D];switch($type(E)){case"element":E=[E];break;case"string":E=this.document.getElements(E,true);
-break;default:E=false;}if(E){F.extend(E);}}return new Elements(F);},getDocument:function(){return this.document;},getWindow:function(){return this;}});
-$.string=function(C,B,A){C=A.getElementById(C);return(C)?$.element(C,B):null;};$.element=function(A,D){$uid(A);if(!D&&!A.$family&&!(/^object|embed$/i).test(A.tagName)){var B=Element.Prototype;
-for(var C in B){A[C]=B[C];}}return A;};$.object=function(B,C,A){if(B.toElement){return $.element(B.toElement(A),C);}return null;};$.textnode=$.whitespace=$.window=$.document=$arguments(0);
-Native.implement([Element,Document],{getElement:function(A,B){return $(this.getElements(A,true)[0]||null,B);},getElements:function(A,D){A=A.split(",");
-var C=[];var B=(A.length>1);A.each(function(E){var F=this.getElementsByTagName(E.trim());(B)?C.extend(F):C=F;},this);return new Elements(C,{ddup:B,cash:!D});
-}});Element.Storage={get:function(A){return(this[A]||(this[A]={}));}};Element.Inserters=new Hash({before:function(B,A){if(A.parentNode){A.parentNode.insertBefore(B,A);
-}},after:function(B,A){if(!A.parentNode){return ;}var C=A.nextSibling;(C)?A.parentNode.insertBefore(B,C):A.parentNode.appendChild(B);},bottom:function(B,A){A.appendChild(B);
-},top:function(B,A){var C=A.firstChild;(C)?A.insertBefore(B,C):A.appendChild(B);}});Element.Inserters.inside=Element.Inserters.bottom;Element.Inserters.each(function(C,B){var A=B.capitalize();
-Element.implement("inject"+A,function(D){C(this,$(D,true));return this;});Element.implement("grab"+A,function(D){C($(D,true),this);return this;});});Element.implement({getDocument:function(){return this.ownerDocument;
-},getWindow:function(){return this.ownerDocument.getWindow();},getElementById:function(D,C){var B=this.ownerDocument.getElementById(D);if(!B){return null;
-}for(var A=B.parentNode;A!=this;A=A.parentNode){if(!A){return null;}}return $.element(B,C);},set:function(D,B){switch($type(D)){case"object":for(var C in D){this.set(C,D[C]);
-}break;case"string":var A=Element.Properties.get(D);(A&&A.set)?A.set.apply(this,Array.slice(arguments,1)):this.setProperty(D,B);}return this;},get:function(B){var A=Element.Properties.get(B);
-return(A&&A.get)?A.get.apply(this,Array.slice(arguments,1)):this.getProperty(B);},erase:function(B){var A=Element.Properties.get(B);(A&&A.erase)?A.erase.apply(this,Array.slice(arguments,1)):this.removeProperty(B);
-return this;},match:function(A){return(!A||Element.get(this,"tag")==A);},inject:function(B,A){Element.Inserters.get(A||"bottom")(this,$(B,true));return this;
-},wraps:function(B,A){B=$(B,true);return this.replaces(B).grab(B,A);},grab:function(B,A){Element.Inserters.get(A||"bottom")($(B,true),this);return this;
-},appendText:function(B,A){return this.grab(this.getDocument().newTextNode(B),A);},adopt:function(){Array.flatten(arguments).each(function(A){A=$(A,true);
-if(A){this.appendChild(A);}},this);return this;},dispose:function(){return(this.parentNode)?this.parentNode.removeChild(this):this;},clone:function(D,C){switch($type(this)){case"element":var H={};
-for(var G=0,E=this.attributes.length;G<E;G++){var B=this.attributes[G],L=B.nodeName.toLowerCase();if(Browser.Engine.trident&&(/input/i).test(this.tagName)&&(/width|height/).test(L)){continue;
-}var K=(L=="style"&&this.style)?this.style.cssText:B.nodeValue;if(!$chk(K)||L=="uid"||(L=="id"&&!C)){continue;}if(K!="inherit"&&["string","number"].contains($type(K))){H[L]=K;
-}}var J=new Element(this.nodeName.toLowerCase(),H);if(D!==false){for(var I=0,F=this.childNodes.length;I<F;I++){var A=Element.clone(this.childNodes[I],true,C);
-if(A){J.grab(A);}}}return J;case"textnode":return document.newTextNode(this.nodeValue);}return null;},replaces:function(A){A=$(A,true);A.parentNode.replaceChild(this,A);
-return this;},hasClass:function(A){return this.className.contains(A," ");},addClass:function(A){if(!this.hasClass(A)){this.className=(this.className+" "+A).clean();
-}return this;},removeClass:function(A){this.className=this.className.replace(new RegExp("(^|\\s)"+A+"(?:\\s|$)"),"$1").clean();return this;},toggleClass:function(A){return this.hasClass(A)?this.removeClass(A):this.addClass(A);
-},getComputedStyle:function(B){if(this.currentStyle){return this.currentStyle[B.camelCase()];}var A=this.getWindow().getComputedStyle(this,null);return(A)?A.getPropertyValue([B.hyphenate()]):null;
-},empty:function(){$A(this.childNodes).each(function(A){Browser.freeMem(A);Element.empty(A);Element.dispose(A);},this);return this;},destroy:function(){Browser.freeMem(this.empty().dispose());
-return null;},getSelected:function(){return new Elements($A(this.options).filter(function(A){return A.selected;}));},toQueryString:function(){var A=[];
-this.getElements("input, select, textarea").each(function(B){if(!B.name||B.disabled){return ;}var C=(B.tagName.toLowerCase()=="select")?Element.getSelected(B).map(function(D){return D.value;
-}):((B.type=="radio"||B.type=="checkbox")&&!B.checked)?null:B.value;$splat(C).each(function(D){if(D){A.push(B.name+"="+encodeURIComponent(D));}});});return A.join("&");
-},getProperty:function(C){var B=Element.Attributes,A=B.Props[C];var D=(A)?this[A]:this.getAttribute(C,2);return(B.Bools[C])?!!D:(A)?D:D||null;},getProperties:function(){var A=$A(arguments);
-return A.map(function(B){return this.getProperty(B);},this).associate(A);},setProperty:function(D,E){var C=Element.Attributes,B=C.Props[D],A=$defined(E);
-if(B&&C.Bools[D]){E=(E||!A)?true:false;}else{if(!A){return this.removeProperty(D);}}(B)?this[B]=E:this.setAttribute(D,E);return this;},setProperties:function(A){for(var B in A){this.setProperty(B,A[B]);
-}return this;},removeProperty:function(D){var C=Element.Attributes,B=C.Props[D],A=(B&&C.Bools[D]);(B)?this[B]=(A)?false:"":this.removeAttribute(D);return this;
-},removeProperties:function(){Array.each(arguments,this.removeProperty,this);return this;}});(function(){var A=function(D,B,I,C,F,H){var E=D[I||B];var G=[];
-while(E){if(E.nodeType==1&&(!C||Element.match(E,C))){G.push(E);if(!F){break;}}E=E[B];}return(F)?new Elements(G,{ddup:false,cash:!H}):$(G[0],H);};Element.implement({getPrevious:function(B,C){return A(this,"previousSibling",null,B,false,C);
-},getAllPrevious:function(B,C){return A(this,"previousSibling",null,B,true,C);},getNext:function(B,C){return A(this,"nextSibling",null,B,false,C);},getAllNext:function(B,C){return A(this,"nextSibling",null,B,true,C);
-},getFirst:function(B,C){return A(this,"nextSibling","firstChild",B,false,C);},getLast:function(B,C){return A(this,"previousSibling","lastChild",B,false,C);
-},getParent:function(B,C){return A(this,"parentNode",null,B,false,C);},getParents:function(B,C){return A(this,"parentNode",null,B,true,C);},getChildren:function(B,C){return A(this,"nextSibling","firstChild",B,true,C);
-},hasChild:function(B){B=$(B,true);return(!!B&&$A(this.getElementsByTagName(B.tagName)).contains(B));}});})();Element.Properties=new Hash;Element.Properties.style={set:function(A){this.style.cssText=A;
-},get:function(){return this.style.cssText;},erase:function(){this.style.cssText="";}};Element.Properties.tag={get:function(){return this.tagName.toLowerCase();
-}};Element.Properties.href={get:function(){return(!this.href)?null:this.href.replace(new RegExp("^"+document.location.protocol+"//"+document.location.host),"");
-}};Element.Properties.html={set:function(){return this.innerHTML=Array.flatten(arguments).join("");}};Native.implement([Element,Window,Document],{addListener:function(B,A){if(this.addEventListener){this.addEventListener(B,A,false);
-}else{this.attachEvent("on"+B,A);}return this;},removeListener:function(B,A){if(this.removeEventListener){this.removeEventListener(B,A,false);}else{this.detachEvent("on"+B,A);
-}return this;},retrieve:function(B,A){var D=Element.Storage.get(this.uid);var C=D[B];if($defined(A)&&!$defined(C)){C=D[B]=A;}return $pick(C);},store:function(B,A){var C=Element.Storage.get(this.uid);
-C[B]=A;return this;},eliminate:function(A){var B=Element.Storage.get(this.uid);delete B[A];return this;}});Element.Attributes=new Hash({Props:{html:"innerHTML","class":"className","for":"htmlFor",text:(Browser.Engine.trident)?"innerText":"textContent"},Bools:["compact","nowrap","ismap","declare","noshade","checked","disabled","readonly","multiple","selected","noresize","defer"],Camels:["value","accessKey","cellPadding","cellSpacing","colSpan","frameBorder","maxLength","readOnly","rowSpan","tabIndex","useMap"]});
-Browser.freeMem=function(A){if(!A){return ;}if(Browser.Engine.trident&&(/object/i).test(A.tagName)){for(var B in A){if(typeof A[B]=="function"){A[B]=$empty;
-}}Element.dispose(A);}if(A.uid&&A.removeEvents){A.removeEvents();}};(function(B){var C=B.Bools,A=B.Camels;B.Bools=C=C.associate(C);Hash.extend(Hash.combine(B.Props,C),A.associate(A.map(function(D){return D.toLowerCase();
-})));B.erase("Camels");})(Element.Attributes);window.addListener("unload",function(){window.removeListener("unload",arguments.callee);document.purge();
-if(Browser.Engine.trident){CollectGarbage();}});Element.Properties.events={set:function(A){this.addEvents(A);}};Native.implement([Element,Window,Document],{addEvent:function(E,G){var H=this.retrieve("events",{});
-H[E]=H[E]||{keys:[],values:[]};if(H[E].keys.contains(G)){return this;}H[E].keys.push(G);var F=E,A=Element.Events.get(E),C=G,I=this;if(A){if(A.onAdd){A.onAdd.call(this,G);
-}if(A.condition){C=function(J){if(A.condition.call(this,J)){return G.call(this,J);}return false;};}F=A.base||F;}var D=function(){return G.call(I);};var B=Element.NativeEvents[F]||0;
-if(B){if(B==2){D=function(J){J=new Event(J,I.getWindow());if(C.call(I,J)===false){J.stop();}};}this.addListener(F,D);}H[E].values.push(D);return this;},removeEvent:function(D,C){var B=this.retrieve("events");
-if(!B||!B[D]){return this;}var G=B[D].keys.indexOf(C);if(G==-1){return this;}var A=B[D].keys.splice(G,1)[0];var F=B[D].values.splice(G,1)[0];var E=Element.Events.get(D);
-if(E){if(E.onRemove){E.onRemove.call(this,C);}D=E.base||D;}return(Element.NativeEvents[D])?this.removeListener(D,F):this;},addEvents:function(A){for(var B in A){this.addEvent(B,A[B]);
-}return this;},removeEvents:function(B){var A=this.retrieve("events");if(!A){return this;}if(!B){for(var C in A){this.removeEvents(C);}A=null;}else{if(A[B]){while(A[B].keys[0]){this.removeEvent(B,A[B].keys[0]);
-}A[B]=null;}}return this;},fireEvent:function(D,B,A){var C=this.retrieve("events");if(!C||!C[D]){return this;}C[D].keys.each(function(E){E.create({bind:this,delay:A,"arguments":B})();
-},this);return this;},cloneEvents:function(D,A){D=$(D);var C=D.retrieve("events");if(!C){return this;}if(!A){for(var B in C){this.cloneEvents(D,B);}}else{if(C[A]){C[A].keys.each(function(E){this.addEvent(A,E);
-},this);}}return this;}});Element.NativeEvents={click:2,dblclick:2,mouseup:2,mousedown:2,contextmenu:2,mousewheel:2,DOMMouseScroll:2,mouseover:2,mouseout:2,mousemove:2,selectstart:2,selectend:2,keydown:2,keypress:2,keyup:2,focus:2,blur:2,change:2,reset:2,select:2,submit:2,load:1,unload:1,beforeunload:2,resize:1,move:1,DOMContentLoaded:1,readystatechange:1,error:1,abort:1,scroll:1};
-(function(){var A=function(B){var C=B.relatedTarget;if(C==undefined){return true;}if(C===false){return false;}return($type(this)!="document"&&C!=this&&C.prefix!="xul"&&!this.hasChild(C));
-};Element.Events=new Hash({mouseenter:{base:"mouseover",condition:A},mouseleave:{base:"mouseout",condition:A},mousewheel:{base:(Browser.Engine.gecko)?"DOMMouseScroll":"mousewheel"}});
-})();Element.Properties.styles={set:function(A){this.setStyles(A);}};Element.Properties.opacity={set:function(A,B){if(!B){if(A==0){if(this.style.visibility!="hidden"){this.style.visibility="hidden";
-}}else{if(this.style.visibility!="visible"){this.style.visibility="visible";}}}if(!this.currentStyle||!this.currentStyle.hasLayout){this.style.zoom=1;}if(Browser.Engine.trident){this.style.filter=(A==1)?"":"alpha(opacity="+A*100+")";
-}this.style.opacity=A;this.store("opacity",A);},get:function(){return this.retrieve("opacity",1);}};Element.implement({setOpacity:function(A){return this.set("opacity",A,true);
-},getOpacity:function(){return this.get("opacity");},setStyle:function(B,A){switch(B){case"opacity":return this.set("opacity",parseFloat(A));case"float":B=(Browser.Engine.trident)?"styleFloat":"cssFloat";
-}B=B.camelCase();if($type(A)!="string"){var C=(Element.Styles.get(B)||"@").split(" ");A=$splat(A).map(function(E,D){if(!C[D]){return"";}return($type(E)=="number")?C[D].replace("@",Math.round(E)):E;
-}).join(" ");}else{if(A==String(Number(A))){A=Math.round(A);}}this.style[B]=A;return this;},getStyle:function(G){switch(G){case"opacity":return this.get("opacity");
-case"float":G=(Browser.Engine.trident)?"styleFloat":"cssFloat";}G=G.camelCase();var A=this.style[G];if(!$chk(A)){A=[];for(var F in Element.ShortStyles){if(G!=F){continue;
-}for(var E in Element.ShortStyles[F]){A.push(this.getStyle(E));}return A.join(" ");}A=this.getComputedStyle(G);}if(A){A=String(A);var C=A.match(/rgba?\([\d\s,]+\)/);
-if(C){A=A.replace(C[0],C[0].rgbToHex());}}if(Browser.Engine.presto||(Browser.Engine.trident&&!$chk(parseInt(A)))){if(G.test(/^(height|width)$/)){var B=(G=="width")?["left","right"]:["top","bottom"],D=0;
-B.each(function(H){D+=this.getStyle("border-"+H+"-width").toInt()+this.getStyle("padding-"+H).toInt();},this);return this["offset"+G.capitalize()]-D+"px";
-}if(Browser.Engine.presto&&String(A).test("px")){return A;}if(G.test(/(border(.+)Width|margin|padding)/)){return"0px";}}return A;},setStyles:function(B){for(var A in B){this.setStyle(A,B[A]);
-}return this;},getStyles:function(){var A={};Array.each(arguments,function(B){A[B]=this.getStyle(B);},this);return A;}});Element.Styles=new Hash({left:"@px",top:"@px",bottom:"@px",right:"@px",width:"@px",height:"@px",maxWidth:"@px",maxHeight:"@px",minWidth:"@px",minHeight:"@px",backgroundColor:"rgb(@, @, @)",backgroundPosition:"@px @px",color:"rgb(@, @, @)",fontSize:"@px",letterSpacing:"@px",lineHeight:"@px",clip:"rect(@px @px @px @px)",margin:"@px @px @px @px",padding:"@px @px @px @px",border:"@px @ rgb(@, @, @) @px @ rgb(@, @, @) @px @ rgb(@, @, @)",borderWidth:"@px @px @px @px",borderStyle:"@ @ @ @",borderColor:"rgb(@, @, @) rgb(@, @, @) rgb(@, @, @) rgb(@, @, @)",zIndex:"@",zoom:"@",fontWeight:"@",textIndent:"@px",opacity:"@"});
-Element.ShortStyles={margin:{},padding:{},border:{},borderWidth:{},borderStyle:{},borderColor:{}};["Top","Right","Bottom","Left"].each(function(G){var F=Element.ShortStyles;
-var B=Element.Styles;["margin","padding"].each(function(H){var I=H+G;F[H][I]=B[I]="@px";});var E="border"+G;F.border[E]=B[E]="@px @ rgb(@, @, @)";var D=E+"Width",A=E+"Style",C=E+"Color";
-F[E]={};F.borderWidth[D]=F[E][D]=B[D]="@px";F.borderStyle[A]=F[E][A]=B[A]="@";F.borderColor[C]=F[E][C]=B[C]="rgb(@, @, @)";});(function(){Element.implement({scrollTo:function(H,I){if(B(this)){this.getWindow().scrollTo(H,I);
-}else{this.scrollLeft=H;this.scrollTop=I;}return this;},getSize:function(){if(B(this)){return this.getWindow().getSize();}return{x:this.offsetWidth,y:this.offsetHeight};
-},getScrollSize:function(){if(B(this)){return this.getWindow().getScrollSize();}return{x:this.scrollWidth,y:this.scrollHeight};},getScroll:function(){if(B(this)){return this.getWindow().getScroll();
-}return{x:this.scrollLeft,y:this.scrollTop};},getScrolls:function(){var I=this,H={x:0,y:0};while(I&&!B(I)){H.x+=I.scrollLeft;H.y+=I.scrollTop;I=I.parentNode;
-}return H;},getOffsetParent:function(){var H=this;if(B(H)){return null;}if(!Browser.Engine.trident){return H.offsetParent;}while((H=H.parentNode)&&!B(H)){if(D(H,"position")!="static"){return H;
-}}return null;},getOffsets:function(){var I=this,H={x:0,y:0};if(B(this)){return H;}while(I&&!B(I)){H.x+=I.offsetLeft;H.y+=I.offsetTop;if(Browser.Engine.gecko){if(!F(I)){H.x+=C(I);
-H.y+=G(I);}var J=I.parentNode;if(J&&D(J,"overflow")!="visible"){H.x+=C(J);H.y+=G(J);}}else{if(I!=this&&(Browser.Engine.trident||Browser.Engine.webkit)){H.x+=C(I);
-H.y+=G(I);}}I=I.offsetParent;if(Browser.Engine.trident){while(I&&!I.currentStyle.hasLayout){I=I.offsetParent;}}}if(Browser.Engine.gecko&&!F(this)){H.x-=C(this);
-H.y-=G(this);}return H;},getPosition:function(K){if(B(this)){return{x:0,y:0};}var L=this.getOffsets(),I=this.getScrolls();var H={x:L.x-I.x,y:L.y-I.y};var J=(K&&(K=$(K)))?K.getPosition():{x:0,y:0};
-return{x:H.x-J.x,y:H.y-J.y};},getCoordinates:function(J){if(B(this)){return this.getWindow().getCoordinates();}var H=this.getPosition(J),I=this.getSize();
-var K={left:H.x,top:H.y,width:I.x,height:I.y};K.right=K.left+K.width;K.bottom=K.top+K.height;return K;},computePosition:function(H){return{left:H.x-E(this,"margin-left"),top:H.y-E(this,"margin-top")};
-},position:function(H){return this.setStyles(this.computePosition(H));}});Native.implement([Document,Window],{getSize:function(){var I=this.getWindow();
-if(Browser.Engine.presto||Browser.Engine.webkit){return{x:I.innerWidth,y:I.innerHeight};}var H=A(this);return{x:H.clientWidth,y:H.clientHeight};},getScroll:function(){var I=this.getWindow();
-var H=A(this);return{x:I.pageXOffset||H.scrollLeft,y:I.pageYOffset||H.scrollTop};},getScrollSize:function(){var I=A(this);var H=this.getSize();return{x:Math.max(I.scrollWidth,H.x),y:Math.max(I.scrollHeight,H.y)};
-},getPosition:function(){return{x:0,y:0};},getCoordinates:function(){var H=this.getSize();return{top:0,left:0,bottom:H.y,right:H.x,height:H.y,width:H.x};
-}});var D=Element.getComputedStyle;function E(H,I){return D(H,I).toInt()||0;}function F(H){return D(H,"-moz-box-sizing")=="border-box";}function G(H){return E(H,"border-top-width");
-}function C(H){return E(H,"border-left-width");}function B(H){return(/^(?:body|html)$/i).test(H.tagName);}function A(H){var I=H.getDocument();return(!I.compatMode||I.compatMode=="CSS1Compat")?I.html:I.body;
-}})();Native.implement([Window,Document,Element],{getHeight:function(){return this.getSize().y;},getWidth:function(){return this.getSize().x;},getScrollTop:function(){return this.getScroll().y;
-},getScrollLeft:function(){return this.getScroll().x;},getScrollHeight:function(){return this.getScrollSize().y;},getScrollWidth:function(){return this.getScrollSize().x;
-},getTop:function(){return this.getPosition().y;},getLeft:function(){return this.getPosition().x;}});Native.implement([Document,Element],{getElements:function(H,G){H=H.split(",");
-var C,E={};for(var D=0,B=H.length;D<B;D++){var A=H[D],F=Selectors.Utils.search(this,A,E);if(D!=0&&F.item){F=$A(F);}C=(D==0)?F:(C.item)?$A(C).concat(F):C.concat(F);
-}return new Elements(C,{ddup:(H.length>1),cash:!G});}});Element.implement({match:function(B){if(!B){return true;}var D=Selectors.Utils.parseTagAndID(B);
-var A=D[0],E=D[1];if(!Selectors.Filters.byID(this,E)||!Selectors.Filters.byTag(this,A)){return false;}var C=Selectors.Utils.parseSelector(B);return(C)?Selectors.Utils.filter(this,C,{}):true;
-}});var Selectors={Cache:{nth:{},parsed:{}}};Selectors.RegExps={id:(/#([\w-]+)/),tag:(/^(\w+|\*)/),quick:(/^(\w+|\*)$/),splitter:(/\s*([+>~\s])\s*([a-zA-Z#.*:\[])/g),combined:(/\.([\w-]+)|\[(\w+)(?:([!*^$~|]?=)["']?(.*?)["']?)?\]|:([\w-]+)(?:\(["']?(.*?)?["']?\)|$)/g)};
-Selectors.Utils={chk:function(B,C){if(!C){return true;}var A=$uid(B);if(!C[A]){return C[A]=true;}return false;},parseNthArgument:function(F){if(Selectors.Cache.nth[F]){return Selectors.Cache.nth[F];
-}var C=F.match(/^([+-]?\d*)?([a-z]+)?([+-]?\d*)?$/);if(!C){return false;}var E=parseInt(C[1]);var B=(E||E===0)?E:1;var D=C[2]||false;var A=parseInt(C[3])||0;
-if(B!=0){A--;while(A<1){A+=B;}while(A>=B){A-=B;}}else{B=A;D="index";}switch(D){case"n":C={a:B,b:A,special:"n"};break;case"odd":C={a:2,b:0,special:"n"};
-break;case"even":C={a:2,b:1,special:"n"};break;case"first":C={a:0,special:"index"};break;case"last":C={special:"last-child"};break;case"only":C={special:"only-child"};
-break;default:C={a:(B-1),special:"index"};}return Selectors.Cache.nth[F]=C;},parseSelector:function(E){if(Selectors.Cache.parsed[E]){return Selectors.Cache.parsed[E];
-}var D,H={classes:[],pseudos:[],attributes:[]};while((D=Selectors.RegExps.combined.exec(E))){var I=D[1],G=D[2],F=D[3],B=D[4],C=D[5],J=D[6];if(I){H.classes.push(I);
-}else{if(C){var A=Selectors.Pseudo.get(C);if(A){H.pseudos.push({parser:A,argument:J});}else{H.attributes.push({name:C,operator:"=",value:J});}}else{if(G){H.attributes.push({name:G,operator:F,value:B});
-}}}}if(!H.classes.length){delete H.classes;}if(!H.attributes.length){delete H.attributes;}if(!H.pseudos.length){delete H.pseudos;}if(!H.classes&&!H.attributes&&!H.pseudos){H=null;
-}return Selectors.Cache.parsed[E]=H;},parseTagAndID:function(B){var A=B.match(Selectors.RegExps.tag);var C=B.match(Selectors.RegExps.id);return[(A)?A[1]:"*",(C)?C[1]:false];
-},filter:function(F,C,E){var D;if(C.classes){for(D=C.classes.length;D--;D){var G=C.classes[D];if(!Selectors.Filters.byClass(F,G)){return false;}}}if(C.attributes){for(D=C.attributes.length;
-D--;D){var B=C.attributes[D];if(!Selectors.Filters.byAttribute(F,B.name,B.operator,B.value)){return false;}}}if(C.pseudos){for(D=C.pseudos.length;D--;D){var A=C.pseudos[D];
-if(!Selectors.Filters.byPseudo(F,A.parser,A.argument,E)){return false;}}}return true;},getByTagAndID:function(B,A,D){if(D){var C=(B.getElementById)?B.getElementById(D,true):Element.getElementById(B,D,true);
-return(C&&Selectors.Filters.byTag(C,A))?[C]:[];}else{return B.getElementsByTagName(A);}},search:function(J,I,O){var B=[];var C=I.trim().replace(Selectors.RegExps.splitter,function(Z,Y,X){B.push(Y);
-return":)"+X;}).split(":)");var K,F,E,V;for(var U=0,Q=C.length;U<Q;U++){var T=C[U];if(U==0&&Selectors.RegExps.quick.test(T)){K=J.getElementsByTagName(T);
-continue;}var A=B[U-1];var L=Selectors.Utils.parseTagAndID(T);var W=L[0],M=L[1];if(U==0){K=Selectors.Utils.getByTagAndID(J,W,M);}else{var D={},H=[];for(var S=0,R=K.length;
-S<R;S++){H=Selectors.Getters[A](H,K[S],W,M,D);}K=H;}var G=Selectors.Utils.parseSelector(T);if(G){E=[];for(var P=0,N=K.length;P<N;P++){V=K[P];if(Selectors.Utils.filter(V,G,O)){E.push(V);
-}}K=E;}}return K;}};Selectors.Getters={" ":function(H,G,I,A,E){var D=Selectors.Utils.getByTagAndID(G,I,A);for(var C=0,B=D.length;C<B;C++){var F=D[C];if(Selectors.Utils.chk(F,E)){H.push(F);
-}}return H;},">":function(H,G,I,A,F){var C=Selectors.Utils.getByTagAndID(G,I,A);for(var E=0,D=C.length;E<D;E++){var B=C[E];if(B.parentNode==G&&Selectors.Utils.chk(B,F)){H.push(B);
-}}return H;},"+":function(C,B,A,E,D){while((B=B.nextSibling)){if(B.nodeType==1){if(Selectors.Utils.chk(B,D)&&Selectors.Filters.byTag(B,A)&&Selectors.Filters.byID(B,E)){C.push(B);
-}break;}}return C;},"~":function(C,B,A,E,D){while((B=B.nextSibling)){if(B.nodeType==1){if(!Selectors.Utils.chk(B,D)){break;}if(Selectors.Filters.byTag(B,A)&&Selectors.Filters.byID(B,E)){C.push(B);
-}}}return C;}};Selectors.Filters={byTag:function(B,A){return(A=="*"||(B.tagName&&B.tagName.toLowerCase()==A));},byID:function(A,B){return(!B||(A.id&&A.id==B));
-},byClass:function(B,A){return(B.className&&B.className.contains(A," "));},byPseudo:function(A,D,C,B){return D.call(A,C,B);},byAttribute:function(C,D,B,E){var A=Element.prototype.getProperty.call(C,D);
-if(!A){return false;}if(!B||E==undefined){return true;}switch(B){case"=":return(A==E);case"*=":return(A.contains(E));case"^=":return(A.substr(0,E.length)==E);
-case"$=":return(A.substr(A.length-E.length)==E);case"!=":return(A!=E);case"~=":return A.contains(E," ");case"|=":return A.contains(E,"-");}return false;
-}};Selectors.Pseudo=new Hash({empty:function(){return !(this.innerText||this.textContent||"").length;},not:function(A){return !Element.match(this,A);},contains:function(A){return(this.innerText||this.textContent||"").contains(A);
-},"first-child":function(){return Selectors.Pseudo.index.call(this,0);},"last-child":function(){var A=this;while((A=A.nextSibling)){if(A.nodeType==1){return false;
-}}return true;},"only-child":function(){var B=this;while((B=B.previousSibling)){if(B.nodeType==1){return false;}}var A=this;while((A=A.nextSibling)){if(A.nodeType==1){return false;
-}}return true;},"nth-child":function(G,E){G=(G==undefined)?"n":G;var C=Selectors.Utils.parseNthArgument(G);if(C.special!="n"){return Selectors.Pseudo[C.special].call(this,C.a,E);
-}var F=0;E.positions=E.positions||{};var D=$uid(this);if(!E.positions[D]){var B=this;while((B=B.previousSibling)){if(B.nodeType!=1){continue;}F++;var A=E.positions[$uid(B)];
-if(A!=undefined){F=A+F;break;}}E.positions[D]=F;}return(E.positions[D]%C.a==C.b);},index:function(A){var B=this,C=0;while((B=B.previousSibling)){if(B.nodeType==1&&++C>A){return false;
-}}return(C==A);},even:function(B,A){return Selectors.Pseudo["nth-child"].call(this,"2n+1",A);},odd:function(B,A){return Selectors.Pseudo["nth-child"].call(this,"2n",A);
-}});Element.Events.domready={onAdd:function(A){if(Browser.loaded){A.call(this);}}};(function(){var B=function(){if(Browser.loaded){return ;}Browser.loaded=true;
-window.fireEvent("domready");document.fireEvent("domready");};switch(Browser.Engine.name){case"webkit":(function(){(["loaded","complete"].contains(document.readyState))?B():arguments.callee.delay(50);
-})();break;case"trident":var A=document.createElement("div");(function(){($try(function(){A.doScroll("left");return $(A).inject(document.body).set("html","temp").dispose();
-}))?B():arguments.callee.delay(50);})();break;default:window.addEvent("load",B);document.addEvent("DOMContentLoaded",B);}})();var JSON=new Hash({encode:function(B){switch($type(B)){case"string":return'"'+B.replace(/[\x00-\x1f\\"]/g,JSON.$replaceChars)+'"';
-case"array":return"["+String(B.map(JSON.encode).filter($defined))+"]";case"object":case"hash":var A=[];Hash.each(B,function(E,D){var C=JSON.encode(E);if(C){A.push(JSON.encode(D)+":"+C);
-}});return"{"+A+"}";case"number":case"boolean":return String(B);case false:return"null";}return null;},$specialChars:{"\b":"\\b","\t":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"},$replaceChars:function(A){return JSON.$specialChars[A]||"\\u00"+Math.floor(A.charCodeAt()/16).toString(16)+(A.charCodeAt()%16).toString(16);
-},decode:function(string,secure){if($type(string)!="string"||!string.length){return null;}if(secure&&!(/^[,:{}\[\]0-9.\-+Eaeflnr-u \n\r\t]*$/).test(string.replace(/\\./g,"@").replace(/"[^"\\\n\r]*"/g,""))){return null;
-}return eval("("+string+")");}});Native.implement([Hash,Array,String,Number],{toJSON:function(){return JSON.encode(this);}});var Cookie=new Class({Implements:Options,options:{path:false,domain:false,duration:false,secure:false,document:document},initialize:function(B,A){this.key=B;
-this.setOptions(A);},write:function(B){B=encodeURIComponent(B);if(this.options.domain){B+="; domain="+this.options.domain;}if(this.options.path){B+="; path="+this.options.path;
-}if(this.options.duration){var A=new Date();A.setTime(A.getTime()+this.options.duration*24*60*60*1000);B+="; expires="+A.toGMTString();}if(this.options.secure){B+="; secure";
-}this.options.document.cookie=this.key+"="+B;return this;},read:function(){var A=this.options.document.cookie.match("(?:^|;)\\s*"+this.key.escapeRegExp()+"=([^;]*)");
-return(A)?decodeURIComponent(A[1]):null;},dispose:function(){new Cookie(this.key,$merge(this.options,{duration:-1})).write("");return this;}});Cookie.write=function(B,C,A){return new Cookie(B,A).write(C);
-};Cookie.read=function(A){return new Cookie(A).read();};Cookie.dispose=function(B,A){return new Cookie(B,A).dispose();};var Fx=new Class({Implements:[Chain,Events,Options],options:{fps:50,unit:false,duration:500,link:"ignore",transition:function(A){return -(Math.cos(Math.PI*A)-1)/2;
-}},initialize:function(A){this.subject=this.subject||this;this.setOptions(A);this.options.duration=Fx.Durations[this.options.duration]||this.options.duration.toInt();
-var B=this.options.wait;if(B===false){this.options.link="cancel";}},step:function(){var A=$time();if(A<this.time+this.options.duration){var B=this.options.transition((A-this.time)/this.options.duration);
-this.set(this.compute(this.from,this.to,B));}else{this.set(this.compute(this.from,this.to,1));this.complete();}},set:function(A){return A;},compute:function(C,B,A){return Fx.compute(C,B,A);
-},check:function(A){if(!this.timer){return true;}switch(this.options.link){case"cancel":this.cancel();return true;case"chain":this.chain(A.bind(this,Array.slice(arguments,1)));
-return false;}return false;},start:function(B,A){if(!this.check(arguments.callee,B,A)){return this;}this.from=B;this.to=A;this.time=0;this.startTimer();
-this.onStart();return this;},complete:function(){if(this.stopTimer()){this.onComplete();}return this;},cancel:function(){if(this.stopTimer()){this.onCancel();
-}return this;},onStart:function(){this.fireEvent("start",this.subject);},onComplete:function(){this.fireEvent("complete",this.subject);if(!this.callChain()){this.fireEvent("chainComplete",this.subject);
-}},onCancel:function(){this.fireEvent("cancel",this.subject).clearChain();},pause:function(){this.stopTimer();return this;},resume:function(){this.startTimer();
-return this;},stopTimer:function(){if(!this.timer){return false;}this.time=$time()-this.time;this.timer=$clear(this.timer);return true;},startTimer:function(){if(this.timer){return false;
-}this.time=$time()-this.time;this.timer=this.step.periodical(Math.round(1000/this.options.fps),this);return true;}});Fx.compute=function(C,B,A){return(B-C)*A+C;
-};Fx.Durations={"short":250,normal:500,"long":1000};Fx.CSS=new Class({Extends:Fx,prepare:function(D,E,B){B=$splat(B);var C=B[1];if(!$chk(C)){B[1]=B[0];
-B[0]=D.getStyle(E);}var A=B.map(this.parse);return{from:A[0],to:A[1]};},parse:function(A){A=$lambda(A)();A=(typeof A=="string")?A.split(" "):$splat(A);
-return A.map(function(C){C=String(C);var B=false;Fx.CSS.Parsers.each(function(F,E){if(B){return ;}var D=F.parse(C);if($chk(D)){B={value:D,parser:F};}});
-B=B||{value:C,parser:Fx.CSS.Parsers.String};return B;});},compute:function(D,C,B){var A=[];(Math.min(D.length,C.length)).times(function(E){A.push({value:D[E].parser.compute(D[E].value,C[E].value,B),parser:D[E].parser});
-});A.$family={name:"fx:css:value"};return A;},serve:function(C,B){if($type(C)!="fx:css:value"){C=this.parse(C);}var A=[];C.each(function(D){A=A.concat(D.parser.serve(D.value,B));
-});return A;},render:function(A,D,C,B){A.setStyle(D,this.serve(C,B));},search:function(A){if(Fx.CSS.Cache[A]){return Fx.CSS.Cache[A];}var B={};Array.each(document.styleSheets,function(E,D){var C=E.href;
-if(C&&C.contains("://")&&!C.contains(document.domain)){return ;}var F=E.rules||E.cssRules;Array.each(F,function(I,G){if(!I.style){return ;}var H=(I.selectorText)?I.selectorText.replace(/^\w+/,function(J){return J.toLowerCase();
-}):null;if(!H||!H.test("^"+A+"$")){return ;}Element.Styles.each(function(K,J){if(!I.style[J]||Element.ShortStyles[J]){return ;}K=String(I.style[J]);B[J]=(K.test(/^rgb/))?K.rgbToHex():K;
-});});});return Fx.CSS.Cache[A]=B;}});Fx.CSS.Cache={};Fx.CSS.Parsers=new Hash({Color:{parse:function(A){if(A.match(/^#[0-9a-f]{3,6}$/i)){return A.hexToRgb(true);
-}return((A=A.match(/(\d+),\s*(\d+),\s*(\d+)/)))?[A[1],A[2],A[3]]:false;},compute:function(C,B,A){return C.map(function(E,D){return Math.round(Fx.compute(C[D],B[D],A));
-});},serve:function(A){return A.map(Number);}},Number:{parse:parseFloat,compute:Fx.compute,serve:function(B,A){return(A)?B+A:B;}},String:{parse:$lambda(false),compute:$arguments(1),serve:$arguments(0)}});
-Fx.Tween=new Class({Extends:Fx.CSS,initialize:function(B,A){this.element=this.subject=$(B);this.parent(A);},set:function(B,A){if(arguments.length==1){A=B;
-B=this.property||this.options.property;}this.render(this.element,B,A,this.options.unit);return this;},start:function(C,E,D){if(!this.check(arguments.callee,C,E,D)){return this;
-}var B=Array.flatten(arguments);this.property=this.options.property||B.shift();var A=this.prepare(this.element,this.property,B);return this.parent(A.from,A.to);
-}});Element.Properties.tween={set:function(A){var B=this.retrieve("tween");if(B){B.cancel();}return this.eliminate("tween").store("tween:options",$extend({link:"cancel"},A));
-},get:function(A){if(A||!this.retrieve("tween")){if(A||!this.retrieve("tween:options")){this.set("tween",A);}this.store("tween",new Fx.Tween(this,this.retrieve("tween:options")));
-}return this.retrieve("tween");}};Element.implement({tween:function(A,C,B){this.get("tween").start(arguments);return this;},fade:function(C){var E=this.get("tween"),D="opacity",A;
-C=$pick(C,"toggle");switch(C){case"in":E.start(D,1);break;case"out":E.start(D,0);break;case"show":E.set(D,1);break;case"hide":E.set(D,0);break;case"toggle":var B=this.retrieve("fade:flag",this.get("opacity")==1);
-E.start(D,(B)?0:1);this.store("fade:flag",!B);A=true;break;default:E.start(D,arguments);}if(!A){this.eliminate("fade:flag");}return this;},highlight:function(C,A){if(!A){A=this.retrieve("highlight:original",this.getStyle("background-color"));
-A=(A=="transparent")?"#fff":A;}var B=this.get("tween");B.start("background-color",C||"#ffff88",A).chain(function(){this.setStyle("background-color",this.retrieve("highlight:original"));
-B.callChain();}.bind(this));return this;}});Fx.Morph=new Class({Extends:Fx.CSS,initialize:function(B,A){this.element=this.subject=$(B);this.parent(A);},set:function(A){if(typeof A=="string"){A=this.search(A);
-}for(var B in A){this.render(this.element,B,A[B],this.options.unit);}return this;},compute:function(E,D,C){var A={};for(var B in E){A[B]=this.parent(E[B],D[B],C);
-}return A;},start:function(B){if(!this.check(arguments.callee,B)){return this;}if(typeof B=="string"){B=this.search(B);}var E={},D={};for(var C in B){var A=this.prepare(this.element,C,B[C]);
-E[C]=A.from;D[C]=A.to;}return this.parent(E,D);}});Element.Properties.morph={set:function(A){var B=this.retrieve("morph");if(B){B.cancel();}return this.eliminate("morph").store("morph:options",$extend({link:"cancel"},A));
-},get:function(A){if(A||!this.retrieve("morph")){if(A||!this.retrieve("morph:options")){this.set("morph",A);}this.store("morph",new Fx.Morph(this,this.retrieve("morph:options")));
-}return this.retrieve("morph");}};Element.implement({morph:function(A){this.get("morph").start(A);return this;}});(function(){var A=Fx.prototype.initialize;
-Fx.prototype.initialize=function(B){A.call(this,B);var C=this.options.transition;if(typeof C=="string"&&(C=C.split(":"))){var D=Fx.Transitions;D=D[C[0]]||D[C[0].capitalize()];
-if(C[1]){D=D["ease"+C[1].capitalize()+(C[2]?C[2].capitalize():"")];}this.options.transition=D;}};})();Fx.Transition=function(B,A){A=$splat(A);return $extend(B,{easeIn:function(C){return B(C,A);
-},easeOut:function(C){return 1-B(1-C,A);},easeInOut:function(C){return(C<=0.5)?B(2*C,A)/2:(2-B(2*(1-C),A))/2;}});};Fx.Transitions=new Hash({linear:$arguments(0)});
-Fx.Transitions.extend=function(A){for(var B in A){Fx.Transitions[B]=new Fx.Transition(A[B]);}};Fx.Transitions.extend({Pow:function(B,A){return Math.pow(B,A[0]||6);
-},Expo:function(A){return Math.pow(2,8*(A-1));},Circ:function(A){return 1-Math.sin(Math.acos(A));},Sine:function(A){return 1-Math.sin((1-A)*Math.PI/2);
-},Back:function(B,A){A=A[0]||1.618;return Math.pow(B,2)*((A+1)*B-A);},Bounce:function(D){var C;for(var B=0,A=1;1;B+=A,A/=2){if(D>=(7-4*B)/11){C=-Math.pow((11-6*B-11*D)/4,2)+A*A;
-break;}}return C;},Elastic:function(B,A){return Math.pow(2,10*--B)*Math.cos(20*B*Math.PI*(A[0]||1)/3);}});["Quad","Cubic","Quart","Quint"].each(function(B,A){Fx.Transitions[B]=new Fx.Transition(function(C){return Math.pow(C,[A+2]);
-});});var Request=new Class({Implements:[Chain,Events,Options],options:{url:"",data:"",headers:{"X-Requested-With":"XMLHttpRequest",Accept:"text/javascript, text/html, application/xml, text/xml, */*"},async:true,format:false,method:"post",link:"ignore",isSuccess:null,emulation:true,urlEncoded:true,encoding:"utf-8",evalScripts:false,evalResponse:false},initialize:function(A){this.xhr=new Browser.Request();
-this.setOptions(A);this.options.isSuccess=this.options.isSuccess||this.isSuccess;this.headers=new Hash(this.options.headers);},onStateChange:function(){if(this.xhr.readyState!=4||!this.running){return ;
-}this.running=false;this.status=0;$try(function(){this.status=this.xhr.status;}.bind(this));if(this.options.isSuccess.call(this,this.status)){this.response={text:this.xhr.responseText,xml:this.xhr.responseXML};
-this.success(this.response.text,this.response.xml);}else{this.response={text:null,xml:null};this.failure();}this.xhr.onreadystatechange=$empty;},isSuccess:function(){return((this.status>=200)&&(this.status<300));
-},processScripts:function(A){if(this.options.evalResponse||(/(ecma|java)script/).test(this.getHeader("Content-type"))){return $exec(A);}return A.stripScripts(this.options.evalScripts);
-},success:function(B,A){this.onSuccess(this.processScripts(B),A);},onSuccess:function(){this.fireEvent("complete",arguments).fireEvent("success",arguments).callChain();
-},failure:function(){this.onFailure();},onFailure:function(){this.fireEvent("complete").fireEvent("failure",this.xhr);},setHeader:function(A,B){this.headers.set(A,B);
-return this;},getHeader:function(A){return $try(function(){return this.xhr.getResponseHeader(A);}.bind(this));},check:function(A){if(!this.running){return true;
-}switch(this.options.link){case"cancel":this.cancel();return true;case"chain":this.chain(A.bind(this,Array.slice(arguments,1)));return false;}return false;
-},send:function(I){if(!this.check(arguments.callee,I)){return this;}this.running=true;var G=$type(I);if(G=="string"||G=="element"){I={data:I};}var D=this.options;
-I=$extend({data:D.data,url:D.url,method:D.method},I);var E=I.data,B=I.url,A=I.method;switch($type(E)){case"element":E=$(E).toQueryString();break;case"object":case"hash":E=Hash.toQueryString(E);
-}if(this.options.format){var H="format="+this.options.format;E=(E)?H+"&"+E:H;}if(this.options.emulation&&["put","delete"].contains(A)){var F="_method="+A;
-E=(E)?F+"&"+E:F;A="post";}if(this.options.urlEncoded&&A=="post"){var C=(this.options.encoding)?"; charset="+this.options.encoding:"";this.headers.set("Content-type","application/x-www-form-urlencoded"+C);
-}if(E&&A=="get"){B=B+(B.contains("?")?"&":"?")+E;E=null;}this.xhr.open(A.toUpperCase(),B,this.options.async);this.xhr.onreadystatechange=this.onStateChange.bind(this);
-this.headers.each(function(K,J){if(!$try(function(){this.xhr.setRequestHeader(J,K);return true;}.bind(this))){this.fireEvent("exception",[J,K]);}},this);
-this.fireEvent("request");this.xhr.send(E);if(!this.options.async){this.onStateChange();}return this;},cancel:function(){if(!this.running){return this;
-}this.running=false;this.xhr.abort();this.xhr.onreadystatechange=$empty;this.xhr=new Browser.Request();this.fireEvent("cancel");return this;}});(function(){var A={};
-["get","post","put","delete","GET","POST","PUT","DELETE"].each(function(B){A[B]=function(){var C=Array.link(arguments,{url:String.type,data:$defined});
-return this.send($extend(C,{method:B.toLowerCase()}));};});Request.implement(A);})();Element.Properties.send={set:function(A){var B=this.retrieve("send");
-if(B){B.cancel();}return this.eliminate("send").store("send:options",$extend({data:this,link:"cancel",method:this.get("method")||"post",url:this.get("action")},A));
-},get:function(A){if(A||!this.retrieve("send")){if(A||!this.retrieve("send:options")){this.set("send",A);}this.store("send",new Request(this.retrieve("send:options")));
-}return this.retrieve("send");}};Element.implement({send:function(A){var B=this.get("send");B.send({data:this,url:A||B.options.url});return this;}});Request.HTML=new Class({Extends:Request,options:{update:false,evalScripts:true,filter:false},processHTML:function(C){var B=C.match(/<body[^>]*>([\s\S]*?)<\/body>/i);
-C=(B)?B[1]:C;var A=new Element("div");return $try(function(){var D="<root>"+C+"</root>",G;if(Browser.Engine.trident){G=new ActiveXObject("Microsoft.XMLDOM");
-G.async=false;G.loadXML(D);}else{G=new DOMParser().parseFromString(D,"text/xml");}D=G.getElementsByTagName("root")[0];for(var F=0,E=D.childNodes.length;
-F<E;F++){var H=Element.clone(D.childNodes[F],true,true);if(H){A.grab(H);}}return A;})||A.set("html",C);},success:function(D){var C=this.options,B=this.response;
-B.html=D.stripScripts(function(E){B.javascript=E;});var A=this.processHTML(B.html);B.tree=A.childNodes;B.elements=A.getElements("*");if(C.filter){B.tree=B.elements.filter(C.filter);
-}if(C.update){$(C.update).empty().adopt(B.tree);}if(C.evalScripts){$exec(B.javascript);}this.onSuccess(B.tree,B.elements,B.html,B.javascript);}});Element.Properties.load={set:function(A){var B=this.retrieve("load");
-if(B){send.cancel();}return this.eliminate("load").store("load:options",$extend({data:this,link:"cancel",update:this,method:"get"},A));},get:function(A){if(A||!this.retrieve("load")){if(A||!this.retrieve("load:options")){this.set("load",A);
-}this.store("load",new Request.HTML(this.retrieve("load:options")));}return this.retrieve("load");}};Element.implement({load:function(){this.get("load").send(Array.link(arguments,{data:Object.type,url:String.type}));
-return this;}});Request.JSON=new Class({Extends:Request,options:{secure:true},initialize:function(A){this.parent(A);this.headers.extend({Accept:"application/json","X-Request":"JSON"});
-},success:function(A){this.response.json=JSON.decode(A,this.options.secure);this.onSuccess(this.response.json,A);}});
\ No newline at end of file

=== removed file 'loggerhead/static/javascript/mootools-1.2-more.js'
--- loggerhead/static/javascript/mootools-1.2-more.js	2008-06-18 07:49:45 +0000
+++ loggerhead/static/javascript/mootools-1.2-more.js	1970-01-01 00:00:00 +0000
@@ -1,97 +0,0 @@
-//MooTools More, <http://mootools.net/more>. Copyright (c) 2006-2008 Valerio Proietti, <http://mad4milk.net>, MIT Style License.
-
-Fx.Slide=new Class({Extends:Fx,options:{mode:"vertical"},initialize:function(B,A){this.addEvent("complete",function(){this.open=(this.wrapper["offset"+this.layout.capitalize()]!=0);
-if(this.open&&Browser.Engine.webkit419){this.element.dispose().inject(this.wrapper);}},true);this.element=this.subject=$(B);this.parent(A);var C=this.element.retrieve("wrapper");
-this.wrapper=C||new Element("div",{styles:$extend(this.element.getStyles("margin","position"),{overflow:"hidden"})}).wraps(this.element);this.element.store("wrapper",this.wrapper).setStyle("margin",0);
-this.now=[];this.open=true;},vertical:function(){this.margin="margin-top";this.layout="height";this.offset=this.element.offsetHeight;},horizontal:function(){this.margin="margin-left";
-this.layout="width";this.offset=this.element.offsetWidth;},set:function(A){this.element.setStyle(this.margin,A[0]);this.wrapper.setStyle(this.layout,A[1]);
-return this;},compute:function(E,D,C){var B=[];var A=2;A.times(function(F){B[F]=Fx.compute(E[F],D[F],C);});return B;},start:function(B,E){if(!this.check(arguments.callee,B,E)){return this;
-}this[E||this.options.mode]();var D=this.element.getStyle(this.margin).toInt();var C=this.wrapper.getStyle(this.layout).toInt();var A=[[D,C],[0,this.offset]];
-var G=[[D,C],[-this.offset,0]];var F;switch(B){case"in":F=A;break;case"out":F=G;break;case"toggle":F=(this.wrapper["offset"+this.layout.capitalize()]==0)?A:G;
-}return this.parent(F[0],F[1]);},slideIn:function(A){return this.start("in",A);},slideOut:function(A){return this.start("out",A);},hide:function(A){this[A||this.options.mode]();
-this.open=false;return this.set([-this.offset,0]);},show:function(A){this[A||this.options.mode]();this.open=true;return this.set([0,this.offset]);},toggle:function(A){return this.start("toggle",A);
-}});Element.Properties.slide={set:function(B){var A=this.retrieve("slide");if(A){A.cancel();}return this.eliminate("slide").store("slide:options",$extend({link:"cancel"},B));
-},get:function(A){if(A||!this.retrieve("slide")){if(A||!this.retrieve("slide:options")){this.set("slide",A);}this.store("slide",new Fx.Slide(this,this.retrieve("slide:options")));
-}return this.retrieve("slide");}};Element.implement({slide:function(D,E){D=D||"toggle";var B=this.get("slide"),A;switch(D){case"hide":B.hide(E);break;case"show":B.show(E);
-break;case"toggle":var C=this.retrieve("slide:flag",B.open);B[(C)?"slideOut":"slideIn"](E);this.store("slide:flag",!C);A=true;break;default:B.start(D,E);
-}if(!A){this.eliminate("slide:flag");}return this;}});Fx.Elements=new Class({Extends:Fx.CSS,initialize:function(B,A){this.elements=this.subject=$$(B);this.parent(A);
-},compute:function(G,H,I){var C={};for(var D in G){var A=G[D],E=H[D],F=C[D]={};for(var B in A){F[B]=this.parent(A[B],E[B],I);}}return C;},set:function(B){for(var C in B){var A=B[C];
-for(var D in A){this.render(this.elements[C],D,A[D],this.options.unit);}}return this;},start:function(C){if(!this.check(arguments.callee,C)){return this;
-}var H={},I={};for(var D in C){var F=C[D],A=H[D]={},G=I[D]={};for(var B in F){var E=this.prepare(this.elements[D],B,F[B]);A[B]=E.from;G[B]=E.to;}}return this.parent(H,I);
-}});var Drag=new Class({Implements:[Events,Options],options:{snap:6,unit:"px",grid:false,style:true,limit:false,handle:false,invert:false,preventDefault:false,modifiers:{x:"left",y:"top"}},initialize:function(){var B=Array.link(arguments,{options:Object.type,element:$defined});
-this.element=$(B.element);this.document=this.element.getDocument();this.setOptions(B.options||{});var A=$type(this.options.handle);this.handles=(A=="array"||A=="collection")?$$(this.options.handle):$(this.options.handle)||this.element;
-this.mouse={now:{},pos:{}};this.value={start:{},now:{}};this.selection=(Browser.Engine.trident)?"selectstart":"mousedown";this.bound={start:this.start.bind(this),check:this.check.bind(this),drag:this.drag.bind(this),stop:this.stop.bind(this),cancel:this.cancel.bind(this),eventStop:$lambda(false)};
-this.attach();},attach:function(){this.handles.addEvent("mousedown",this.bound.start);return this;},detach:function(){this.handles.removeEvent("mousedown",this.bound.start);
-return this;},start:function(C){if(this.options.preventDefault){C.preventDefault();}this.fireEvent("beforeStart",this.element);this.mouse.start=C.page;
-var A=this.options.limit;this.limit={x:[],y:[]};for(var D in this.options.modifiers){if(!this.options.modifiers[D]){continue;}if(this.options.style){this.value.now[D]=this.element.getStyle(this.options.modifiers[D]).toInt();
-}else{this.value.now[D]=this.element[this.options.modifiers[D]];}if(this.options.invert){this.value.now[D]*=-1;}this.mouse.pos[D]=C.page[D]-this.value.now[D];
-if(A&&A[D]){for(var B=2;B--;B){if($chk(A[D][B])){this.limit[D][B]=$lambda(A[D][B])();}}}}if($type(this.options.grid)=="number"){this.options.grid={x:this.options.grid,y:this.options.grid};
-}this.document.addEvents({mousemove:this.bound.check,mouseup:this.bound.cancel});this.document.addEvent(this.selection,this.bound.eventStop);},check:function(A){if(this.options.preventDefault){A.preventDefault();
-}var B=Math.round(Math.sqrt(Math.pow(A.page.x-this.mouse.start.x,2)+Math.pow(A.page.y-this.mouse.start.y,2)));if(B>this.options.snap){this.cancel();this.document.addEvents({mousemove:this.bound.drag,mouseup:this.bound.stop});
-this.fireEvent("start",this.element).fireEvent("snap",this.element);}},drag:function(A){if(this.options.preventDefault){A.preventDefault();}this.mouse.now=A.page;
-for(var B in this.options.modifiers){if(!this.options.modifiers[B]){continue;}this.value.now[B]=this.mouse.now[B]-this.mouse.pos[B];if(this.options.invert){this.value.now[B]*=-1;
-}if(this.options.limit&&this.limit[B]){if($chk(this.limit[B][1])&&(this.value.now[B]>this.limit[B][1])){this.value.now[B]=this.limit[B][1];}else{if($chk(this.limit[B][0])&&(this.value.now[B]<this.limit[B][0])){this.value.now[B]=this.limit[B][0];
-}}}if(this.options.grid[B]){this.value.now[B]-=(this.value.now[B]%this.options.grid[B]);}if(this.options.style){this.element.setStyle(this.options.modifiers[B],this.value.now[B]+this.options.unit);
-}else{this.element[this.options.modifiers[B]]=this.value.now[B];}}this.fireEvent("drag",this.element);},cancel:function(A){this.document.removeEvent("mousemove",this.bound.check);
-this.document.removeEvent("mouseup",this.bound.cancel);if(A){this.document.removeEvent(this.selection,this.bound.eventStop);this.fireEvent("cancel",this.element);
-}},stop:function(A){this.document.removeEvent(this.selection,this.bound.eventStop);this.document.removeEvent("mousemove",this.bound.drag);this.document.removeEvent("mouseup",this.bound.stop);
-if(A){this.fireEvent("complete",this.element);}}});Element.implement({makeResizable:function(A){return new Drag(this,$merge({modifiers:{x:"width",y:"height"}},A));
-}});Hash.Cookie=new Class({Extends:Cookie,options:{autoSave:true},initialize:function(B,A){this.parent(B,A);this.load();},save:function(){var A=JSON.encode(this.hash);
-if(!A||A.length>4096){return false;}if(A=="{}"){this.dispose();}else{this.write(A);}return true;},load:function(){this.hash=new Hash(JSON.decode(this.read(),true));
-return this;}});Hash.Cookie.implement((function(){var A={};Hash.each(Hash.prototype,function(C,B){A[B]=function(){var D=C.apply(this.hash,arguments);if(this.options.autoSave){this.save();
-}return D;};});return A;})());var Color=new Native({initialize:function(B,C){if(arguments.length>=3){C="rgb";B=Array.slice(arguments,0,3);}else{if(typeof B=="string"){if(B.match(/rgb/)){B=B.rgbToHex().hexToRgb(true);
-}else{if(B.match(/hsb/)){B=B.hsbToRgb();}else{B=B.hexToRgb(true);}}}}C=C||"rgb";switch(C){case"hsb":var A=B;B=B.hsbToRgb();B.hsb=A;break;case"hex":B=B.hexToRgb(true);
-break;}B.rgb=B.slice(0,3);B.hsb=B.hsb||B.rgbToHsb();B.hex=B.rgbToHex();return $extend(B,this);}});Color.implement({mix:function(){var A=Array.slice(arguments);
-var C=($type(A.getLast())=="number")?A.pop():50;var B=this.slice();A.each(function(D){D=new Color(D);for(var E=0;E<3;E++){B[E]=Math.round((B[E]/100*(100-C))+(D[E]/100*C));
-}});return new Color(B,"rgb");},invert:function(){return new Color(this.map(function(A){return 255-A;}));},setHue:function(A){return new Color([A,this.hsb[1],this.hsb[2]],"hsb");
-},setSaturation:function(A){return new Color([this.hsb[0],A,this.hsb[2]],"hsb");},setBrightness:function(A){return new Color([this.hsb[0],this.hsb[1],A],"hsb");
-}});function $RGB(C,B,A){return new Color([C,B,A],"rgb");}function $HSB(C,B,A){return new Color([C,B,A],"hsb");}function $HEX(A){return new Color(A,"hex");
-}Array.implement({rgbToHsb:function(){var B=this[0],C=this[1],J=this[2];var G,F,H;var I=Math.max(B,C,J),E=Math.min(B,C,J);var K=I-E;H=I/255;F=(I!=0)?K/I:0;
-if(F==0){G=0;}else{var D=(I-B)/K;var A=(I-C)/K;var L=(I-J)/K;if(B==I){G=L-A;}else{if(C==I){G=2+D-L;}else{G=4+A-D;}}G/=6;if(G<0){G++;}}return[Math.round(G*360),Math.round(F*100),Math.round(H*100)];
-},hsbToRgb:function(){var C=Math.round(this[2]/100*255);if(this[1]==0){return[C,C,C];}else{var A=this[0]%360;var E=A%60;var F=Math.round((this[2]*(100-this[1]))/10000*255);
-var D=Math.round((this[2]*(6000-this[1]*E))/600000*255);var B=Math.round((this[2]*(6000-this[1]*(60-E)))/600000*255);switch(Math.floor(A/60)){case 0:return[C,B,F];
-case 1:return[D,C,F];case 2:return[F,C,B];case 3:return[F,D,C];case 4:return[B,F,C];case 5:return[C,F,D];}}return false;}});String.implement({rgbToHsb:function(){var A=this.match(/\d{1,3}/g);
-return(A)?hsb.rgbToHsb():null;},hsbToRgb:function(){var A=this.match(/\d{1,3}/g);return(A)?A.hsbToRgb():null;}});var Group=new Class({initialize:function(){this.instances=Array.flatten(arguments);
-this.events={};this.checker={};},addEvent:function(B,A){this.checker[B]=this.checker[B]||{};this.events[B]=this.events[B]||[];if(this.events[B].contains(A)){return false;
-}else{this.events[B].push(A);}this.instances.each(function(C,D){C.addEvent(B,this.check.bind(this,[B,C,D]));},this);return this;},check:function(C,A,B){this.checker[C][B]=true;
-var D=this.instances.every(function(F,E){return this.checker[C][E]||false;},this);if(!D){return ;}this.checker[C]={};this.events[C].each(function(E){E.call(this,this.instances,A);
-},this);}});var Asset=new Hash({javascript:function(F,D){D=$extend({onload:$empty,document:document,check:$lambda(true)},D);var B=new Element("script",{src:F,type:"text/javascript"});
-var E=D.onload.bind(B),A=D.check,G=D.document;delete D.onload;delete D.check;delete D.document;B.addEvents({load:E,readystatechange:function(){if(["loaded","complete"].contains(this.readyState)){E();
-}}}).setProperties(D);if(Browser.Engine.webkit419){var C=(function(){if(!$try(A)){return ;}$clear(C);E();}).periodical(50);}return B.inject(G.head);},css:function(B,A){return new Element("link",$merge({rel:"stylesheet",media:"screen",type:"text/css",href:B},A)).inject(document.head);
-},image:function(C,B){B=$merge({onload:$empty,onabort:$empty,onerror:$empty},B);var D=new Image();var A=$(D)||new Element("img");["load","abort","error"].each(function(E){var F="on"+E;
-var G=B[F];delete B[F];D[F]=function(){if(!D){return ;}if(!A.parentNode){A.width=D.width;A.height=D.height;}D=D.onload=D.onabort=D.onerror=null;G.delay(1,A,A);
-A.fireEvent(E,A,1);};});D.src=A.src=C;if(D&&D.complete){D.onload.delay(1);}return A.setProperties(B);},images:function(D,C){C=$merge({onComplete:$empty,onProgress:$empty},C);
-if(!D.push){D=[D];}var A=[];var B=0;D.each(function(F){var E=new Asset.image(F,{onload:function(){C.onProgress.call(this,B,D.indexOf(F));B++;if(B==D.length){C.onComplete();
-}}});A.push(E);});return new Elements(A);}});var Tips=new Class({Implements:[Events,Options],options:{onShow:function(A){A.setStyle("visibility","visible");
-},onHide:function(A){A.setStyle("visibility","hidden");},showDelay:100,hideDelay:100,className:null,offsets:{x:16,y:16},fixed:false},initialize:function(){var C=Array.link(arguments,{options:Object.type,elements:$defined});
-this.setOptions(C.options||null);this.tip=new Element("div").inject(document.body);if(this.options.className){this.tip.addClass(this.options.className);
-}var B=new Element("div",{"class":"tip-top"}).inject(this.tip);this.container=new Element("div",{"class":"tip"}).inject(this.tip);var A=new Element("div",{"class":"tip-bottom"}).inject(this.tip);
-this.tip.setStyles({position:"absolute",top:0,left:0,visibility:"hidden"});if(C.elements){this.attach(C.elements);}},attach:function(A){$$(A).each(function(D){var G=D.retrieve("tip:title",D.get("title"));
-var F=D.retrieve("tip:text",D.get("rel")||D.get("href"));var E=D.retrieve("tip:enter",this.elementEnter.bindWithEvent(this,D));var C=D.retrieve("tip:leave",this.elementLeave.bindWithEvent(this,D));
-D.addEvents({mouseenter:E,mouseleave:C});if(!this.options.fixed){var B=D.retrieve("tip:move",this.elementMove.bindWithEvent(this,D));D.addEvent("mousemove",B);
-}D.store("tip:native",D.get("title"));D.erase("title");},this);return this;},detach:function(A){$$(A).each(function(C){C.removeEvent("mouseenter",C.retrieve("tip:enter")||$empty);
-C.removeEvent("mouseleave",C.retrieve("tip:leave")||$empty);C.removeEvent("mousemove",C.retrieve("tip:move")||$empty);C.eliminate("tip:enter").eliminate("tip:leave").eliminate("tip:move");
-var B=C.retrieve("tip:native");if(B){C.set("title",B);}});return this;},elementEnter:function(B,A){$A(this.container.childNodes).each(Element.dispose);
-var D=A.retrieve("tip:title");if(D){this.titleElement=new Element("div",{"class":"tip-title"}).inject(this.container);this.fill(this.titleElement,D);}var C=A.retrieve("tip:text");
-if(C){this.textElement=new Element("div",{"class":"tip-text"}).inject(this.container);this.fill(this.textElement,C);}this.timer=$clear(this.timer);this.timer=this.show.delay(this.options.showDelay,this);
-this.position((!this.options.fixed)?B:{page:A.getPosition()});},elementLeave:function(A){$clear(this.timer);this.timer=this.hide.delay(this.options.hideDelay,this);
-},elementMove:function(A){this.position(A);},position:function(D){var B=window.getSize(),A=window.getScroll();var E={x:this.tip.offsetWidth,y:this.tip.offsetHeight};
-var C={x:"left",y:"top"};for(var F in C){var G=D.page[F]+this.options.offsets[F];if((G+E[F]-A[F])>B[F]){G=D.page[F]-this.options.offsets[F]-E[F];}this.tip.setStyle(C[F],G);
-}},fill:function(A,B){(typeof B=="string")?A.set("html",B):A.adopt(B);},show:function(){this.fireEvent("show",this.tip);},hide:function(){this.fireEvent("hide",this.tip);
-}});var Slider=new Class({Implements:[Events,Options],options:{onTick:function(A){if(this.options.snap){A=this.toPosition(this.step);}this.knob.setStyle(this.property,A);
-},snap:false,offset:0,range:false,wheel:false,steps:100,mode:"horizontal"},initialize:function(E,A,D){this.setOptions(D);this.element=$(E);this.knob=$(A);
-this.previousChange=this.previousEnd=this.step=-1;this.element.addEvent("mousedown",this.clickedElement.bind(this));if(this.options.wheel){this.element.addEvent("mousewheel",this.scrolledElement.bindWithEvent(this));
-}var F,B={},C={x:false,y:false};switch(this.options.mode){case"vertical":this.axis="y";this.property="top";F="offsetHeight";break;case"horizontal":this.axis="x";
-this.property="left";F="offsetWidth";}this.half=this.knob[F]/2;this.full=this.element[F]-this.knob[F]+(this.options.offset*2);this.min=$chk(this.options.range[0])?this.options.range[0]:0;
-this.max=$chk(this.options.range[1])?this.options.range[1]:this.options.steps;this.range=this.max-this.min;this.steps=this.options.steps||this.full;this.stepSize=Math.abs(this.range)/this.steps;
-this.stepWidth=this.stepSize*this.full/Math.abs(this.range);this.knob.setStyle("position","relative").setStyle(this.property,-this.options.offset);C[this.axis]=this.property;
-B[this.axis]=[-this.options.offset,this.full-this.options.offset];this.drag=new Drag(this.knob,{snap:0,limit:B,modifiers:C,onDrag:this.draggedKnob.bind(this),onStart:this.draggedKnob.bind(this),onComplete:function(){this.draggedKnob();
-this.end();}.bind(this)});if(this.options.snap){this.drag.options.grid=Math.ceil(this.stepWidth);this.drag.options.limit[this.axis][1]=this.full;}},set:function(A){if(!((this.range>0)^(A<this.min))){A=this.min;
-}if(!((this.range>0)^(A>this.max))){A=this.max;}this.step=Math.round(A);this.checkStep();this.end();this.fireEvent("tick",this.toPosition(this.step));return this;
-},clickedElement:function(C){var B=this.range<0?-1:1;var A=C.page[this.axis]-this.element.getPosition()[this.axis]-this.half;A=A.limit(-this.options.offset,this.full-this.options.offset);
-this.step=Math.round(this.min+B*this.toStep(A));this.checkStep();this.end();this.fireEvent("tick",A);},scrolledElement:function(A){var B=(this.options.mode=="horizontal")?(A.wheel<0):(A.wheel>0);
-this.set(B?this.step-this.stepSize:this.step+this.stepSize);A.stop();},draggedKnob:function(){var B=this.range<0?-1:1;var A=this.drag.value.now[this.axis];
-A=A.limit(-this.options.offset,this.full-this.options.offset);this.step=Math.round(this.min+B*this.toStep(A));this.checkStep();},checkStep:function(){if(this.previousChange!=this.step){this.previousChange=this.step;
-this.fireEvent("change",this.step);}},end:function(){if(this.previousEnd!==this.step){this.previousEnd=this.step;this.fireEvent("complete",this.step+"");
-}},toStep:function(A){var B=(A+this.options.offset)*this.stepSize/this.full*this.steps;return this.options.steps?Math.round(B-=B%this.stepSize):B;},toPosition:function(A){return(this.full*Math.abs(this.min-A))/(this.steps*this.stepSize)-this.options.offset;
-}});
\ No newline at end of file

=== added directory 'loggerhead/static/javascript/yui'
=== added directory 'loggerhead/static/javascript/yui/build'
=== added directory 'loggerhead/static/javascript/yui/build/anim'
=== added file 'loggerhead/static/javascript/yui/build/anim/README'
--- loggerhead/static/javascript/yui/build/anim/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+**** version 3.0.0 PR2 ***
+
+* easing attribute now accepts string ("easeOut" resolves to Y.Easing.easeOut)
+
+
+**** version 3.0.0 PR1 ***
+
+* initial 3.0 revision

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-base-debug.js'
--- loggerhead/static/javascript/yui/build/anim/anim-base-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-base-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,593 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-base', function(Y) {
+
+/**
+ * Y.Animation Utility.
+ * @module anim
+ */
+
+    /**
+     * Handles animation _queueing and threading.
+     * @class Anim
+     * @constructor
+     * @extends Base
+     */
+
+    var RUNNING = 'running',
+        START_TIME = 'startTime',
+        ELAPSED_TIME = 'elapsedTime',
+        /**
+        * @event start
+        * @description fires when an animation begins.
+        * @param {Event} ev The start event.
+        * @type Event.Custom
+        */
+        START = 'start',
+
+        /**
+        * @event tween
+        * @description fires every frame of the animation.
+        * @param {Event} ev The tween event.
+        * @type Event.Custom
+        */
+        TWEEN = 'tween',
+
+        /**
+        * @event end
+        * @description fires after the animation completes.
+        * @param {Event} ev The end event.
+        * @type Event.Custom
+        */
+        END = 'end',
+        NODE = 'node',
+        PAUSED = 'paused',
+        REVERSE = 'reverse', // TODO: cleanup
+        ITERATION_COUNT = 'iterationCount',
+
+        NUM = Number;
+
+    var _running = {},
+        _instances = {},
+        _timer;
+
+    Y.Anim = function() {
+        Y.Anim.superclass.constructor.apply(this, arguments);
+        _instances[Y.stamp(this)] = this;
+    };
+
+    Y.Anim.NAME = 'anim';
+
+    /**
+     * Regex of properties that should use the default unit.
+     *
+     * @property RE_DEFAULT_UNIT
+     * @static
+     */
+    Y.Anim.RE_DEFAULT_UNIT = /^width|height|top|right|bottom|left|margin.*|padding.*|border.*$/i;
+
+    /**
+     * The default unit to use with properties that pass the RE_DEFAULT_UNIT test.
+     *
+     * @property DEFAULT_UNIT
+     * @static
+     */
+    Y.Anim.DEFAULT_UNIT = 'px';
+
+    Y.Anim.DEFAULT_EASING = function (t, b, c, d) {
+        return c * t / d + b; // linear easing
+    };
+
+    /**
+     * Bucket for custom getters and setters
+     *
+     * @property behaviors
+     * @static
+     */
+    Y.Anim.behaviors = {
+        left: {
+            get: function(anim, attr) {
+                return anim._getOffset(attr);
+            }
+        }
+    };
+
+    Y.Anim.behaviors.top = Y.Anim.behaviors.left;
+
+    /**
+     * The default setter to use when setting object properties.
+     *
+     * @property DEFAULT_SETTER
+     * @static
+     */
+    Y.Anim.DEFAULT_SETTER = function(anim, att, from, to, elapsed, duration, fn, unit) {
+        unit = unit || '';
+        anim._node.setStyle(att, fn(elapsed, NUM(from), NUM(to) - NUM(from), duration) + unit);
+    };
+
+    /**
+     * The default getter to use when getting object properties.
+     *
+     * @property DEFAULT_GETTER
+     * @static
+     */
+    Y.Anim.DEFAULT_GETTER = function(anim, prop) {
+        return anim._node.getComputedStyle(prop);
+    };
+
+    Y.Anim.ATTRS = {
+        /**
+         * The object to be animated.
+         * @attribute node
+         * @type Node
+         */
+        node: {
+            set: function(node) {
+                node = Y.Node.get(node);
+                this._node = node;
+                if (!node) {
+                    Y.fail('Y.Anim: invalid node: ' + node);
+                }
+                return node;
+            }
+        },
+
+        /**
+         * The length of the animation.  Defaults to "1" (second).
+         * @attribute duration
+         * @type NUM
+         */
+        duration: {
+            value: 1
+        },
+
+        /**
+         * The method that will provide values to the attribute(s) during the animation. 
+         * Defaults to "Easing.easeNone".
+         * @attribute easing
+         * @type Function
+         */
+        easing: {
+            value: Y.Anim.DEFAULT_EASING,
+
+            set: function(val) {
+                if (typeof val === 'string' && Y.Easing) {
+                    return Y.Easing[val];
+                }
+            }
+        },
+
+        /**
+         * The starting values for the animated properties. 
+         * Fields may be strings, numbers, or functions.
+         * If a function is used, the return value becomes the from value.
+         * If no from value is specified, the DEFAULT_GETTER will be used. 
+         * @attribute from
+         * @type Object
+         */
+        from: {},
+
+        /**
+         * The ending values for the animated properties. 
+         * Fields may be strings, numbers, or functions.
+         * @attribute to
+         * @type Object
+         */
+        to: {},
+
+        /**
+         * Date stamp for the first frame of the animation.
+         * @attribute startTime
+         * @type Int
+         * @default 0 
+         * @readOnly
+         */
+        startTime: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * Current time the animation has been running.
+         * @attribute elapsedTime
+         * @type Int
+         * @default 0 
+         * @readOnly
+         */
+        elapsedTime: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * Whether or not the animation is currently running.
+         * @attribute running 
+         * @type Boolean
+         * @default false 
+         * @readOnly
+         */
+        running: {
+            get: function() {
+                return !!_running[Y.stamp(this)];
+            },
+            value: false,
+            readOnly: true
+        },
+
+        /**
+         * The number of times the animation should run 
+         * @attribute iterations
+         * @type Int
+         * @default 1 
+         */
+        iterations: {
+            value: 1
+        },
+
+        /**
+         * The number of iterations that have occurred.
+         * Resets when an animation ends (reaches iteration count or stop() called). 
+         * @attribute iterationCount
+         * @type Int
+         * @default 0
+         * @readOnly
+         */
+        iterationCount: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * How iterations of the animation should behave. 
+         * Possible values are "normal" and "alternate".
+         * Normal will repeat the animation, alternate will reverse on every other pass.
+         *
+         * @attribute direction
+         * @type String
+         * @default "normal"
+         */
+        direction: {
+            value: 'normal' // | alternate (fwd on odd, rev on even per spec)
+        },
+
+        /**
+         * Whether or not the animation is currently paused.
+         * @attribute running 
+         * @type Boolean
+         * @default false 
+         * @readOnly
+         */
+        paused: {
+            readOnly: true,
+            value: false
+        },
+
+        /**
+         * If true, animation begins from last frame
+         * @attribute reverse
+         * @type Boolean
+         * @default false 
+         */
+        reverse: {
+            value: false
+        }
+
+
+    };
+
+    /**
+     * Runs all animation instances.
+     * @method run
+     * @static
+     */    
+    Y.Anim.run = function() {
+        for (var i in _instances) {
+            if (_instances[i].run) {
+                _instances[i].run();
+            }
+        }
+    };
+
+    /**
+     * Pauses all animation instances.
+     * @method pause
+     * @static
+     */    
+    Y.Anim.pause = function() {
+        for (var i in _running) { // stop timer if nothing running
+            if (_running[i].pause) {
+                _running[i].pause();
+            }
+        }
+        Y.Anim._stopTimer();
+    };
+
+    /**
+     * Stops all animation instances.
+     * @method stop
+     * @static
+     */    
+    Y.Anim.stop = function() {
+        for (var i in _running) { // stop timer if nothing running
+            if (_running[i].stop) {
+                _running[i].stop();
+            }
+        }
+        Y.Anim._stopTimer();
+    };
+    
+    Y.Anim._startTimer = function() {
+        if (!_timer) {
+            _timer = setInterval(Y.Anim._runFrame, 1);
+        }
+    };
+
+    Y.Anim._stopTimer = function() {
+        clearInterval(_timer);
+        _timer = 0;
+    };
+
+    /**
+     * Called per Interval to handle each animation frame.
+     * @method _runFrame
+     * @private
+     * @static
+     */    
+    Y.Anim._runFrame = function() {
+        var done = true;
+        for (var anim in _running) {
+            if (_running[anim]._runFrame) {
+                done = false;
+                _running[anim]._runFrame();
+            }
+        }
+
+        if (done) {
+            Y.Anim._stopTimer();
+        }
+    };
+
+    Y.Anim.RE_UNITS = /^(-?\d*\.?\d*){1}(em|ex|px|in|cm|mm|pt|pc|%)*$/;
+
+    var proto = {
+        /**
+         * Starts or resumes an animation.
+         * percent start time marker.
+         * @method run
+         * @chainable
+         */    
+        run: function() {
+            if (!this.get(RUNNING)) {
+                this._start();
+            } else if (this.get(PAUSED)) {
+                this._resume();
+            }
+            return this;
+        },
+
+        /**
+         * Pauses the animation and
+         * freezes it in its current state and time.
+         * Calling run() will continue where it left off.
+         * @method pause
+         * @chainable
+         */    
+        pause: function() {
+            if (this.get(RUNNING)) {
+                this._pause();
+            }
+            return this;
+        },
+
+        /**
+         * Stops the animation and resets its time.
+         * @method stop
+         * @chainable
+         */    
+        stop: function(finish) {
+            if (this.get(RUNNING) || this.get(PAUSED)) {
+                this._end(finish);
+            }
+            return this;
+        },
+
+        _added: false,
+
+        _start: function() {
+            this._set(START_TIME, new Date() - this.get(ELAPSED_TIME));
+            this._actualFrames = 0;
+            if (!this.get(PAUSED)) {
+                this._initAttr();
+            }
+            _running[Y.stamp(this)] = this;
+            Y.Anim._startTimer();
+
+            this.fire(START);
+        },
+
+        _pause: function() {
+            this._set(START_TIME, null);
+            this._set(PAUSED, true);
+            delete _running[Y.stamp(this)];
+
+            /**
+            * @event pause
+            * @description fires when an animation is paused.
+            * @param {Event} ev The pause event.
+            * @type Event.Custom
+            */
+            this.fire('pause');
+        },
+
+        _resume: function() {
+            this._set(PAUSED, false);
+            _running[Y.stamp(this)] = this;
+
+            /**
+            * @event resume
+            * @description fires when an animation is resumed (run from pause).
+            * @param {Event} ev The pause event.
+            * @type Event.Custom
+            */
+            this.fire('resume');
+        },
+
+        _end: function(finish) {
+            this._set(START_TIME, null);
+            this._set(ELAPSED_TIME, 0);
+            this._set(PAUSED, false);
+
+            delete _running[Y.stamp(this)];
+            this.fire(END, {elapsed: this.get(ELAPSED_TIME)});
+        },
+
+        _runFrame: function() {
+            var attr = this._runtimeAttr,
+                customAttr = Y.Anim.behaviors,
+                easing = attr.easing,
+                d = attr.duration,
+                t = new Date() - this.get(START_TIME),
+                reversed = this.get(REVERSE),
+                done = (t >= d),
+                lastFrame = d,
+                attribute,
+                setter;
+                
+            if (reversed) {
+                t = d - t;
+                done = (t <= 0);
+                lastFrame = 0;
+            }
+
+            for (var i in attr) {
+                if (attr[i].to) {
+                    attribute = attr[i];
+                    setter = (i in customAttr && 'set' in customAttr[i]) ?
+                            customAttr[i].set : Y.Anim.DEFAULT_SETTER;
+
+                    if (!done) {
+                        setter(this, i, attribute.from, attribute.to, t, d, easing, attribute.unit); 
+                    } else { // ensure final frame value is set
+                       // TODO: handle keyframes 
+                        setter(this, i, attribute.from, attribute.to, lastFrame, d, easing, attribute.unit); 
+                    }
+                }
+            }
+
+            this._actualFrames += 1;
+            this._set(ELAPSED_TIME, t);
+
+            this.fire(TWEEN);
+            if (done) {
+                this._lastFrame();
+            }
+        },
+
+        _lastFrame: function() {
+            var iter = this.get('iterations'),
+                iterCount = this.get(ITERATION_COUNT);
+
+            iterCount += 1;
+            if (iter === 'infinite' || iterCount < iter) {
+                if (this.get('direction') === 'alternate') {
+                    this.set(REVERSE, !this.get(REVERSE)); // flip it
+                }
+                /**
+                * @event iteration
+                * @description fires when an animation begins an iteration.
+                * @param {Event} ev The iteration event.
+                * @type Event.Custom
+                */
+                this.fire('iteration');
+            } else {
+                iterCount = 0;
+                this._end();
+            }
+
+            this._set(START_TIME, new Date());
+            this._set(ITERATION_COUNT, iterCount);
+        },
+
+        _initAttr: function() {
+            var from = this.get('from') || {},
+                to = this.get('to') || {},
+                dur = this.get('duration') * 1000,
+                node = this.get(NODE),
+                easing = this.get('easing') || {},
+                attr = {},
+                customAttr = Y.Anim.behaviors,
+                unit, begin, end;
+
+            Y.each(to, function(val, name) {
+                if (typeof val === 'function') {
+                    val = val.call(this, node);
+                }
+
+                begin = from[name];
+                if (begin === undefined) {
+                    begin = (name in customAttr && 'get' in customAttr[name])  ?
+                            customAttr[name].get(this, name) : Y.Anim.DEFAULT_GETTER(this, name);
+                } else if (typeof begin === 'function') {
+                    begin = begin.call(this, node);
+                }
+
+                var mFrom = Y.Anim.RE_UNITS.exec(begin);
+                var mTo = Y.Anim.RE_UNITS.exec(val);
+
+                begin = mFrom ? mFrom[1] : begin;
+                var end = mTo ? mTo[1] : val,
+                    unit = mTo ? mTo[2] : mFrom ?  mFrom[2] : ''; // one might be zero TODO: mixed units
+
+                if (!unit && Y.Anim.RE_DEFAULT_UNIT.test(name)) {
+                    unit = Y.Anim.DEFAULT_UNIT;
+                }
+
+                if (!begin || !end) {
+                    Y.fail('invalid "from" or "to" for "' + name + '"', 'Anim');
+                    return;
+                }
+
+                attr[name] = {
+                    from: begin,
+                    to: end,
+                    unit: unit
+                };
+
+                attr.duration = dur;
+                attr.easing = easing;
+
+            }, this);
+
+            this._runtimeAttr = attr;
+        },
+
+
+        // TODO: move to computedStyle? (browsers dont agree on default computed offsets)
+        _getOffset: function(attr) {
+            var node = this._node,
+                val = node.getComputedStyle(attr),
+                get = (attr === 'left') ? 'getX': 'getY',
+                set = (attr === 'left') ? 'setX': 'setY';
+
+            if (val === 'auto') {
+                var position = node.getStyle('position');
+                if (position === 'absolute' || position === 'fixed') {
+                    val = node[get]();
+                    node[set](val);
+                } else {
+                    val = 0;
+                }
+            }
+
+            return val;
+        }
+    };
+
+    Y.extend(Y.Anim, Y.Base, proto);
+
+
+}, '3.0.0pr2' ,{requires:['base', 'node']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-base-min.js'
--- loggerhead/static/javascript/yui/build/anim/anim-base-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-base-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("anim-base",function(B){var C="running",N="startTime",L="elapsedTime",J="start",I="tween",M="end",D="node",K="paused",P="reverse",H="iterationCount",A=Number;var F={},O={},E;B.Anim=function(){B.Anim.superclass.constructor.apply(this,arguments);O[B.stamp(this)]=this;};B.Anim.NAME="anim";B.Anim.RE_DEFAULT_UNIT=/^width|height|top|right|bottom|left|margin.*|padding.*|border.*$/i;B.Anim.DEFAULT_UNIT="px";B.Anim.DEFAULT_EASING=function(R,Q,T,S){return T*R/S+Q;};B.Anim.behaviors={left:{get:function(R,Q){return R._getOffset(Q);}}};B.Anim.behaviors.top=B.Anim.behaviors.left;B.Anim.DEFAULT_SETTER=function(U,R,X,W,Q,V,S,T){T=T||"";U._node.setStyle(R,S(Q,A(X),A(W)-A(X),V)+T);};B.Anim.DEFAULT_GETTER=function(Q,R){return Q._node.getComputedStyle(R);};B.Anim.ATTRS={node:{set:function(Q){Q=B.Node.get(Q);this._node=Q;if(!Q){B.fail("Y.Anim: invalid node: "+Q);}return Q;}},duration:{value:1},easing:{value:B.Anim.DEFAULT_EASING,set:function(Q){if(typeof Q==="string"&&B.Easing){return B.Easing[Q];}}},from:{},to:{},startTime:{value:0,readOnly:true},elapsedTime:{value:0,readOnly:true},running:{get:function(){return !!F[B.stamp(this)];},value:false,readOnly:true},iterations:{value:1},iterationCount:{value:0,readOnly:true},direction:{value:"normal"},paused:{readOnly:true,value:false},reverse:{value:false}};B.Anim.run=function(){for(var Q in O){if(O[Q].run){O[Q].run();}}};B.Anim.pause=function(){for(var Q in F){if(F[Q].pause){F[Q].pause();}}B.Anim._stopTimer();};B.Anim.stop=function(){for(var Q in F){if(F[Q].stop){F[Q].stop();}}B.Anim._stopTimer();};B.Anim._startTimer=function(){if(!E){E=setInterval(B.Anim._runFrame,1);}};B.Anim._stopTimer=function(){clearInterval(E);E=0;};B.Anim._runFrame=function(){var Q=true;for(var R in F){if(F[R]._runFrame){Q=false;F[R]._runFrame();}}if(Q){B.Anim._stopTimer();}};B.Anim.RE_UNITS=/^(-?\d*\.?\d*){1}(em|ex|px|in|cm|mm|pt|pc|%)*$/;var G={run:function(){if(!this.get(C)){this._start();}else{if(this.get(K)){this._resume();}}return this;},pause:function(){if(this.get(C)){this._pause();}return this;},stop:function(Q){if(this.get(C)||this.get(K)){this._end(Q);}return this;},_added:false,_start:function(){this._set(N,new Date()-this.get(L));this._actualFrames=0;if(!this.get(K)){this._initAttr();}F[B.stamp(this)]=this;B.Anim._startTimer();this.fire(J);},_pause:function(){this._set(N,null);this._set(K,true);delete F[B.stamp(this)];this.fire("pause");},_resume:function(){this._set(K,false);F[B.stamp(this)]=this;this.fire("resume");},_end:function(Q){this._set(N,null);this._set(L,0);this._set(K,false);delete F[B.stamp(this)];this.fire(M,{elapsed:this.get(L)});},_runFrame:function(){var X=this._runtimeAttr,S=B.Anim.behaviors,Y=X.easing,Z=X.duration,a=new Date()-this.get(N),W=this.get(P),U=(a>=Z),Q=Z,R,T;if(W){a=Z-a;U=(a<=0);Q=0;}for(var V in X){if(X[V].to){R=X[V];T=(V in S&&"set" in S[V])?S[V].set:B.Anim.DEFAULT_SETTER;if(!U){T(this,V,R.from,R.to,a,Z,Y,R.unit);}else{T(this,V,R.from,R.to,Q,Z,Y,R.unit);}}}this._actualFrames+=1;this._set(L,a);this.fire(I);if(U){this._lastFrame();}},_lastFrame:function(){var Q=this.get("iterations"),R=this.get(H);R+=1;if(Q==="infinite"||R<Q){if(this.get("direction")==="alternate"){this.set(P,!this.get(P));}this.fire("iteration");}else{R=0;this._end();}this._set(N,new Date());this._set(H,R);},_initAttr:function(){var X=this.get("from")||{},Y=this.get("to")||{},Q=this.get("duration")*1000,T=this.get(D),W=this.get("easing")||{},V={},R=B.Anim.behaviors,Z,S,U;B.each(Y,function(f,c){if(typeof f==="function"){f=f.call(this,T);}S=X[c];if(S===undefined){S=(c in R&&"get" in R[c])?R[c].get(this,c):B.Anim.DEFAULT_GETTER(this,c);}else{if(typeof S==="function"){S=S.call(this,T);}}var b=B.Anim.RE_UNITS.exec(S);var d=B.Anim.RE_UNITS.exec(f);S=b?b[1]:S;var a=d?d[1]:f,e=d?d[2]:b?b[2]:"";if(!e&&B.Anim.RE_DEFAULT_UNIT.test(c)){e=B.Anim.DEFAULT_UNIT;}if(!S||!a){B.fail('invalid "from" or "to" for "'+c+'"',"Anim");return ;}V[c]={from:S,to:a,unit:e};V.duration=Q;V.easing=W;},this);this._runtimeAttr=V;},_getOffset:function(R){var T=this._node,U=T.getComputedStyle(R),S=(R==="left")?"getX":"getY",V=(R==="left")?"setX":"setY";if(U==="auto"){var Q=T.getStyle("position");if(Q==="absolute"||Q==="fixed"){U=T[S]();T[V](U);}else{U=0;}}return U;}};B.extend(B.Anim,B.Base,G);},"3.0.0pr2",{requires:["base","node"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-base.js'
--- loggerhead/static/javascript/yui/build/anim/anim-base.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-base.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,593 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-base', function(Y) {
+
+/**
+ * Y.Animation Utility.
+ * @module anim
+ */
+
+    /**
+     * Handles animation _queueing and threading.
+     * @class Anim
+     * @constructor
+     * @extends Base
+     */
+
+    var RUNNING = 'running',
+        START_TIME = 'startTime',
+        ELAPSED_TIME = 'elapsedTime',
+        /**
+        * @event start
+        * @description fires when an animation begins.
+        * @param {Event} ev The start event.
+        * @type Event.Custom
+        */
+        START = 'start',
+
+        /**
+        * @event tween
+        * @description fires every frame of the animation.
+        * @param {Event} ev The tween event.
+        * @type Event.Custom
+        */
+        TWEEN = 'tween',
+
+        /**
+        * @event end
+        * @description fires after the animation completes.
+        * @param {Event} ev The end event.
+        * @type Event.Custom
+        */
+        END = 'end',
+        NODE = 'node',
+        PAUSED = 'paused',
+        REVERSE = 'reverse', // TODO: cleanup
+        ITERATION_COUNT = 'iterationCount',
+
+        NUM = Number;
+
+    var _running = {},
+        _instances = {},
+        _timer;
+
+    Y.Anim = function() {
+        Y.Anim.superclass.constructor.apply(this, arguments);
+        _instances[Y.stamp(this)] = this;
+    };
+
+    Y.Anim.NAME = 'anim';
+
+    /**
+     * Regex of properties that should use the default unit.
+     *
+     * @property RE_DEFAULT_UNIT
+     * @static
+     */
+    Y.Anim.RE_DEFAULT_UNIT = /^width|height|top|right|bottom|left|margin.*|padding.*|border.*$/i;
+
+    /**
+     * The default unit to use with properties that pass the RE_DEFAULT_UNIT test.
+     *
+     * @property DEFAULT_UNIT
+     * @static
+     */
+    Y.Anim.DEFAULT_UNIT = 'px';
+
+    Y.Anim.DEFAULT_EASING = function (t, b, c, d) {
+        return c * t / d + b; // linear easing
+    };
+
+    /**
+     * Bucket for custom getters and setters
+     *
+     * @property behaviors
+     * @static
+     */
+    Y.Anim.behaviors = {
+        left: {
+            get: function(anim, attr) {
+                return anim._getOffset(attr);
+            }
+        }
+    };
+
+    Y.Anim.behaviors.top = Y.Anim.behaviors.left;
+
+    /**
+     * The default setter to use when setting object properties.
+     *
+     * @property DEFAULT_SETTER
+     * @static
+     */
+    Y.Anim.DEFAULT_SETTER = function(anim, att, from, to, elapsed, duration, fn, unit) {
+        unit = unit || '';
+        anim._node.setStyle(att, fn(elapsed, NUM(from), NUM(to) - NUM(from), duration) + unit);
+    };
+
+    /**
+     * The default getter to use when getting object properties.
+     *
+     * @property DEFAULT_GETTER
+     * @static
+     */
+    Y.Anim.DEFAULT_GETTER = function(anim, prop) {
+        return anim._node.getComputedStyle(prop);
+    };
+
+    Y.Anim.ATTRS = {
+        /**
+         * The object to be animated.
+         * @attribute node
+         * @type Node
+         */
+        node: {
+            set: function(node) {
+                node = Y.Node.get(node);
+                this._node = node;
+                if (!node) {
+                    Y.fail('Y.Anim: invalid node: ' + node);
+                }
+                return node;
+            }
+        },
+
+        /**
+         * The length of the animation.  Defaults to "1" (second).
+         * @attribute duration
+         * @type NUM
+         */
+        duration: {
+            value: 1
+        },
+
+        /**
+         * The method that will provide values to the attribute(s) during the animation. 
+         * Defaults to "Easing.easeNone".
+         * @attribute easing
+         * @type Function
+         */
+        easing: {
+            value: Y.Anim.DEFAULT_EASING,
+
+            set: function(val) {
+                if (typeof val === 'string' && Y.Easing) {
+                    return Y.Easing[val];
+                }
+            }
+        },
+
+        /**
+         * The starting values for the animated properties. 
+         * Fields may be strings, numbers, or functions.
+         * If a function is used, the return value becomes the from value.
+         * If no from value is specified, the DEFAULT_GETTER will be used. 
+         * @attribute from
+         * @type Object
+         */
+        from: {},
+
+        /**
+         * The ending values for the animated properties. 
+         * Fields may be strings, numbers, or functions.
+         * @attribute to
+         * @type Object
+         */
+        to: {},
+
+        /**
+         * Date stamp for the first frame of the animation.
+         * @attribute startTime
+         * @type Int
+         * @default 0 
+         * @readOnly
+         */
+        startTime: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * Current time the animation has been running.
+         * @attribute elapsedTime
+         * @type Int
+         * @default 0 
+         * @readOnly
+         */
+        elapsedTime: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * Whether or not the animation is currently running.
+         * @attribute running 
+         * @type Boolean
+         * @default false 
+         * @readOnly
+         */
+        running: {
+            get: function() {
+                return !!_running[Y.stamp(this)];
+            },
+            value: false,
+            readOnly: true
+        },
+
+        /**
+         * The number of times the animation should run 
+         * @attribute iterations
+         * @type Int
+         * @default 1 
+         */
+        iterations: {
+            value: 1
+        },
+
+        /**
+         * The number of iterations that have occurred.
+         * Resets when an animation ends (reaches iteration count or stop() called). 
+         * @attribute iterationCount
+         * @type Int
+         * @default 0
+         * @readOnly
+         */
+        iterationCount: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * How iterations of the animation should behave. 
+         * Possible values are "normal" and "alternate".
+         * Normal will repeat the animation, alternate will reverse on every other pass.
+         *
+         * @attribute direction
+         * @type String
+         * @default "normal"
+         */
+        direction: {
+            value: 'normal' // | alternate (fwd on odd, rev on even per spec)
+        },
+
+        /**
+         * Whether or not the animation is currently paused.
+         * @attribute running 
+         * @type Boolean
+         * @default false 
+         * @readOnly
+         */
+        paused: {
+            readOnly: true,
+            value: false
+        },
+
+        /**
+         * If true, animation begins from last frame
+         * @attribute reverse
+         * @type Boolean
+         * @default false 
+         */
+        reverse: {
+            value: false
+        }
+
+
+    };
+
+    /**
+     * Runs all animation instances.
+     * @method run
+     * @static
+     */    
+    Y.Anim.run = function() {
+        for (var i in _instances) {
+            if (_instances[i].run) {
+                _instances[i].run();
+            }
+        }
+    };
+
+    /**
+     * Pauses all animation instances.
+     * @method pause
+     * @static
+     */    
+    Y.Anim.pause = function() {
+        for (var i in _running) { // stop timer if nothing running
+            if (_running[i].pause) {
+                _running[i].pause();
+            }
+        }
+        Y.Anim._stopTimer();
+    };
+
+    /**
+     * Stops all animation instances.
+     * @method stop
+     * @static
+     */    
+    Y.Anim.stop = function() {
+        for (var i in _running) { // stop timer if nothing running
+            if (_running[i].stop) {
+                _running[i].stop();
+            }
+        }
+        Y.Anim._stopTimer();
+    };
+    
+    Y.Anim._startTimer = function() {
+        if (!_timer) {
+            _timer = setInterval(Y.Anim._runFrame, 1);
+        }
+    };
+
+    Y.Anim._stopTimer = function() {
+        clearInterval(_timer);
+        _timer = 0;
+    };
+
+    /**
+     * Called per Interval to handle each animation frame.
+     * @method _runFrame
+     * @private
+     * @static
+     */    
+    Y.Anim._runFrame = function() {
+        var done = true;
+        for (var anim in _running) {
+            if (_running[anim]._runFrame) {
+                done = false;
+                _running[anim]._runFrame();
+            }
+        }
+
+        if (done) {
+            Y.Anim._stopTimer();
+        }
+    };
+
+    Y.Anim.RE_UNITS = /^(-?\d*\.?\d*){1}(em|ex|px|in|cm|mm|pt|pc|%)*$/;
+
+    var proto = {
+        /**
+         * Starts or resumes an animation.
+         * percent start time marker.
+         * @method run
+         * @chainable
+         */    
+        run: function() {
+            if (!this.get(RUNNING)) {
+                this._start();
+            } else if (this.get(PAUSED)) {
+                this._resume();
+            }
+            return this;
+        },
+
+        /**
+         * Pauses the animation and
+         * freezes it in its current state and time.
+         * Calling run() will continue where it left off.
+         * @method pause
+         * @chainable
+         */    
+        pause: function() {
+            if (this.get(RUNNING)) {
+                this._pause();
+            }
+            return this;
+        },
+
+        /**
+         * Stops the animation and resets its time.
+         * @method stop
+         * @chainable
+         */    
+        stop: function(finish) {
+            if (this.get(RUNNING) || this.get(PAUSED)) {
+                this._end(finish);
+            }
+            return this;
+        },
+
+        _added: false,
+
+        _start: function() {
+            this._set(START_TIME, new Date() - this.get(ELAPSED_TIME));
+            this._actualFrames = 0;
+            if (!this.get(PAUSED)) {
+                this._initAttr();
+            }
+            _running[Y.stamp(this)] = this;
+            Y.Anim._startTimer();
+
+            this.fire(START);
+        },
+
+        _pause: function() {
+            this._set(START_TIME, null);
+            this._set(PAUSED, true);
+            delete _running[Y.stamp(this)];
+
+            /**
+            * @event pause
+            * @description fires when an animation is paused.
+            * @param {Event} ev The pause event.
+            * @type Event.Custom
+            */
+            this.fire('pause');
+        },
+
+        _resume: function() {
+            this._set(PAUSED, false);
+            _running[Y.stamp(this)] = this;
+
+            /**
+            * @event resume
+            * @description fires when an animation is resumed (run from pause).
+            * @param {Event} ev The pause event.
+            * @type Event.Custom
+            */
+            this.fire('resume');
+        },
+
+        _end: function(finish) {
+            this._set(START_TIME, null);
+            this._set(ELAPSED_TIME, 0);
+            this._set(PAUSED, false);
+
+            delete _running[Y.stamp(this)];
+            this.fire(END, {elapsed: this.get(ELAPSED_TIME)});
+        },
+
+        _runFrame: function() {
+            var attr = this._runtimeAttr,
+                customAttr = Y.Anim.behaviors,
+                easing = attr.easing,
+                d = attr.duration,
+                t = new Date() - this.get(START_TIME),
+                reversed = this.get(REVERSE),
+                done = (t >= d),
+                lastFrame = d,
+                attribute,
+                setter;
+                
+            if (reversed) {
+                t = d - t;
+                done = (t <= 0);
+                lastFrame = 0;
+            }
+
+            for (var i in attr) {
+                if (attr[i].to) {
+                    attribute = attr[i];
+                    setter = (i in customAttr && 'set' in customAttr[i]) ?
+                            customAttr[i].set : Y.Anim.DEFAULT_SETTER;
+
+                    if (!done) {
+                        setter(this, i, attribute.from, attribute.to, t, d, easing, attribute.unit); 
+                    } else { // ensure final frame value is set
+                       // TODO: handle keyframes 
+                        setter(this, i, attribute.from, attribute.to, lastFrame, d, easing, attribute.unit); 
+                    }
+                }
+            }
+
+            this._actualFrames += 1;
+            this._set(ELAPSED_TIME, t);
+
+            this.fire(TWEEN);
+            if (done) {
+                this._lastFrame();
+            }
+        },
+
+        _lastFrame: function() {
+            var iter = this.get('iterations'),
+                iterCount = this.get(ITERATION_COUNT);
+
+            iterCount += 1;
+            if (iter === 'infinite' || iterCount < iter) {
+                if (this.get('direction') === 'alternate') {
+                    this.set(REVERSE, !this.get(REVERSE)); // flip it
+                }
+                /**
+                * @event iteration
+                * @description fires when an animation begins an iteration.
+                * @param {Event} ev The iteration event.
+                * @type Event.Custom
+                */
+                this.fire('iteration');
+            } else {
+                iterCount = 0;
+                this._end();
+            }
+
+            this._set(START_TIME, new Date());
+            this._set(ITERATION_COUNT, iterCount);
+        },
+
+        _initAttr: function() {
+            var from = this.get('from') || {},
+                to = this.get('to') || {},
+                dur = this.get('duration') * 1000,
+                node = this.get(NODE),
+                easing = this.get('easing') || {},
+                attr = {},
+                customAttr = Y.Anim.behaviors,
+                unit, begin, end;
+
+            Y.each(to, function(val, name) {
+                if (typeof val === 'function') {
+                    val = val.call(this, node);
+                }
+
+                begin = from[name];
+                if (begin === undefined) {
+                    begin = (name in customAttr && 'get' in customAttr[name])  ?
+                            customAttr[name].get(this, name) : Y.Anim.DEFAULT_GETTER(this, name);
+                } else if (typeof begin === 'function') {
+                    begin = begin.call(this, node);
+                }
+
+                var mFrom = Y.Anim.RE_UNITS.exec(begin);
+                var mTo = Y.Anim.RE_UNITS.exec(val);
+
+                begin = mFrom ? mFrom[1] : begin;
+                var end = mTo ? mTo[1] : val,
+                    unit = mTo ? mTo[2] : mFrom ?  mFrom[2] : ''; // one might be zero TODO: mixed units
+
+                if (!unit && Y.Anim.RE_DEFAULT_UNIT.test(name)) {
+                    unit = Y.Anim.DEFAULT_UNIT;
+                }
+
+                if (!begin || !end) {
+                    Y.fail('invalid "from" or "to" for "' + name + '"', 'Anim');
+                    return;
+                }
+
+                attr[name] = {
+                    from: begin,
+                    to: end,
+                    unit: unit
+                };
+
+                attr.duration = dur;
+                attr.easing = easing;
+
+            }, this);
+
+            this._runtimeAttr = attr;
+        },
+
+
+        // TODO: move to computedStyle? (browsers dont agree on default computed offsets)
+        _getOffset: function(attr) {
+            var node = this._node,
+                val = node.getComputedStyle(attr),
+                get = (attr === 'left') ? 'getX': 'getY',
+                set = (attr === 'left') ? 'setX': 'setY';
+
+            if (val === 'auto') {
+                var position = node.getStyle('position');
+                if (position === 'absolute' || position === 'fixed') {
+                    val = node[get]();
+                    node[set](val);
+                } else {
+                    val = 0;
+                }
+            }
+
+            return val;
+        }
+    };
+
+    Y.extend(Y.Anim, Y.Base, proto);
+
+
+}, '3.0.0pr2' ,{requires:['base', 'node']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-color-debug.js'
--- loggerhead/static/javascript/yui/build/anim/anim-color-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-color-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,55 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-color', function(Y) {
+
+/**
+ * Adds support for color properties in <code>to</code>
+ * and <code>from</code> attributes.
+ * @module anim
+ * @submodule anim-color
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.color = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        from = Y.Color.re_RGB.exec(Y.Color.toRGB(from));
+        to = Y.Color.re_RGB.exec(Y.Color.toRGB(to));
+
+        if (!from || from.length < 3 || !to || to.length < 3) {
+            Y.fail('invalid from or to passed to color behavior');
+        }
+
+        anim._node.setStyle(att, 'rgb(' + [
+            Math.floor(fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)),
+            Math.floor(fn(elapsed, NUM(from[2]), NUM(to[2]) - NUM(from[2]), duration)),
+            Math.floor(fn(elapsed, NUM(from[3]), NUM(to[3]) - NUM(from[3]), duration))
+        ].join(', ') + ')');
+    },
+    
+    // TODO: default bgcolor const
+    get: function(anim, att) {
+        var val = anim._node.getComputedStyle(att);
+        val = (val === 'transparent') ? 'rgb(255, 255, 255)' : val;
+        return val;
+    }
+};
+
+Y.each(['backgroundColor',
+        'borderColor',
+        'borderTopColor',
+        'borderRightColor', 
+        'borderBottomColor', 
+        'borderLeftColor'],
+        function(v, i) {
+            Y.Anim.behaviors[v] = Y.Anim.behaviors.color;
+        }
+);
+
+
+}, '3.0.0pr2' ,{requires:['anim-base', 'node-style']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-color-min.js'
--- loggerhead/static/javascript/yui/build/anim/anim-color-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-color-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("anim-color",function(B){var A=Number;B.Anim.behaviors.color={set:function(F,D,I,H,C,G,E){I=B.Color.re_RGB.exec(B.Color.toRGB(I));H=B.Color.re_RGB.exec(B.Color.toRGB(H));if(!I||I.length<3||!H||H.length<3){B.fail("invalid from or to passed to color behavior");}F._node.setStyle(D,"rgb("+[Math.floor(E(C,A(I[1]),A(H[1])-A(I[1]),G)),Math.floor(E(C,A(I[2]),A(H[2])-A(I[2]),G)),Math.floor(E(C,A(I[3]),A(H[3])-A(I[3]),G))].join(", ")+")");},get:function(D,C){var E=D._node.getComputedStyle(C);E=(E==="transparent")?"rgb(255, 255, 255)":E;return E;}};B.each(["backgroundColor","borderColor","borderTopColor","borderRightColor","borderBottomColor","borderLeftColor"],function(C,D){B.Anim.behaviors[C]=B.Anim.behaviors.color;});},"3.0.0pr2",{requires:["anim-base","node-style"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-color.js'
--- loggerhead/static/javascript/yui/build/anim/anim-color.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-color.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,55 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-color', function(Y) {
+
+/**
+ * Adds support for color properties in <code>to</code>
+ * and <code>from</code> attributes.
+ * @module anim
+ * @submodule anim-color
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.color = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        from = Y.Color.re_RGB.exec(Y.Color.toRGB(from));
+        to = Y.Color.re_RGB.exec(Y.Color.toRGB(to));
+
+        if (!from || from.length < 3 || !to || to.length < 3) {
+            Y.fail('invalid from or to passed to color behavior');
+        }
+
+        anim._node.setStyle(att, 'rgb(' + [
+            Math.floor(fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)),
+            Math.floor(fn(elapsed, NUM(from[2]), NUM(to[2]) - NUM(from[2]), duration)),
+            Math.floor(fn(elapsed, NUM(from[3]), NUM(to[3]) - NUM(from[3]), duration))
+        ].join(', ') + ')');
+    },
+    
+    // TODO: default bgcolor const
+    get: function(anim, att) {
+        var val = anim._node.getComputedStyle(att);
+        val = (val === 'transparent') ? 'rgb(255, 255, 255)' : val;
+        return val;
+    }
+};
+
+Y.each(['backgroundColor',
+        'borderColor',
+        'borderTopColor',
+        'borderRightColor', 
+        'borderBottomColor', 
+        'borderLeftColor'],
+        function(v, i) {
+            Y.Anim.behaviors[v] = Y.Anim.behaviors.color;
+        }
+);
+
+
+}, '3.0.0pr2' ,{requires:['anim-base', 'node-style']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-curve-debug.js'
--- loggerhead/static/javascript/yui/build/anim/anim-curve-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-curve-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,63 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-curve', function(Y) {
+
+/**
+ * Adds support for the <code>curve</code> property for the <code>to</code> 
+ * attribute.  A curve is zero or more control points and an end point.
+ * @module anim
+ * @submodule anim-curve
+ * @for Anim
+ */
+
+Y.Anim.behaviors.curve = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        from = from.slice.call(from);
+        to = to.slice.call(to);
+        var t = fn(elapsed, 0, 100, duration) / 100;
+        to.unshift(from);
+        anim._node.setXY(Y.Anim.getBezier(to, t));
+    },
+
+    get: function(anim, att) {
+        return anim._node.getXY();
+    }
+};
+
+/**
+ * Get the current position of the animated element based on t.
+ * Each point is an array of "x" and "y" values (0 = x, 1 = y)
+ * At least 2 points are required (start and end).
+ * First point is start. Last point is end.
+ * Additional control points are optional.     
+ * @method getBezier
+ * @static
+ * @param {Array} points An array containing Bezier points
+ * @param {Number} t A number between 0 and 1 which is the basis for determining current position
+ * @return {Array} An array containing int x and y member data
+ */
+Y.Anim.getBezier = function(points, t) {  
+    var n = points.length;
+    var tmp = [];
+
+    for (var i = 0; i < n; ++i){
+        tmp[i] = [points[i][0], points[i][1]]; // save input
+    }
+    
+    for (var j = 1; j < n; ++j) {
+        for (i = 0; i < n - j; ++i) {
+            tmp[i][0] = (1 - t) * tmp[i][0] + t * tmp[parseInt(i + 1, 10)][0];
+            tmp[i][1] = (1 - t) * tmp[i][1] + t * tmp[parseInt(i + 1, 10)][1]; 
+        }
+    }
+
+    return [ tmp[0][0], tmp[0][1] ]; 
+
+};
+
+
+}, '3.0.0pr2' ,{requires:['anim-base', 'node-screen']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-curve-min.js'
--- loggerhead/static/javascript/yui/build/anim/anim-curve-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-curve-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("anim-curve",function(A){A.Anim.behaviors.curve={set:function(F,C,I,H,B,G,E){I=I.slice.call(I);H=H.slice.call(H);var D=E(B,0,100,G)/100;H.unshift(I);F._node.setXY(A.Anim.getBezier(H,D));},get:function(C,B){return C._node.getXY();}};A.Anim.getBezier=function(F,E){var G=F.length;var D=[];for(var C=0;C<G;++C){D[C]=[F[C][0],F[C][1]];}for(var B=1;B<G;++B){for(C=0;C<G-B;++C){D[C][0]=(1-E)*D[C][0]+E*D[parseInt(C+1,10)][0];D[C][1]=(1-E)*D[C][1]+E*D[parseInt(C+1,10)][1];}}return[D[0][0],D[0][1]];};},"3.0.0pr2",{requires:["anim-base","node-screen"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-curve.js'
--- loggerhead/static/javascript/yui/build/anim/anim-curve.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-curve.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,63 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-curve', function(Y) {
+
+/**
+ * Adds support for the <code>curve</code> property for the <code>to</code> 
+ * attribute.  A curve is zero or more control points and an end point.
+ * @module anim
+ * @submodule anim-curve
+ * @for Anim
+ */
+
+Y.Anim.behaviors.curve = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        from = from.slice.call(from);
+        to = to.slice.call(to);
+        var t = fn(elapsed, 0, 100, duration) / 100;
+        to.unshift(from);
+        anim._node.setXY(Y.Anim.getBezier(to, t));
+    },
+
+    get: function(anim, att) {
+        return anim._node.getXY();
+    }
+};
+
+/**
+ * Get the current position of the animated element based on t.
+ * Each point is an array of "x" and "y" values (0 = x, 1 = y)
+ * At least 2 points are required (start and end).
+ * First point is start. Last point is end.
+ * Additional control points are optional.     
+ * @method getBezier
+ * @static
+ * @param {Array} points An array containing Bezier points
+ * @param {Number} t A number between 0 and 1 which is the basis for determining current position
+ * @return {Array} An array containing int x and y member data
+ */
+Y.Anim.getBezier = function(points, t) {  
+    var n = points.length;
+    var tmp = [];
+
+    for (var i = 0; i < n; ++i){
+        tmp[i] = [points[i][0], points[i][1]]; // save input
+    }
+    
+    for (var j = 1; j < n; ++j) {
+        for (i = 0; i < n - j; ++i) {
+            tmp[i][0] = (1 - t) * tmp[i][0] + t * tmp[parseInt(i + 1, 10)][0];
+            tmp[i][1] = (1 - t) * tmp[i][1] + t * tmp[parseInt(i + 1, 10)][1]; 
+        }
+    }
+
+    return [ tmp[0][0], tmp[0][1] ]; 
+
+};
+
+
+}, '3.0.0pr2' ,{requires:['anim-base', 'node-screen']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-debug.js'
--- loggerhead/static/javascript/yui/build/anim/anim-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1106 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim', function(Y) {
+
+/**
+ * Y.Animation Utility.
+ * @module anim
+ */
+
+    /**
+     * Handles animation _queueing and threading.
+     * @class Anim
+     * @constructor
+     * @extends Base
+     */
+
+    var RUNNING = 'running',
+        START_TIME = 'startTime',
+        ELAPSED_TIME = 'elapsedTime',
+        /**
+        * @event start
+        * @description fires when an animation begins.
+        * @param {Event} ev The start event.
+        * @type Event.Custom
+        */
+        START = 'start',
+
+        /**
+        * @event tween
+        * @description fires every frame of the animation.
+        * @param {Event} ev The tween event.
+        * @type Event.Custom
+        */
+        TWEEN = 'tween',
+
+        /**
+        * @event end
+        * @description fires after the animation completes.
+        * @param {Event} ev The end event.
+        * @type Event.Custom
+        */
+        END = 'end',
+        NODE = 'node',
+        PAUSED = 'paused',
+        REVERSE = 'reverse', // TODO: cleanup
+        ITERATION_COUNT = 'iterationCount',
+
+        NUM = Number;
+
+    var _running = {},
+        _instances = {},
+        _timer;
+
+    Y.Anim = function() {
+        Y.Anim.superclass.constructor.apply(this, arguments);
+        _instances[Y.stamp(this)] = this;
+    };
+
+    Y.Anim.NAME = 'anim';
+
+    /**
+     * Regex of properties that should use the default unit.
+     *
+     * @property RE_DEFAULT_UNIT
+     * @static
+     */
+    Y.Anim.RE_DEFAULT_UNIT = /^width|height|top|right|bottom|left|margin.*|padding.*|border.*$/i;
+
+    /**
+     * The default unit to use with properties that pass the RE_DEFAULT_UNIT test.
+     *
+     * @property DEFAULT_UNIT
+     * @static
+     */
+    Y.Anim.DEFAULT_UNIT = 'px';
+
+    Y.Anim.DEFAULT_EASING = function (t, b, c, d) {
+        return c * t / d + b; // linear easing
+    };
+
+    /**
+     * Bucket for custom getters and setters
+     *
+     * @property behaviors
+     * @static
+     */
+    Y.Anim.behaviors = {
+        left: {
+            get: function(anim, attr) {
+                return anim._getOffset(attr);
+            }
+        }
+    };
+
+    Y.Anim.behaviors.top = Y.Anim.behaviors.left;
+
+    /**
+     * The default setter to use when setting object properties.
+     *
+     * @property DEFAULT_SETTER
+     * @static
+     */
+    Y.Anim.DEFAULT_SETTER = function(anim, att, from, to, elapsed, duration, fn, unit) {
+        unit = unit || '';
+        anim._node.setStyle(att, fn(elapsed, NUM(from), NUM(to) - NUM(from), duration) + unit);
+    };
+
+    /**
+     * The default getter to use when getting object properties.
+     *
+     * @property DEFAULT_GETTER
+     * @static
+     */
+    Y.Anim.DEFAULT_GETTER = function(anim, prop) {
+        return anim._node.getComputedStyle(prop);
+    };
+
+    Y.Anim.ATTRS = {
+        /**
+         * The object to be animated.
+         * @attribute node
+         * @type Node
+         */
+        node: {
+            set: function(node) {
+                node = Y.Node.get(node);
+                this._node = node;
+                if (!node) {
+                    Y.fail('Y.Anim: invalid node: ' + node);
+                }
+                return node;
+            }
+        },
+
+        /**
+         * The length of the animation.  Defaults to "1" (second).
+         * @attribute duration
+         * @type NUM
+         */
+        duration: {
+            value: 1
+        },
+
+        /**
+         * The method that will provide values to the attribute(s) during the animation. 
+         * Defaults to "Easing.easeNone".
+         * @attribute easing
+         * @type Function
+         */
+        easing: {
+            value: Y.Anim.DEFAULT_EASING,
+
+            set: function(val) {
+                if (typeof val === 'string' && Y.Easing) {
+                    return Y.Easing[val];
+                }
+            }
+        },
+
+        /**
+         * The starting values for the animated properties. 
+         * Fields may be strings, numbers, or functions.
+         * If a function is used, the return value becomes the from value.
+         * If no from value is specified, the DEFAULT_GETTER will be used. 
+         * @attribute from
+         * @type Object
+         */
+        from: {},
+
+        /**
+         * The ending values for the animated properties. 
+         * Fields may be strings, numbers, or functions.
+         * @attribute to
+         * @type Object
+         */
+        to: {},
+
+        /**
+         * Date stamp for the first frame of the animation.
+         * @attribute startTime
+         * @type Int
+         * @default 0 
+         * @readOnly
+         */
+        startTime: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * Current time the animation has been running.
+         * @attribute elapsedTime
+         * @type Int
+         * @default 0 
+         * @readOnly
+         */
+        elapsedTime: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * Whether or not the animation is currently running.
+         * @attribute running 
+         * @type Boolean
+         * @default false 
+         * @readOnly
+         */
+        running: {
+            get: function() {
+                return !!_running[Y.stamp(this)];
+            },
+            value: false,
+            readOnly: true
+        },
+
+        /**
+         * The number of times the animation should run 
+         * @attribute iterations
+         * @type Int
+         * @default 1 
+         */
+        iterations: {
+            value: 1
+        },
+
+        /**
+         * The number of iterations that have occurred.
+         * Resets when an animation ends (reaches iteration count or stop() called). 
+         * @attribute iterationCount
+         * @type Int
+         * @default 0
+         * @readOnly
+         */
+        iterationCount: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * How iterations of the animation should behave. 
+         * Possible values are "normal" and "alternate".
+         * Normal will repeat the animation, alternate will reverse on every other pass.
+         *
+         * @attribute direction
+         * @type String
+         * @default "normal"
+         */
+        direction: {
+            value: 'normal' // | alternate (fwd on odd, rev on even per spec)
+        },
+
+        /**
+         * Whether or not the animation is currently paused.
+         * @attribute running 
+         * @type Boolean
+         * @default false 
+         * @readOnly
+         */
+        paused: {
+            readOnly: true,
+            value: false
+        },
+
+        /**
+         * If true, animation begins from last frame
+         * @attribute reverse
+         * @type Boolean
+         * @default false 
+         */
+        reverse: {
+            value: false
+        }
+
+
+    };
+
+    /**
+     * Runs all animation instances.
+     * @method run
+     * @static
+     */    
+    Y.Anim.run = function() {
+        for (var i in _instances) {
+            if (_instances[i].run) {
+                _instances[i].run();
+            }
+        }
+    };
+
+    /**
+     * Pauses all animation instances.
+     * @method pause
+     * @static
+     */    
+    Y.Anim.pause = function() {
+        for (var i in _running) { // stop timer if nothing running
+            if (_running[i].pause) {
+                _running[i].pause();
+            }
+        }
+        Y.Anim._stopTimer();
+    };
+
+    /**
+     * Stops all animation instances.
+     * @method stop
+     * @static
+     */    
+    Y.Anim.stop = function() {
+        for (var i in _running) { // stop timer if nothing running
+            if (_running[i].stop) {
+                _running[i].stop();
+            }
+        }
+        Y.Anim._stopTimer();
+    };
+    
+    Y.Anim._startTimer = function() {
+        if (!_timer) {
+            _timer = setInterval(Y.Anim._runFrame, 1);
+        }
+    };
+
+    Y.Anim._stopTimer = function() {
+        clearInterval(_timer);
+        _timer = 0;
+    };
+
+    /**
+     * Called per Interval to handle each animation frame.
+     * @method _runFrame
+     * @private
+     * @static
+     */    
+    Y.Anim._runFrame = function() {
+        var done = true;
+        for (var anim in _running) {
+            if (_running[anim]._runFrame) {
+                done = false;
+                _running[anim]._runFrame();
+            }
+        }
+
+        if (done) {
+            Y.Anim._stopTimer();
+        }
+    };
+
+    Y.Anim.RE_UNITS = /^(-?\d*\.?\d*){1}(em|ex|px|in|cm|mm|pt|pc|%)*$/;
+
+    var proto = {
+        /**
+         * Starts or resumes an animation.
+         * percent start time marker.
+         * @method run
+         * @chainable
+         */    
+        run: function() {
+            if (!this.get(RUNNING)) {
+                this._start();
+            } else if (this.get(PAUSED)) {
+                this._resume();
+            }
+            return this;
+        },
+
+        /**
+         * Pauses the animation and
+         * freezes it in its current state and time.
+         * Calling run() will continue where it left off.
+         * @method pause
+         * @chainable
+         */    
+        pause: function() {
+            if (this.get(RUNNING)) {
+                this._pause();
+            }
+            return this;
+        },
+
+        /**
+         * Stops the animation and resets its time.
+         * @method stop
+         * @chainable
+         */    
+        stop: function(finish) {
+            if (this.get(RUNNING) || this.get(PAUSED)) {
+                this._end(finish);
+            }
+            return this;
+        },
+
+        _added: false,
+
+        _start: function() {
+            this._set(START_TIME, new Date() - this.get(ELAPSED_TIME));
+            this._actualFrames = 0;
+            if (!this.get(PAUSED)) {
+                this._initAttr();
+            }
+            _running[Y.stamp(this)] = this;
+            Y.Anim._startTimer();
+
+            this.fire(START);
+        },
+
+        _pause: function() {
+            this._set(START_TIME, null);
+            this._set(PAUSED, true);
+            delete _running[Y.stamp(this)];
+
+            /**
+            * @event pause
+            * @description fires when an animation is paused.
+            * @param {Event} ev The pause event.
+            * @type Event.Custom
+            */
+            this.fire('pause');
+        },
+
+        _resume: function() {
+            this._set(PAUSED, false);
+            _running[Y.stamp(this)] = this;
+
+            /**
+            * @event resume
+            * @description fires when an animation is resumed (run from pause).
+            * @param {Event} ev The pause event.
+            * @type Event.Custom
+            */
+            this.fire('resume');
+        },
+
+        _end: function(finish) {
+            this._set(START_TIME, null);
+            this._set(ELAPSED_TIME, 0);
+            this._set(PAUSED, false);
+
+            delete _running[Y.stamp(this)];
+            this.fire(END, {elapsed: this.get(ELAPSED_TIME)});
+        },
+
+        _runFrame: function() {
+            var attr = this._runtimeAttr,
+                customAttr = Y.Anim.behaviors,
+                easing = attr.easing,
+                d = attr.duration,
+                t = new Date() - this.get(START_TIME),
+                reversed = this.get(REVERSE),
+                done = (t >= d),
+                lastFrame = d,
+                attribute,
+                setter;
+                
+            if (reversed) {
+                t = d - t;
+                done = (t <= 0);
+                lastFrame = 0;
+            }
+
+            for (var i in attr) {
+                if (attr[i].to) {
+                    attribute = attr[i];
+                    setter = (i in customAttr && 'set' in customAttr[i]) ?
+                            customAttr[i].set : Y.Anim.DEFAULT_SETTER;
+
+                    if (!done) {
+                        setter(this, i, attribute.from, attribute.to, t, d, easing, attribute.unit); 
+                    } else { // ensure final frame value is set
+                       // TODO: handle keyframes 
+                        setter(this, i, attribute.from, attribute.to, lastFrame, d, easing, attribute.unit); 
+                    }
+                }
+            }
+
+            this._actualFrames += 1;
+            this._set(ELAPSED_TIME, t);
+
+            this.fire(TWEEN);
+            if (done) {
+                this._lastFrame();
+            }
+        },
+
+        _lastFrame: function() {
+            var iter = this.get('iterations'),
+                iterCount = this.get(ITERATION_COUNT);
+
+            iterCount += 1;
+            if (iter === 'infinite' || iterCount < iter) {
+                if (this.get('direction') === 'alternate') {
+                    this.set(REVERSE, !this.get(REVERSE)); // flip it
+                }
+                /**
+                * @event iteration
+                * @description fires when an animation begins an iteration.
+                * @param {Event} ev The iteration event.
+                * @type Event.Custom
+                */
+                this.fire('iteration');
+            } else {
+                iterCount = 0;
+                this._end();
+            }
+
+            this._set(START_TIME, new Date());
+            this._set(ITERATION_COUNT, iterCount);
+        },
+
+        _initAttr: function() {
+            var from = this.get('from') || {},
+                to = this.get('to') || {},
+                dur = this.get('duration') * 1000,
+                node = this.get(NODE),
+                easing = this.get('easing') || {},
+                attr = {},
+                customAttr = Y.Anim.behaviors,
+                unit, begin, end;
+
+            Y.each(to, function(val, name) {
+                if (typeof val === 'function') {
+                    val = val.call(this, node);
+                }
+
+                begin = from[name];
+                if (begin === undefined) {
+                    begin = (name in customAttr && 'get' in customAttr[name])  ?
+                            customAttr[name].get(this, name) : Y.Anim.DEFAULT_GETTER(this, name);
+                } else if (typeof begin === 'function') {
+                    begin = begin.call(this, node);
+                }
+
+                var mFrom = Y.Anim.RE_UNITS.exec(begin);
+                var mTo = Y.Anim.RE_UNITS.exec(val);
+
+                begin = mFrom ? mFrom[1] : begin;
+                var end = mTo ? mTo[1] : val,
+                    unit = mTo ? mTo[2] : mFrom ?  mFrom[2] : ''; // one might be zero TODO: mixed units
+
+                if (!unit && Y.Anim.RE_DEFAULT_UNIT.test(name)) {
+                    unit = Y.Anim.DEFAULT_UNIT;
+                }
+
+                if (!begin || !end) {
+                    Y.fail('invalid "from" or "to" for "' + name + '"', 'Anim');
+                    return;
+                }
+
+                attr[name] = {
+                    from: begin,
+                    to: end,
+                    unit: unit
+                };
+
+                attr.duration = dur;
+                attr.easing = easing;
+
+            }, this);
+
+            this._runtimeAttr = attr;
+        },
+
+
+        // TODO: move to computedStyle? (browsers dont agree on default computed offsets)
+        _getOffset: function(attr) {
+            var node = this._node,
+                val = node.getComputedStyle(attr),
+                get = (attr === 'left') ? 'getX': 'getY',
+                set = (attr === 'left') ? 'setX': 'setY';
+
+            if (val === 'auto') {
+                var position = node.getStyle('position');
+                if (position === 'absolute' || position === 'fixed') {
+                    val = node[get]();
+                    node[set](val);
+                } else {
+                    val = 0;
+                }
+            }
+
+            return val;
+        }
+    };
+
+    Y.extend(Y.Anim, Y.Base, proto);
+/*
+TERMS OF USE - EASING EQUATIONS
+Open source under the BSD License.
+Copyright 2001 Robert Penner All rights reserved.
+
+Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
+
+ * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
+ * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
+ * Neither the name of the author nor the names of contributors may be used to endorse or promote products derived from this software without specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+*/
+
+/**
+ * The easing module provides methods for customizing
+ * how an animation behaves during each run.
+ * @class Easing
+ * @module anim
+ * @submodule anim-easing
+ */
+
+Y.Easing = {
+
+    /**
+     * Uniform speed between points.
+     * @method easeNone
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeNone: function (t, b, c, d) {
+        return c*t/d + b;
+    },
+    
+    /**
+     * Begins slowly and accelerates towards end. (quadratic)
+     * @method easeIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeIn: function (t, b, c, d) {
+        return c*(t/=d)*t + b;
+    },
+
+    /**
+     * Begins quickly and decelerates towards end.  (quadratic)
+     * @method easeOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeOut: function (t, b, c, d) {
+        return -c *(t/=d)*(t-2) + b;
+    },
+    
+    /**
+     * Begins slowly and decelerates towards end. (quadratic)
+     * @method easeBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeBoth: function (t, b, c, d) {
+        if ((t/=d/2) < 1) {
+            return c/2*t*t + b;
+        }
+        
+        return -c/2 * ((--t)*(t-2) - 1) + b;
+    },
+    
+    /**
+     * Begins slowly and accelerates towards end. (quartic)
+     * @method easeInStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeInStrong: function (t, b, c, d) {
+        return c*(t/=d)*t*t*t + b;
+    },
+    
+    /**
+     * Begins quickly and decelerates towards end.  (quartic)
+     * @method easeOutStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeOutStrong: function (t, b, c, d) {
+        return -c * ((t=t/d-1)*t*t*t - 1) + b;
+    },
+    
+    /**
+     * Begins slowly and decelerates towards end. (quartic)
+     * @method easeBothStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeBothStrong: function (t, b, c, d) {
+        if ((t/=d/2) < 1) {
+            return c/2*t*t*t*t + b;
+        }
+        
+        return -c/2 * ((t-=2)*t*t*t - 2) + b;
+    },
+
+    /**
+     * Snap in elastic effect.
+     * @method elasticIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+
+    elasticIn: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        if ( (t /= d) === 1 ) {
+            return b+c;
+        }
+        if (!p) {
+            p = d* 0.3;
+        }
+        
+        if (!a || a < Math.abs(c)) {
+            a = c; 
+            s = p/4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        return -(a*Math.pow(2,10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
+    },
+
+    /**
+     * Snap out elastic effect.
+     * @method elasticOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    elasticOut: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        if ( (t /= d) === 1 ) {
+            return b+c;
+        }
+        if (!p) {
+            p=d * 0.3;
+        }
+        
+        if (!a || a < Math.abs(c)) {
+            a = c;
+            s = p / 4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        return a*Math.pow(2,-10*t) * Math.sin( (t*d-s)*(2*Math.PI)/p ) + c + b;
+    },
+    
+    /**
+     * Snap both elastic effect.
+     * @method elasticBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    elasticBoth: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        
+        if ( (t /= d/2) === 2 ) {
+            return b+c;
+        }
+        
+        if (!p) {
+            p = d*(0.3*1.5);
+        }
+        
+        if ( !a || a < Math.abs(c) ) {
+            a = c; 
+            s = p/4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        if (t < 1) {
+            return -0.5*(a*Math.pow(2,10*(t-=1)) * 
+                    Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
+        }
+        return a*Math.pow(2,-10*(t-=1)) * 
+                Math.sin( (t*d-s)*(2*Math.PI)/p )*0.5 + c + b;
+    },
+
+
+    /**
+     * Backtracks slightly, then reverses direction and moves to end.
+     * @method backIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backIn: function (t, b, c, d, s) {
+        if (s == undefined) {
+            s = 1.70158;
+        }
+        if (t === d) {
+            t -= 0.001;
+        }
+        return c*(t/=d)*t*((s+1)*t - s) + b;
+    },
+
+    /**
+     * Overshoots end, then reverses and comes back to end.
+     * @method backOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backOut: function (t, b, c, d, s) {
+        if (typeof s === 'undefined') {
+            s = 1.70158;
+        }
+        return c*((t=t/d-1)*t*((s+1)*t + s) + 1) + b;
+    },
+    
+    /**
+     * Backtracks slightly, then reverses direction, overshoots end, 
+     * then reverses and comes back to end.
+     * @method backBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backBoth: function (t, b, c, d, s) {
+        if (typeof s === 'undefined') {
+            s = 1.70158; 
+        }
+        
+        if ((t /= d/2 ) < 1) {
+            return c/2*(t*t*(((s*=(1.525))+1)*t - s)) + b;
+        }
+        return c/2*((t-=2)*t*(((s*=(1.525))+1)*t + s) + 2) + b;
+    },
+
+    /**
+     * Bounce off of start.
+     * @method bounceIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceIn: function (t, b, c, d) {
+        return c - Y.Easing.bounceOut(d-t, 0, c, d) + b;
+    },
+    
+    /**
+     * Bounces off end.
+     * @method bounceOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceOut: function (t, b, c, d) {
+        if ((t/=d) < (1/2.75)) {
+                return c*(7.5625*t*t) + b;
+        } else if (t < (2/2.75)) {
+                return c*(7.5625*(t-=(1.5/2.75))*t + 0.75) + b;
+        } else if (t < (2.5/2.75)) {
+                return c*(7.5625*(t-=(2.25/2.75))*t + 0.9375) + b;
+        }
+        return c*(7.5625*(t-=(2.625/2.75))*t + 0.984375) + b;
+    },
+    
+    /**
+     * Bounces off start and end.
+     * @method bounceBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceBoth: function (t, b, c, d) {
+        if (t < d/2) {
+            return Y.Easing.bounceIn(t * 2, 0, c, d) * 0.5 + b;
+        }
+        return Y.Easing.bounceOut(t * 2 - d, 0, c, d) * 0.5 + c * 0.5 + b;
+    }
+};
+/**
+ * Adds support for the <code>xy</code> property in <code>from</code> and 
+ * <code>to</code> attributes.
+ * @module anim
+ * @submodule anim-xy
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.xy = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        anim._node.setXY([
+            fn(elapsed, NUM(from[0]), NUM(to[0]) - NUM(from[0]), duration),
+            fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)
+        ]);
+    },
+    get: function(anim) {
+        return anim._node.getXY();
+    }
+};
+
+/**
+ * Adds support for color properties in <code>to</code>
+ * and <code>from</code> attributes.
+ * @module anim
+ * @submodule anim-color
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.color = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        from = Y.Color.re_RGB.exec(Y.Color.toRGB(from));
+        to = Y.Color.re_RGB.exec(Y.Color.toRGB(to));
+
+        if (!from || from.length < 3 || !to || to.length < 3) {
+            Y.fail('invalid from or to passed to color behavior');
+        }
+
+        anim._node.setStyle(att, 'rgb(' + [
+            Math.floor(fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)),
+            Math.floor(fn(elapsed, NUM(from[2]), NUM(to[2]) - NUM(from[2]), duration)),
+            Math.floor(fn(elapsed, NUM(from[3]), NUM(to[3]) - NUM(from[3]), duration))
+        ].join(', ') + ')');
+    },
+    
+    // TODO: default bgcolor const
+    get: function(anim, att) {
+        var val = anim._node.getComputedStyle(att);
+        val = (val === 'transparent') ? 'rgb(255, 255, 255)' : val;
+        return val;
+    }
+};
+
+Y.each(['backgroundColor',
+        'borderColor',
+        'borderTopColor',
+        'borderRightColor', 
+        'borderBottomColor', 
+        'borderLeftColor'],
+        function(v, i) {
+            Y.Anim.behaviors[v] = Y.Anim.behaviors.color;
+        }
+);
+/**
+ * Adds support for the <code>scroll</code> property in <code>to</code>
+ * and <code>from</code> attributes.
+ * @module anim
+ * @submodule anim-scroll
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.scroll = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        var
+            node = anim._node, 
+            val = ([
+            fn(elapsed, NUM(from[0]), NUM(to[0]) - NUM(from[0]), duration),
+            fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)
+        ]);
+
+        if (val[0]) {
+            node.set('scrollLeft', val[0]);
+        }
+
+        if (val[1]) {
+            node.set('scrollTop', val[1]);
+        }
+    },
+    get: function(anim) {
+        var node = anim._node;
+        return [node.get('scrollLeft'), node.get('scrollTop')];
+    }
+};
+
+/**
+ * Adds support for the <code>curve</code> property for the <code>to</code> 
+ * attribute.  A curve is zero or more control points and an end point.
+ * @module anim
+ * @submodule anim-curve
+ * @for Anim
+ */
+
+Y.Anim.behaviors.curve = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        from = from.slice.call(from);
+        to = to.slice.call(to);
+        var t = fn(elapsed, 0, 100, duration) / 100;
+        to.unshift(from);
+        anim._node.setXY(Y.Anim.getBezier(to, t));
+    },
+
+    get: function(anim, att) {
+        return anim._node.getXY();
+    }
+};
+
+/**
+ * Get the current position of the animated element based on t.
+ * Each point is an array of "x" and "y" values (0 = x, 1 = y)
+ * At least 2 points are required (start and end).
+ * First point is start. Last point is end.
+ * Additional control points are optional.     
+ * @method getBezier
+ * @static
+ * @param {Array} points An array containing Bezier points
+ * @param {Number} t A number between 0 and 1 which is the basis for determining current position
+ * @return {Array} An array containing int x and y member data
+ */
+Y.Anim.getBezier = function(points, t) {  
+    var n = points.length;
+    var tmp = [];
+
+    for (var i = 0; i < n; ++i){
+        tmp[i] = [points[i][0], points[i][1]]; // save input
+    }
+    
+    for (var j = 1; j < n; ++j) {
+        for (i = 0; i < n - j; ++i) {
+            tmp[i][0] = (1 - t) * tmp[i][0] + t * tmp[parseInt(i + 1, 10)][0];
+            tmp[i][1] = (1 - t) * tmp[i][1] + t * tmp[parseInt(i + 1, 10)][1]; 
+        }
+    }
+
+    return [ tmp[0][0], tmp[0][1] ]; 
+
+};
+/**
+ *  Binds an Anim instance to a Node instance
+ * @module anim
+ * @namespace plugin
+ * @submodule anim-node-plugin
+ */
+
+var NodeFX = function(config) {
+    var config = Y.merge(config);
+    config.node = config.owner;
+    NodeFX.superclass.constructor.apply(this, arguments);
+};
+
+NodeFX.NAME = "nodefx";
+NodeFX.NS = "fx";
+
+Y.extend(NodeFX, Y.Anim);
+
+Y.namespace('plugin');
+Y.plugin.NodeFX = NodeFX;
+
+
+}, '3.0.0pr2' ,{requires:['base', 'node']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-easing-debug.js'
--- loggerhead/static/javascript/yui/build/anim/anim-easing-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-easing-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,353 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-easing', function(Y) {
+
+/*
+TERMS OF USE - EASING EQUATIONS
+Open source under the BSD License.
+Copyright 2001 Robert Penner All rights reserved.
+
+Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
+
+ * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
+ * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
+ * Neither the name of the author nor the names of contributors may be used to endorse or promote products derived from this software without specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+*/
+
+/**
+ * The easing module provides methods for customizing
+ * how an animation behaves during each run.
+ * @class Easing
+ * @module anim
+ * @submodule anim-easing
+ */
+
+Y.Easing = {
+
+    /**
+     * Uniform speed between points.
+     * @method easeNone
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeNone: function (t, b, c, d) {
+        return c*t/d + b;
+    },
+    
+    /**
+     * Begins slowly and accelerates towards end. (quadratic)
+     * @method easeIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeIn: function (t, b, c, d) {
+        return c*(t/=d)*t + b;
+    },
+
+    /**
+     * Begins quickly and decelerates towards end.  (quadratic)
+     * @method easeOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeOut: function (t, b, c, d) {
+        return -c *(t/=d)*(t-2) + b;
+    },
+    
+    /**
+     * Begins slowly and decelerates towards end. (quadratic)
+     * @method easeBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeBoth: function (t, b, c, d) {
+        if ((t/=d/2) < 1) {
+            return c/2*t*t + b;
+        }
+        
+        return -c/2 * ((--t)*(t-2) - 1) + b;
+    },
+    
+    /**
+     * Begins slowly and accelerates towards end. (quartic)
+     * @method easeInStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeInStrong: function (t, b, c, d) {
+        return c*(t/=d)*t*t*t + b;
+    },
+    
+    /**
+     * Begins quickly and decelerates towards end.  (quartic)
+     * @method easeOutStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeOutStrong: function (t, b, c, d) {
+        return -c * ((t=t/d-1)*t*t*t - 1) + b;
+    },
+    
+    /**
+     * Begins slowly and decelerates towards end. (quartic)
+     * @method easeBothStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeBothStrong: function (t, b, c, d) {
+        if ((t/=d/2) < 1) {
+            return c/2*t*t*t*t + b;
+        }
+        
+        return -c/2 * ((t-=2)*t*t*t - 2) + b;
+    },
+
+    /**
+     * Snap in elastic effect.
+     * @method elasticIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+
+    elasticIn: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        if ( (t /= d) === 1 ) {
+            return b+c;
+        }
+        if (!p) {
+            p = d* 0.3;
+        }
+        
+        if (!a || a < Math.abs(c)) {
+            a = c; 
+            s = p/4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        return -(a*Math.pow(2,10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
+    },
+
+    /**
+     * Snap out elastic effect.
+     * @method elasticOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    elasticOut: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        if ( (t /= d) === 1 ) {
+            return b+c;
+        }
+        if (!p) {
+            p=d * 0.3;
+        }
+        
+        if (!a || a < Math.abs(c)) {
+            a = c;
+            s = p / 4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        return a*Math.pow(2,-10*t) * Math.sin( (t*d-s)*(2*Math.PI)/p ) + c + b;
+    },
+    
+    /**
+     * Snap both elastic effect.
+     * @method elasticBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    elasticBoth: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        
+        if ( (t /= d/2) === 2 ) {
+            return b+c;
+        }
+        
+        if (!p) {
+            p = d*(0.3*1.5);
+        }
+        
+        if ( !a || a < Math.abs(c) ) {
+            a = c; 
+            s = p/4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        if (t < 1) {
+            return -0.5*(a*Math.pow(2,10*(t-=1)) * 
+                    Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
+        }
+        return a*Math.pow(2,-10*(t-=1)) * 
+                Math.sin( (t*d-s)*(2*Math.PI)/p )*0.5 + c + b;
+    },
+
+
+    /**
+     * Backtracks slightly, then reverses direction and moves to end.
+     * @method backIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backIn: function (t, b, c, d, s) {
+        if (s == undefined) {
+            s = 1.70158;
+        }
+        if (t === d) {
+            t -= 0.001;
+        }
+        return c*(t/=d)*t*((s+1)*t - s) + b;
+    },
+
+    /**
+     * Overshoots end, then reverses and comes back to end.
+     * @method backOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backOut: function (t, b, c, d, s) {
+        if (typeof s === 'undefined') {
+            s = 1.70158;
+        }
+        return c*((t=t/d-1)*t*((s+1)*t + s) + 1) + b;
+    },
+    
+    /**
+     * Backtracks slightly, then reverses direction, overshoots end, 
+     * then reverses and comes back to end.
+     * @method backBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backBoth: function (t, b, c, d, s) {
+        if (typeof s === 'undefined') {
+            s = 1.70158; 
+        }
+        
+        if ((t /= d/2 ) < 1) {
+            return c/2*(t*t*(((s*=(1.525))+1)*t - s)) + b;
+        }
+        return c/2*((t-=2)*t*(((s*=(1.525))+1)*t + s) + 2) + b;
+    },
+
+    /**
+     * Bounce off of start.
+     * @method bounceIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceIn: function (t, b, c, d) {
+        return c - Y.Easing.bounceOut(d-t, 0, c, d) + b;
+    },
+    
+    /**
+     * Bounces off end.
+     * @method bounceOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceOut: function (t, b, c, d) {
+        if ((t/=d) < (1/2.75)) {
+                return c*(7.5625*t*t) + b;
+        } else if (t < (2/2.75)) {
+                return c*(7.5625*(t-=(1.5/2.75))*t + 0.75) + b;
+        } else if (t < (2.5/2.75)) {
+                return c*(7.5625*(t-=(2.25/2.75))*t + 0.9375) + b;
+        }
+        return c*(7.5625*(t-=(2.625/2.75))*t + 0.984375) + b;
+    },
+    
+    /**
+     * Bounces off start and end.
+     * @method bounceBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceBoth: function (t, b, c, d) {
+        if (t < d/2) {
+            return Y.Easing.bounceIn(t * 2, 0, c, d) * 0.5 + b;
+        }
+        return Y.Easing.bounceOut(t * 2 - d, 0, c, d) * 0.5 + c * 0.5 + b;
+    }
+};
+
+
+}, '3.0.0pr2' ,{requires:['anim-base']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-easing-min.js'
--- loggerhead/static/javascript/yui/build/anim/anim-easing-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-easing-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("anim-easing",function(A){A.Easing={easeNone:function(C,B,E,D){return E*C/D+B;},easeIn:function(C,B,E,D){return E*(C/=D)*C+B;},easeOut:function(C,B,E,D){return -E*(C/=D)*(C-2)+B;},easeBoth:function(C,B,E,D){if((C/=D/2)<1){return E/2*C*C+B;}return -E/2*((--C)*(C-2)-1)+B;},easeInStrong:function(C,B,E,D){return E*(C/=D)*C*C*C+B;},easeOutStrong:function(C,B,E,D){return -E*((C=C/D-1)*C*C*C-1)+B;},easeBothStrong:function(C,B,E,D){if((C/=D/2)<1){return E/2*C*C*C*C+B;}return -E/2*((C-=2)*C*C*C-2)+B;},elasticIn:function(D,B,H,G,C,F){var E;if(D===0){return B;}if((D/=G)===1){return B+H;}if(!F){F=G*0.3;}if(!C||C<Math.abs(H)){C=H;E=F/4;}else{E=F/(2*Math.PI)*Math.asin(H/C);}return -(C*Math.pow(2,10*(D-=1))*Math.sin((D*G-E)*(2*Math.PI)/F))+B;},elasticOut:function(D,B,H,G,C,F){var E;if(D===0){return B;}if((D/=G)===1){return B+H;}if(!F){F=G*0.3;}if(!C||C<Math.abs(H)){C=H;E=F/4;}else{E=F/(2*Math.PI)*Math.asin(H/C);}return C*Math.pow(2,-10*D)*Math.sin((D*G-E)*(2*Math.PI)/F)+H+B;},elasticBoth:function(D,B,H,G,C,F){var E;if(D===0){return B;}if((D/=G/2)===2){return B+H;}if(!F){F=G*(0.3*1.5);}if(!C||C<Math.abs(H)){C=H;E=F/4;}else{E=F/(2*Math.PI)*Math.asin(H/C);}if(D<1){return -0.5*(C*Math.pow(2,10*(D-=1))*Math.sin((D*G-E)*(2*Math.PI)/F))+B;}return C*Math.pow(2,-10*(D-=1))*Math.sin((D*G-E)*(2*Math.PI)/F)*0.5+H+B;},backIn:function(C,B,F,E,D){if(D==undefined){D=1.70158;}if(C===E){C-=0.001;}return F*(C/=E)*C*((D+1)*C-D)+B;},backOut:function(C,B,F,E,D){if(typeof D==="undefined"){D=1.70158;}return F*((C=C/E-1)*C*((D+1)*C+D)+1)+B;},backBoth:function(C,B,F,E,D){if(typeof D==="undefined"){D=1.70158;}if((C/=E/2)<1){return F/2*(C*C*(((D*=(1.525))+1)*C-D))+B;}return F/2*((C-=2)*C*(((D*=(1.525))+1)*C+D)+2)+B;},bounceIn:function(C,B,E,D){return E-A.Easing.bounceOut(D-C,0,E,D)+B;},bounceOut:function(C,B,E,D){if((C/=D)<(1/2.75)){return E*(7.5625*C*C)+B;}else{if(C<(2/2.75)){return E*(7.5625*(C-=(1.5/2.75))*C+0.75)+B;}else{if(C<(2.5/2.75)){return E*(7.5625*(C-=(2.25/2.75))*C+0.9375)+B;}}}return E*(7.5625*(C-=(2.625/2.75))*C+0.984375)+B;},bounceBoth:function(C,B,E,D){if(C<D/2){return A.Easing.bounceIn(C*2,0,E,D)*0.5+B;}return A.Easing.bounceOut(C*2-D,0,E,D)*0.5+E*0.5+B;}};},"3.0.0pr2",{requires:["anim-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-easing.js'
--- loggerhead/static/javascript/yui/build/anim/anim-easing.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-easing.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,353 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-easing', function(Y) {
+
+/*
+TERMS OF USE - EASING EQUATIONS
+Open source under the BSD License.
+Copyright 2001 Robert Penner All rights reserved.
+
+Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
+
+ * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
+ * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
+ * Neither the name of the author nor the names of contributors may be used to endorse or promote products derived from this software without specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+*/
+
+/**
+ * The easing module provides methods for customizing
+ * how an animation behaves during each run.
+ * @class Easing
+ * @module anim
+ * @submodule anim-easing
+ */
+
+Y.Easing = {
+
+    /**
+     * Uniform speed between points.
+     * @method easeNone
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeNone: function (t, b, c, d) {
+        return c*t/d + b;
+    },
+    
+    /**
+     * Begins slowly and accelerates towards end. (quadratic)
+     * @method easeIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeIn: function (t, b, c, d) {
+        return c*(t/=d)*t + b;
+    },
+
+    /**
+     * Begins quickly and decelerates towards end.  (quadratic)
+     * @method easeOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeOut: function (t, b, c, d) {
+        return -c *(t/=d)*(t-2) + b;
+    },
+    
+    /**
+     * Begins slowly and decelerates towards end. (quadratic)
+     * @method easeBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeBoth: function (t, b, c, d) {
+        if ((t/=d/2) < 1) {
+            return c/2*t*t + b;
+        }
+        
+        return -c/2 * ((--t)*(t-2) - 1) + b;
+    },
+    
+    /**
+     * Begins slowly and accelerates towards end. (quartic)
+     * @method easeInStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeInStrong: function (t, b, c, d) {
+        return c*(t/=d)*t*t*t + b;
+    },
+    
+    /**
+     * Begins quickly and decelerates towards end.  (quartic)
+     * @method easeOutStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeOutStrong: function (t, b, c, d) {
+        return -c * ((t=t/d-1)*t*t*t - 1) + b;
+    },
+    
+    /**
+     * Begins slowly and decelerates towards end. (quartic)
+     * @method easeBothStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeBothStrong: function (t, b, c, d) {
+        if ((t/=d/2) < 1) {
+            return c/2*t*t*t*t + b;
+        }
+        
+        return -c/2 * ((t-=2)*t*t*t - 2) + b;
+    },
+
+    /**
+     * Snap in elastic effect.
+     * @method elasticIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+
+    elasticIn: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        if ( (t /= d) === 1 ) {
+            return b+c;
+        }
+        if (!p) {
+            p = d* 0.3;
+        }
+        
+        if (!a || a < Math.abs(c)) {
+            a = c; 
+            s = p/4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        return -(a*Math.pow(2,10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
+    },
+
+    /**
+     * Snap out elastic effect.
+     * @method elasticOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    elasticOut: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        if ( (t /= d) === 1 ) {
+            return b+c;
+        }
+        if (!p) {
+            p=d * 0.3;
+        }
+        
+        if (!a || a < Math.abs(c)) {
+            a = c;
+            s = p / 4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        return a*Math.pow(2,-10*t) * Math.sin( (t*d-s)*(2*Math.PI)/p ) + c + b;
+    },
+    
+    /**
+     * Snap both elastic effect.
+     * @method elasticBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    elasticBoth: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        
+        if ( (t /= d/2) === 2 ) {
+            return b+c;
+        }
+        
+        if (!p) {
+            p = d*(0.3*1.5);
+        }
+        
+        if ( !a || a < Math.abs(c) ) {
+            a = c; 
+            s = p/4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        if (t < 1) {
+            return -0.5*(a*Math.pow(2,10*(t-=1)) * 
+                    Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
+        }
+        return a*Math.pow(2,-10*(t-=1)) * 
+                Math.sin( (t*d-s)*(2*Math.PI)/p )*0.5 + c + b;
+    },
+
+
+    /**
+     * Backtracks slightly, then reverses direction and moves to end.
+     * @method backIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backIn: function (t, b, c, d, s) {
+        if (s == undefined) {
+            s = 1.70158;
+        }
+        if (t === d) {
+            t -= 0.001;
+        }
+        return c*(t/=d)*t*((s+1)*t - s) + b;
+    },
+
+    /**
+     * Overshoots end, then reverses and comes back to end.
+     * @method backOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backOut: function (t, b, c, d, s) {
+        if (typeof s === 'undefined') {
+            s = 1.70158;
+        }
+        return c*((t=t/d-1)*t*((s+1)*t + s) + 1) + b;
+    },
+    
+    /**
+     * Backtracks slightly, then reverses direction, overshoots end, 
+     * then reverses and comes back to end.
+     * @method backBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backBoth: function (t, b, c, d, s) {
+        if (typeof s === 'undefined') {
+            s = 1.70158; 
+        }
+        
+        if ((t /= d/2 ) < 1) {
+            return c/2*(t*t*(((s*=(1.525))+1)*t - s)) + b;
+        }
+        return c/2*((t-=2)*t*(((s*=(1.525))+1)*t + s) + 2) + b;
+    },
+
+    /**
+     * Bounce off of start.
+     * @method bounceIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceIn: function (t, b, c, d) {
+        return c - Y.Easing.bounceOut(d-t, 0, c, d) + b;
+    },
+    
+    /**
+     * Bounces off end.
+     * @method bounceOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceOut: function (t, b, c, d) {
+        if ((t/=d) < (1/2.75)) {
+                return c*(7.5625*t*t) + b;
+        } else if (t < (2/2.75)) {
+                return c*(7.5625*(t-=(1.5/2.75))*t + 0.75) + b;
+        } else if (t < (2.5/2.75)) {
+                return c*(7.5625*(t-=(2.25/2.75))*t + 0.9375) + b;
+        }
+        return c*(7.5625*(t-=(2.625/2.75))*t + 0.984375) + b;
+    },
+    
+    /**
+     * Bounces off start and end.
+     * @method bounceBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceBoth: function (t, b, c, d) {
+        if (t < d/2) {
+            return Y.Easing.bounceIn(t * 2, 0, c, d) * 0.5 + b;
+        }
+        return Y.Easing.bounceOut(t * 2 - d, 0, c, d) * 0.5 + c * 0.5 + b;
+    }
+};
+
+
+}, '3.0.0pr2' ,{requires:['anim-base']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-min.js'
--- loggerhead/static/javascript/yui/build/anim/anim-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("anim",function(C){var D="running",O="startTime",M="elapsedTime",K="start",J="tween",N="end",E="node",L="paused",Q="reverse",I="iterationCount",B=Number;var G={},P={},F;C.Anim=function(){C.Anim.superclass.constructor.apply(this,arguments);P[C.stamp(this)]=this;};C.Anim.NAME="anim";C.Anim.RE_DEFAULT_UNIT=/^width|height|top|right|bottom|left|margin.*|padding.*|border.*$/i;C.Anim.DEFAULT_UNIT="px";C.Anim.DEFAULT_EASING=function(S,R,U,T){return U*S/T+R;};C.Anim.behaviors={left:{get:function(S,R){return S._getOffset(R);}}};C.Anim.behaviors.top=C.Anim.behaviors.left;C.Anim.DEFAULT_SETTER=function(V,S,Y,X,R,W,T,U){U=U||"";V._node.setStyle(S,T(R,B(Y),B(X)-B(Y),W)+U);};C.Anim.DEFAULT_GETTER=function(R,S){return R._node.getComputedStyle(S);};C.Anim.ATTRS={node:{set:function(R){R=C.Node.get(R);this._node=R;if(!R){C.fail("Y.Anim: invalid node: "+R);}return R;}},duration:{value:1},easing:{value:C.Anim.DEFAULT_EASING,set:function(R){if(typeof R==="string"&&C.Easing){return C.Easing[R];}}},from:{},to:{},startTime:{value:0,readOnly:true},elapsedTime:{value:0,readOnly:true},running:{get:function(){return !!G[C.stamp(this)];},value:false,readOnly:true},iterations:{value:1},iterationCount:{value:0,readOnly:true},direction:{value:"normal"},paused:{readOnly:true,value:false},reverse:{value:false}};C.Anim.run=function(){for(var R in P){if(P[R].run){P[R].run();}}};C.Anim.pause=function(){for(var R in G){if(G[R].pause){G[R].pause();}}C.Anim._stopTimer();};C.Anim.stop=function(){for(var R in G){if(G[R].stop){G[R].stop();}}C.Anim._stopTimer();};C.Anim._startTimer=function(){if(!F){F=setInterval(C.Anim._runFrame,1);}};C.Anim._stopTimer=function(){clearInterval(F);F=0;};C.Anim._runFrame=function(){var R=true;for(var S in G){if(G[S]._runFrame){R=false;G[S]._runFrame();}}if(R){C.Anim._stopTimer();}};C.Anim.RE_UNITS=/^(-?\d*\.?\d*){1}(em|ex|px|in|cm|mm|pt|pc|%)*$/;var H={run:function(){if(!this.get(D)){this._start();}else{if(this.get(L)){this._resume();}}return this;},pause:function(){if(this.get(D)){this._pause();}return this;},stop:function(R){if(this.get(D)||this.get(L)){this._end(R);}return this;},_added:false,_start:function(){this._set(O,new Date()-this.get(M));this._actualFrames=0;if(!this.get(L)){this._initAttr();}G[C.stamp(this)]=this;C.Anim._startTimer();this.fire(K);},_pause:function(){this._set(O,null);this._set(L,true);delete G[C.stamp(this)];this.fire("pause");},_resume:function(){this._set(L,false);G[C.stamp(this)]=this;this.fire("resume");},_end:function(R){this._set(O,null);this._set(M,0);this._set(L,false);delete G[C.stamp(this)];this.fire(N,{elapsed:this.get(M)});},_runFrame:function(){var Y=this._runtimeAttr,T=C.Anim.behaviors,Z=Y.easing,a=Y.duration,b=new Date()-this.get(O),X=this.get(Q),V=(b>=a),R=a,S,U;if(X){b=a-b;V=(b<=0);R=0;}for(var W in Y){if(Y[W].to){S=Y[W];U=(W in T&&"set" in T[W])?T[W].set:C.Anim.DEFAULT_SETTER;if(!V){U(this,W,S.from,S.to,b,a,Z,S.unit);}else{U(this,W,S.from,S.to,R,a,Z,S.unit);}}}this._actualFrames+=1;this._set(M,b);this.fire(J);if(V){this._lastFrame();}},_lastFrame:function(){var R=this.get("iterations"),S=this.get(I);S+=1;if(R==="infinite"||S<R){if(this.get("direction")==="alternate"){this.set(Q,!this.get(Q));}this.fire("iteration");}else{S=0;this._end();}this._set(O,new Date());this._set(I,S);},_initAttr:function(){var Y=this.get("from")||{},Z=this.get("to")||{},R=this.get("duration")*1000,U=this.get(E),X=this.get("easing")||{},W={},S=C.Anim.behaviors,a,T,V;C.each(Z,function(g,d){if(typeof g==="function"){g=g.call(this,U);}T=Y[d];if(T===undefined){T=(d in S&&"get" in S[d])?S[d].get(this,d):C.Anim.DEFAULT_GETTER(this,d);}else{if(typeof T==="function"){T=T.call(this,U);}}var c=C.Anim.RE_UNITS.exec(T);var e=C.Anim.RE_UNITS.exec(g);T=c?c[1]:T;var b=e?e[1]:g,f=e?e[2]:c?c[2]:"";if(!f&&C.Anim.RE_DEFAULT_UNIT.test(d)){f=C.Anim.DEFAULT_UNIT;}if(!T||!b){C.fail('invalid "from" or "to" for "'+d+'"',"Anim");return ;}W[d]={from:T,to:b,unit:f};W.duration=R;W.easing=X;},this);this._runtimeAttr=W;},_getOffset:function(S){var U=this._node,V=U.getComputedStyle(S),T=(S==="left")?"getX":"getY",W=(S==="left")?"setX":"setY";if(V==="auto"){var R=U.getStyle("position");if(R==="absolute"||R==="fixed"){V=U[T]();U[W](V);}else{V=0;}}return V;}};C.extend(C.Anim,C.Base,H);C.Easing={easeNone:function(S,R,U,T){return U*S/T+R;},easeIn:function(S,R,U,T){return U*(S/=T)*S+R;},easeOut:function(S,R,U,T){return -U*(S/=T)*(S-2)+R;},easeBoth:function(S,R,U,T){if((S/=T/2)<1){return U/2*S*S+R;}return -U/2*((--S)*(S-2)-1)+R;},easeInStrong:function(S,R,U,T){return U*(S/=T)*S*S*S+R;},easeOutStrong:function(S,R,U,T){return -U*((S=S/T-1)*S*S*S-1)+R;},easeBothStrong:function(S,R,U,T){if((S/=T/2)<1){return U/2*S*S*S*S+R;}return -U/2*((S-=2)*S*S*S-2)+R;},elasticIn:function(T,R,X,W,S,V){var U;if(T===0){return R;}if((T/=W)===1){return R+X;}if(!V){V=W*0.3;}if(!S||S<Math.abs(X)){S=X;U=V/4;}else{U=V/(2*Math.PI)*Math.asin(X/S);}return -(S*Math.pow(2,10*(T-=1))*Math.sin((T*W-U)*(2*Math.PI)/V))+R;},elasticOut:function(T,R,X,W,S,V){var U;if(T===0){return R;}if((T/=W)===1){return R+X;}if(!V){V=W*0.3;}if(!S||S<Math.abs(X)){S=X;U=V/4;}else{U=V/(2*Math.PI)*Math.asin(X/S);}return S*Math.pow(2,-10*T)*Math.sin((T*W-U)*(2*Math.PI)/V)+X+R;},elasticBoth:function(T,R,X,W,S,V){var U;if(T===0){return R;}if((T/=W/2)===2){return R+X;}if(!V){V=W*(0.3*1.5);}if(!S||S<Math.abs(X)){S=X;U=V/4;}else{U=V/(2*Math.PI)*Math.asin(X/S);}if(T<1){return -0.5*(S*Math.pow(2,10*(T-=1))*Math.sin((T*W-U)*(2*Math.PI)/V))+R;}return S*Math.pow(2,-10*(T-=1))*Math.sin((T*W-U)*(2*Math.PI)/V)*0.5+X+R;},backIn:function(S,R,V,U,T){if(T==undefined){T=1.70158;}if(S===U){S-=0.001;}return V*(S/=U)*S*((T+1)*S-T)+R;},backOut:function(S,R,V,U,T){if(typeof T==="undefined"){T=1.70158;}return V*((S=S/U-1)*S*((T+1)*S+T)+1)+R;},backBoth:function(S,R,V,U,T){if(typeof T==="undefined"){T=1.70158;}if((S/=U/2)<1){return V/2*(S*S*(((T*=(1.525))+1)*S-T))+R;}return V/2*((S-=2)*S*(((T*=(1.525))+1)*S+T)+2)+R;},bounceIn:function(S,R,U,T){return U-C.Easing.bounceOut(T-S,0,U,T)+R;},bounceOut:function(S,R,U,T){if((S/=T)<(1/2.75)){return U*(7.5625*S*S)+R;
+}else{if(S<(2/2.75)){return U*(7.5625*(S-=(1.5/2.75))*S+0.75)+R;}else{if(S<(2.5/2.75)){return U*(7.5625*(S-=(2.25/2.75))*S+0.9375)+R;}}}return U*(7.5625*(S-=(2.625/2.75))*S+0.984375)+R;},bounceBoth:function(S,R,U,T){if(S<T/2){return C.Easing.bounceIn(S*2,0,U,T)*0.5+R;}return C.Easing.bounceOut(S*2-T,0,U,T)*0.5+U*0.5+R;}};var B=Number;C.Anim.behaviors.xy={set:function(U,S,X,W,R,V,T){U._node.setXY([T(R,B(X[0]),B(W[0])-B(X[0]),V),T(R,B(X[1]),B(W[1])-B(X[1]),V)]);},get:function(R){return R._node.getXY();}};var B=Number;C.Anim.behaviors.color={set:function(U,S,X,W,R,V,T){X=C.Color.re_RGB.exec(C.Color.toRGB(X));W=C.Color.re_RGB.exec(C.Color.toRGB(W));if(!X||X.length<3||!W||W.length<3){C.fail("invalid from or to passed to color behavior");}U._node.setStyle(S,"rgb("+[Math.floor(T(R,B(X[1]),B(W[1])-B(X[1]),V)),Math.floor(T(R,B(X[2]),B(W[2])-B(X[2]),V)),Math.floor(T(R,B(X[3]),B(W[3])-B(X[3]),V))].join(", ")+")");},get:function(S,R){var T=S._node.getComputedStyle(R);T=(T==="transparent")?"rgb(255, 255, 255)":T;return T;}};C.each(["backgroundColor","borderColor","borderTopColor","borderRightColor","borderBottomColor","borderLeftColor"],function(R,S){C.Anim.behaviors[R]=C.Anim.behaviors.color;});var B=Number;C.Anim.behaviors.scroll={set:function(U,V,X,Y,Z,T,W){var S=U._node,R=([W(Z,B(X[0]),B(Y[0])-B(X[0]),T),W(Z,B(X[1]),B(Y[1])-B(X[1]),T)]);if(R[0]){S.set("scrollLeft",R[0]);}if(R[1]){S.set("scrollTop",R[1]);}},get:function(S){var R=S._node;return[R.get("scrollLeft"),R.get("scrollTop")];}};C.Anim.behaviors.curve={set:function(V,S,Y,X,R,W,U){Y=Y.slice.call(Y);X=X.slice.call(X);var T=U(R,0,100,W)/100;X.unshift(Y);V._node.setXY(C.Anim.getBezier(X,T));},get:function(S,R){return S._node.getXY();}};C.Anim.getBezier=function(V,U){var W=V.length;var T=[];for(var S=0;S<W;++S){T[S]=[V[S][0],V[S][1]];}for(var R=1;R<W;++R){for(S=0;S<W-R;++S){T[S][0]=(1-U)*T[S][0]+U*T[parseInt(S+1,10)][0];T[S][1]=(1-U)*T[S][1]+U*T[parseInt(S+1,10)][1];}}return[T[0][0],T[0][1]];};var A=function(R){var R=C.merge(R);R.node=R.owner;A.superclass.constructor.apply(this,arguments);};A.NAME="nodefx";A.NS="fx";C.extend(A,C.Anim);C.namespace("plugin");C.plugin.NodeFX=A;},"3.0.0pr2",{requires:["base","node"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-node-plugin-debug.js'
--- loggerhead/static/javascript/yui/build/anim/anim-node-plugin-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-node-plugin-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,28 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-node-plugin', function(Y) {
+
+/**
+ *  Binds an Anim instance to a Node instance
+ * @module anim
+ * @submodule anim-node-plugin
+ */
+
+Y.namespace('Plugin');
+Y.Plugin.NodeFX = function(config) {
+    config.node = config.owner;
+    Y.Plugin.NodeFX.superclass.constructor.apply(this, arguments);
+};
+
+Y.Plugin.NodeFX.NAME = "nodefxplugin";
+Y.Plugin.NodeFX.NS = "fx";
+
+Y.extend(Y.Plugin.NodeFX, Y.Anim);
+
+
+
+}, '3.0.0pr2' ,{requires:['anim-base', 'node-base']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-node-plugin-min.js'
--- loggerhead/static/javascript/yui/build/anim/anim-node-plugin-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-node-plugin-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("anim-node-plugin",function(A){A.namespace("Plugin");A.Plugin.NodeFX=function(B){B.node=B.owner;A.Plugin.NodeFX.superclass.constructor.apply(this,arguments);};A.Plugin.NodeFX.NAME="nodefxplugin";A.Plugin.NodeFX.NS="fx";A.extend(A.Plugin.NodeFX,A.Anim);},"3.0.0pr2",{requires:["anim-base","node-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-node-plugin.js'
--- loggerhead/static/javascript/yui/build/anim/anim-node-plugin.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-node-plugin.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,28 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-node-plugin', function(Y) {
+
+/**
+ *  Binds an Anim instance to a Node instance
+ * @module anim
+ * @submodule anim-node-plugin
+ */
+
+Y.namespace('Plugin');
+Y.Plugin.NodeFX = function(config) {
+    config.node = config.owner;
+    Y.Plugin.NodeFX.superclass.constructor.apply(this, arguments);
+};
+
+Y.Plugin.NodeFX.NAME = "nodefxplugin";
+Y.Plugin.NodeFX.NS = "fx";
+
+Y.extend(Y.Plugin.NodeFX, Y.Anim);
+
+
+
+}, '3.0.0pr2' ,{requires:['anim-base', 'node-base']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-scroll-debug.js'
--- loggerhead/static/javascript/yui/build/anim/anim-scroll-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-scroll-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,44 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-scroll', function(Y) {
+
+/**
+ * Adds support for the <code>scroll</code> property in <code>to</code>
+ * and <code>from</code> attributes.
+ * @module anim
+ * @submodule anim-scroll
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.scroll = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        var
+            node = anim._node, 
+            val = ([
+            fn(elapsed, NUM(from[0]), NUM(to[0]) - NUM(from[0]), duration),
+            fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)
+        ]);
+
+        if (val[0]) {
+            node.set('scrollLeft', val[0]);
+        }
+
+        if (val[1]) {
+            node.set('scrollTop', val[1]);
+        }
+    },
+    get: function(anim) {
+        var node = anim._node;
+        return [node.get('scrollLeft'), node.get('scrollTop')];
+    }
+};
+
+
+
+}, '3.0.0pr2' ,{requires:['anim-base', 'node-base']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-scroll-min.js'
--- loggerhead/static/javascript/yui/build/anim/anim-scroll-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-scroll-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("anim-scroll",function(B){var A=Number;B.Anim.behaviors.scroll={set:function(F,G,I,J,K,E,H){var D=F._node,C=([H(K,A(I[0]),A(J[0])-A(I[0]),E),H(K,A(I[1]),A(J[1])-A(I[1]),E)]);if(C[0]){D.set("scrollLeft",C[0]);}if(C[1]){D.set("scrollTop",C[1]);}},get:function(D){var C=D._node;return[C.get("scrollLeft"),C.get("scrollTop")];}};},"3.0.0pr2",{requires:["anim-base","node-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-scroll.js'
--- loggerhead/static/javascript/yui/build/anim/anim-scroll.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-scroll.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,44 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-scroll', function(Y) {
+
+/**
+ * Adds support for the <code>scroll</code> property in <code>to</code>
+ * and <code>from</code> attributes.
+ * @module anim
+ * @submodule anim-scroll
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.scroll = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        var
+            node = anim._node, 
+            val = ([
+            fn(elapsed, NUM(from[0]), NUM(to[0]) - NUM(from[0]), duration),
+            fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)
+        ]);
+
+        if (val[0]) {
+            node.set('scrollLeft', val[0]);
+        }
+
+        if (val[1]) {
+            node.set('scrollTop', val[1]);
+        }
+    },
+    get: function(anim) {
+        var node = anim._node;
+        return [node.get('scrollLeft'), node.get('scrollTop')];
+    }
+};
+
+
+
+}, '3.0.0pr2' ,{requires:['anim-base', 'node-base']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-xy-debug.js'
--- loggerhead/static/javascript/yui/build/anim/anim-xy-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-xy-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,33 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-xy', function(Y) {
+
+/**
+ * Adds support for the <code>xy</code> property in <code>from</code> and 
+ * <code>to</code> attributes.
+ * @module anim
+ * @submodule anim-xy
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.xy = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        anim._node.setXY([
+            fn(elapsed, NUM(from[0]), NUM(to[0]) - NUM(from[0]), duration),
+            fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)
+        ]);
+    },
+    get: function(anim) {
+        return anim._node.getXY();
+    }
+};
+
+
+
+}, '3.0.0pr2' ,{requires:['anim-base', 'node-screen']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-xy-min.js'
--- loggerhead/static/javascript/yui/build/anim/anim-xy-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-xy-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("anim-xy",function(B){var A=Number;B.Anim.behaviors.xy={set:function(F,D,I,H,C,G,E){F._node.setXY([E(C,A(I[0]),A(H[0])-A(I[0]),G),E(C,A(I[1]),A(H[1])-A(I[1]),G)]);},get:function(C){return C._node.getXY();}};},"3.0.0pr2",{requires:["anim-base","node-screen"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/anim/anim-xy.js'
--- loggerhead/static/javascript/yui/build/anim/anim-xy.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim-xy.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,33 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim-xy', function(Y) {
+
+/**
+ * Adds support for the <code>xy</code> property in <code>from</code> and 
+ * <code>to</code> attributes.
+ * @module anim
+ * @submodule anim-xy
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.xy = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        anim._node.setXY([
+            fn(elapsed, NUM(from[0]), NUM(to[0]) - NUM(from[0]), duration),
+            fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)
+        ]);
+    },
+    get: function(anim) {
+        return anim._node.getXY();
+    }
+};
+
+
+
+}, '3.0.0pr2' ,{requires:['anim-base', 'node-screen']});

=== added file 'loggerhead/static/javascript/yui/build/anim/anim.js'
--- loggerhead/static/javascript/yui/build/anim/anim.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/anim/anim.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1106 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('anim', function(Y) {
+
+/**
+ * Y.Animation Utility.
+ * @module anim
+ */
+
+    /**
+     * Handles animation _queueing and threading.
+     * @class Anim
+     * @constructor
+     * @extends Base
+     */
+
+    var RUNNING = 'running',
+        START_TIME = 'startTime',
+        ELAPSED_TIME = 'elapsedTime',
+        /**
+        * @event start
+        * @description fires when an animation begins.
+        * @param {Event} ev The start event.
+        * @type Event.Custom
+        */
+        START = 'start',
+
+        /**
+        * @event tween
+        * @description fires every frame of the animation.
+        * @param {Event} ev The tween event.
+        * @type Event.Custom
+        */
+        TWEEN = 'tween',
+
+        /**
+        * @event end
+        * @description fires after the animation completes.
+        * @param {Event} ev The end event.
+        * @type Event.Custom
+        */
+        END = 'end',
+        NODE = 'node',
+        PAUSED = 'paused',
+        REVERSE = 'reverse', // TODO: cleanup
+        ITERATION_COUNT = 'iterationCount',
+
+        NUM = Number;
+
+    var _running = {},
+        _instances = {},
+        _timer;
+
+    Y.Anim = function() {
+        Y.Anim.superclass.constructor.apply(this, arguments);
+        _instances[Y.stamp(this)] = this;
+    };
+
+    Y.Anim.NAME = 'anim';
+
+    /**
+     * Regex of properties that should use the default unit.
+     *
+     * @property RE_DEFAULT_UNIT
+     * @static
+     */
+    Y.Anim.RE_DEFAULT_UNIT = /^width|height|top|right|bottom|left|margin.*|padding.*|border.*$/i;
+
+    /**
+     * The default unit to use with properties that pass the RE_DEFAULT_UNIT test.
+     *
+     * @property DEFAULT_UNIT
+     * @static
+     */
+    Y.Anim.DEFAULT_UNIT = 'px';
+
+    Y.Anim.DEFAULT_EASING = function (t, b, c, d) {
+        return c * t / d + b; // linear easing
+    };
+
+    /**
+     * Bucket for custom getters and setters
+     *
+     * @property behaviors
+     * @static
+     */
+    Y.Anim.behaviors = {
+        left: {
+            get: function(anim, attr) {
+                return anim._getOffset(attr);
+            }
+        }
+    };
+
+    Y.Anim.behaviors.top = Y.Anim.behaviors.left;
+
+    /**
+     * The default setter to use when setting object properties.
+     *
+     * @property DEFAULT_SETTER
+     * @static
+     */
+    Y.Anim.DEFAULT_SETTER = function(anim, att, from, to, elapsed, duration, fn, unit) {
+        unit = unit || '';
+        anim._node.setStyle(att, fn(elapsed, NUM(from), NUM(to) - NUM(from), duration) + unit);
+    };
+
+    /**
+     * The default getter to use when getting object properties.
+     *
+     * @property DEFAULT_GETTER
+     * @static
+     */
+    Y.Anim.DEFAULT_GETTER = function(anim, prop) {
+        return anim._node.getComputedStyle(prop);
+    };
+
+    Y.Anim.ATTRS = {
+        /**
+         * The object to be animated.
+         * @attribute node
+         * @type Node
+         */
+        node: {
+            set: function(node) {
+                node = Y.Node.get(node);
+                this._node = node;
+                if (!node) {
+                    Y.fail('Y.Anim: invalid node: ' + node);
+                }
+                return node;
+            }
+        },
+
+        /**
+         * The length of the animation.  Defaults to "1" (second).
+         * @attribute duration
+         * @type NUM
+         */
+        duration: {
+            value: 1
+        },
+
+        /**
+         * The method that will provide values to the attribute(s) during the animation. 
+         * Defaults to "Easing.easeNone".
+         * @attribute easing
+         * @type Function
+         */
+        easing: {
+            value: Y.Anim.DEFAULT_EASING,
+
+            set: function(val) {
+                if (typeof val === 'string' && Y.Easing) {
+                    return Y.Easing[val];
+                }
+            }
+        },
+
+        /**
+         * The starting values for the animated properties. 
+         * Fields may be strings, numbers, or functions.
+         * If a function is used, the return value becomes the from value.
+         * If no from value is specified, the DEFAULT_GETTER will be used. 
+         * @attribute from
+         * @type Object
+         */
+        from: {},
+
+        /**
+         * The ending values for the animated properties. 
+         * Fields may be strings, numbers, or functions.
+         * @attribute to
+         * @type Object
+         */
+        to: {},
+
+        /**
+         * Date stamp for the first frame of the animation.
+         * @attribute startTime
+         * @type Int
+         * @default 0 
+         * @readOnly
+         */
+        startTime: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * Current time the animation has been running.
+         * @attribute elapsedTime
+         * @type Int
+         * @default 0 
+         * @readOnly
+         */
+        elapsedTime: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * Whether or not the animation is currently running.
+         * @attribute running 
+         * @type Boolean
+         * @default false 
+         * @readOnly
+         */
+        running: {
+            get: function() {
+                return !!_running[Y.stamp(this)];
+            },
+            value: false,
+            readOnly: true
+        },
+
+        /**
+         * The number of times the animation should run 
+         * @attribute iterations
+         * @type Int
+         * @default 1 
+         */
+        iterations: {
+            value: 1
+        },
+
+        /**
+         * The number of iterations that have occurred.
+         * Resets when an animation ends (reaches iteration count or stop() called). 
+         * @attribute iterationCount
+         * @type Int
+         * @default 0
+         * @readOnly
+         */
+        iterationCount: {
+            value: 0,
+            readOnly: true
+        },
+
+        /**
+         * How iterations of the animation should behave. 
+         * Possible values are "normal" and "alternate".
+         * Normal will repeat the animation, alternate will reverse on every other pass.
+         *
+         * @attribute direction
+         * @type String
+         * @default "normal"
+         */
+        direction: {
+            value: 'normal' // | alternate (fwd on odd, rev on even per spec)
+        },
+
+        /**
+         * Whether or not the animation is currently paused.
+         * @attribute running 
+         * @type Boolean
+         * @default false 
+         * @readOnly
+         */
+        paused: {
+            readOnly: true,
+            value: false
+        },
+
+        /**
+         * If true, animation begins from last frame
+         * @attribute reverse
+         * @type Boolean
+         * @default false 
+         */
+        reverse: {
+            value: false
+        }
+
+
+    };
+
+    /**
+     * Runs all animation instances.
+     * @method run
+     * @static
+     */    
+    Y.Anim.run = function() {
+        for (var i in _instances) {
+            if (_instances[i].run) {
+                _instances[i].run();
+            }
+        }
+    };
+
+    /**
+     * Pauses all animation instances.
+     * @method pause
+     * @static
+     */    
+    Y.Anim.pause = function() {
+        for (var i in _running) { // stop timer if nothing running
+            if (_running[i].pause) {
+                _running[i].pause();
+            }
+        }
+        Y.Anim._stopTimer();
+    };
+
+    /**
+     * Stops all animation instances.
+     * @method stop
+     * @static
+     */    
+    Y.Anim.stop = function() {
+        for (var i in _running) { // stop timer if nothing running
+            if (_running[i].stop) {
+                _running[i].stop();
+            }
+        }
+        Y.Anim._stopTimer();
+    };
+    
+    Y.Anim._startTimer = function() {
+        if (!_timer) {
+            _timer = setInterval(Y.Anim._runFrame, 1);
+        }
+    };
+
+    Y.Anim._stopTimer = function() {
+        clearInterval(_timer);
+        _timer = 0;
+    };
+
+    /**
+     * Called per Interval to handle each animation frame.
+     * @method _runFrame
+     * @private
+     * @static
+     */    
+    Y.Anim._runFrame = function() {
+        var done = true;
+        for (var anim in _running) {
+            if (_running[anim]._runFrame) {
+                done = false;
+                _running[anim]._runFrame();
+            }
+        }
+
+        if (done) {
+            Y.Anim._stopTimer();
+        }
+    };
+
+    Y.Anim.RE_UNITS = /^(-?\d*\.?\d*){1}(em|ex|px|in|cm|mm|pt|pc|%)*$/;
+
+    var proto = {
+        /**
+         * Starts or resumes an animation.
+         * percent start time marker.
+         * @method run
+         * @chainable
+         */    
+        run: function() {
+            if (!this.get(RUNNING)) {
+                this._start();
+            } else if (this.get(PAUSED)) {
+                this._resume();
+            }
+            return this;
+        },
+
+        /**
+         * Pauses the animation and
+         * freezes it in its current state and time.
+         * Calling run() will continue where it left off.
+         * @method pause
+         * @chainable
+         */    
+        pause: function() {
+            if (this.get(RUNNING)) {
+                this._pause();
+            }
+            return this;
+        },
+
+        /**
+         * Stops the animation and resets its time.
+         * @method stop
+         * @chainable
+         */    
+        stop: function(finish) {
+            if (this.get(RUNNING) || this.get(PAUSED)) {
+                this._end(finish);
+            }
+            return this;
+        },
+
+        _added: false,
+
+        _start: function() {
+            this._set(START_TIME, new Date() - this.get(ELAPSED_TIME));
+            this._actualFrames = 0;
+            if (!this.get(PAUSED)) {
+                this._initAttr();
+            }
+            _running[Y.stamp(this)] = this;
+            Y.Anim._startTimer();
+
+            this.fire(START);
+        },
+
+        _pause: function() {
+            this._set(START_TIME, null);
+            this._set(PAUSED, true);
+            delete _running[Y.stamp(this)];
+
+            /**
+            * @event pause
+            * @description fires when an animation is paused.
+            * @param {Event} ev The pause event.
+            * @type Event.Custom
+            */
+            this.fire('pause');
+        },
+
+        _resume: function() {
+            this._set(PAUSED, false);
+            _running[Y.stamp(this)] = this;
+
+            /**
+            * @event resume
+            * @description fires when an animation is resumed (run from pause).
+            * @param {Event} ev The pause event.
+            * @type Event.Custom
+            */
+            this.fire('resume');
+        },
+
+        _end: function(finish) {
+            this._set(START_TIME, null);
+            this._set(ELAPSED_TIME, 0);
+            this._set(PAUSED, false);
+
+            delete _running[Y.stamp(this)];
+            this.fire(END, {elapsed: this.get(ELAPSED_TIME)});
+        },
+
+        _runFrame: function() {
+            var attr = this._runtimeAttr,
+                customAttr = Y.Anim.behaviors,
+                easing = attr.easing,
+                d = attr.duration,
+                t = new Date() - this.get(START_TIME),
+                reversed = this.get(REVERSE),
+                done = (t >= d),
+                lastFrame = d,
+                attribute,
+                setter;
+                
+            if (reversed) {
+                t = d - t;
+                done = (t <= 0);
+                lastFrame = 0;
+            }
+
+            for (var i in attr) {
+                if (attr[i].to) {
+                    attribute = attr[i];
+                    setter = (i in customAttr && 'set' in customAttr[i]) ?
+                            customAttr[i].set : Y.Anim.DEFAULT_SETTER;
+
+                    if (!done) {
+                        setter(this, i, attribute.from, attribute.to, t, d, easing, attribute.unit); 
+                    } else { // ensure final frame value is set
+                       // TODO: handle keyframes 
+                        setter(this, i, attribute.from, attribute.to, lastFrame, d, easing, attribute.unit); 
+                    }
+                }
+            }
+
+            this._actualFrames += 1;
+            this._set(ELAPSED_TIME, t);
+
+            this.fire(TWEEN);
+            if (done) {
+                this._lastFrame();
+            }
+        },
+
+        _lastFrame: function() {
+            var iter = this.get('iterations'),
+                iterCount = this.get(ITERATION_COUNT);
+
+            iterCount += 1;
+            if (iter === 'infinite' || iterCount < iter) {
+                if (this.get('direction') === 'alternate') {
+                    this.set(REVERSE, !this.get(REVERSE)); // flip it
+                }
+                /**
+                * @event iteration
+                * @description fires when an animation begins an iteration.
+                * @param {Event} ev The iteration event.
+                * @type Event.Custom
+                */
+                this.fire('iteration');
+            } else {
+                iterCount = 0;
+                this._end();
+            }
+
+            this._set(START_TIME, new Date());
+            this._set(ITERATION_COUNT, iterCount);
+        },
+
+        _initAttr: function() {
+            var from = this.get('from') || {},
+                to = this.get('to') || {},
+                dur = this.get('duration') * 1000,
+                node = this.get(NODE),
+                easing = this.get('easing') || {},
+                attr = {},
+                customAttr = Y.Anim.behaviors,
+                unit, begin, end;
+
+            Y.each(to, function(val, name) {
+                if (typeof val === 'function') {
+                    val = val.call(this, node);
+                }
+
+                begin = from[name];
+                if (begin === undefined) {
+                    begin = (name in customAttr && 'get' in customAttr[name])  ?
+                            customAttr[name].get(this, name) : Y.Anim.DEFAULT_GETTER(this, name);
+                } else if (typeof begin === 'function') {
+                    begin = begin.call(this, node);
+                }
+
+                var mFrom = Y.Anim.RE_UNITS.exec(begin);
+                var mTo = Y.Anim.RE_UNITS.exec(val);
+
+                begin = mFrom ? mFrom[1] : begin;
+                var end = mTo ? mTo[1] : val,
+                    unit = mTo ? mTo[2] : mFrom ?  mFrom[2] : ''; // one might be zero TODO: mixed units
+
+                if (!unit && Y.Anim.RE_DEFAULT_UNIT.test(name)) {
+                    unit = Y.Anim.DEFAULT_UNIT;
+                }
+
+                if (!begin || !end) {
+                    Y.fail('invalid "from" or "to" for "' + name + '"', 'Anim');
+                    return;
+                }
+
+                attr[name] = {
+                    from: begin,
+                    to: end,
+                    unit: unit
+                };
+
+                attr.duration = dur;
+                attr.easing = easing;
+
+            }, this);
+
+            this._runtimeAttr = attr;
+        },
+
+
+        // TODO: move to computedStyle? (browsers dont agree on default computed offsets)
+        _getOffset: function(attr) {
+            var node = this._node,
+                val = node.getComputedStyle(attr),
+                get = (attr === 'left') ? 'getX': 'getY',
+                set = (attr === 'left') ? 'setX': 'setY';
+
+            if (val === 'auto') {
+                var position = node.getStyle('position');
+                if (position === 'absolute' || position === 'fixed') {
+                    val = node[get]();
+                    node[set](val);
+                } else {
+                    val = 0;
+                }
+            }
+
+            return val;
+        }
+    };
+
+    Y.extend(Y.Anim, Y.Base, proto);
+/*
+TERMS OF USE - EASING EQUATIONS
+Open source under the BSD License.
+Copyright 2001 Robert Penner All rights reserved.
+
+Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
+
+ * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
+ * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
+ * Neither the name of the author nor the names of contributors may be used to endorse or promote products derived from this software without specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+*/
+
+/**
+ * The easing module provides methods for customizing
+ * how an animation behaves during each run.
+ * @class Easing
+ * @module anim
+ * @submodule anim-easing
+ */
+
+Y.Easing = {
+
+    /**
+     * Uniform speed between points.
+     * @method easeNone
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeNone: function (t, b, c, d) {
+        return c*t/d + b;
+    },
+    
+    /**
+     * Begins slowly and accelerates towards end. (quadratic)
+     * @method easeIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeIn: function (t, b, c, d) {
+        return c*(t/=d)*t + b;
+    },
+
+    /**
+     * Begins quickly and decelerates towards end.  (quadratic)
+     * @method easeOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeOut: function (t, b, c, d) {
+        return -c *(t/=d)*(t-2) + b;
+    },
+    
+    /**
+     * Begins slowly and decelerates towards end. (quadratic)
+     * @method easeBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeBoth: function (t, b, c, d) {
+        if ((t/=d/2) < 1) {
+            return c/2*t*t + b;
+        }
+        
+        return -c/2 * ((--t)*(t-2) - 1) + b;
+    },
+    
+    /**
+     * Begins slowly and accelerates towards end. (quartic)
+     * @method easeInStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeInStrong: function (t, b, c, d) {
+        return c*(t/=d)*t*t*t + b;
+    },
+    
+    /**
+     * Begins quickly and decelerates towards end.  (quartic)
+     * @method easeOutStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeOutStrong: function (t, b, c, d) {
+        return -c * ((t=t/d-1)*t*t*t - 1) + b;
+    },
+    
+    /**
+     * Begins slowly and decelerates towards end. (quartic)
+     * @method easeBothStrong
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    easeBothStrong: function (t, b, c, d) {
+        if ((t/=d/2) < 1) {
+            return c/2*t*t*t*t + b;
+        }
+        
+        return -c/2 * ((t-=2)*t*t*t - 2) + b;
+    },
+
+    /**
+     * Snap in elastic effect.
+     * @method elasticIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+
+    elasticIn: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        if ( (t /= d) === 1 ) {
+            return b+c;
+        }
+        if (!p) {
+            p = d* 0.3;
+        }
+        
+        if (!a || a < Math.abs(c)) {
+            a = c; 
+            s = p/4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        return -(a*Math.pow(2,10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
+    },
+
+    /**
+     * Snap out elastic effect.
+     * @method elasticOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    elasticOut: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        if ( (t /= d) === 1 ) {
+            return b+c;
+        }
+        if (!p) {
+            p=d * 0.3;
+        }
+        
+        if (!a || a < Math.abs(c)) {
+            a = c;
+            s = p / 4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        return a*Math.pow(2,-10*t) * Math.sin( (t*d-s)*(2*Math.PI)/p ) + c + b;
+    },
+    
+    /**
+     * Snap both elastic effect.
+     * @method elasticBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} a Amplitude (optional)
+     * @param {Number} p Period (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    elasticBoth: function (t, b, c, d, a, p) {
+        var s;
+        if (t === 0) {
+            return b;
+        }
+        
+        if ( (t /= d/2) === 2 ) {
+            return b+c;
+        }
+        
+        if (!p) {
+            p = d*(0.3*1.5);
+        }
+        
+        if ( !a || a < Math.abs(c) ) {
+            a = c; 
+            s = p/4;
+        }
+        else {
+            s = p/(2*Math.PI) * Math.asin (c/a);
+        }
+        
+        if (t < 1) {
+            return -0.5*(a*Math.pow(2,10*(t-=1)) * 
+                    Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
+        }
+        return a*Math.pow(2,-10*(t-=1)) * 
+                Math.sin( (t*d-s)*(2*Math.PI)/p )*0.5 + c + b;
+    },
+
+
+    /**
+     * Backtracks slightly, then reverses direction and moves to end.
+     * @method backIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backIn: function (t, b, c, d, s) {
+        if (s == undefined) {
+            s = 1.70158;
+        }
+        if (t === d) {
+            t -= 0.001;
+        }
+        return c*(t/=d)*t*((s+1)*t - s) + b;
+    },
+
+    /**
+     * Overshoots end, then reverses and comes back to end.
+     * @method backOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backOut: function (t, b, c, d, s) {
+        if (typeof s === 'undefined') {
+            s = 1.70158;
+        }
+        return c*((t=t/d-1)*t*((s+1)*t + s) + 1) + b;
+    },
+    
+    /**
+     * Backtracks slightly, then reverses direction, overshoots end, 
+     * then reverses and comes back to end.
+     * @method backBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @param {Number} s Overshoot (optional)
+     * @return {Number} The computed value for the current animation frame
+     */
+    backBoth: function (t, b, c, d, s) {
+        if (typeof s === 'undefined') {
+            s = 1.70158; 
+        }
+        
+        if ((t /= d/2 ) < 1) {
+            return c/2*(t*t*(((s*=(1.525))+1)*t - s)) + b;
+        }
+        return c/2*((t-=2)*t*(((s*=(1.525))+1)*t + s) + 2) + b;
+    },
+
+    /**
+     * Bounce off of start.
+     * @method bounceIn
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceIn: function (t, b, c, d) {
+        return c - Y.Easing.bounceOut(d-t, 0, c, d) + b;
+    },
+    
+    /**
+     * Bounces off end.
+     * @method bounceOut
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceOut: function (t, b, c, d) {
+        if ((t/=d) < (1/2.75)) {
+                return c*(7.5625*t*t) + b;
+        } else if (t < (2/2.75)) {
+                return c*(7.5625*(t-=(1.5/2.75))*t + 0.75) + b;
+        } else if (t < (2.5/2.75)) {
+                return c*(7.5625*(t-=(2.25/2.75))*t + 0.9375) + b;
+        }
+        return c*(7.5625*(t-=(2.625/2.75))*t + 0.984375) + b;
+    },
+    
+    /**
+     * Bounces off start and end.
+     * @method bounceBoth
+     * @param {Number} t Time value used to compute current value
+     * @param {Number} b Starting value
+     * @param {Number} c Delta between start and end values
+     * @param {Number} d Total length of animation
+     * @return {Number} The computed value for the current animation frame
+     */
+    bounceBoth: function (t, b, c, d) {
+        if (t < d/2) {
+            return Y.Easing.bounceIn(t * 2, 0, c, d) * 0.5 + b;
+        }
+        return Y.Easing.bounceOut(t * 2 - d, 0, c, d) * 0.5 + c * 0.5 + b;
+    }
+};
+/**
+ * Adds support for the <code>xy</code> property in <code>from</code> and 
+ * <code>to</code> attributes.
+ * @module anim
+ * @submodule anim-xy
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.xy = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        anim._node.setXY([
+            fn(elapsed, NUM(from[0]), NUM(to[0]) - NUM(from[0]), duration),
+            fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)
+        ]);
+    },
+    get: function(anim) {
+        return anim._node.getXY();
+    }
+};
+
+/**
+ * Adds support for color properties in <code>to</code>
+ * and <code>from</code> attributes.
+ * @module anim
+ * @submodule anim-color
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.color = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        from = Y.Color.re_RGB.exec(Y.Color.toRGB(from));
+        to = Y.Color.re_RGB.exec(Y.Color.toRGB(to));
+
+        if (!from || from.length < 3 || !to || to.length < 3) {
+            Y.fail('invalid from or to passed to color behavior');
+        }
+
+        anim._node.setStyle(att, 'rgb(' + [
+            Math.floor(fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)),
+            Math.floor(fn(elapsed, NUM(from[2]), NUM(to[2]) - NUM(from[2]), duration)),
+            Math.floor(fn(elapsed, NUM(from[3]), NUM(to[3]) - NUM(from[3]), duration))
+        ].join(', ') + ')');
+    },
+    
+    // TODO: default bgcolor const
+    get: function(anim, att) {
+        var val = anim._node.getComputedStyle(att);
+        val = (val === 'transparent') ? 'rgb(255, 255, 255)' : val;
+        return val;
+    }
+};
+
+Y.each(['backgroundColor',
+        'borderColor',
+        'borderTopColor',
+        'borderRightColor', 
+        'borderBottomColor', 
+        'borderLeftColor'],
+        function(v, i) {
+            Y.Anim.behaviors[v] = Y.Anim.behaviors.color;
+        }
+);
+/**
+ * Adds support for the <code>scroll</code> property in <code>to</code>
+ * and <code>from</code> attributes.
+ * @module anim
+ * @submodule anim-scroll
+ * @for Anim
+ */
+
+var NUM = Number;
+
+Y.Anim.behaviors.scroll = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        var
+            node = anim._node, 
+            val = ([
+            fn(elapsed, NUM(from[0]), NUM(to[0]) - NUM(from[0]), duration),
+            fn(elapsed, NUM(from[1]), NUM(to[1]) - NUM(from[1]), duration)
+        ]);
+
+        if (val[0]) {
+            node.set('scrollLeft', val[0]);
+        }
+
+        if (val[1]) {
+            node.set('scrollTop', val[1]);
+        }
+    },
+    get: function(anim) {
+        var node = anim._node;
+        return [node.get('scrollLeft'), node.get('scrollTop')];
+    }
+};
+
+/**
+ * Adds support for the <code>curve</code> property for the <code>to</code> 
+ * attribute.  A curve is zero or more control points and an end point.
+ * @module anim
+ * @submodule anim-curve
+ * @for Anim
+ */
+
+Y.Anim.behaviors.curve = {
+    set: function(anim, att, from, to, elapsed, duration, fn) {
+        from = from.slice.call(from);
+        to = to.slice.call(to);
+        var t = fn(elapsed, 0, 100, duration) / 100;
+        to.unshift(from);
+        anim._node.setXY(Y.Anim.getBezier(to, t));
+    },
+
+    get: function(anim, att) {
+        return anim._node.getXY();
+    }
+};
+
+/**
+ * Get the current position of the animated element based on t.
+ * Each point is an array of "x" and "y" values (0 = x, 1 = y)
+ * At least 2 points are required (start and end).
+ * First point is start. Last point is end.
+ * Additional control points are optional.     
+ * @method getBezier
+ * @static
+ * @param {Array} points An array containing Bezier points
+ * @param {Number} t A number between 0 and 1 which is the basis for determining current position
+ * @return {Array} An array containing int x and y member data
+ */
+Y.Anim.getBezier = function(points, t) {  
+    var n = points.length;
+    var tmp = [];
+
+    for (var i = 0; i < n; ++i){
+        tmp[i] = [points[i][0], points[i][1]]; // save input
+    }
+    
+    for (var j = 1; j < n; ++j) {
+        for (i = 0; i < n - j; ++i) {
+            tmp[i][0] = (1 - t) * tmp[i][0] + t * tmp[parseInt(i + 1, 10)][0];
+            tmp[i][1] = (1 - t) * tmp[i][1] + t * tmp[parseInt(i + 1, 10)][1]; 
+        }
+    }
+
+    return [ tmp[0][0], tmp[0][1] ]; 
+
+};
+/**
+ *  Binds an Anim instance to a Node instance
+ * @module anim
+ * @namespace plugin
+ * @submodule anim-node-plugin
+ */
+
+var NodeFX = function(config) {
+    var config = Y.merge(config);
+    config.node = config.owner;
+    NodeFX.superclass.constructor.apply(this, arguments);
+};
+
+NodeFX.NAME = "nodefx";
+NodeFX.NS = "fx";
+
+Y.extend(NodeFX, Y.Anim);
+
+Y.namespace('plugin');
+Y.plugin.NodeFX = NodeFX;
+
+
+}, '3.0.0pr2' ,{requires:['base', 'node']});

=== added directory 'loggerhead/static/javascript/yui/build/attribute'
=== added file 'loggerhead/static/javascript/yui/build/attribute/README'
--- loggerhead/static/javascript/yui/build/attribute/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/attribute/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,21 @@
+3.0.0PR2
+
+* Added valueFn support, to allowing static 
+  attribute values configuration to set instance
+  based values.
+  
+* Added reset method.
+
+* Added private setter for use by class implementation
+  code to set readOnly, writeOnce values.
+
+3.0.0PR1 - Initial release
+
+Module Name: "attribute"
+Documentation: http://developer.yahoo.com/yui/3/attribute
+
+The Attribute utility allows you to add attributes to any class 
+through an augmentable Attribute interface. The interface adds 
+get and set methods to your class for attribute access, in 
+addition to supporting change events allowing you to listen 
+for changes in attribute values.
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/attribute/attribute-debug.js'
--- loggerhead/static/javascript/yui/build/attribute/attribute-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/attribute/attribute-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,802 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('attribute', function(Y) {
+
+    /**
+     * Managed Attribute Provider
+     * @module attribute
+     */
+
+    /**
+     * Maintain state for a collection of items.  Individual properties 
+     * are stored in hash tables.  This is instead of having state objects 
+     * for each item in the collection.  For large collections, especially 
+     * changing ones, this approach may perform better.
+     * 
+     * @constructor
+     * @class State
+     */
+    Y.State = function() { 
+
+        /**
+         * Hash of attributes
+         * @property data
+         */
+        this.data = {};
+    };
+
+    Y.State.prototype = {
+
+        /**
+         * Add an item with all of the properties in the supplied object.
+         * @method add
+         * @param name {string} identifier for this attribute
+         * @param o hash of attributes
+         */
+        add: function(name, o) {
+            Y.each(o, function(v, k) {
+                if (!this.data[k]) {
+                    this.data[k] = {};
+                }
+
+                this.data[k][name] = v;
+            }, this);
+        },
+
+        /**
+         * Remove entire item, or optionally specified fields
+         * @method remove
+         * @param name {string} name of attribute
+         * @param o {string|object|array} single key or collection of keys to delete
+         */
+        remove: function(name, o) {
+            var d = this.data, 
+                del = function(key) {
+                    if (d[key] && (name in d[key])) {
+                        delete d[key][name];
+                    }
+                };
+
+            if (Y.Lang.isString(o)) {
+                del(o);
+            } else {
+                Y.each(o || d, function(v, k) {
+                    if(Y.Lang.isString(k)) {
+                        del(k);
+                    } else {
+                        del(v);
+                    }
+                }, this);
+
+            }
+        },
+
+        /**
+         * For a given item, gets an attribute.  If key is not
+         * supplied, a disposable object with all attributes is 
+         * returned.  Use of the latter option makes sense when
+         * working with single items, but not if object explosion
+         * might cause gc problems.
+         * @method get
+         * @param name {string} name of attribute
+         * @param key {string} optional attribute to get
+         * @return either the value of the supplied key or an object with
+         * all data.
+         */
+        // get: function(name, key, val) {
+        get: function(name, key) {
+            var d = this.data,
+                o;
+
+            if (key) {
+                return (d[key] && name in d[key]) ?  d[key][name] : undefined;
+            } else {
+                Y.each(d, function(v, k) {
+                    if (name in d[k]) {
+                        o = o || {};
+                        o[k] = v[name];
+                    }
+                }, this);
+
+                return o;
+
+            }
+        }
+
+        // figure out what kind of functionality we may need here
+        // get whole list
+        // get a list of items and values for a given key
+        // get a list of items where a key has the supplied value
+        /*
+        list: function(key, val) {
+            var o = {}, d = this.data, test = !L.isUndefined(val);
+
+            Y.each(this, function(v, k) {
+
+                // verify key
+                if (key && k !== key) {
+                    return;
+                // verify value.  note, v will be the item names, so this
+                // isn't working ... need to iterate v items
+                } else if (test && v !== val) {
+                    return;
+                }
+
+                o[k] = v;
+
+            }, this);
+
+            return o;
+        }
+        */
+    };
+
+    /**
+     * Managed Attribute Provider
+     * @module attribute
+     */
+
+    var O = Y.Object,
+
+        DOT = ".",
+        CHANGE = "Change",
+        GET = "get",
+        SET = "set",
+        VALUE = "value",
+        CLONE = "clone",
+        READ_ONLY = "readOnly",
+        WRITE_ONCE = "writeOnce",
+        VALIDATOR = "validator",
+
+        CLONE_ENUM;
+
+    /**
+     * <p>
+     * Attribute provides managed attribute support. 
+     * </p>
+     * <p>
+     * The class is designed to be augmented onto a host class, 
+     * and allows the host to support get/set methods for attributes,
+     * initial configuration support and attribute change events.
+     * </p>
+     * <p>Attributes added to the host can:</p>
+     * <ul>
+     *     <li>Be defined as read-only.</li>
+     *     <li>Be defined as write-once.</li>
+     *     <li>Be defined with a set function, used to manipulate
+     *     values passed to Attribute's set method, before they are stored.</li>
+     *     <li>Be defined with a validator function, to validate values before they are stored.</li>
+     *     <li>Be defined with a get function, which can be used to manipulate stored values,
+     *     before they are returned by Attribute's get method.</li>
+     *     <li>Specify if and how they should be cloned on 'get' (see <a href="#property_CLONE">Attribute.CLONE</a> for supported clone modes).</li>
+     * </ul>
+     *
+     * <p>See the <a href="#method_addAtt">addAtt</a> method, for details about how to add attributes with
+     * a specific configuration</p>
+     *
+     * @class Attribute
+     * @uses Event.Target
+     */
+    function Attribute() {
+        Y.Event.Target.call(this, {emitFacade:true});
+        this._conf = this._conf || new Y.State();
+        Y.log('att constructor called', 'info', 'attribute');
+    }
+
+    /**
+     * <p>
+     * Constants for clone formats supported by Attribute.
+     * </p>
+     * <p>
+     * By default attribute values returned by the get method
+     * are not cloned. However setting the attribute's "clone"
+     * property to:
+     * </p>
+     * <dl>
+     *     <dt>Attribute.CLONE.DEEP</dt>
+     *     <dd>Will result in a deep cloned value being returned
+     *        (using YUI's clone method). This can be expensive for complex
+     *        objects.
+     *     </dd>
+     *     <dt>Attribute.CLONE.SHALLOW</dt>
+     *     <dd>Will result in a shallow cloned value being returned
+     *        (using YUI's merge method).
+     *     </dd>
+     *     <dt>Attribute.CLONE.IMMUTABLE</dt>
+     *     <dd>Will result in a deep cloned value being returned
+     *         when using the get method. Additionally users will
+     *         not be able to set sub values of the attribute 
+     *         using the complex attribute notation (obj.set("x.y.z, 5)).
+     *         However the value of the attribute can be changed, making
+     *         it different from a READONLY attribute.
+     *     </dd>
+     *     <dt>Attribute.CLONE.NONE</dt>
+     *     <dd>
+     *         The value will not be cloned, resulting in a reference
+     *         to the stored value being passed back, if the value is an object.
+     *         This is the default behavior.
+     *     </dd>
+     * </dl>
+     * 
+     * @property CLONE
+     * @static
+     * @final
+     * @type Object
+     */
+    Attribute.CLONE = {
+        NONE : 0,
+        DEEP : 1,
+        SHALLOW : 2,
+        IMMUTABLE: 3
+    };
+
+    CLONE_ENUM = Attribute.CLONE;
+
+    Attribute.prototype = {
+        /**
+         * <p>
+         * Adds an attribute, with the provided configuration to the host object. Intended
+         * to be used by the host object to setup it's set of available attributes.
+         * </p>
+         * <p>
+         * The config argument object literal supports the following optional properties:
+         * </p>
+         * <dl>
+         *    <dt>value &#60;Any&#62;</dt>
+         *    <dd>The initial value to set on the attribute</dd>
+         *    <dt>readOnly &#60;Boolean&#62;</dt>
+         *    <dd>Whether or not the attribute is read only. Attributes having readOnly set to true
+         *        cannot be set by invoking the set method.</dd>
+         *    <dt>writeOnce &#60;Boolean&#62;</dt>
+         *    <dd>Whether or not the attribute is "write once". Attributes having writeOnce set to true, 
+         *        can only have their values set once, be it through the default configuration, 
+         *        constructor configuration arguments, or by invoking set.</dd>
+         *    <dt>set &#60;Function&#62;</dt>
+         *    <dd>The setter function to be invoked (within the context of the host object) before 
+         *        the attribute is stored by a call to the set method. The value returned by the 
+         *        set function will be the finally stored value.</dd>
+         *    <dt>get &#60;Function&#62;</dt>
+         *    <dd>The getter function to be invoked (within the context of the host object) before
+         *    the stored values is returned to a user invoking the get method for the attribute.
+         *    The value returned by the get function is the final value which will be returned to the 
+         *    user when they invoke get.</dd>
+         *    <dt>validator &#60;Function&#62;</dt>
+         *    <dd>The validator function which is invoked prior to setting the stored value. Returning
+         *    false from the validator function will prevent the value from being stored</dd>
+         *    <dt>clone &#60;int&#62;</dt>
+         *    <dd>If and how the value returned by a call to the get method, should be de-referenced from
+         *    the stored value. By default values are not cloned, and hence a call to get will return
+         *    a reference to the stored value. See Attribute.CLONE for more details about the clone 
+         *    options available</dd>
+         * </dl>
+         *
+         * @method addAtt
+         * 
+         * @param {String} name The attribute key
+         * @param {Object} config (optional) An object literal specifying the configuration for the attribute.
+         * <strong>NOTE:</strong> The config object is modified when adding an attribute, 
+         * so if you need to protect the original values, you will need to merge or clone the object.
+         * 
+         */
+        addAtt: function(name, config) {
+            Y.log('adding attribute: ' + name, 'info', 'attribute');
+            var value, hasValue = (VALUE in config);
+
+            if (config[READ_ONLY] && !hasValue) { Y.log('readOnly attribute: ' + name + ', added without an initial value. Value will be set on intial call to set', 'warn', 'attribute');}
+
+            if(hasValue) {
+                value = config.value;
+                delete config.value;
+            }
+
+            config.initValue = value;
+            this._conf.add(name, config);
+
+            if (hasValue) {
+                this.set(name, value);
+            }
+        },
+
+        /**
+         * Resets the given attribute or all attributes to the initial value.
+         *
+         * @method reset
+         * @param {String} name optional An attribute to reset.  If omitted, all attributes are reset
+         */
+        reset: function(name) {
+            if (name) {
+                this.set(name, this._conf.data['initValue'][name]);
+            } else {
+                var initVals = this._conf.data['initValue'];
+                Y.each(initVals, function(v, n) {
+                    this._set(n, v);
+                }, this);
+            }
+        },
+
+        /**
+         * Removes an attribute.
+         *
+         * @method removeAtt
+         * @param {String} name The attribute key
+         */
+        removeAtt: function(name) {
+            this._conf.remove(name);
+        },
+
+        /**
+         * Returns the current value of the attribute. If the attribute
+         * has been configured with a 'get' handler, this method will delegate
+         * to the 'get' handler to obtain the value of the attribute.
+         * The 'get' handler will be passed the current value of the attribute 
+         * as the only argument.
+         *
+         * @method get
+         *
+         * @param {String} key The attribute whose value will be returned. If
+         * the value of the attribute is an Object, dot notation can be used to
+         * obtain the value of a property of the object (e.g. <code>get("x.y.z")</code>)
+         * 
+         * @return {Any} The current value of the attribute
+         */
+        get: function(name) {
+
+            var conf = this._conf,
+                path,
+                getFn,
+                clone,
+                val;
+
+            if (name.indexOf(DOT) !== -1) {
+                path = name.split(DOT);
+                name = path.shift();
+            }
+
+            val = conf.get(name, VALUE);
+            getFn = conf.get(name, GET);
+            clone = conf.get(name, CLONE);
+
+            val = (clone) ? this._cloneAttVal(val, clone) : val;
+            val = (getFn) ? getFn.call(this, val) : val;
+            val = (path) ? this._getSubAttVal(path, val) : val;
+
+            return val;
+        },
+
+        /**
+         * Allows setting of readOnly/writeOnce attributes.
+         *
+         * @method _set
+         * @protected
+         * @chainable
+         * @return {Object} Reference to the host object
+         */
+        _set: function(name, val, opts) {
+            return this.set(name, val, opts, true);
+        },
+
+        /**
+         * Sets the value of an attribute.
+         *
+         * @method set
+         * @chainable
+         * 
+         * @param {String} name The name of the attribute. Note, if the 
+         * value of the attribute is an Object, dot notation can be used
+         * to set the value of a property within the object 
+         * (e.g. <code>set("x.y.z", 5)</code>), if the attribute has not
+         * been declared as an immutable attribute (see <a href="#property_CLONE">Attribute.CLONE</a>).
+         * 
+         * @param {Any} value The value to apply to the attribute
+         * 
+         * @param {Object} opts Optional event data. This object will be mixed into
+         * the event facade passed as the first argument to subscribers 
+         * of attribute change events
+         * 
+         * @return {Object} Reference to the host object
+         */
+        set: function(name, val, opts, privateSet) {
+            var conf = this._conf,
+                data = conf.data,
+                strPath,
+                path,
+                currVal,
+                initialSet = (!data.value || !(name in data.value));
+
+            if (name.indexOf(DOT) !== -1) {
+                strPath = name;
+                path = name.split(DOT);
+                name = path.shift();
+            }
+
+            if (path && conf.get(name, CLONE) === CLONE_ENUM.IMMUTABLE) {
+                Y.log('set ' + name + ' failed; Attribute is IMMUTABLE. Setting a sub value is not permitted', 'info', 'attribute');
+                return this;
+            }
+
+            if (!initialSet && !privateSet) {
+                if (conf.get(name, WRITE_ONCE)) {
+                    Y.log('set ' + name + ' failed; Attribute is writeOnce', 'info', 'attribute');
+                    return this;
+                }
+                if (conf.get(name, READ_ONLY)) {
+                    Y.log('set ' + name + ' failed; Attribute is readOnly', 'info', 'attribute');
+                    return this;
+                }
+            }
+
+            if (!conf.get(name)) {
+                //Y.log('Set called with unconfigured attribute. Adding a new attribute: ' + name, 'info', 'attribute');
+                Y.log('set ' + name + ' failed; Attribute is not configured', 'info', 'attribute');
+                return this;
+            }
+
+            currVal = this.get(name);
+
+            if (path) {
+               val = this._setSubAttVal(path, Y.clone(currVal), val);
+               if (val === undefined) {
+                   // Path not valid, don't set anything.
+                   Y.log('set ' + strPath + 'failed; attribute sub path is invalid', 'error', 'attribute');
+                   return this;
+               }
+            }
+
+            this._fireAttChange(name, currVal, val, name, strPath, opts);
+
+            return this;
+        },
+
+        /**
+         * <p>
+         * Alias for the Event.Target <a href="Event.Target.html#method_subscribe">subscribe</a> method.
+         * </p>
+         * 
+         * <p>Subscribers using this method to listen for attribute change events will be notified just
+         * <strong>before</strong> the state of the attribute has been modified, and before the default handler has been
+         * invoked.</p>
+         * 
+         * <p>The <a href="Event.Target.html#method_after">after</a> method, inherited from Event Target, can be used by subscribers
+         * who wish to be notified <strong>after</strong> the attribute's value has changed.</p>
+         * 
+         * @param {String} type The event type. For attribute change events, the event type is "[Attribute Name]Change", e.g.
+         * for the attribute "enabled", the event type will be "enabledChange".
+         * @param {Function} fn The subscribed function to invoke
+         * @param {Object} context Optional execution context
+         * @param {Any*} args* 0..n additional arguments to append to supply to the subscribed function when the event fires.
+         * @method on
+         * @return {Event.Handle} The handle object for unsubscribing the subscriber from the event.
+         */
+        on : function() {
+            return this.subscribe.apply(this, arguments);
+        },
+
+        /**
+         * Default handler implementation for set events
+         *
+         * @private
+         * @method _defAttSet
+         * @param {Event.Facade} e The event object for the custom event
+         */
+        _defAttSet : function(e) {
+            var conf = this._conf,
+                name = e.attrName,
+                val = e.newVal,
+                retVal,
+                valFn  = conf.get(name, VALIDATOR),
+                setFn = conf.get(name, SET);
+
+            if (setFn) {
+                retVal = setFn.call(this, val);
+                if (retVal !== undefined) {
+                    Y.log('attribute: ' + name + ' modified by setter', 'info', 'attribute');
+                    val = retVal; // setter can change value
+                }
+            }
+
+            if (!valFn || valFn.call(this, val)) {
+                conf.add(name, { value: val });
+                e.newVal = conf.get(name, VALUE);
+            } else {
+                // Prevent "after" listeners from being 
+                // invoked since nothing changed.
+                e.stopImmediatePropagation();
+            }
+        },
+
+        /**
+         * Retrieves the sub value at the provided path,
+         * from the value object provided.
+         *
+         * @method _getSubAttVal
+         * @private
+         *
+         * @param {Array} path  A path array, specifying the object traversal path
+         *                      from which to obtain the sub value.
+         * @param {Object} val  The object from which to extract the property value
+         * @return {Any} The value stored in the path or undefined if not found.
+         */
+        _getSubAttVal: function (path, val) {
+            var pl = path.length,
+                i;
+
+            if (pl > 0) {
+                for (i = 0; val !== undefined && i < pl; ++i) {
+                    val = val[path[i]];
+                }
+            }
+
+            return val;
+        },
+
+        /**
+         * Sets the sub value at the provided path on the value object.
+         * Returns the modified value object, or undefined if the path is invalid.
+         *
+         * @method _setSubAttVal
+         * @private
+         * 
+         * @param {Array} path  A path array, specifying the object traversal path
+         *                      at which to set the sub value.
+         * @param {Object} val  The object on which to set the sub value.
+         * @param {Any} subval  The sub value to set.
+         * @return {Object}     The modified object, with the new sub value set, or 
+         *                      undefined, if the path was invalid.
+         */
+        _setSubAttVal: function(path, val, subval) {
+
+            var leafIdx = path.length-1,
+                i,
+                o;
+
+            if (leafIdx >= 0) {
+                o = val;
+
+                for (i = 0; o !== undefined && i < leafIdx; ++i) {
+                    o = o[path[i]];
+                }
+
+                // Not preventing new properties from being added
+                if (o !== undefined /* && o[path[i]] !== undefined */) {
+                    o[path[i]] = subval;
+                } else {
+                    val = undefined;
+                }
+            }
+
+            return val;
+        },
+
+        /**
+         * Sets multiple attribute values.
+         * 
+         * @method setAtts
+         * @param {Object} atts  A hash of attributes: name/value pairs
+         */
+        setAtts: function(atts) {
+            for (var att in atts) {
+                if ( O.owns(atts, att) ) {
+                    this.set(att, atts[att]);
+                }
+            }
+        },
+
+        /**
+         * Gets multiple attribute values.
+         *
+         * @method getAtts
+         * @param {Array} Optional. An array of attribute names, whose values are required. If omitted, all attribute values are
+         * returned.
+         * @return {Object} A hash of attributes: name/value pairs
+         */
+        getAtts: function(atts) {
+            var o = {}, i, l, att;
+            atts = atts || O.keys(this._conf.data[VALUE]);
+
+            for (i = 0, l = atts.length; i < l; i++) {
+                // Go through get, to retrieve massaged values and honor cloning
+                att = atts[i];
+                o[att] = this.get(att); 
+            }
+
+            return o;
+        },
+
+        /**
+         * Configures attributes, and sets initial values
+         *
+         * @method _initAtts
+         * @protected
+         * 
+         * @param {Object} cfg Attribute configuration object literal
+         * @param {Object} initValues Name/value hash of initial values to apply
+         */
+        _initAtts : function(cfg, initValues) {
+            if (cfg) {
+                var att,
+                    attCfg,
+                    values,
+                    value,
+                    atts = cfg;
+
+                values = this._splitAttVals(initValues);
+
+                for (att in atts) {
+                    if (O.owns(atts, att)) {
+                        attCfg = Y.merge(atts[att]);
+                        value = this._initAttVal(att, attCfg, values);
+                        if (value !== undefined) {
+                            attCfg.value = value;
+                        }
+
+                        this.addAtt(att, attCfg);
+                    }
+                }
+            }
+        },
+
+        /**
+         * Utility to split out regular attribute values
+         * from complex attribute values, so that complex
+         * attributes can be keyed by top level attribute name.
+         *
+         * @method _splitAttrValues
+         * @param {Object} valueHash Name/value hash of initial values
+         *
+         * @return {Object} Object literal with 2 properties - "simple" and "complex",
+         * containing simple and complex attribute values respectively keyed 
+         * by attribute the top level attribute name.
+         * @private
+         */
+        _splitAttVals: function(valueHash) {
+            var vals = {},
+                subvals = {},
+                path,
+                attr,
+                v;
+
+            for (var k in valueHash) {
+                if (O.owns(valueHash, k)) {
+                    if (k.indexOf(DOT) !== -1) {
+                        path = k.split(DOT);
+                        attr = path.shift();
+                        v = subvals[attr] = subvals[attr] || [];
+                        v[v.length] = {
+                            path : path, 
+                            value: valueHash[k]
+                        };
+                    } else {
+                        vals[k] = valueHash[k];
+                    }
+                }
+            }
+            return { simple:vals, complex:subvals };
+        },
+
+        /**
+         * Returns the initial value of the given attribute from
+         * either the default configuration provided, or the 
+         * over-ridden value if it exists in the initValues 
+         * hash provided.
+         *
+         * @param {String} att Attribute name
+         * @param {Object} cfg Default attribute configuration
+         * object literal
+         * @param {Object} initVales Initial attribute values, provided 
+         * for the instance
+         *
+         * @return {Any} Initial value of the attribute.
+         *
+         * @method _initAttVal
+         * @private
+         */
+        _initAttVal : function(att, cfg, initValues) {
+
+            var hasVal = (VALUE in cfg),
+                val = (cfg.valueFn) ? cfg.valueFn.call(this) : cfg.value,
+                simple,
+                complex,
+                i,
+                l,
+                path,
+                subval,
+                subvals;
+
+            if (!cfg[READ_ONLY] && initValues) {
+                // Simple Attributes
+                simple = initValues.simple;
+                if (simple && O.owns(simple, att)) {
+                    hasVal = true;
+                    val = simple[att];
+                }
+
+                // Complex Attributes
+                complex = initValues.complex;
+                if (complex && O.owns(complex, att)) {
+                    hasVal = true;
+                    subvals = complex[att];
+                    for (i = 0, l = subvals.length; i < l; ++i) {
+                        path = subvals[i].path;
+                        subval = subvals[i].value;
+                        val = this._setSubAttVal(path, val, subval);
+                    }
+                }
+            }
+
+            return val;
+        },
+
+        /**
+         * <p>
+         * Clone utility method, which will 
+         * clone the provided value using YUI's 
+         * merge, or clone utilities based
+         * on the clone type provided. See <a href="#property_CLONE">Attribute.CLONE</a>
+         * </p>
+         * 
+         * @method _cloneAttVal
+         * @private 
+         * @param {Any} val Value to clone
+         * @param {int} type Clone type to use, See the CLONE property
+         * @return {Any} The cloned copy of the object, based on the provided type.
+         */
+        _cloneAttVal : function(val, type) {
+            switch(type) {
+                case CLONE_ENUM.SHALLOW:
+                    val = Y.merge(val);
+                    break;
+                case CLONE_ENUM.DEEP:
+                case CLONE_ENUM.IMMUTABLE:
+                    val = Y.clone(val);
+                    break;
+            }
+            return val;
+        },
+
+        /**
+         * Utility method to help setup the event payload and 
+         * fire the attribute change event.
+         * 
+         * @method _fireAttChange
+         * @private
+         * @param {String} type The event name
+         * @param {Any} currVal The current value of the attribute
+         * @param {Any} newVal The new value of the attribute
+         * @param {String} attrName The name of the attribute
+         * @param {String} strFullPath The full path of the property being changed, 
+         * if this is a sub-attribute value being change
+         * @param {Object} opts Any additional event data to mix into the attribute change event's event facade.
+         */
+        _fireAttChange: function(type, currVal, newVal, attrName, strFullPath, opts) {
+            type = type + CHANGE;
+
+            // TODO: Publishing temporarily, while we address event bubbling/queuing
+            this.publish(type, {queuable:false, defaultFn:this._defAttSet, silent:true});
+
+            var eData = {
+                type: type,
+                prevVal: currVal,
+                newVal: newVal,
+                attrName: attrName,
+                subAttrName: strFullPath
+            };
+
+            if (opts) {
+                Y.mix(eData, opts);
+            }
+
+            this.fire(eData);
+        }
+    };
+
+    Y.mix(Attribute, Y.Event.Target, false, null, 1);
+
+    Y.Attribute = Attribute;
+
+
+
+}, '3.0.0pr2' ,{requires:['event']});

=== added file 'loggerhead/static/javascript/yui/build/attribute/attribute-min.js'
--- loggerhead/static/javascript/yui/build/attribute/attribute-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/attribute/attribute-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("attribute",function(B){B.State=function(){this.data={};};B.State.prototype={add:function(N,O){B.each(O,function(Q,P){if(!this.data[P]){this.data[P]={};}this.data[P][N]=Q;},this);},remove:function(O,Q){var P=this.data,N=function(R){if(P[R]&&(O in P[R])){delete P[R][O];}};if(B.Lang.isString(Q)){N(Q);}else{B.each(Q||P,function(S,R){if(B.Lang.isString(R)){N(R);}else{N(S);}},this);}},get:function(N,O){var Q=this.data,P;if(O){return(Q[O]&&N in Q[O])?Q[O][N]:undefined;}else{B.each(Q,function(S,R){if(N in Q[R]){P=P||{};P[R]=S[N];}},this);return P;}}};var J=B.Object,K=".",F="Change",L="get",E="set",I="value",D="clone",M="readOnly",G="writeOnce",C="validator",H;function A(){B.Event.Target.call(this,{emitFacade:true});this._conf=this._conf||new B.State();}A.CLONE={NONE:0,DEEP:1,SHALLOW:2,IMMUTABLE:3};H=A.CLONE;A.prototype={addAtt:function(O,N){var Q,P=(I in N);if(P){Q=N.value;delete N.value;}N.initValue=Q;this._conf.add(O,N);if(P){this.set(O,Q);}},reset:function(O){if(O){this.set(O,this._conf.data["initValue"][O]);}else{var N=this._conf.data["initValue"];B.each(N,function(P,Q){this._set(Q,P);},this);}},removeAtt:function(N){this._conf.remove(N);},get:function(P){var O=this._conf,Q,N,S,R;if(P.indexOf(K)!==-1){Q=P.split(K);P=Q.shift();}R=O.get(P,I);N=O.get(P,L);S=O.get(P,D);R=(S)?this._cloneAttVal(R,S):R;R=(N)?N.call(this,R):R;R=(Q)?this._getSubAttVal(Q,R):R;return R;},_set:function(N,P,O){return this.set(N,P,O,true);},set:function(O,Q,N,V){var U=this._conf,S=U.data,T,W,P,R=(!S.value||!(O in S.value));if(O.indexOf(K)!==-1){T=O;W=O.split(K);O=W.shift();}if(W&&U.get(O,D)===H.IMMUTABLE){return this;}if(!R&&!V){if(U.get(O,G)){return this;}if(U.get(O,M)){return this;}}if(!U.get(O)){return this;}P=this.get(O);if(W){Q=this._setSubAttVal(W,B.clone(P),Q);if(Q===undefined){return this;}}this._fireAttChange(O,P,Q,O,T,N);return this;},on:function(){return this.subscribe.apply(this,arguments);},_defAttSet:function(S){var P=this._conf,O=S.attrName,T=S.newVal,R,N=P.get(O,C),Q=P.get(O,E);if(Q){R=Q.call(this,T);if(R!==undefined){T=R;}}if(!N||N.call(this,T)){P.add(O,{value:T});S.newVal=P.get(O,I);}else{S.stopImmediatePropagation();}},_getSubAttVal:function(P,Q){var O=P.length,N;if(O>0){for(N=0;Q!==undefined&&N<O;++N){Q=Q[P[N]];}}return Q;},_setSubAttVal:function(Q,S,P){var O=Q.length-1,N,R;if(O>=0){R=S;for(N=0;R!==undefined&&N<O;++N){R=R[Q[N]];}if(R!==undefined){R[Q[N]]=P;}else{S=undefined;}}return S;},setAtts:function(O){for(var N in O){if(J.owns(O,N)){this.set(N,O[N]);}}},getAtts:function(R){var Q={},P,N,O;R=R||J.keys(this._conf.data[I]);for(P=0,N=R.length;P<N;P++){O=R[P];Q[O]=this.get(O);}return Q;},_initAtts:function(N,Q){if(N){var P,S,O,R,T=N;O=this._splitAttVals(Q);for(P in T){if(J.owns(T,P)){S=B.merge(T[P]);R=this._initAttVal(P,S,O);if(R!==undefined){S.value=R;}this.addAtt(P,S);}}}},_splitAttVals:function(Q){var S={},R={},T,N,P;for(var O in Q){if(J.owns(Q,O)){if(O.indexOf(K)!==-1){T=O.split(K);N=T.shift();P=R[N]=R[N]||[];P[P.length]={path:T,value:Q[O]};}else{S[O]=Q[O];}}}return{simple:S,complex:R};},_initAttVal:function(U,S,X){var W=(I in S),O=(S.valueFn)?S.valueFn.call(this):S.value,N,P,R,Q,Y,V,T;if(!S[M]&&X){N=X.simple;if(N&&J.owns(N,U)){W=true;O=N[U];}P=X.complex;if(P&&J.owns(P,U)){W=true;T=P[U];for(R=0,Q=T.length;R<Q;++R){Y=T[R].path;V=T[R].value;O=this._setSubAttVal(Y,O,V);}}}return O;},_cloneAttVal:function(O,N){switch(N){case H.SHALLOW:O=B.merge(O);break;case H.DEEP:case H.IMMUTABLE:O=B.clone(O);break;}return O;},_fireAttChange:function(Q,S,N,O,T,R){Q=Q+F;this.publish(Q,{queuable:false,defaultFn:this._defAttSet,silent:true});var P={type:Q,prevVal:S,newVal:N,attrName:O,subAttrName:T};if(R){B.mix(P,R);}this.fire(P);}};B.mix(A,B.Event.Target,false,null,1);B.Attribute=A;},"3.0.0pr2",{requires:["event"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/attribute/attribute.js'
--- loggerhead/static/javascript/yui/build/attribute/attribute.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/attribute/attribute.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,792 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('attribute', function(Y) {
+
+    /**
+     * Managed Attribute Provider
+     * @module attribute
+     */
+
+    /**
+     * Maintain state for a collection of items.  Individual properties 
+     * are stored in hash tables.  This is instead of having state objects 
+     * for each item in the collection.  For large collections, especially 
+     * changing ones, this approach may perform better.
+     * 
+     * @constructor
+     * @class State
+     */
+    Y.State = function() { 
+
+        /**
+         * Hash of attributes
+         * @property data
+         */
+        this.data = {};
+    };
+
+    Y.State.prototype = {
+
+        /**
+         * Add an item with all of the properties in the supplied object.
+         * @method add
+         * @param name {string} identifier for this attribute
+         * @param o hash of attributes
+         */
+        add: function(name, o) {
+            Y.each(o, function(v, k) {
+                if (!this.data[k]) {
+                    this.data[k] = {};
+                }
+
+                this.data[k][name] = v;
+            }, this);
+        },
+
+        /**
+         * Remove entire item, or optionally specified fields
+         * @method remove
+         * @param name {string} name of attribute
+         * @param o {string|object|array} single key or collection of keys to delete
+         */
+        remove: function(name, o) {
+            var d = this.data, 
+                del = function(key) {
+                    if (d[key] && (name in d[key])) {
+                        delete d[key][name];
+                    }
+                };
+
+            if (Y.Lang.isString(o)) {
+                del(o);
+            } else {
+                Y.each(o || d, function(v, k) {
+                    if(Y.Lang.isString(k)) {
+                        del(k);
+                    } else {
+                        del(v);
+                    }
+                }, this);
+
+            }
+        },
+
+        /**
+         * For a given item, gets an attribute.  If key is not
+         * supplied, a disposable object with all attributes is 
+         * returned.  Use of the latter option makes sense when
+         * working with single items, but not if object explosion
+         * might cause gc problems.
+         * @method get
+         * @param name {string} name of attribute
+         * @param key {string} optional attribute to get
+         * @return either the value of the supplied key or an object with
+         * all data.
+         */
+        // get: function(name, key, val) {
+        get: function(name, key) {
+            var d = this.data,
+                o;
+
+            if (key) {
+                return (d[key] && name in d[key]) ?  d[key][name] : undefined;
+            } else {
+                Y.each(d, function(v, k) {
+                    if (name in d[k]) {
+                        o = o || {};
+                        o[k] = v[name];
+                    }
+                }, this);
+
+                return o;
+
+            }
+        }
+
+        // figure out what kind of functionality we may need here
+        // get whole list
+        // get a list of items and values for a given key
+        // get a list of items where a key has the supplied value
+        /*
+        list: function(key, val) {
+            var o = {}, d = this.data, test = !L.isUndefined(val);
+
+            Y.each(this, function(v, k) {
+
+                // verify key
+                if (key && k !== key) {
+                    return;
+                // verify value.  note, v will be the item names, so this
+                // isn't working ... need to iterate v items
+                } else if (test && v !== val) {
+                    return;
+                }
+
+                o[k] = v;
+
+            }, this);
+
+            return o;
+        }
+        */
+    };
+
+    /**
+     * Managed Attribute Provider
+     * @module attribute
+     */
+
+    var O = Y.Object,
+
+        DOT = ".",
+        CHANGE = "Change",
+        GET = "get",
+        SET = "set",
+        VALUE = "value",
+        CLONE = "clone",
+        READ_ONLY = "readOnly",
+        WRITE_ONCE = "writeOnce",
+        VALIDATOR = "validator",
+
+        CLONE_ENUM;
+
+    /**
+     * <p>
+     * Attribute provides managed attribute support. 
+     * </p>
+     * <p>
+     * The class is designed to be augmented onto a host class, 
+     * and allows the host to support get/set methods for attributes,
+     * initial configuration support and attribute change events.
+     * </p>
+     * <p>Attributes added to the host can:</p>
+     * <ul>
+     *     <li>Be defined as read-only.</li>
+     *     <li>Be defined as write-once.</li>
+     *     <li>Be defined with a set function, used to manipulate
+     *     values passed to Attribute's set method, before they are stored.</li>
+     *     <li>Be defined with a validator function, to validate values before they are stored.</li>
+     *     <li>Be defined with a get function, which can be used to manipulate stored values,
+     *     before they are returned by Attribute's get method.</li>
+     *     <li>Specify if and how they should be cloned on 'get' (see <a href="#property_CLONE">Attribute.CLONE</a> for supported clone modes).</li>
+     * </ul>
+     *
+     * <p>See the <a href="#method_addAtt">addAtt</a> method, for details about how to add attributes with
+     * a specific configuration</p>
+     *
+     * @class Attribute
+     * @uses Event.Target
+     */
+    function Attribute() {
+        Y.Event.Target.call(this, {emitFacade:true});
+        this._conf = this._conf || new Y.State();
+    }
+
+    /**
+     * <p>
+     * Constants for clone formats supported by Attribute.
+     * </p>
+     * <p>
+     * By default attribute values returned by the get method
+     * are not cloned. However setting the attribute's "clone"
+     * property to:
+     * </p>
+     * <dl>
+     *     <dt>Attribute.CLONE.DEEP</dt>
+     *     <dd>Will result in a deep cloned value being returned
+     *        (using YUI's clone method). This can be expensive for complex
+     *        objects.
+     *     </dd>
+     *     <dt>Attribute.CLONE.SHALLOW</dt>
+     *     <dd>Will result in a shallow cloned value being returned
+     *        (using YUI's merge method).
+     *     </dd>
+     *     <dt>Attribute.CLONE.IMMUTABLE</dt>
+     *     <dd>Will result in a deep cloned value being returned
+     *         when using the get method. Additionally users will
+     *         not be able to set sub values of the attribute 
+     *         using the complex attribute notation (obj.set("x.y.z, 5)).
+     *         However the value of the attribute can be changed, making
+     *         it different from a READONLY attribute.
+     *     </dd>
+     *     <dt>Attribute.CLONE.NONE</dt>
+     *     <dd>
+     *         The value will not be cloned, resulting in a reference
+     *         to the stored value being passed back, if the value is an object.
+     *         This is the default behavior.
+     *     </dd>
+     * </dl>
+     * 
+     * @property CLONE
+     * @static
+     * @final
+     * @type Object
+     */
+    Attribute.CLONE = {
+        NONE : 0,
+        DEEP : 1,
+        SHALLOW : 2,
+        IMMUTABLE: 3
+    };
+
+    CLONE_ENUM = Attribute.CLONE;
+
+    Attribute.prototype = {
+        /**
+         * <p>
+         * Adds an attribute, with the provided configuration to the host object. Intended
+         * to be used by the host object to setup it's set of available attributes.
+         * </p>
+         * <p>
+         * The config argument object literal supports the following optional properties:
+         * </p>
+         * <dl>
+         *    <dt>value &#60;Any&#62;</dt>
+         *    <dd>The initial value to set on the attribute</dd>
+         *    <dt>readOnly &#60;Boolean&#62;</dt>
+         *    <dd>Whether or not the attribute is read only. Attributes having readOnly set to true
+         *        cannot be set by invoking the set method.</dd>
+         *    <dt>writeOnce &#60;Boolean&#62;</dt>
+         *    <dd>Whether or not the attribute is "write once". Attributes having writeOnce set to true, 
+         *        can only have their values set once, be it through the default configuration, 
+         *        constructor configuration arguments, or by invoking set.</dd>
+         *    <dt>set &#60;Function&#62;</dt>
+         *    <dd>The setter function to be invoked (within the context of the host object) before 
+         *        the attribute is stored by a call to the set method. The value returned by the 
+         *        set function will be the finally stored value.</dd>
+         *    <dt>get &#60;Function&#62;</dt>
+         *    <dd>The getter function to be invoked (within the context of the host object) before
+         *    the stored values is returned to a user invoking the get method for the attribute.
+         *    The value returned by the get function is the final value which will be returned to the 
+         *    user when they invoke get.</dd>
+         *    <dt>validator &#60;Function&#62;</dt>
+         *    <dd>The validator function which is invoked prior to setting the stored value. Returning
+         *    false from the validator function will prevent the value from being stored</dd>
+         *    <dt>clone &#60;int&#62;</dt>
+         *    <dd>If and how the value returned by a call to the get method, should be de-referenced from
+         *    the stored value. By default values are not cloned, and hence a call to get will return
+         *    a reference to the stored value. See Attribute.CLONE for more details about the clone 
+         *    options available</dd>
+         * </dl>
+         *
+         * @method addAtt
+         * 
+         * @param {String} name The attribute key
+         * @param {Object} config (optional) An object literal specifying the configuration for the attribute.
+         * <strong>NOTE:</strong> The config object is modified when adding an attribute, 
+         * so if you need to protect the original values, you will need to merge or clone the object.
+         * 
+         */
+        addAtt: function(name, config) {
+            var value, hasValue = (VALUE in config);
+
+
+            if(hasValue) {
+                value = config.value;
+                delete config.value;
+            }
+
+            config.initValue = value;
+            this._conf.add(name, config);
+
+            if (hasValue) {
+                this.set(name, value);
+            }
+        },
+
+        /**
+         * Resets the given attribute or all attributes to the initial value.
+         *
+         * @method reset
+         * @param {String} name optional An attribute to reset.  If omitted, all attributes are reset
+         */
+        reset: function(name) {
+            if (name) {
+                this.set(name, this._conf.data['initValue'][name]);
+            } else {
+                var initVals = this._conf.data['initValue'];
+                Y.each(initVals, function(v, n) {
+                    this._set(n, v);
+                }, this);
+            }
+        },
+
+        /**
+         * Removes an attribute.
+         *
+         * @method removeAtt
+         * @param {String} name The attribute key
+         */
+        removeAtt: function(name) {
+            this._conf.remove(name);
+        },
+
+        /**
+         * Returns the current value of the attribute. If the attribute
+         * has been configured with a 'get' handler, this method will delegate
+         * to the 'get' handler to obtain the value of the attribute.
+         * The 'get' handler will be passed the current value of the attribute 
+         * as the only argument.
+         *
+         * @method get
+         *
+         * @param {String} key The attribute whose value will be returned. If
+         * the value of the attribute is an Object, dot notation can be used to
+         * obtain the value of a property of the object (e.g. <code>get("x.y.z")</code>)
+         * 
+         * @return {Any} The current value of the attribute
+         */
+        get: function(name) {
+
+            var conf = this._conf,
+                path,
+                getFn,
+                clone,
+                val;
+
+            if (name.indexOf(DOT) !== -1) {
+                path = name.split(DOT);
+                name = path.shift();
+            }
+
+            val = conf.get(name, VALUE);
+            getFn = conf.get(name, GET);
+            clone = conf.get(name, CLONE);
+
+            val = (clone) ? this._cloneAttVal(val, clone) : val;
+            val = (getFn) ? getFn.call(this, val) : val;
+            val = (path) ? this._getSubAttVal(path, val) : val;
+
+            return val;
+        },
+
+        /**
+         * Allows setting of readOnly/writeOnce attributes.
+         *
+         * @method _set
+         * @protected
+         * @chainable
+         * @return {Object} Reference to the host object
+         */
+        _set: function(name, val, opts) {
+            return this.set(name, val, opts, true);
+        },
+
+        /**
+         * Sets the value of an attribute.
+         *
+         * @method set
+         * @chainable
+         * 
+         * @param {String} name The name of the attribute. Note, if the 
+         * value of the attribute is an Object, dot notation can be used
+         * to set the value of a property within the object 
+         * (e.g. <code>set("x.y.z", 5)</code>), if the attribute has not
+         * been declared as an immutable attribute (see <a href="#property_CLONE">Attribute.CLONE</a>).
+         * 
+         * @param {Any} value The value to apply to the attribute
+         * 
+         * @param {Object} opts Optional event data. This object will be mixed into
+         * the event facade passed as the first argument to subscribers 
+         * of attribute change events
+         * 
+         * @return {Object} Reference to the host object
+         */
+        set: function(name, val, opts, privateSet) {
+            var conf = this._conf,
+                data = conf.data,
+                strPath,
+                path,
+                currVal,
+                initialSet = (!data.value || !(name in data.value));
+
+            if (name.indexOf(DOT) !== -1) {
+                strPath = name;
+                path = name.split(DOT);
+                name = path.shift();
+            }
+
+            if (path && conf.get(name, CLONE) === CLONE_ENUM.IMMUTABLE) {
+                return this;
+            }
+
+            if (!initialSet && !privateSet) {
+                if (conf.get(name, WRITE_ONCE)) {
+                    return this;
+                }
+                if (conf.get(name, READ_ONLY)) {
+                    return this;
+                }
+            }
+
+            if (!conf.get(name)) {
+                return this;
+            }
+
+            currVal = this.get(name);
+
+            if (path) {
+               val = this._setSubAttVal(path, Y.clone(currVal), val);
+               if (val === undefined) {
+                   // Path not valid, don't set anything.
+                   return this;
+               }
+            }
+
+            this._fireAttChange(name, currVal, val, name, strPath, opts);
+
+            return this;
+        },
+
+        /**
+         * <p>
+         * Alias for the Event.Target <a href="Event.Target.html#method_subscribe">subscribe</a> method.
+         * </p>
+         * 
+         * <p>Subscribers using this method to listen for attribute change events will be notified just
+         * <strong>before</strong> the state of the attribute has been modified, and before the default handler has been
+         * invoked.</p>
+         * 
+         * <p>The <a href="Event.Target.html#method_after">after</a> method, inherited from Event Target, can be used by subscribers
+         * who wish to be notified <strong>after</strong> the attribute's value has changed.</p>
+         * 
+         * @param {String} type The event type. For attribute change events, the event type is "[Attribute Name]Change", e.g.
+         * for the attribute "enabled", the event type will be "enabledChange".
+         * @param {Function} fn The subscribed function to invoke
+         * @param {Object} context Optional execution context
+         * @param {Any*} args* 0..n additional arguments to append to supply to the subscribed function when the event fires.
+         * @method on
+         * @return {Event.Handle} The handle object for unsubscribing the subscriber from the event.
+         */
+        on : function() {
+            return this.subscribe.apply(this, arguments);
+        },
+
+        /**
+         * Default handler implementation for set events
+         *
+         * @private
+         * @method _defAttSet
+         * @param {Event.Facade} e The event object for the custom event
+         */
+        _defAttSet : function(e) {
+            var conf = this._conf,
+                name = e.attrName,
+                val = e.newVal,
+                retVal,
+                valFn  = conf.get(name, VALIDATOR),
+                setFn = conf.get(name, SET);
+
+            if (setFn) {
+                retVal = setFn.call(this, val);
+                if (retVal !== undefined) {
+                    val = retVal; // setter can change value
+                }
+            }
+
+            if (!valFn || valFn.call(this, val)) {
+                conf.add(name, { value: val });
+                e.newVal = conf.get(name, VALUE);
+            } else {
+                // Prevent "after" listeners from being 
+                // invoked since nothing changed.
+                e.stopImmediatePropagation();
+            }
+        },
+
+        /**
+         * Retrieves the sub value at the provided path,
+         * from the value object provided.
+         *
+         * @method _getSubAttVal
+         * @private
+         *
+         * @param {Array} path  A path array, specifying the object traversal path
+         *                      from which to obtain the sub value.
+         * @param {Object} val  The object from which to extract the property value
+         * @return {Any} The value stored in the path or undefined if not found.
+         */
+        _getSubAttVal: function (path, val) {
+            var pl = path.length,
+                i;
+
+            if (pl > 0) {
+                for (i = 0; val !== undefined && i < pl; ++i) {
+                    val = val[path[i]];
+                }
+            }
+
+            return val;
+        },
+
+        /**
+         * Sets the sub value at the provided path on the value object.
+         * Returns the modified value object, or undefined if the path is invalid.
+         *
+         * @method _setSubAttVal
+         * @private
+         * 
+         * @param {Array} path  A path array, specifying the object traversal path
+         *                      at which to set the sub value.
+         * @param {Object} val  The object on which to set the sub value.
+         * @param {Any} subval  The sub value to set.
+         * @return {Object}     The modified object, with the new sub value set, or 
+         *                      undefined, if the path was invalid.
+         */
+        _setSubAttVal: function(path, val, subval) {
+
+            var leafIdx = path.length-1,
+                i,
+                o;
+
+            if (leafIdx >= 0) {
+                o = val;
+
+                for (i = 0; o !== undefined && i < leafIdx; ++i) {
+                    o = o[path[i]];
+                }
+
+                // Not preventing new properties from being added
+                if (o !== undefined /* && o[path[i]] !== undefined */) {
+                    o[path[i]] = subval;
+                } else {
+                    val = undefined;
+                }
+            }
+
+            return val;
+        },
+
+        /**
+         * Sets multiple attribute values.
+         * 
+         * @method setAtts
+         * @param {Object} atts  A hash of attributes: name/value pairs
+         */
+        setAtts: function(atts) {
+            for (var att in atts) {
+                if ( O.owns(atts, att) ) {
+                    this.set(att, atts[att]);
+                }
+            }
+        },
+
+        /**
+         * Gets multiple attribute values.
+         *
+         * @method getAtts
+         * @param {Array} Optional. An array of attribute names, whose values are required. If omitted, all attribute values are
+         * returned.
+         * @return {Object} A hash of attributes: name/value pairs
+         */
+        getAtts: function(atts) {
+            var o = {}, i, l, att;
+            atts = atts || O.keys(this._conf.data[VALUE]);
+
+            for (i = 0, l = atts.length; i < l; i++) {
+                // Go through get, to retrieve massaged values and honor cloning
+                att = atts[i];
+                o[att] = this.get(att); 
+            }
+
+            return o;
+        },
+
+        /**
+         * Configures attributes, and sets initial values
+         *
+         * @method _initAtts
+         * @protected
+         * 
+         * @param {Object} cfg Attribute configuration object literal
+         * @param {Object} initValues Name/value hash of initial values to apply
+         */
+        _initAtts : function(cfg, initValues) {
+            if (cfg) {
+                var att,
+                    attCfg,
+                    values,
+                    value,
+                    atts = cfg;
+
+                values = this._splitAttVals(initValues);
+
+                for (att in atts) {
+                    if (O.owns(atts, att)) {
+                        attCfg = Y.merge(atts[att]);
+                        value = this._initAttVal(att, attCfg, values);
+                        if (value !== undefined) {
+                            attCfg.value = value;
+                        }
+
+                        this.addAtt(att, attCfg);
+                    }
+                }
+            }
+        },
+
+        /**
+         * Utility to split out regular attribute values
+         * from complex attribute values, so that complex
+         * attributes can be keyed by top level attribute name.
+         *
+         * @method _splitAttrValues
+         * @param {Object} valueHash Name/value hash of initial values
+         *
+         * @return {Object} Object literal with 2 properties - "simple" and "complex",
+         * containing simple and complex attribute values respectively keyed 
+         * by attribute the top level attribute name.
+         * @private
+         */
+        _splitAttVals: function(valueHash) {
+            var vals = {},
+                subvals = {},
+                path,
+                attr,
+                v;
+
+            for (var k in valueHash) {
+                if (O.owns(valueHash, k)) {
+                    if (k.indexOf(DOT) !== -1) {
+                        path = k.split(DOT);
+                        attr = path.shift();
+                        v = subvals[attr] = subvals[attr] || [];
+                        v[v.length] = {
+                            path : path, 
+                            value: valueHash[k]
+                        };
+                    } else {
+                        vals[k] = valueHash[k];
+                    }
+                }
+            }
+            return { simple:vals, complex:subvals };
+        },
+
+        /**
+         * Returns the initial value of the given attribute from
+         * either the default configuration provided, or the 
+         * over-ridden value if it exists in the initValues 
+         * hash provided.
+         *
+         * @param {String} att Attribute name
+         * @param {Object} cfg Default attribute configuration
+         * object literal
+         * @param {Object} initVales Initial attribute values, provided 
+         * for the instance
+         *
+         * @return {Any} Initial value of the attribute.
+         *
+         * @method _initAttVal
+         * @private
+         */
+        _initAttVal : function(att, cfg, initValues) {
+
+            var hasVal = (VALUE in cfg),
+                val = (cfg.valueFn) ? cfg.valueFn.call(this) : cfg.value,
+                simple,
+                complex,
+                i,
+                l,
+                path,
+                subval,
+                subvals;
+
+            if (!cfg[READ_ONLY] && initValues) {
+                // Simple Attributes
+                simple = initValues.simple;
+                if (simple && O.owns(simple, att)) {
+                    hasVal = true;
+                    val = simple[att];
+                }
+
+                // Complex Attributes
+                complex = initValues.complex;
+                if (complex && O.owns(complex, att)) {
+                    hasVal = true;
+                    subvals = complex[att];
+                    for (i = 0, l = subvals.length; i < l; ++i) {
+                        path = subvals[i].path;
+                        subval = subvals[i].value;
+                        val = this._setSubAttVal(path, val, subval);
+                    }
+                }
+            }
+
+            return val;
+        },
+
+        /**
+         * <p>
+         * Clone utility method, which will 
+         * clone the provided value using YUI's 
+         * merge, or clone utilities based
+         * on the clone type provided. See <a href="#property_CLONE">Attribute.CLONE</a>
+         * </p>
+         * 
+         * @method _cloneAttVal
+         * @private 
+         * @param {Any} val Value to clone
+         * @param {int} type Clone type to use, See the CLONE property
+         * @return {Any} The cloned copy of the object, based on the provided type.
+         */
+        _cloneAttVal : function(val, type) {
+            switch(type) {
+                case CLONE_ENUM.SHALLOW:
+                    val = Y.merge(val);
+                    break;
+                case CLONE_ENUM.DEEP:
+                case CLONE_ENUM.IMMUTABLE:
+                    val = Y.clone(val);
+                    break;
+            }
+            return val;
+        },
+
+        /**
+         * Utility method to help setup the event payload and 
+         * fire the attribute change event.
+         * 
+         * @method _fireAttChange
+         * @private
+         * @param {String} type The event name
+         * @param {Any} currVal The current value of the attribute
+         * @param {Any} newVal The new value of the attribute
+         * @param {String} attrName The name of the attribute
+         * @param {String} strFullPath The full path of the property being changed, 
+         * if this is a sub-attribute value being change
+         * @param {Object} opts Any additional event data to mix into the attribute change event's event facade.
+         */
+        _fireAttChange: function(type, currVal, newVal, attrName, strFullPath, opts) {
+            type = type + CHANGE;
+
+            // TODO: Publishing temporarily, while we address event bubbling/queuing
+            this.publish(type, {queuable:false, defaultFn:this._defAttSet, silent:true});
+
+            var eData = {
+                type: type,
+                prevVal: currVal,
+                newVal: newVal,
+                attrName: attrName,
+                subAttrName: strFullPath
+            };
+
+            if (opts) {
+                Y.mix(eData, opts);
+            }
+
+            this.fire(eData);
+        }
+    };
+
+    Y.mix(Attribute, Y.Event.Target, false, null, 1);
+
+    Y.Attribute = Attribute;
+
+
+
+}, '3.0.0pr2' ,{requires:['event']});

=== added directory 'loggerhead/static/javascript/yui/build/base'
=== added file 'loggerhead/static/javascript/yui/build/base/README'
--- loggerhead/static/javascript/yui/build/base/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/base/README	2008-10-20 07:34:21 +0000
@@ -0,0 +1,11 @@
+3.0.0PR1 - Initial release
+
+Module Name: "base"
+Documentation: http://developer.yahoo.com/yui/3/base
+
+Base is designed to be a low level class from which other attribute 
+and event target based classes in the YUI library can be derived. 
+It provides a standard template for creating attribute based objects 
+across the library and provides a consistent init() and destroy() 
+sequence, by chaining initialization (initializer) and destruction 
+(destructor) methods for the class hierarcy.

=== added file 'loggerhead/static/javascript/yui/build/base/base-debug.js'
--- loggerhead/static/javascript/yui/build/base/base-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/base/base-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,705 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('base', function(Y) {
+
+    /**
+     * Base class support for objects requiring
+     * managed attributes and acting as event targets
+     *
+     * @module base
+     */
+    var L = Y.Lang,
+        O = Y.Object,
+        SEP = ":",
+        DESTROY = "destroy",
+        INIT = "init",
+        VALUE = "value",
+        INITIALIZED = "initialized",
+        DESTROYED = "destroyed",
+        INITIALIZER = "initializer",
+        DESTRUCTOR = "destructor";
+
+    var ETP = Y.Event.Target.prototype;
+
+    /**
+     * <p>
+     * Provides a base class for managed attribute based
+     * objects, which handles the chaining of initializer and destructor methods
+     * across the hierarchy during init and destroy lifecycle methods and 
+     * handles automatic configuration of registered Attributes, through 
+     * the static <a href="#property_ATTRS">ATTRS</a> property.
+     * </p>
+     *
+     * <p>The Base class also handles prefixing of event types with the static <a href="#property_NAME">NAME</a> 
+     * property for all events fired from instances of classes derived from Base.</p>
+     *
+     * @constructor
+     * @class Base
+     * @uses Attribute
+     *
+     * @param {Object} config Object literal of configuration property name/value pairs
+     */
+    var Base = function() {
+        Y.log('constructor called', 'life', 'base');
+        Y.Attribute.call(this);
+        this.init.apply(this, arguments);
+    };
+
+    /**
+     * <p>
+     * Name string to be used to identify instances of 
+     * this class, for example in prefixing events.
+     * </p>
+     * <p>
+     * Classes extending Base, should define their own
+     * static NAME property.
+     * </p>
+     * @property NAME
+     * @type String
+     * @static
+     */
+    Base.NAME = 'base';
+
+    /**
+     * Object literal defining the set of attributes which
+     * will be available for instances of this class, and 
+     * how they are configured. See Attributes addAtt method
+     * for a description of configuration options available 
+     * for each attribute.
+     *
+     * @property ATTRS
+     * @type Object
+     * @static
+     */
+    Base.ATTRS = {
+        /**
+         * Flag indicating whether or not this object
+         * has been through the init lifecycle phase.
+         *
+         * @attribute initialized
+         * @readOnly
+         * @default false
+         * @type boolean
+         */
+        initialized: {
+            readOnly:true,
+            value:false
+        },
+
+        /**
+         * Flag indicating whether or not this object
+         * has been through the destroy lifecycle phase.
+         *
+         * @attribute destroyed
+         * @readOnly
+         * @default false
+         * @type boolean
+         */
+        destroyed: {
+            readOnly:true,
+            value:false
+        }
+    };
+
+    /**
+     * The build configuration for the Base class.
+     * Defines the static fields which need to be aggregated,
+     * when this class is used as the main class passed to 
+     * the <a href="#method_build">Base.build</a> method.
+     *
+     * @property _buildCfg
+     * @type Object
+     * @static
+     * @final
+     * @private
+     */    
+    Base._buildCfg = {
+        aggregates : ["ATTRS"]
+    };
+
+    var _instances = {};
+
+    /**
+     * <p>
+     * Builds a constructor function (class) from the
+     * main function, and array of extension functions (classes)
+     * provided.
+     * </p>
+     * <p>
+     * The cfg object literal supports the following properties
+     * </p>
+     * <dl>
+     *    <dt>dynamic &#60;boolean&#62;</dt>
+     *    <dd>
+     *    <p>If true (default), a completely new class
+     *    is created which extends the main class, and acts as the 
+     *    host on which the extension classes are augmented.</p>
+     *    <p>If false, the extensions classes are augmented directly to
+     *    the main class, modifying the main classes prototype.</p>
+     *    </dd>
+     *    <dt>aggregates &#60;String[]&#62;</dt>
+     *    <dd>An array of static property names, which will get aggregated
+     *    on to the built class, in addition to the default properties build 
+     *    will always aggregate as defined by the main class' _buildCfg
+     *    property.
+     *    </dd>
+     * </dl>
+     *
+     * @method build
+     * @static
+     * @param {Function} main The main class on which to base the built class
+     * @param {Function[]} extensions The set of extension classes which will be
+     * augmented/aggregated to the built class.
+     * @param {Object} cfg
+     * @return {Function} A custom class, created from the provided main and extension classes
+     */
+    Base.build = function(main, extensions, cfg) {
+
+        var build = Base.build,
+
+            builtClass = build._getClass(main, cfg),
+            aggregates = build._getAggregates(main, cfg),
+            dynamic = builtClass._yuibuild.dynamic,
+
+            key = main.NAME,
+
+            i, l;
+
+        // Shallow isolate aggregates
+        if (dynamic) {
+            if (aggregates) {
+                for (i = 0, l = aggregates.length; i < l; ++i) {
+                    var val = aggregates[i];
+                    if (O.owns(main, val)) {
+                        builtClass[val] = L.isArray(main[val]) ? [] : {};
+                    }
+                }
+                Y.aggregate(builtClass, main, true, aggregates);
+            }
+        }
+
+        // Augment/Aggregate
+        for (i = 0, l = extensions.length; i < l; i++) {
+            var extClass = extensions[i];
+
+            if (aggregates) {
+                Y.aggregate(builtClass, extClass, true, aggregates);
+            }
+
+            // Old augment
+            Y.mix(builtClass, extClass, true, null, 1);
+
+            builtClass._yuibuild.exts.push(extClass);
+            key = key + ":" + Y.stamp(extClass);
+        }
+
+        builtClass._yuibuild.id = key;
+        builtClass.prototype.hasImpl = build._hasImpl;
+
+        if (dynamic) {
+            builtClass.NAME = main.NAME;
+            builtClass.prototype.constructor = builtClass;
+        }
+
+        return builtClass;
+    };
+    
+    Y.mix(Base.build, {
+
+        _template: function(main) {
+
+            function BuiltClass() {
+
+                BuiltClass.superclass.constructor.apply(this, arguments);
+
+                var f = BuiltClass._yuibuild.exts, 
+                    l = f.length;
+
+                for (var i = 0; i < l; i++) {
+                    f[i].apply(this, arguments);
+                }
+
+                return this;
+            }
+            Y.extend(BuiltClass, main);
+            return BuiltClass;
+        },
+
+        _hasImpl : function(extClass) {
+            if (this.constructor._yuibuild) {
+                var f = this.constructor._yuibuild.exts,
+                    l = f.length,
+                    i;
+
+                for (i = 0; i < l; i++) {
+                    if (f[i] === extClass) {
+                        return true;
+                    }
+                }
+            }
+
+            return false;
+        },
+
+        _getClass : function(main, cfg) {
+
+            // Create dynamic class or just modify main class
+            var dynamic = (cfg && false === cfg.dynamic) ? false : true,
+                builtClass = (dynamic) ? Base.build._template(main) : main;
+
+            builtClass._yuibuild = {
+                id: null,
+                exts : [],
+                dynamic : dynamic
+            };
+
+            return builtClass;
+        },
+
+        _getAggregates : function(main, cfg) {
+            var aggr = [],
+                cfgAggr = (cfg && cfg.aggregates),
+                c = main;
+
+            while (c && c.prototype) {
+                var classAggr = c._buildCfg && c._buildCfg.aggregates;
+                if (classAggr) {
+                    aggr = aggr.concat(classAggr);
+                }
+                c = c.superclass ? c.superclass.constructor : null;
+            }
+
+            if (cfgAggr) {
+                aggr = aggr.concat(cfgAggr);
+            }
+
+            return aggr;
+        }
+    });
+
+    /**
+     * <p>
+     * Creates a new object instance, based on a dynamically created custom class.
+     * The custom class is created from the main class passed in as the first parameter 
+     * along with the list of extension classes passed in
+     * as the second parameter using <a href="#method_build">Base.build</a> 
+     * with "dynamic" set to true. See the documentation for Base.build method 
+     * to see how the main class and extension classes are used.
+     * </p>
+     *
+     * <p>Any arguments following the 2nd argument are passed as arguments to the 
+     * constructor of the newly created class used to create the instance.</p>
+     * 
+     * @method create
+     * @static
+     *
+     * @param {Function} main The main class on which the instance it to be 
+     * based. This class will be extended to create the class for the custom instance
+     * @param {Array} extensions The list of extension classes used to augment the
+     * main class with.
+     * @param {Any*} args* 0..n arguments to pass to the constructor of the 
+     * newly created class, when creating the instance.
+     * @return {Object} An instance of the custom class
+     */
+    Base.create = function(main, extensions, args) {
+        var c = Base.build(main, extensions),
+            cArgs = Y.Array(arguments, 2, true);
+
+        function F(){}
+        F.prototype = c.prototype;
+
+        return c.apply(new F(), cArgs);
+    };
+
+    Base.prototype = {
+
+        /**
+         * Init lifecycle method, invoked during construction.
+         * Fires the init event prior to invoking initializers on
+         * the class hierarchy.
+         * 
+         * @method init
+         * @final
+         * @chainable
+         * @param {Object} config Object literal of configuration property name/value pairs
+         * @return {Base} A reference to this object
+         */
+        init: function(config) {
+            Y.log('init called', 'life', 'base');
+
+            /**
+             * The name string to be used to identify 
+             * this instance of object. 
+             * @property name
+             * @type String
+             */
+            this.name = this.constructor.NAME;
+
+            /**
+             * <p>
+             * Lifecycle event for the init phase, fired prior to initialization. 
+             * Invoking the preventDefault method on the event object provided 
+             * to subscribers will prevent initialization from occuring.
+             * </p>
+             * <p>
+             * Subscribers to the "after" momemt of this event, will be notified
+             * after initialization of the object is complete (and therefore
+             * cannot prevent initialization).
+             * </p>
+             *
+             * @event init
+             * @preventable _defInitFn
+             * @param {Event.Facade} e Event object
+             * @param config Object literal of configuration name/value pairs
+             */
+            this.publish(INIT, {
+                queuable:false,
+                defaultFn:this._defInitFn
+            });
+            this.fire(INIT, null, config);
+
+            return this;
+        },
+
+        /**
+         * <p>
+         * Destroy lifecycle method. Fires the destroy
+         * event, prior to invoking destructors for the
+         * class hierarchy.
+         * </p>
+         * <p>
+         * Subscribers to the destroy
+         * event can invoke preventDefault on the event object, to prevent destruction
+         * from proceeding.
+         * </p>
+         * @method destroy
+         * @return {Base} A reference to this object
+         * @final
+         * @chainable
+         */
+        destroy: function() {
+            Y.log('destroy called', 'life', 'base');
+
+            /**
+             * <p>
+             * Lifecycle event for the destroy phase, 
+             * fired prior to destruction. Invoking the preventDefault 
+             * method on the event object provided to subscribers will 
+             * prevent destruction from proceeding.
+             * </p>
+             * <p>
+             * Subscribers to the "after" moment of this event, will be notified
+             * after destruction is complete (and as a result cannot prevent
+             * destruction).
+             * </p>
+             * @event destroy
+             * @preventable _defDestroyFn
+             * @param {Event.Facade} e Event object
+             */
+            this.publish(DESTROY, {
+                queuable:false,
+                defaultFn: this._defDestroyFn
+            });
+            this.fire(DESTROY);
+            return this;
+        },
+
+        /**
+         * Default init event handler
+         *
+         * @method _defInitFn
+         * @param {Event.Facade} e Event object
+         * @param {Object} config Object literal of configuration property name/value pairs
+         * @protected
+         */
+        _defInitFn : function(e, config) {
+            _instances[Y.stamp(this)] = this;
+            this._initHierarchy(config);
+
+            this._set(INITIALIZED, true);
+        },
+
+        /**
+         * Default destroy event handler
+         *
+         * @method _defDestroyFn
+         * @param {Event.Facade} e Event object
+         * @protected
+         */
+        _defDestroyFn : function(e) {
+            this._destroyHierarchy();
+            delete _instances[this._yuid];
+
+            this._set(DESTROYED, true);
+        },
+
+        /**
+         * Returns the top down class hierarchy for this object,
+         * with Base being the first class in the array.
+         *
+         * @protected
+         * @return {Function[]} An Array of classes (constructor functions), making up the class heirarchy for this object
+         */
+        _getClasses : function() {
+            if (!this._classes) {
+                var c = this.constructor, 
+                    classes = [];
+
+                while (c && c.prototype) {
+                    classes.unshift(c);
+                    c = c.superclass ? c.superclass.constructor : null;
+                }
+                this._classes = classes;
+            }
+            return this._classes.concat();
+        },
+
+        /**
+         * Initializes the class hierarchy rooted at this base class,
+         * which includes initializing attributes for each class defined 
+         * in the class's static <a href="#property_ATTRS">ATTRS</a> property and invoking the initializer 
+         * method on the prototype of each class in the hierarchy.
+         * 
+         * @method _initHierarchy
+         * @param {Object} userConf Object literal containing attribute name/value pairs
+         * @private
+         */
+        _initHierarchy : function(userConf) {
+            var constr,
+                classes = this._getClasses();
+
+            for (var ci = 0, cl = classes.length; ci < cl; ci++) {
+                constr = classes[ci];
+
+                if (constr._yuibuild && constr._yuibuild.exts && !constr._yuibuild.dynamic) {
+                    for (var ei = 0, el = constr._yuibuild.exts.length; ei < el; ei++) {
+                        constr._yuibuild.exts[ei].apply(this, arguments);
+                    }
+                }
+
+                this._initAtts(constr.ATTRS, userConf);
+
+                if (O.owns(constr.prototype, INITIALIZER)) {
+                    constr.prototype[INITIALIZER].apply(this, arguments);
+                }
+            }
+        },
+
+        /**
+         * Destroys the class hierarchy rooted at this base class by invoking
+         * the descructor method on the prototype of each class in the hierarchy.
+         *
+         * @method _destroyHierarchy
+         * @private
+         */
+        _destroyHierarchy : function() {
+            var constr,
+                classes = this._getClasses();
+
+            for (var ci = classes.length-1; ci >= 0; ci--) {
+                constr = classes[ci];
+                if (O.owns(constr.prototype, DESTRUCTOR)) {
+                    constr.prototype[DESTRUCTOR].apply(this, arguments);
+                }
+            }
+        },
+
+        /**
+         * Default toString implementation. Provides the constructor NAME
+         * and the instance ID.
+         * 
+         * @method toString
+         * @return {String} String representation for this object
+         */
+        toString: function() {
+            return this.constructor.NAME + "[" + Y.stamp(this) + "]";
+        },
+
+        /**
+         * <p>
+         * Subscribe to a custom event hosted by this object.
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_subscribe">subscribe</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         * 
+         * @method subscribe
+         * @param {String} type The type of event to subscribe to. If 
+         * the type string does not contain a prefix ("prefix:eventType"), 
+         * the name property of the instance will be used as the default prefix.
+         * @param {Function} fn The subscribed callback function, invoked when the event is fired.
+         * @param {Object} context Optional execution context for the callback.
+         * @param {Any*} args* 0..n params to supply to the callback
+         * 
+         * @return {Event.Handle} An event handle which can be used to unsubscribe the subscribed callback.
+         */
+        subscribe : function() {
+            var a = arguments;
+            a[0] = this._prefixEvtType(a[0]);
+            return ETP.subscribe.apply(this, a);
+        },
+
+        /**
+         * <p>
+         * Fire a custom event by name.  The callback functions will be executed
+         * from the context specified when the event was created, and with the 
+         * following parameters.
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_fire">fire</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         * 
+         * @method fire
+         * @param {String|Object} type The type of the event, or an object that contains
+         * a 'type' property. If the type does not contain a prefix ("prefix:eventType"),
+         * the name property of the instance will be used as the default prefix.
+         * @param {Any*} args* 0..n Additional arguments to pass to subscribers.
+         * @return {boolean} The return value from Event Target's <a href="Event.Target.html#method_fire">fire</a> method.
+         *
+         */
+        fire : function() {
+            var a = arguments;
+            if (L.isString(a[0])) {
+                a[0] = this._prefixEvtType(a[0]);
+            } else if (a[0].type){
+                a[0].type = this._prefixEvtType(a[0].type);
+            }
+            return ETP.fire.apply(this, a);
+        },
+
+        /**
+         * <p>
+         * Creates a new custom event of the specified type.  If a custom event
+         * by that name already exists, it will not be re-created.  In either
+         * case the custom event is returned. 
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_publish">publish</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         *
+         * @method publish
+         * @param {String} type  The type, or name of the event. If the type does not 
+         * contain a prefix ("prefix:eventType"), the name property of the instance will 
+         * be used as the default prefix.
+         * @param {Object} opts Optional config params (see Event.Target <a href="Event.Target.html#method_publish">publish</a> for details)
+         * @return {Event.Custom} The published custom event object
+         */
+        publish : function() {
+            var a = arguments;
+            a[0] = this._prefixEvtType(a[0]);
+            return ETP.publish.apply(this, a);
+        },
+
+        /**
+         * <p>
+         * Subscribe to a custom event hosted by this object.  The
+         * supplied callback will execute <em>after</em> any listeners added
+         * via the subscribe method, and after the default function,
+         * if configured for the event, has executed.
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_after">after</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         * @method after
+         * @param {String} type The type of event to subscribe to. If 
+         * the type string does not contain a prefix ("prefix:eventType"), 
+         * the name property of the instance will be used as the default prefix.
+         * @param {Function} fn  The subscribed callback function
+         * @param {Object} context Optional execution context for the callback
+         * @param {Any*} args* 0..n params to supply to the callback
+         * @return {Event.Handle} Event handle which can be used to unsubscribe the subscribed callback.
+         */
+        after : function() {
+            var a = arguments;
+            a[0] = this._prefixEvtType(a[0]);
+            return ETP.after.apply(this, a);
+        },
+
+        /**
+         * <p>
+         * Unsubscribes one or more listeners the from the specified event.
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_unsubscribe">unsubscribe</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         * @method unsubscribe
+         * @param {String|Object} type Either the handle to the subscriber or the 
+         *                        type of event.  If the type
+         *                        is not specified, it will attempt to remove
+         *                        the listener from all hosted events. If 
+         *                        the type string does not contain a prefix 
+         *                        ("prefix:eventType"), the name property of the 
+         *                        instance will be used as the default prefix.
+         * @param {Function} fn The subscribed function to unsubscribe, if not
+         *                          supplied, all subscribers will be removed.
+         * @param {Object} context The custom object passed to subscribe.  This is
+         *                        optional, but if supplied will be used to
+         *                        disambiguate multiple listeners that are the same
+         *                        (e.g., you subscribe many object using a function
+         *                        that lives on the prototype)
+         * @return {boolean} true if the subscriber was found and detached.
+         */
+        unsubscribe: function(type, fn, context) {
+            var a = arguments;
+            if (L.isString(a[0])) {
+                a[0] = this._prefixEvtType(a[0]);
+            }
+            return ETP.unsubscribe.apply(this, a);
+        },
+
+        /**
+         * <p>
+         * Removes all listeners from the specified event.  If the event type
+         * is not specified, all listeners from all hosted custom events will
+         * be removed.
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_unsubscribeAll">unsubscribeAll</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         * @method unsubscribeAll
+         * @param {String} type The type, or name of the event. If 
+         * the type string does not contain a prefix ("prefix:eventType"), 
+         * the name property of the instance will be used as the default prefix
+         * @return {int} The number of listeners unsubscribed
+         */
+        unsubscribeAll: function(type) {
+            var a = arguments;
+            a[0] = this._prefixEvtType(a[0]);
+            return ETP.unsubscribeAll.apply(this, a);
+        },
+
+        /**
+         * Utility method to prefix the event name with the
+         * name property of the instance, if absent
+         *
+         * @method _prefixEvtType
+         * @private
+         * @param {String} type The event name
+         * @return {String} The prefixed event name
+         */
+        _prefixEvtType: function(type) {
+            if (type.indexOf(SEP) === -1 && this.name) {
+               type = this.name + ":" + type;
+            }
+            return type;
+        }
+    };
+
+    Y.mix(Base, Y.Attribute, false, null, 1);
+
+    Base.prototype.constructor = Base;
+    Y.Base = Base;
+
+
+
+}, '3.0.0pr2' ,{requires:['attribute']});

=== added file 'loggerhead/static/javascript/yui/build/base/base-min.js'
--- loggerhead/static/javascript/yui/build/base/base-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/base/base-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("base",function(A){var J=A.Lang,H=A.Object,I=":",E="destroy",N="init",G="value",M="initialized",F="destroyed",B="initializer",K="destructor";var C=A.Event.Target.prototype;var D=function(){A.Attribute.call(this);this.init.apply(this,arguments);};D.NAME="base";D.ATTRS={initialized:{readOnly:true,value:false},destroyed:{readOnly:true,value:false}};D._buildCfg={aggregates:["ATTRS"]};var P={};D.build=function(S,W,V){var Y=D.build,L=Y._getClass(S,V),U=Y._getAggregates(S,V),Q=L._yuibuild.dynamic,Z=S.NAME,T,R;if(Q){if(U){for(T=0,R=U.length;T<R;++T){var O=U[T];if(H.owns(S,O)){L[O]=J.isArray(S[O])?[]:{};}}A.aggregate(L,S,true,U);}}for(T=0,R=W.length;T<R;T++){var X=W[T];if(U){A.aggregate(L,X,true,U);}A.mix(L,X,true,null,1);L._yuibuild.exts.push(X);Z=Z+":"+A.stamp(X);}L._yuibuild.id=Z;L.prototype.hasImpl=Y._hasImpl;if(Q){L.NAME=S.NAME;L.prototype.constructor=L;}return L;};A.mix(D.build,{_template:function(L){function O(){O.superclass.constructor.apply(this,arguments);var S=O._yuibuild.exts,Q=S.length;for(var R=0;R<Q;R++){S[R].apply(this,arguments);}return this;}A.extend(O,L);return O;},_hasImpl:function(O){if(this.constructor._yuibuild){var R=this.constructor._yuibuild.exts,L=R.length,Q;for(Q=0;Q<L;Q++){if(R[Q]===O){return true;}}}return false;},_getClass:function(L,O){var Q=(O&&false===O.dynamic)?false:true,R=(Q)?D.build._template(L):L;R._yuibuild={id:null,exts:[],dynamic:Q};return R;},_getAggregates:function(L,O){var Q=[],S=(O&&O.aggregates),T=L;while(T&&T.prototype){var R=T._buildCfg&&T._buildCfg.aggregates;if(R){Q=Q.concat(R);}T=T.superclass?T.superclass.constructor:null;}if(S){Q=Q.concat(S);}return Q;}});D.create=function(O,R,Q){var T=D.build(O,R),L=A.Array(arguments,2,true);function S(){}S.prototype=T.prototype;return T.apply(new S(),L);};D.prototype={init:function(L){this.name=this.constructor.NAME;this.publish(N,{queuable:false,defaultFn:this._defInitFn});this.fire(N,null,L);return this;},destroy:function(){this.publish(E,{queuable:false,defaultFn:this._defDestroyFn});this.fire(E);return this;},_defInitFn:function(O,L){P[A.stamp(this)]=this;this._initHierarchy(L);this._set(M,true);},_defDestroyFn:function(L){this._destroyHierarchy();delete P[this._yuid];this._set(F,true);},_getClasses:function(){if(!this._classes){var O=this.constructor,L=[];while(O&&O.prototype){L.unshift(O);O=O.superclass?O.superclass.constructor:null;}this._classes=L;}return this._classes.concat();},_initHierarchy:function(T){var S,Q=this._getClasses();for(var O=0,L=Q.length;O<L;O++){S=Q[O];if(S._yuibuild&&S._yuibuild.exts&&!S._yuibuild.dynamic){for(var U=0,R=S._yuibuild.exts.length;U<R;U++){S._yuibuild.exts[U].apply(this,arguments);}}this._initAtts(S.ATTRS,T);if(H.owns(S.prototype,B)){S.prototype[B].apply(this,arguments);}}},_destroyHierarchy:function(){var Q,O=this._getClasses();for(var L=O.length-1;L>=0;L--){Q=O[L];if(H.owns(Q.prototype,K)){Q.prototype[K].apply(this,arguments);}}},toString:function(){return this.constructor.NAME+"["+A.stamp(this)+"]";},subscribe:function(){var L=arguments;L[0]=this._prefixEvtType(L[0]);return C.subscribe.apply(this,L);},fire:function(){var L=arguments;if(J.isString(L[0])){L[0]=this._prefixEvtType(L[0]);}else{if(L[0].type){L[0].type=this._prefixEvtType(L[0].type);}}return C.fire.apply(this,L);},publish:function(){var L=arguments;L[0]=this._prefixEvtType(L[0]);return C.publish.apply(this,L);},after:function(){var L=arguments;L[0]=this._prefixEvtType(L[0]);return C.after.apply(this,L);},unsubscribe:function(R,Q,O){var L=arguments;if(J.isString(L[0])){L[0]=this._prefixEvtType(L[0]);}return C.unsubscribe.apply(this,L);},unsubscribeAll:function(O){var L=arguments;L[0]=this._prefixEvtType(L[0]);return C.unsubscribeAll.apply(this,L);},_prefixEvtType:function(L){if(L.indexOf(I)===-1&&this.name){L=this.name+":"+L;}return L;}};A.mix(D,A.Attribute,false,null,1);D.prototype.constructor=D;A.Base=D;},"3.0.0pr2",{requires:["attribute"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/base/base.js'
--- loggerhead/static/javascript/yui/build/base/base.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/base/base.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,702 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('base', function(Y) {
+
+    /**
+     * Base class support for objects requiring
+     * managed attributes and acting as event targets
+     *
+     * @module base
+     */
+    var L = Y.Lang,
+        O = Y.Object,
+        SEP = ":",
+        DESTROY = "destroy",
+        INIT = "init",
+        VALUE = "value",
+        INITIALIZED = "initialized",
+        DESTROYED = "destroyed",
+        INITIALIZER = "initializer",
+        DESTRUCTOR = "destructor";
+
+    var ETP = Y.Event.Target.prototype;
+
+    /**
+     * <p>
+     * Provides a base class for managed attribute based
+     * objects, which handles the chaining of initializer and destructor methods
+     * across the hierarchy during init and destroy lifecycle methods and 
+     * handles automatic configuration of registered Attributes, through 
+     * the static <a href="#property_ATTRS">ATTRS</a> property.
+     * </p>
+     *
+     * <p>The Base class also handles prefixing of event types with the static <a href="#property_NAME">NAME</a> 
+     * property for all events fired from instances of classes derived from Base.</p>
+     *
+     * @constructor
+     * @class Base
+     * @uses Attribute
+     *
+     * @param {Object} config Object literal of configuration property name/value pairs
+     */
+    var Base = function() {
+        Y.Attribute.call(this);
+        this.init.apply(this, arguments);
+    };
+
+    /**
+     * <p>
+     * Name string to be used to identify instances of 
+     * this class, for example in prefixing events.
+     * </p>
+     * <p>
+     * Classes extending Base, should define their own
+     * static NAME property.
+     * </p>
+     * @property NAME
+     * @type String
+     * @static
+     */
+    Base.NAME = 'base';
+
+    /**
+     * Object literal defining the set of attributes which
+     * will be available for instances of this class, and 
+     * how they are configured. See Attributes addAtt method
+     * for a description of configuration options available 
+     * for each attribute.
+     *
+     * @property ATTRS
+     * @type Object
+     * @static
+     */
+    Base.ATTRS = {
+        /**
+         * Flag indicating whether or not this object
+         * has been through the init lifecycle phase.
+         *
+         * @attribute initialized
+         * @readOnly
+         * @default false
+         * @type boolean
+         */
+        initialized: {
+            readOnly:true,
+            value:false
+        },
+
+        /**
+         * Flag indicating whether or not this object
+         * has been through the destroy lifecycle phase.
+         *
+         * @attribute destroyed
+         * @readOnly
+         * @default false
+         * @type boolean
+         */
+        destroyed: {
+            readOnly:true,
+            value:false
+        }
+    };
+
+    /**
+     * The build configuration for the Base class.
+     * Defines the static fields which need to be aggregated,
+     * when this class is used as the main class passed to 
+     * the <a href="#method_build">Base.build</a> method.
+     *
+     * @property _buildCfg
+     * @type Object
+     * @static
+     * @final
+     * @private
+     */    
+    Base._buildCfg = {
+        aggregates : ["ATTRS"]
+    };
+
+    var _instances = {};
+
+    /**
+     * <p>
+     * Builds a constructor function (class) from the
+     * main function, and array of extension functions (classes)
+     * provided.
+     * </p>
+     * <p>
+     * The cfg object literal supports the following properties
+     * </p>
+     * <dl>
+     *    <dt>dynamic &#60;boolean&#62;</dt>
+     *    <dd>
+     *    <p>If true (default), a completely new class
+     *    is created which extends the main class, and acts as the 
+     *    host on which the extension classes are augmented.</p>
+     *    <p>If false, the extensions classes are augmented directly to
+     *    the main class, modifying the main classes prototype.</p>
+     *    </dd>
+     *    <dt>aggregates &#60;String[]&#62;</dt>
+     *    <dd>An array of static property names, which will get aggregated
+     *    on to the built class, in addition to the default properties build 
+     *    will always aggregate as defined by the main class' _buildCfg
+     *    property.
+     *    </dd>
+     * </dl>
+     *
+     * @method build
+     * @static
+     * @param {Function} main The main class on which to base the built class
+     * @param {Function[]} extensions The set of extension classes which will be
+     * augmented/aggregated to the built class.
+     * @param {Object} cfg
+     * @return {Function} A custom class, created from the provided main and extension classes
+     */
+    Base.build = function(main, extensions, cfg) {
+
+        var build = Base.build,
+
+            builtClass = build._getClass(main, cfg),
+            aggregates = build._getAggregates(main, cfg),
+            dynamic = builtClass._yuibuild.dynamic,
+
+            key = main.NAME,
+
+            i, l;
+
+        // Shallow isolate aggregates
+        if (dynamic) {
+            if (aggregates) {
+                for (i = 0, l = aggregates.length; i < l; ++i) {
+                    var val = aggregates[i];
+                    if (O.owns(main, val)) {
+                        builtClass[val] = L.isArray(main[val]) ? [] : {};
+                    }
+                }
+                Y.aggregate(builtClass, main, true, aggregates);
+            }
+        }
+
+        // Augment/Aggregate
+        for (i = 0, l = extensions.length; i < l; i++) {
+            var extClass = extensions[i];
+
+            if (aggregates) {
+                Y.aggregate(builtClass, extClass, true, aggregates);
+            }
+
+            // Old augment
+            Y.mix(builtClass, extClass, true, null, 1);
+
+            builtClass._yuibuild.exts.push(extClass);
+            key = key + ":" + Y.stamp(extClass);
+        }
+
+        builtClass._yuibuild.id = key;
+        builtClass.prototype.hasImpl = build._hasImpl;
+
+        if (dynamic) {
+            builtClass.NAME = main.NAME;
+            builtClass.prototype.constructor = builtClass;
+        }
+
+        return builtClass;
+    };
+    
+    Y.mix(Base.build, {
+
+        _template: function(main) {
+
+            function BuiltClass() {
+
+                BuiltClass.superclass.constructor.apply(this, arguments);
+
+                var f = BuiltClass._yuibuild.exts, 
+                    l = f.length;
+
+                for (var i = 0; i < l; i++) {
+                    f[i].apply(this, arguments);
+                }
+
+                return this;
+            }
+            Y.extend(BuiltClass, main);
+            return BuiltClass;
+        },
+
+        _hasImpl : function(extClass) {
+            if (this.constructor._yuibuild) {
+                var f = this.constructor._yuibuild.exts,
+                    l = f.length,
+                    i;
+
+                for (i = 0; i < l; i++) {
+                    if (f[i] === extClass) {
+                        return true;
+                    }
+                }
+            }
+
+            return false;
+        },
+
+        _getClass : function(main, cfg) {
+
+            // Create dynamic class or just modify main class
+            var dynamic = (cfg && false === cfg.dynamic) ? false : true,
+                builtClass = (dynamic) ? Base.build._template(main) : main;
+
+            builtClass._yuibuild = {
+                id: null,
+                exts : [],
+                dynamic : dynamic
+            };
+
+            return builtClass;
+        },
+
+        _getAggregates : function(main, cfg) {
+            var aggr = [],
+                cfgAggr = (cfg && cfg.aggregates),
+                c = main;
+
+            while (c && c.prototype) {
+                var classAggr = c._buildCfg && c._buildCfg.aggregates;
+                if (classAggr) {
+                    aggr = aggr.concat(classAggr);
+                }
+                c = c.superclass ? c.superclass.constructor : null;
+            }
+
+            if (cfgAggr) {
+                aggr = aggr.concat(cfgAggr);
+            }
+
+            return aggr;
+        }
+    });
+
+    /**
+     * <p>
+     * Creates a new object instance, based on a dynamically created custom class.
+     * The custom class is created from the main class passed in as the first parameter 
+     * along with the list of extension classes passed in
+     * as the second parameter using <a href="#method_build">Base.build</a> 
+     * with "dynamic" set to true. See the documentation for Base.build method 
+     * to see how the main class and extension classes are used.
+     * </p>
+     *
+     * <p>Any arguments following the 2nd argument are passed as arguments to the 
+     * constructor of the newly created class used to create the instance.</p>
+     * 
+     * @method create
+     * @static
+     *
+     * @param {Function} main The main class on which the instance it to be 
+     * based. This class will be extended to create the class for the custom instance
+     * @param {Array} extensions The list of extension classes used to augment the
+     * main class with.
+     * @param {Any*} args* 0..n arguments to pass to the constructor of the 
+     * newly created class, when creating the instance.
+     * @return {Object} An instance of the custom class
+     */
+    Base.create = function(main, extensions, args) {
+        var c = Base.build(main, extensions),
+            cArgs = Y.Array(arguments, 2, true);
+
+        function F(){}
+        F.prototype = c.prototype;
+
+        return c.apply(new F(), cArgs);
+    };
+
+    Base.prototype = {
+
+        /**
+         * Init lifecycle method, invoked during construction.
+         * Fires the init event prior to invoking initializers on
+         * the class hierarchy.
+         * 
+         * @method init
+         * @final
+         * @chainable
+         * @param {Object} config Object literal of configuration property name/value pairs
+         * @return {Base} A reference to this object
+         */
+        init: function(config) {
+
+            /**
+             * The name string to be used to identify 
+             * this instance of object. 
+             * @property name
+             * @type String
+             */
+            this.name = this.constructor.NAME;
+
+            /**
+             * <p>
+             * Lifecycle event for the init phase, fired prior to initialization. 
+             * Invoking the preventDefault method on the event object provided 
+             * to subscribers will prevent initialization from occuring.
+             * </p>
+             * <p>
+             * Subscribers to the "after" momemt of this event, will be notified
+             * after initialization of the object is complete (and therefore
+             * cannot prevent initialization).
+             * </p>
+             *
+             * @event init
+             * @preventable _defInitFn
+             * @param {Event.Facade} e Event object
+             * @param config Object literal of configuration name/value pairs
+             */
+            this.publish(INIT, {
+                queuable:false,
+                defaultFn:this._defInitFn
+            });
+            this.fire(INIT, null, config);
+
+            return this;
+        },
+
+        /**
+         * <p>
+         * Destroy lifecycle method. Fires the destroy
+         * event, prior to invoking destructors for the
+         * class hierarchy.
+         * </p>
+         * <p>
+         * Subscribers to the destroy
+         * event can invoke preventDefault on the event object, to prevent destruction
+         * from proceeding.
+         * </p>
+         * @method destroy
+         * @return {Base} A reference to this object
+         * @final
+         * @chainable
+         */
+        destroy: function() {
+
+            /**
+             * <p>
+             * Lifecycle event for the destroy phase, 
+             * fired prior to destruction. Invoking the preventDefault 
+             * method on the event object provided to subscribers will 
+             * prevent destruction from proceeding.
+             * </p>
+             * <p>
+             * Subscribers to the "after" moment of this event, will be notified
+             * after destruction is complete (and as a result cannot prevent
+             * destruction).
+             * </p>
+             * @event destroy
+             * @preventable _defDestroyFn
+             * @param {Event.Facade} e Event object
+             */
+            this.publish(DESTROY, {
+                queuable:false,
+                defaultFn: this._defDestroyFn
+            });
+            this.fire(DESTROY);
+            return this;
+        },
+
+        /**
+         * Default init event handler
+         *
+         * @method _defInitFn
+         * @param {Event.Facade} e Event object
+         * @param {Object} config Object literal of configuration property name/value pairs
+         * @protected
+         */
+        _defInitFn : function(e, config) {
+            _instances[Y.stamp(this)] = this;
+            this._initHierarchy(config);
+
+            this._set(INITIALIZED, true);
+        },
+
+        /**
+         * Default destroy event handler
+         *
+         * @method _defDestroyFn
+         * @param {Event.Facade} e Event object
+         * @protected
+         */
+        _defDestroyFn : function(e) {
+            this._destroyHierarchy();
+            delete _instances[this._yuid];
+
+            this._set(DESTROYED, true);
+        },
+
+        /**
+         * Returns the top down class hierarchy for this object,
+         * with Base being the first class in the array.
+         *
+         * @protected
+         * @return {Function[]} An Array of classes (constructor functions), making up the class heirarchy for this object
+         */
+        _getClasses : function() {
+            if (!this._classes) {
+                var c = this.constructor, 
+                    classes = [];
+
+                while (c && c.prototype) {
+                    classes.unshift(c);
+                    c = c.superclass ? c.superclass.constructor : null;
+                }
+                this._classes = classes;
+            }
+            return this._classes.concat();
+        },
+
+        /**
+         * Initializes the class hierarchy rooted at this base class,
+         * which includes initializing attributes for each class defined 
+         * in the class's static <a href="#property_ATTRS">ATTRS</a> property and invoking the initializer 
+         * method on the prototype of each class in the hierarchy.
+         * 
+         * @method _initHierarchy
+         * @param {Object} userConf Object literal containing attribute name/value pairs
+         * @private
+         */
+        _initHierarchy : function(userConf) {
+            var constr,
+                classes = this._getClasses();
+
+            for (var ci = 0, cl = classes.length; ci < cl; ci++) {
+                constr = classes[ci];
+
+                if (constr._yuibuild && constr._yuibuild.exts && !constr._yuibuild.dynamic) {
+                    for (var ei = 0, el = constr._yuibuild.exts.length; ei < el; ei++) {
+                        constr._yuibuild.exts[ei].apply(this, arguments);
+                    }
+                }
+
+                this._initAtts(constr.ATTRS, userConf);
+
+                if (O.owns(constr.prototype, INITIALIZER)) {
+                    constr.prototype[INITIALIZER].apply(this, arguments);
+                }
+            }
+        },
+
+        /**
+         * Destroys the class hierarchy rooted at this base class by invoking
+         * the descructor method on the prototype of each class in the hierarchy.
+         *
+         * @method _destroyHierarchy
+         * @private
+         */
+        _destroyHierarchy : function() {
+            var constr,
+                classes = this._getClasses();
+
+            for (var ci = classes.length-1; ci >= 0; ci--) {
+                constr = classes[ci];
+                if (O.owns(constr.prototype, DESTRUCTOR)) {
+                    constr.prototype[DESTRUCTOR].apply(this, arguments);
+                }
+            }
+        },
+
+        /**
+         * Default toString implementation. Provides the constructor NAME
+         * and the instance ID.
+         * 
+         * @method toString
+         * @return {String} String representation for this object
+         */
+        toString: function() {
+            return this.constructor.NAME + "[" + Y.stamp(this) + "]";
+        },
+
+        /**
+         * <p>
+         * Subscribe to a custom event hosted by this object.
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_subscribe">subscribe</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         * 
+         * @method subscribe
+         * @param {String} type The type of event to subscribe to. If 
+         * the type string does not contain a prefix ("prefix:eventType"), 
+         * the name property of the instance will be used as the default prefix.
+         * @param {Function} fn The subscribed callback function, invoked when the event is fired.
+         * @param {Object} context Optional execution context for the callback.
+         * @param {Any*} args* 0..n params to supply to the callback
+         * 
+         * @return {Event.Handle} An event handle which can be used to unsubscribe the subscribed callback.
+         */
+        subscribe : function() {
+            var a = arguments;
+            a[0] = this._prefixEvtType(a[0]);
+            return ETP.subscribe.apply(this, a);
+        },
+
+        /**
+         * <p>
+         * Fire a custom event by name.  The callback functions will be executed
+         * from the context specified when the event was created, and with the 
+         * following parameters.
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_fire">fire</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         * 
+         * @method fire
+         * @param {String|Object} type The type of the event, or an object that contains
+         * a 'type' property. If the type does not contain a prefix ("prefix:eventType"),
+         * the name property of the instance will be used as the default prefix.
+         * @param {Any*} args* 0..n Additional arguments to pass to subscribers.
+         * @return {boolean} The return value from Event Target's <a href="Event.Target.html#method_fire">fire</a> method.
+         *
+         */
+        fire : function() {
+            var a = arguments;
+            if (L.isString(a[0])) {
+                a[0] = this._prefixEvtType(a[0]);
+            } else if (a[0].type){
+                a[0].type = this._prefixEvtType(a[0].type);
+            }
+            return ETP.fire.apply(this, a);
+        },
+
+        /**
+         * <p>
+         * Creates a new custom event of the specified type.  If a custom event
+         * by that name already exists, it will not be re-created.  In either
+         * case the custom event is returned. 
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_publish">publish</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         *
+         * @method publish
+         * @param {String} type  The type, or name of the event. If the type does not 
+         * contain a prefix ("prefix:eventType"), the name property of the instance will 
+         * be used as the default prefix.
+         * @param {Object} opts Optional config params (see Event.Target <a href="Event.Target.html#method_publish">publish</a> for details)
+         * @return {Event.Custom} The published custom event object
+         */
+        publish : function() {
+            var a = arguments;
+            a[0] = this._prefixEvtType(a[0]);
+            return ETP.publish.apply(this, a);
+        },
+
+        /**
+         * <p>
+         * Subscribe to a custom event hosted by this object.  The
+         * supplied callback will execute <em>after</em> any listeners added
+         * via the subscribe method, and after the default function,
+         * if configured for the event, has executed.
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_after">after</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         * @method after
+         * @param {String} type The type of event to subscribe to. If 
+         * the type string does not contain a prefix ("prefix:eventType"), 
+         * the name property of the instance will be used as the default prefix.
+         * @param {Function} fn  The subscribed callback function
+         * @param {Object} context Optional execution context for the callback
+         * @param {Any*} args* 0..n params to supply to the callback
+         * @return {Event.Handle} Event handle which can be used to unsubscribe the subscribed callback.
+         */
+        after : function() {
+            var a = arguments;
+            a[0] = this._prefixEvtType(a[0]);
+            return ETP.after.apply(this, a);
+        },
+
+        /**
+         * <p>
+         * Unsubscribes one or more listeners the from the specified event.
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_unsubscribe">unsubscribe</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         * @method unsubscribe
+         * @param {String|Object} type Either the handle to the subscriber or the 
+         *                        type of event.  If the type
+         *                        is not specified, it will attempt to remove
+         *                        the listener from all hosted events. If 
+         *                        the type string does not contain a prefix 
+         *                        ("prefix:eventType"), the name property of the 
+         *                        instance will be used as the default prefix.
+         * @param {Function} fn The subscribed function to unsubscribe, if not
+         *                          supplied, all subscribers will be removed.
+         * @param {Object} context The custom object passed to subscribe.  This is
+         *                        optional, but if supplied will be used to
+         *                        disambiguate multiple listeners that are the same
+         *                        (e.g., you subscribe many object using a function
+         *                        that lives on the prototype)
+         * @return {boolean} true if the subscriber was found and detached.
+         */
+        unsubscribe: function(type, fn, context) {
+            var a = arguments;
+            if (L.isString(a[0])) {
+                a[0] = this._prefixEvtType(a[0]);
+            }
+            return ETP.unsubscribe.apply(this, a);
+        },
+
+        /**
+         * <p>
+         * Removes all listeners from the specified event.  If the event type
+         * is not specified, all listeners from all hosted custom events will
+         * be removed.
+         * </p>
+         * <p>
+         * Overrides Event.Target's <a href="Event.Target.html#method_unsubscribeAll">unsubscribeAll</a> method, to add the name prefix 
+         * of the instance to the event type, if absent.
+         * </p>
+         * @method unsubscribeAll
+         * @param {String} type The type, or name of the event. If 
+         * the type string does not contain a prefix ("prefix:eventType"), 
+         * the name property of the instance will be used as the default prefix
+         * @return {int} The number of listeners unsubscribed
+         */
+        unsubscribeAll: function(type) {
+            var a = arguments;
+            a[0] = this._prefixEvtType(a[0]);
+            return ETP.unsubscribeAll.apply(this, a);
+        },
+
+        /**
+         * Utility method to prefix the event name with the
+         * name property of the instance, if absent
+         *
+         * @method _prefixEvtType
+         * @private
+         * @param {String} type The event name
+         * @return {String} The prefixed event name
+         */
+        _prefixEvtType: function(type) {
+            if (type.indexOf(SEP) === -1 && this.name) {
+               type = this.name + ":" + type;
+            }
+            return type;
+        }
+    };
+
+    Y.mix(Base, Y.Attribute, false, null, 1);
+
+    Base.prototype.constructor = Base;
+    Y.Base = Base;
+
+
+
+}, '3.0.0pr2' ,{requires:['attribute']});

=== added directory 'loggerhead/static/javascript/yui/build/classnamemanager'
=== added file 'loggerhead/static/javascript/yui/build/classnamemanager/classnamemanager-debug.js'
--- loggerhead/static/javascript/yui/build/classnamemanager/classnamemanager-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/classnamemanager/classnamemanager-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,92 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('classnamemanager', function(Y) {
+
+/**
+* Contains a singleton (ClassNameManager) that enables easy creation and caching of 
+* prefixed class names.
+* @module classnamemanager
+*/
+
+/**
+ * A singleton class providing: 
+ * 
+ * <ul>
+ *    <li>Easy creation of prefixed class names</li>
+ *    <li>Caching of previously created class names for improved performance.</li>
+ * </ul>
+ * 
+ * @class ClassNameManager
+ * @static 
+ */
+
+// String constants
+var CLASS_NAME_PREFIX = 'classNamePrefix',
+	CLASS_NAME_DELIMITER = 'classNameDelimiter';
+
+
+// Global config
+
+/**
+ * Configuration property indicating the prefix for all CSS class names in this YUI instance.
+ *
+ * @property Y.config.classNamePrefix
+ * @type {String}
+ * @default "yui"
+ * @static
+ */
+Y.config[CLASS_NAME_PREFIX] = Y.config[CLASS_NAME_PREFIX] || 'yui';
+
+
+/**
+ * Configuration property indicating the delimiter used to compose all CSS class names in
+ * this YUI instance.
+ *
+ * @property Y.config.classNameDelimiter
+ * @type {String}
+ * @default "-"
+ * @static
+ */
+Y.config[CLASS_NAME_DELIMITER] = Y.config[CLASS_NAME_DELIMITER] || '-';
+
+
+Y.ClassNameManager = function () {
+
+	var sPrefix = Y.config[CLASS_NAME_PREFIX],
+		sDelimiter = Y.config[CLASS_NAME_DELIMITER],
+		classNames = {};
+
+	return {
+
+		/**
+		 * Returns a class name prefixed with the the value of the 
+		 * <code>Y.config.classNamePrefix</code> attribute + the provided strings.
+		 * Uses the <code>Y.config.classNameDelimiter</code> attribute to delimit the 
+		 * provided strings. E.g. Y.ClassNameManager.getClassName('foo','bar'); // yui-foo-bar
+		 * 
+		 * 
+		 * @method getClassName
+		 * @param {String}+ one or more classname bits to be joined and prefixed
+		 */
+		getClassName: function (c,x) {
+	
+			// Test for multiple classname bits
+			if (x) {
+				c = Y.Array(arguments,0,true).join(sDelimiter);
+			}
+		
+			// memoize in classNames map
+			return classNames[c] || (classNames[c] = sPrefix + sDelimiter + c);
+	
+		}
+	
+	};
+
+}();
+
+
+}, '3.0.0pr2' );

=== added file 'loggerhead/static/javascript/yui/build/classnamemanager/classnamemanager-min.js'
--- loggerhead/static/javascript/yui/build/classnamemanager/classnamemanager-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/classnamemanager/classnamemanager-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("classnamemanager",function(B){var A="classNamePrefix",C="classNameDelimiter";B.config[A]=B.config[A]||"yui";B.config[C]=B.config[C]||"-";B.ClassNameManager=function(){var D=B.config[A],F=B.config[C],E={};return{getClassName:function(H,G){if(G){H=B.Array(arguments,0,true).join(F);}return E[H]||(E[H]=D+F+H);}};}();},"3.0.0pr2");
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/classnamemanager/classnamemanager.js'
--- loggerhead/static/javascript/yui/build/classnamemanager/classnamemanager.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/classnamemanager/classnamemanager.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,92 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('classnamemanager', function(Y) {
+
+/**
+* Contains a singleton (ClassNameManager) that enables easy creation and caching of 
+* prefixed class names.
+* @module classnamemanager
+*/
+
+/**
+ * A singleton class providing: 
+ * 
+ * <ul>
+ *    <li>Easy creation of prefixed class names</li>
+ *    <li>Caching of previously created class names for improved performance.</li>
+ * </ul>
+ * 
+ * @class ClassNameManager
+ * @static 
+ */
+
+// String constants
+var CLASS_NAME_PREFIX = 'classNamePrefix',
+	CLASS_NAME_DELIMITER = 'classNameDelimiter';
+
+
+// Global config
+
+/**
+ * Configuration property indicating the prefix for all CSS class names in this YUI instance.
+ *
+ * @property Y.config.classNamePrefix
+ * @type {String}
+ * @default "yui"
+ * @static
+ */
+Y.config[CLASS_NAME_PREFIX] = Y.config[CLASS_NAME_PREFIX] || 'yui';
+
+
+/**
+ * Configuration property indicating the delimiter used to compose all CSS class names in
+ * this YUI instance.
+ *
+ * @property Y.config.classNameDelimiter
+ * @type {String}
+ * @default "-"
+ * @static
+ */
+Y.config[CLASS_NAME_DELIMITER] = Y.config[CLASS_NAME_DELIMITER] || '-';
+
+
+Y.ClassNameManager = function () {
+
+	var sPrefix = Y.config[CLASS_NAME_PREFIX],
+		sDelimiter = Y.config[CLASS_NAME_DELIMITER],
+		classNames = {};
+
+	return {
+
+		/**
+		 * Returns a class name prefixed with the the value of the 
+		 * <code>Y.config.classNamePrefix</code> attribute + the provided strings.
+		 * Uses the <code>Y.config.classNameDelimiter</code> attribute to delimit the 
+		 * provided strings. E.g. Y.ClassNameManager.getClassName('foo','bar'); // yui-foo-bar
+		 * 
+		 * 
+		 * @method getClassName
+		 * @param {String}+ one or more classname bits to be joined and prefixed
+		 */
+		getClassName: function (c,x) {
+	
+			// Test for multiple classname bits
+			if (x) {
+				c = Y.Array(arguments,0,true).join(sDelimiter);
+			}
+		
+			// memoize in classNames map
+			return classNames[c] || (classNames[c] = sPrefix + sDelimiter + c);
+	
+		}
+	
+	};
+
+}();
+
+
+}, '3.0.0pr2' );

=== added directory 'loggerhead/static/javascript/yui/build/console'
=== added file 'loggerhead/static/javascript/yui/build/console/README'
--- loggerhead/static/javascript/yui/build/console/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/console/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,5 @@
+The Console tool
+    The Console tool creates a cross browser display to read log messages emitted by the YUI logging subsystem.
+
+3.0.0pr2
+    Initial release

=== added directory 'loggerhead/static/javascript/yui/build/console/assets'
=== added file 'loggerhead/static/javascript/yui/build/console/assets/console-core.css'
--- loggerhead/static/javascript/yui/build/console/assets/console-core.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/console/assets/console-core.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-console-hidden { display: none; }

=== added directory 'loggerhead/static/javascript/yui/build/console/assets/skins'
=== added directory 'loggerhead/static/javascript/yui/build/console/assets/skins/sam'
=== added file 'loggerhead/static/javascript/yui/build/console/assets/skins/sam/bg.png'
Binary files loggerhead/static/javascript/yui/build/console/assets/skins/sam/bg.png and loggerhead/static/javascript/yui/build/console/assets/skins/sam/bg.png differ
=== added file 'loggerhead/static/javascript/yui/build/console/assets/skins/sam/console-skin.css'
--- loggerhead/static/javascript/yui/build/console/assets/skins/sam/console-skin.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/console/assets/skins/sam/console-skin.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,99 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-skin-sam .yui-console {
+    position:absolute;
+    right:1em;
+    top:1em;
+    z-index:50;
+}
+
+.yui-skin-sam .yui-console-content {
+    border: 1px solid #777;
+    color:#000;
+    font: normal 13px/1.3 Arial, sans-serif;
+    position: relative;
+    text-align:left;
+    width:27em;
+}
+
+.yui-skin-sam .yui-console-hd,
+.yui-skin-sam .yui-console-controls {
+    background: #D8D8DA url(bg.png) repeat-x 0 0;
+    height: 2em;
+    line-height: 2em;
+    padding: 0 1ex;
+}
+.yui-skin-sam .yui-console-title {
+    font-size: 100%;
+    line-height: 2em;
+    margin: 0;
+}
+.yui-skin-sam .yui-console-controls input,
+.yui-skin-sam .yui-console-controls label {
+    height: 2em;
+    vertical-align: middle;
+    zoom: 1;
+}
+.yui-skin-sam .yui-console-button {
+    background: #D8D8DA url(bg.png) repeat-x 0 0;
+    border: none;
+    border-left: 1px solid #777;
+    padding: 0 .25em;
+    position: absolute;
+    right: 0;
+}
+.yui-skin-sam .yui-console-bd {
+    background: #fff;
+    border-top: 1px solid #777;
+    border-bottom: 1px solid #777;
+    height: 20em;
+    overflow: auto;
+    width: 100%;
+}
+.yui-skin-sam .yui-console-hd .yui-console-controls {
+    position: absolute;
+    right: 0;
+}
+
+/* Log entries */
+.yui-skin-sam .yui-console-entry {
+    border-bottom: 1px dotted #aaa;
+    margin: 0;
+    padding: 0 0 1ex;
+}
+
+.yui-skin-sam .yui-console-entry p {
+    margin: 0;
+}
+.yui-skin-sam .yui-console-entry .yui-console-entry-src {
+    margin: 0 0 0 1ex;
+}
+.yui-skin-sam .yui-console-entry .yui-console-entry-content {
+    margin: 1ex 0 1ex 1ex;
+}
+
+.yui-skin-sam .yui-console-entry-meta {
+    font-family: Arial, sans-serif;
+}
+.yui-skin-sam .yui-console-entry-cat {
+    text-transform: uppercase;
+    padding: 1px 4px;
+    background-color: #ccc;
+}
+.yui-skin-sam .yui-console-entry-src {
+    font-style: italic;
+}
+.yui-skin-sam .yui-console-entry-info .yui-console-entry-cat {
+    background-color: #ac2;
+}
+.yui-skin-sam .yui-console-entry-warn .yui-console-entry-cat {
+    background-color: #e81;
+}
+.yui-skin-sam .yui-console-entry-error .yui-console-entry-cat {
+    background-color: #b00;
+    color: #fff;
+}

=== added file 'loggerhead/static/javascript/yui/build/console/assets/skins/sam/console.css'
--- loggerhead/static/javascript/yui/build/console/assets/skins/sam/console.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/console/assets/skins/sam/console.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-console-hidden{display:none;}.yui-skin-sam .yui-console{position:absolute;right:1em;top:1em;z-index:50;}.yui-skin-sam .yui-console-content{border:1px solid #777;color:#000;font:normal 13px/1.3 Arial,sans-serif;position:relative;text-align:left;width:27em;}.yui-skin-sam .yui-console-hd,.yui-skin-sam .yui-console-controls{background:#D8D8DA url(bg.png) repeat-x 0 0;height:2em;line-height:2em;padding:0 1ex;}.yui-skin-sam .yui-console-title{font-size:100%;line-height:2em;margin:0;}.yui-skin-sam .yui-console-controls input,.yui-skin-sam .yui-console-controls label{height:2em;vertical-align:middle;zoom:1;}.yui-skin-sam .yui-console-button{background:#D8D8DA url(bg.png) repeat-x 0 0;border:none;border-left:1px solid #777;padding:0 .25em;position:absolute;right:0;}.yui-skin-sam .yui-console-bd{background:#fff;border-top:1px solid #777;border-bottom:1px solid #777;height:20em;overflow:auto;width:100%;}.yui-skin-sam .yui-console-hd .yui-console-controls{position:absolute;right:0;}.yui-skin-sam .yui-console-entry{border-bottom:1px dotted #aaa;margin:0;padding:0 0 1ex;}.yui-skin-sam .yui-console-entry p{margin:0;}.yui-skin-sam .yui-console-entry .yui-console-entry-src{margin:0 0 0 1ex;}.yui-skin-sam .yui-console-entry .yui-console-entry-content{margin:1ex 0 1ex 1ex;}.yui-skin-sam .yui-console-entry-meta{font-family:Arial,sans-serif;}.yui-skin-sam .yui-console-entry-cat{text-transform:uppercase;padding:1px 4px;background-color:#ccc;}.yui-skin-sam .yui-console-entry-src{font-style:italic;}.yui-skin-sam .yui-console-entry-info .yui-console-entry-cat{background-color:#ac2;}.yui-skin-sam .yui-console-entry-warn .yui-console-entry-cat{background-color:#e81;}.yui-skin-sam .yui-console-entry-error .yui-console-entry-cat{background-color:#b00;color:#fff;}

=== added file 'loggerhead/static/javascript/yui/build/console/console-debug.js'
--- loggerhead/static/javascript/yui/build/console/console-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/console/console-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1151 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('console', function(Y) {
+
+/**
+ * A user interface for viewing log messages.
+ *
+ * @module console
+ */
+
+var getCN = Y.ClassNameManager.getClassName,
+    CONSOLE        = 'console',
+    ENTRY          = 'entry',
+    RESET          = 'reset',
+    CHECKED        = 'checked',
+    TITLE          = 'title',
+    PAUSE          = 'pause',
+    PAUSED         = 'paused',
+    CLEAR          = 'clear',
+    INFO           = 'info',
+    WARN           = 'warn',
+    ERROR          = 'error',
+    INNER_HTML     = 'innerHTML',
+    CLICK          = 'click',
+    CONTENT_BOX    = 'contentBox',
+    DISABLED       = 'disabled',
+    START_TIME     = 'startTime',
+    LAST_TIME      = 'lastTime',
+    ENTRY_TEMPLATE = 'entryTemplate',
+    RENDERED       = 'rendered',
+
+    DOT = '.',
+
+    C_ENTRY            = getCN(CONSOLE,ENTRY),
+    C_PAUSE            = getCN(CONSOLE,PAUSE),
+    C_CHECKBOX         = getCN(CONSOLE,'checkbox'),
+    C_BUTTON           = getCN(CONSOLE,'button'),
+    C_CLEAR            = getCN(CONSOLE,CLEAR),
+    C_PAUSE_LABEL      = getCN(CONSOLE,PAUSE,'label'),
+    C_ENTRY_META       = getCN(CONSOLE,ENTRY,'meta'),
+    C_ENTRY_CAT        = getCN(CONSOLE,ENTRY,'cat'),
+    C_ENTRY_SRC        = getCN(CONSOLE,ENTRY,'src'),
+    C_ENTRY_TIME       = getCN(CONSOLE,ENTRY,'time'),
+    C_ENTRY_CONTENT    = getCN(CONSOLE,ENTRY,'content'),
+    C_CONSOLE_HD       = getCN(CONSOLE,'hd'),
+    C_CONSOLE_BD       = getCN(CONSOLE,'bd'),
+    C_CONSOLE_FT       = getCN(CONSOLE,'ft'),
+    C_CONSOLE_CONTROLS = getCN(CONSOLE,'controls'),
+    C_CONSOLE_TITLE    = getCN(CONSOLE,TITLE),
+
+    RE_INLINE_SOURCE = /^(\S+)\s/,
+    RE_AMP = /&/g,
+    RE_LT  = /</g,
+    RE_GT  = />/g,
+
+    ESC_AMP = '&#38;',
+    ESC_LT  = '&#60;',
+    ESC_GT  = '&#62;',
+    
+    L = Y.Lang,
+    isString   = L.isString,
+    isNumber   = L.isNumber,
+    isObject   = L.isObject,
+    merge      = Y.merge,
+    substitute = Y.substitute,
+    create     = Y.Node.create;
+    
+/**
+ * Console creates a visualization for messages logged through calls to a YUI
+ * instance's <code>Y.log( message, category, source )</code> method.  The
+ * debug versions of YUI modules will include logging statements to offer some
+ * insight into the steps executed during that module's operation.  Including
+ * log statements in your code will cause those messages to also appear in the
+ * Console.  Use Console to aid in developing your page or application.
+ *
+ * Entry categories are also referred to as the log level, and entries are
+ * filtered against the configured logLevel.
+ *
+ * @class Console
+ * @extends Widget
+ */
+
+function Console() {
+    Console.superclass.constructor.apply(this,arguments);
+}
+
+Y.mix(Console, {
+
+    /**
+     * The identity of the widget.
+     *
+     * @property Console.NAME
+     * @type String
+     * @static
+     */
+    NAME : CONSOLE,
+
+    /**
+     * Static identifier for logLevel configuration setting to allow all
+     * incoming messages to generate Console entries.
+     *
+     * @property Console.LOG_LEVEL_INFO
+     * @type Number
+     * @static
+     */
+    LOG_LEVEL_INFO  : 3,
+
+    /**
+     * Static identifier for logLevel configuration setting to allow only
+     * incoming messages of logLevel &quot;warn&quot; or &quot;error&quot;
+     * to generate Console entries.
+     *
+     * @property Console.LOG_LEVEL_WARN
+     * @type Number
+     * @static
+     */
+    LOG_LEVEL_WARN  : 2,
+
+    /**
+     * Static identifier for logLevel configuration setting to allow only
+     * incoming messages of logLevel &quot;error&quot; to generate
+     * Console entries.
+     *
+     * @property Console.LOG_LEVEL_ERROR
+     * @type Number
+     * @static
+     */
+    LOG_LEVEL_ERROR : 1,
+
+    /**
+     * Map (object) of classNames used to populate the placeholders in the
+     * Console.ENTRY_TEMPLATE markup when rendering a new Console entry.
+     *
+     * <p>By default, the keys contained in the object are:</p>
+     * <ul>
+     *    <li>entry_class</li>
+     *    <li>entry_meta_class</li>
+     *    <li>entry_cat_class</li>
+     *    <li>entry_src_class</li>
+     *    <li>entry_time_class</li>
+     *    <li>entry_content_class</li>
+     * </ul>
+     *
+     * @property Console.ENTRY_CLASSES
+     * @type Object
+     * @static
+     */
+    ENTRY_CLASSES   : {
+        entry_class         : C_ENTRY,
+        entry_meta_class    : C_ENTRY_META,
+        entry_cat_class     : C_ENTRY_CAT,
+        entry_src_class     : C_ENTRY_SRC,
+        entry_time_class    : C_ENTRY_TIME,
+        entry_content_class : C_ENTRY_CONTENT
+    },
+
+    /**
+     * Map (object) of classNames used to populate the placeholders in the
+     * Console.HEADER_TEMPLATE, Console.BODY_TEMPLATE, and
+     * Console.FOOTER_TEMPLATE markup when rendering the Console UI.
+     *
+     * <p>By default, the keys contained in the object are:</p>
+     * <ul>
+     *   <li>console_hd_class</li>
+     *   <li>console_bd_class</li>
+     *   <li>console_ft_class</li>
+     *   <li>console_controls_class</li>
+     *   <li>console_checkbox_class</li>
+     *   <li>console_pause_class</li>
+     *   <li>console_pause_label_class</li>
+     *   <li>console_button_class</li>
+     *   <li>console_clear_class</li>
+     *   <li>console_title_class</li>
+     * </ul>
+     *
+     * @property Console.CHROME_CLASSES
+     * @type Object
+     * @static
+     */
+    CHROME_CLASSES  : {
+        console_hd_class       : C_CONSOLE_HD,
+        console_bd_class       : C_CONSOLE_BD,
+        console_ft_class       : C_CONSOLE_FT,
+        console_controls_class : C_CONSOLE_CONTROLS,
+        console_checkbox_class : C_CHECKBOX,
+        console_pause_class    : C_PAUSE,
+        console_pause_label_class : C_PAUSE_LABEL,
+        console_button_class   : C_BUTTON,
+        console_clear_class    : C_CLEAR,
+        console_title_class    : C_CONSOLE_TITLE
+    },
+
+    /**
+     * Markup template used to generate the DOM structure for the header
+     * section of the Console when it is rendered.  The template includes
+     * these {placeholder}s:
+     *
+     * <ul>
+     *   <li>console_hd_class - contributed by Console.CHROME_CLASSES</li>
+     *   <li>console_title_class - contributed by Console.CHROME_CLASSES</li>
+     *   <li>str_title - pulled from attribute strings.title</li>
+     * </ul>
+     *
+     * @property Console.HEADER_TEMPLATE
+     * @type String
+     * @static
+     */
+    HEADER_TEMPLATE :
+        '<div class="{console_hd_class}">'+
+            '<h4 class="{console_title_class}">{str_title}</h4>'+
+        '</div>',
+
+    /**
+     * Markup template used to generate the DOM structure for the Console body
+     * (where the messages are inserted) when it is rendered.  The template
+     * includes only the {placeholder} &quot;console_bd_class&quot;, which is
+     * constributed by Console.CHROME_CLASSES.
+     *
+     * @property Console.BODY_TEMPLATE
+     * @type String
+     * @static
+     */
+    BODY_TEMPLATE : '<div class="{console_bd_class}"></div>',
+
+    /**
+     * Markup template used to generate the DOM structure for the footer
+     * section of the Console when it is rendered.  The template includes
+     * many of the {placeholder}s from Console.CHROME_CLASSES as well as:
+     *
+     * <ul>
+     *   <li>id_guid - generated unique id, relates the label and checkbox</li>
+     *   <li>str_pause - pulled from attribute strings.pause</li>
+     *   <li>str_clear - pulled from attribute strings.clear</li>
+     * </ul>
+     *
+     * @property Console.HEADER_TEMPLATE
+     * @type String
+     * @static
+     */
+    FOOTER_TEMPLATE :
+        '<div class="{console_ft_class}">'+
+            '<div class="{console_controls_class}">'+
+                '<input type="checkbox" class="{console_checkbox_class} '+
+                        '{console_pause_class}" value="1" id="{id_guid}"> '+
+                '<label for="{id_guid}" class="{console_pause_label_class}">'+
+                    '{str_pause}</label>' +
+                '<input type="button" class="'+
+                    '{console_button_class} {console_clear_class}" '+
+                    'value="{str_clear}">'+
+            '</div>'+
+        '</div>',
+
+    /**
+     * Default markup template used to create the DOM structure for Console
+     * entries. The markup contains {placeholder}s for content and classes
+     * that are replaced via Y.substitute.  The default template contains
+     * the {placeholder}s identified in Console.ENTRY_CLASSES as well as the
+     * following placeholders that will be populated by the log entry data:
+     *
+     * <ul>
+     *   <li>cat_class</li>
+     *   <li>src_class</li>
+     *   <li>label</li>
+     *   <li>totalTime</li>
+     *   <li>elapsedTime</li>
+     *   <li>localTime</li>
+     *   <li>sourceAndDetail</li>
+     *   <li>message</li>
+     * </ul>
+     *
+     * @property Console.ENTRY_TEMPLATE
+     * @type String
+     * @static
+     */
+    ENTRY_TEMPLATE :
+        '<pre class="{entry_class} {cat_class} {src_class}">'+
+            '<div class="{entry_meta_class}">'+
+                '<p>'+
+                    '<span class="{entry_cat_class}">'+
+                        '{label}</span>'+
+                    '<span class="{entry_time_class}">'+
+                        ' {totalTime}ms (+{elapsedTime}) {localTime}:'+
+                    '</span>'+
+                '</p>'+
+                '<p class="{entry_src_class}">'+
+                    '{sourceAndDetail}'+
+                '</p>'+
+            '</div>'+
+            '<p class="{entry_content_class}">{message}</p>'+
+        '</pre>',
+
+    /**
+     * Static property used to define the default attribute configuration of
+     * the Widget.
+     *
+     * @property Console.ATTRS
+     * @Type Object
+     * @static
+     */
+    ATTRS : {
+
+        /**
+         * Name of the custom event that will communicate log messages.
+         *
+         * @attribute logEvent
+         * @type String
+         * @default "yui:log"
+         */
+        logEvent : {
+            value : 'yui:log',
+            writeOnce : true,
+            validator : isString
+        },
+
+        /**
+         * Collection of strings used to label elements in the Console UI.
+         * Default collection contains the following name:value pairs:
+         *
+         * <ul>
+         *   <li>title : &quot;Log Console&quot;</li>
+         *   <li>pause : &quot;Pause&quot;</li>
+         *   <li>clear : &quot;Clear&quot;</li>
+         * </ul>
+         *
+         * @attribute strings
+         * @type Object
+         */
+        strings : {
+            value : {
+                title : "Log Console",
+                pause : "Pause",
+                clear : "Clear"
+            }
+        },
+
+        /**
+         * Boolean to pause the outputting of new messages to the console.
+         * When paused, messages will accumulate in the buffer.
+         *
+         * @attribute paused
+         * @type boolean
+         * @default false
+         */
+        paused : {
+            value : false,
+            validator : L.isBoolean
+        },
+
+        /**
+         * If a category is not specified in the Y.log(..) statement, this
+         * category will be used. Category is also called &quot;log level&quot;.
+         *
+         * @attribute defaultCategory
+         * @type String
+         * @default "info"
+         */
+        defaultCategory : {
+            value : INFO,
+            validator : isString
+        },
+
+        /**
+         * If a source is not specified in the Y.log(..) statement, this
+         * source will be used.
+         *
+         * @attribute defaultSource
+         * @type String
+         * @default "global"
+         */
+        defaultSource   : {
+            value : 'global',
+            validator : isString
+        },
+
+        /**
+         * Markup template used to create the DOM structure for Console entries.
+         *
+         * @attribute entryTemplate
+         * @type String
+         * @default (see Console.ENTRY_TEMPLATE)
+         */
+        entryTemplate : {
+            value : '',
+            validator : isString
+        },
+
+        /**
+         * Minimum entry log level to render into the Console.  The initial
+         * logLevel value for all Console instances defaults from the
+         * Y.config.logLevel YUI configuration, or Console.LOG_LEVEL_INFO if
+         * that configuration is not set.
+         *
+         * Possible values are &quot;info&quot;, &quot;warn&quot;,
+         * &quot;error&quot; (case insensitive), or the corresponding statics
+         * Console.LOG_LEVEL_INFO and so on.
+         *
+         * @attribute logLevel
+         * @type String|Number
+         * @default Y.config.logLevel or Console.LOG_LEVEL_INFO
+         */
+        logLevel : {
+            value : Y.config.logLevel,
+            validator : function (v) {
+                return this._validateNewLogLevel(v);
+            },
+            set : function (v) {
+                return this._setLogLevel(v);
+            }
+        },
+
+        /**
+         * Millisecond timeout to maintain before emptying buffer of Console
+         * entries to the UI.
+         *
+         * @attribute printTimeout
+         * @type Number
+         * @default 100
+         */
+        printTimeout : {
+            value : 100,
+            validator : isNumber
+        },
+
+        /**
+         * Maximum number of Console entries allowed in the Console body at one
+         * time.  This is used to keep acquired messages from exploding the
+         * DOM tree and impacting page performance.
+         *
+         * @attribute consoleLimit
+         * @type Number
+         * @default 500
+         */
+        consoleLimit : {
+            value : 500,
+            validator : isNumber
+        },
+
+        /**
+         * New entries should display at the top of the Console or the bottom?
+         *
+         * @attribute newestOnTop
+         * @type Boolean
+         * @default true
+         */
+        newestOnTop : {
+            value : true
+        },
+
+        /**
+         * When new entries are added to the Console UI, should they be
+         * scrolled into view?
+         *
+         * @attribute scrollIntoView
+         * @type Boolean
+         * @default true
+         */
+        scrollIntoView : {
+            value : true
+        },
+
+        /**
+         * The baseline time for this Console instance, used to measure elapsed
+         * time from the moment the console module is <code>use</code>d to the
+         * moment each new entry is logged (not rendered).
+         *
+         * This value is reset by the instance method myConsole.reset().
+         *
+         * @attribute startTime
+         * @type Date
+         * @default The moment the console module is <code>use</code>d
+         */
+        startTime : {
+            value : new Date()
+        },
+
+        /**
+         * The precise time the last entry was logged.  Used to measure elapsed
+         * time between log messages.
+         *
+         * @attribute lastTime
+         * @type Date
+         * @default The moment the console module is <code>use</code>d
+         */
+        lastTime : {
+            value : new Date(),
+            readOnly: true
+        }
+
+    }
+
+});
+
+Y.extend(Console,Y.Widget,{
+
+    /**
+     * Reference to the Node instance containing the head contents.
+     *
+     * @property _head
+     * @type Node
+     * @default null
+     * @protected
+     */
+    _head    : null,
+
+    /**
+     * Reference to the Node instance that will house the console messages.
+     *
+     * @property _body
+     * @type Node
+     * @default null
+     * @protected
+     */
+    _body    : null,
+
+    /**
+     * Reference to the Node instance containing the footer contents.
+     *
+     * @property _head
+     * @type Node
+     * @default null
+     * @protected
+     */
+    _foot    : null,
+
+    /**
+     * Object API returned from <code>Y.later</code>. Holds the timer id
+     * returned by <code>setTimout</code> for scheduling of buffered messages.
+     *
+     * @property _timeout
+     * @type Object
+     * @default null
+     * @protected
+     */
+    _timeout : null,
+
+    /**
+     * Array of normalized message objects awaiting printing.
+     *
+     * @property buffer
+     * @type Array
+     * @default null
+     */
+    buffer   : null,
+
+    /**
+     * Wrapper for <code>Y.log</code>.
+     *
+     * @method log
+     * @param {Any*} * (all arguments passed through to <code>Y.log</code>)
+     */
+    log : function () {
+        return Y.log.apply(Y,arguments);
+    },
+
+    /**
+     * Clear the console of messages and flush the buffer of pending messages.
+     *
+     * @method clearConsole
+     * @chainable
+     */
+    clearConsole : function () {
+        // TODO: clear event listeners from console contents
+        this._body.set(INNER_HTML,'');
+
+        this._clearTimeout();
+
+        this.buffer = [];
+
+        return this;
+    },
+
+    /**
+     * Clears the console and resets internal timers.
+     *
+     * @method reset
+     * @chainable
+     */
+    reset : function () {
+        this.fire(RESET);
+        
+        return this;
+    },
+
+    /**
+     * Outputs all buffered messages to the console UI.
+     * 
+     * @method printBuffer
+     * @chainable
+     */
+    printBuffer: function () {
+        if (!this.get(PAUSED) && this.get('rendered')) {
+
+            this._clearTimeout();
+
+            var messages = this.buffer,
+                i,len;
+
+            this.buffer = [];
+
+            // TODO: use doc frag
+            for (i = 0, len = messages.length; i < len; ++i) {
+                this.printLogEntry(messages[i]);
+            }
+
+            this._trimOldEntries();
+        }
+
+        return this;
+    },
+
+    /**
+     * Prints the provided message to the console UI.
+     *
+     * @method printLogEntry
+     * @param m {Object} Normalized message object
+     * @chainable
+     */
+    printLogEntry : function (m) {
+        m = merge(
+                this._htmlEscapeMessage(m),
+                Console.ENTRY_CLASSES,
+                {
+                    cat_class : this.getClassName(ENTRY,m.category),
+                    src_class : this.getClassName(ENTRY,m.source)
+                });
+
+        var n = create(substitute(this.get('entryTemplate'),m));
+
+        this._addToConsole(n);
+
+        return this;
+    },
+
+    
+    /**
+     * Constructor code.  Set up the buffer and entry template, publish
+     * internal events, and subscribe to the configured logEvent.
+     * 
+     * @method initializer
+     * @protected
+     */
+    initializer : function () {
+        this.buffer    = [];
+
+        if (!this.get(ENTRY_TEMPLATE)) {
+            this.set(ENTRY_TEMPLATE,Console.ENTRY_TEMPLATE);
+        }
+
+        Y.on(this.get('logEvent'),Y.bind(this._onLogEvent,this));
+
+        /**
+         * Triggers the processing of an incoming message via the default logic
+         * in _defEntryFn.
+         *
+         * @event entry
+         * @param event {Event.Facade} An Event Facade object with the following attribute specific properties added:
+         *  <dl>
+         *      <dt>message</dt>
+         *          <dd>The message data normalized into an object literal (see _normalizeMessage)</dd>
+         *  </dl>
+         * @preventable _defEntryFn
+         */
+        this.publish(ENTRY, { defaultFn: this._defEntryFn });
+
+        /**
+         * Triggers the reset behavior via the default logic in _defResetFn.
+         *
+         * @event reset
+         * @param event {Event.Facade} Event Facade object
+         * @preventable _defResetFn
+         */
+        this.publish(RESET, { defaultFn: this._defResetFn });
+    },
+
+    /**
+     * Generate the Console UI.
+     *
+     * @method renderUI
+     * @protected
+     */
+    renderUI : function () {
+        this._initHead();
+        this._initConsole();
+        this._initFoot();
+    },
+
+    /**
+     * Sync the UI state to the current attribute state.
+     *
+     * @method syncUI
+     */
+    syncUI : function () {
+        this.set(PAUSED,this.get(PAUSED));
+    },
+
+    /**
+     * Set up event listeners to wire up the UI to the internal state.
+     *
+     * @method bindUI
+     * @protected
+     */
+    bindUI : function () {
+        this.get(CONTENT_BOX).query('input[type=checkbox].'+C_PAUSE).
+            on(CLICK,this._onPauseClick,this);
+
+        this.get(CONTENT_BOX).query('input[type=button].'+C_CLEAR).
+            on(CLICK,this._onClearClick,this);
+        
+        // Attribute changes
+        this.after('stringsChange',       this._afterStringsChange);
+        this.after('pausedChange',        this._afterPausedChange);
+        this.after('consoleLimitChange',  this._afterConsoleLimitChange);
+    },
+
+    
+    /**
+     * Create the DOM structure for the header elements.
+     *
+     * @method _initHead
+     * @protected
+     */
+    _initHead : function () {
+        var cb   = this.get(CONTENT_BOX),
+            info = merge(Console.CHROME_CLASSES, {
+                        str_title : this.get('strings.title')
+                    });
+
+        this._head = create(substitute(Console.HEADER_TEMPLATE,info));
+
+        cb.insertBefore(this._head,cb.get('firstChild'));
+    },
+
+    /**
+     * Create the DOM structure for the console body&#8212;where messages are
+     * rendered.
+     *
+     * @method _initConsole
+     * @protected
+     */
+    _initConsole : function () {
+        this._body = create(substitute(
+                            Console.BODY_TEMPLATE,
+                            Console.CHROME_CLASSES));
+
+        this.get(CONTENT_BOX).appendChild(this._body);
+    },
+
+    /**
+     * Create the DOM structure for the footer elements.
+     *
+     * @method _initFoot
+     * @protected
+     */
+    _initFoot : function () {
+        var info = merge(Console.CHROME_CLASSES, {
+                id_guid   : Y.guid(),
+                str_pause : this.get('strings.pause'),
+                str_clear : this.get('strings.clear')
+            });
+
+        this._foot = create(substitute(Console.FOOTER_TEMPLATE,info));
+
+        this.get(CONTENT_BOX).appendChild(this._foot);
+    },
+
+    /**
+     * Determine if incoming log messages are within the configured logLevel
+     * to be buffered for printing.
+     *
+     * @method _isInLogLevel
+     * @protected
+     */
+    _isInLogLevel : function (msg,cat) {
+        var lvl = this.get('logLevel'),
+            mlvl = cat === ERROR ? Console.LOG_LEVEL_ERROR :
+                    cat === WARN ? Console.LOG_LEVEL_WARN  :
+                                   Console.LOG_LEVEL_INFO;
+
+        return lvl >= mlvl;
+    },
+
+    /**
+     * Create a log entry message from the inputs including the following keys:
+     * <ul>
+     *     <li>time - this moment</li>
+     *     <li>message - leg message</li>
+     *     <li>category - aka logLevel</li>
+     *     <li>source - when provided, the widget or util calling Y.log</li>
+     *     <li>sourceAndDetail - same as source but can include instance info</li>
+     *     <li>label - logLevel/category label for the entry</li>
+     *     <li>localTime - readable version of time</li>
+     *     <li>elapsedTime - ms since last entry</li>
+     *     <li>totalTime - ms since Console was instantiated or reset</li>
+     * </ul>
+     *
+     * @mehod _normalizeMessage
+     * @param msg {String} the log message
+     * @param cat {String} OPTIONAL the category or logLevel of the message
+     * @param src {String} OPTIONAL the source widget or util of the message
+     * @return Object the message object
+     * @protected
+     */
+    _normalizeMessage : function (msg,cat,src) {
+        var m = {
+            time            : new Date(),
+            message         : msg,
+            category        : cat || this.get('defaultCategory'),
+            sourceAndDetail : src || this.get('defaultSource'),
+            source          : null,
+            label           : null,
+            localTime       : null,
+            elapsedTime     : null,
+            totalTime       : null
+        };
+
+        // Extract m.source "Foo" from m.sourceAndDetail "Foo bar baz"
+        m.source          = RE_INLINE_SOURCE.test(m.sourceAndDetail) ?
+                                RegExp.$1 : m.sourceAndDetail;
+        m.label           = m.category;
+        m.localTime       = m.time.toLocaleTimeString ? 
+                            m.time.toLocaleTimeString() : (m.time + '');
+        m.elapsedTime     = m.time - this.get(LAST_TIME);
+        m.totalTime       = m.time - this.get(START_TIME);
+
+        this._set(LAST_TIME,m.time);
+
+        return m;
+    },
+
+    /**
+     * Sets a timeout for buffered messages to be output to the console.
+     *
+     * @method _schedulePrint
+     * @protected
+     */
+    _schedulePrint : function () {
+        if (!this.get(PAUSED) && !this._timeout) {
+            this._timeout = Y.later(
+                                this.get('printTimeout'),
+                                this,this.printBuffer);
+        }
+    },
+
+    /**
+     * Inserts a Node into the console body at the top or bottom depending on
+     * the configuration value of newestOnTop.
+     *
+     * @method _addToConsole
+     * @param node {Node} the node to insert into the console body
+     * @protected
+     */
+    _addToConsole : function (node) {
+        var toTop = this.get('newestOnTop'),
+            bd    = this._body,
+            scrollTop;
+
+        bd.insertBefore(node,toTop ? bd.get('firstChild') : null);
+
+        if (this.get('scrollIntoView')) {
+            scrollTop = toTop ? 0 : bd.get('scrollHeight');
+
+            bd.set('scrollTop', scrollTop);
+        }
+    },
+
+    /**
+     * Performs HTML escaping on strings in the message object.
+     *
+     * @method _htmlEscapeMessage
+     * @param m {Object} the normalized message object
+     * @return Object a clone of the message object with proper escapement
+     * @protected
+     */
+    _htmlEscapeMessage : function (m) {
+        m = Y.clone(m);
+        m.message         = this._encodeHTML(m.message);
+        m.label           = this._encodeHTML(m.label);
+        m.source          = this._encodeHTML(m.source);
+        m.sourceAndDetail = this._encodeHTML(m.sourceAndDetail);
+        m.category        = this._encodeHTML(m.category);
+
+        return m;
+    },
+
+    /**
+     * Removes the oldest message entries from the UI to maintain the limit
+     * specified in the consoleLimit configuration.
+     *
+     * @method _trimOldEntries
+     * @protected
+     */
+    _trimOldEntries : function () {
+        var bd = this._body;
+
+        if (bd) {
+            var entries = bd.queryAll(DOT+C_ENTRY),
+                i = entries ? entries.size() - this.get('consoleLimit') : 0;
+
+            if (i > 0) {
+                if (this.get('newestOnTop')) {
+                    for (var l = entries.size(); i<l; i++) {
+                        bd.removeChild(entries.item(i));
+                    }
+                } else {
+                    for (;i>=0;--i) {
+                        bd.removeChild(entries.item(i));
+                    }
+                }
+            }
+        }
+    },
+
+    /**
+     * Returns the input string with ampersands (&amp;), &lt, and &gt; encoded
+     * as HTML entities.
+     *
+     * @method _encodeHTML
+     * @param s {String} the raw string
+     * @return String the encoded string
+     * @protected
+     */
+    _encodeHTML : function (s) {
+        return isString(s) ?
+            s.replace(RE_AMP,ESC_AMP).
+              replace(RE_LT, ESC_LT).
+              replace(RE_GT, ESC_GT) :
+            s;
+    },
+
+    /**
+     * Clears the timeout for printing buffered messages.
+     *
+     * @method _clearTimeout
+     * @protected
+     */
+    _clearTimeout : function () {
+        if (this._timeout) {
+            this._timeout.cancel();
+            this._timeout = null;
+        }
+    },
+
+    /**
+     * Event handler for clicking on the Pause checkbox to update the paused
+     * attribute.
+     *
+     * @method _onPauseClick
+     * @param e {Event} DOM event facade for the click event
+     * @protected
+     */
+    _onPauseClick : function (e) {
+        var paused = e.target.get(CHECKED);
+
+        this.set(PAUSED,paused,{ src: Y.Widget.UI_SRC });
+    },
+
+    /**
+     * Event handler for clicking on the Clear button.  Pass-through to
+     * <code>this.clearConsole()</code>.
+     *
+     * @method _onClearClick
+     * @param e {Event} DOM event facade for the click event
+     * @protected
+     */
+    _onClearClick : function (e) {
+        this.clearConsole();
+    },
+
+
+    /**
+     * Setter method for logLevel attribute.  Acceptable values are
+     * &quot;error&quot, &quot;warn&quot, &quot;info&quot, and
+     * Y.Console.LOG_LEVEL_ERROR, Y.Console.LOG_LEVEL_WARN, 
+     * Y.Console.LOG_LEVEL_INFO.  Any other value becomes
+     * Y.Console.LOG_LEVEL_INFO.
+     *
+     * @method _setLogLevel
+     * @param v {String|Number} String or numeric alias for the desired logLevel
+     * @return Number LOG_LEVEL_ERROR, _WARN, or _INFO
+     * @protected
+     */
+    _setLogLevel : function (v) {
+        if (isString(v)) {
+            v = v.toLowerCase();
+            v = v === ERROR ?
+                        Console.LOG_LEVEL_ERROR :
+                        v === WARN ?
+                            Console.LOG_LEVEL_WARN :
+                            Console.LOG_LEVEL_INFO;
+        } else if (!isNumber(v)) {
+            v = Console.LOG_LEVEL_INFO;
+        }
+
+        return v;
+    },
+
+    /**
+     * Verifies input logLevel is one of Y.Console.LOG_LEVEL_ERROR,
+     * Y.Console.LOG_LEVEL_WARN, or Y.Console.LOG_LEVEL_INFO.
+     *
+     * @method _validateNewLogLevel
+     * @param v {Number} requested logLevel
+     * @return Boolean
+     * @protected
+     */
+    _validateNewLogLevel : function (v) {
+        return v === Console.LOG_LEVEL_INFO ||
+               v === Console.LOG_LEVEL_WARN ||
+               v === Console.LOG_LEVEL_ERROR;
+    },
+
+    /**
+     * Updates the UI if changes are made to any of the strings in the strings
+     * attribute.
+     *
+     * @method _afterStringsChange
+     * @param e {Event} Custom event for the attribute change
+     * @protected
+     */
+    _afterStringsChange : function (e) {
+        var prop   = e.subAttrName ? e.subAttrName.split(DOT)[1] : null,
+            cb     = this.get(CONTENT_BOX),
+            before = e.prevVal,
+            after  = e.newVal,
+            el;
+
+        if ((!prop || prop === TITLE) && before.title !== after.title) {
+            el = cb.query(DOT+C_CONSOLE_TITLE);
+            if (el) {
+                el.set(INNER_HTML,after.title);
+            }
+        }
+
+        if ((!prop || prop === PAUSE) && before.pause !== after.pause) {
+            el = cb.query(DOT+C_PAUSE_LABEL);
+            if (el) {
+                el.set(INNER_HTML,after.pause);
+            }
+        }
+
+        if ((!prop || prop === CLEAR) && before.clear !== after.clear) {
+            el = cb.query(DOT+C_CLEAR);
+            if (el) {
+                el.set('value',after.clear);
+            }
+        }
+    },
+
+    /**
+     * Updates the UI and schedules or cancels the scheduled buffer printing
+     * operation.
+     *
+     * @method _afterPausedChange
+     * @param e {Event} Custom event for the attribute change
+     * @protected
+     */
+    _afterPausedChange : function (e) {
+        var paused = e.newVal;
+
+        if (e.src !== Y.Widget.SRC_UI) {
+            var node = this._foot.queryAll('input[type=checkbox].'+C_PAUSE);
+            if (node) {
+                node.set(CHECKED,paused);
+            }
+        }
+
+        if (!paused) {
+            this._schedulePrint();
+        } else if (this._timeout) {
+            clearTimeout(this._timeout);
+            this._timeout = null;
+        }
+    },
+
+    /**
+     * Calls this._trimOldEntries() in response to changes in the configured
+     * consoleLimit attribute.
+     * 
+     * @method _afterConsoleLimitChange
+     * @param e {Event} Custom event for the attribute change
+     * @protected
+     */
+    _afterConsoleLimitChange : function () {
+        this._trimOldEntries();
+    },
+
+
+    /**
+     * Responds to log events by normalizing qualifying messages and passing
+     * them along through the entry event for buffering etc.
+     * 
+     * @method _onLogEvent
+     * @param msg {String} the log message
+     * @param cat {String} OPTIONAL the category or logLevel of the message
+     * @param src {String} OPTIONAL the source of the message (e.g. widget name)
+     * @protected
+     */
+    _onLogEvent : function (msg,cat,src) {
+
+        if (!this.get(DISABLED) && this._isInLogLevel(msg,cat,src)) {
+
+            /* TODO: needed? */
+            var debug = Y.config.debug;
+            Y.config.debug = false;
+
+            this.fire(ENTRY, {
+                message : this._normalizeMessage.apply(this,arguments)
+            });
+
+            Y.config.debug = debug;
+        }
+    },
+
+    /**
+     * Clears the console, resets the startTime attribute, enables and
+     * unpauses the widget.
+     *
+     * @method _defResetFn
+     * @protected
+     */
+    _defResetFn : function () {
+        this.clearConsole();
+        this.set(START_TIME,new Date());
+        this.set(DISABLED,false);
+        this.set(PAUSED,false);
+    },
+
+    /**
+     * Buffers incoming message objects and schedules the printing.
+     *
+     * @method _defEntryFn
+     * @param e {Event} The Custom event carrying the message in its payload
+     * @protected
+     */
+    _defEntryFn : function (e) {
+        if (e.message) {
+            this.buffer.push(e.message);
+            this._schedulePrint();
+        }
+    }
+
+});
+
+Y.Console = Console;
+
+
+}, '3.0.0pr2' ,{requires:['substitute','widget']});

=== added file 'loggerhead/static/javascript/yui/build/console/console-min.js'
--- loggerhead/static/javascript/yui/build/console/console-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/console/console-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("console",function(D){var G=D.ClassNameManager.getClassName,AC="console",l="entry",v="reset",A="checked",m="title",F="pause",d="paused",q="clear",P="info",g="warn",i="error",w="innerHTML",p="click",b="contentBox",f="disabled",t="startTime",N="lastTime",H="entryTemplate",u="rendered",W=".",x=G(AC,l),Q=G(AC,F),Z=G(AC,"checkbox"),V=G(AC,"button"),AB=G(AC,q),U=G(AC,F,"label"),S=G(AC,l,"meta"),r=G(AC,l,"cat"),e=G(AC,l,"src"),B=G(AC,l,"time"),X=G(AC,l,"content"),c=G(AC,"hd"),a=G(AC,"bd"),C=G(AC,"ft"),E=G(AC,"controls"),h=G(AC,m),k=/^(\S+)\s/,y=/&/g,K=/</g,s=/>/g,I="&#38;",j="&#60;",R="&#62;",J=D.Lang,O=J.isString,AA=J.isNumber,n=J.isObject,o=D.merge,z=D.substitute,M=D.Node.create;function T(){T.superclass.constructor.apply(this,arguments);}D.mix(T,{NAME:AC,LOG_LEVEL_INFO:3,LOG_LEVEL_WARN:2,LOG_LEVEL_ERROR:1,ENTRY_CLASSES:{entry_class:x,entry_meta_class:S,entry_cat_class:r,entry_src_class:e,entry_time_class:B,entry_content_class:X},CHROME_CLASSES:{console_hd_class:c,console_bd_class:a,console_ft_class:C,console_controls_class:E,console_checkbox_class:Z,console_pause_class:Q,console_pause_label_class:U,console_button_class:V,console_clear_class:AB,console_title_class:h},HEADER_TEMPLATE:'<div class="{console_hd_class}">'+'<h4 class="{console_title_class}">{str_title}</h4>'+"</div>",BODY_TEMPLATE:'<div class="{console_bd_class}"></div>',FOOTER_TEMPLATE:'<div class="{console_ft_class}">'+'<div class="{console_controls_class}">'+'<input type="checkbox" class="{console_checkbox_class} '+'{console_pause_class}" value="1" id="{id_guid}"> '+'<label for="{id_guid}" class="{console_pause_label_class}">'+"{str_pause}</label>"+'<input type="button" class="'+'{console_button_class} {console_clear_class}" '+'value="{str_clear}">'+"</div>"+"</div>",ENTRY_TEMPLATE:'<pre class="{entry_class} {cat_class} {src_class}">'+'<div class="{entry_meta_class}">'+"<p>"+'<span class="{entry_cat_class}">'+"{label}</span>"+'<span class="{entry_time_class}">'+" {totalTime}ms (+{elapsedTime}) {localTime}:"+"</span>"+"</p>"+'<p class="{entry_src_class}">'+"{sourceAndDetail}"+"</p>"+"</div>"+'<p class="{entry_content_class}">{message}</p>'+"</pre>",ATTRS:{logEvent:{value:"yui:log",writeOnce:true,validator:O},strings:{value:{title:"Log Console",pause:"Pause",clear:"Clear"}},paused:{value:false,validator:J.isBoolean},defaultCategory:{value:P,validator:O},defaultSource:{value:"global",validator:O},entryTemplate:{value:"",validator:O},logLevel:{value:D.config.logLevel,validator:function(L){return this._validateNewLogLevel(L);},set:function(L){return this._setLogLevel(L);}},printTimeout:{value:100,validator:AA},consoleLimit:{value:500,validator:AA},newestOnTop:{value:true},scrollIntoView:{value:true},startTime:{value:new Date()},lastTime:{value:new Date(),readOnly:true}}});D.extend(T,D.Widget,{_head:null,_body:null,_foot:null,_timeout:null,buffer:null,log:function(){return D.log.apply(D,arguments);},clearConsole:function(){this._body.set(w,"");this._clearTimeout();this.buffer=[];return this;},reset:function(){this.fire(v);return this;},printBuffer:function(){if(!this.get(d)&&this.get("rendered")){this._clearTimeout();var AD=this.buffer,Y,L;this.buffer=[];for(Y=0,L=AD.length;Y<L;++Y){this.printLogEntry(AD[Y]);}this._trimOldEntries();}return this;},printLogEntry:function(L){L=o(this._htmlEscapeMessage(L),T.ENTRY_CLASSES,{cat_class:this.getClassName(l,L.category),src_class:this.getClassName(l,L.source)});var Y=M(z(this.get("entryTemplate"),L));this._addToConsole(Y);return this;},initializer:function(){this.buffer=[];if(!this.get(H)){this.set(H,T.ENTRY_TEMPLATE);}D.on(this.get("logEvent"),D.bind(this._onLogEvent,this));this.publish(l,{defaultFn:this._defEntryFn});this.publish(v,{defaultFn:this._defResetFn});},renderUI:function(){this._initHead();this._initConsole();this._initFoot();},syncUI:function(){this.set(d,this.get(d));},bindUI:function(){this.get(b).query("input[type=checkbox]."+Q).on(p,this._onPauseClick,this);this.get(b).query("input[type=button]."+AB).on(p,this._onClearClick,this);this.after("stringsChange",this._afterStringsChange);this.after("pausedChange",this._afterPausedChange);this.after("consoleLimitChange",this._afterConsoleLimitChange);},_initHead:function(){var L=this.get(b),Y=o(T.CHROME_CLASSES,{str_title:this.get("strings.title")});this._head=M(z(T.HEADER_TEMPLATE,Y));L.insertBefore(this._head,L.get("firstChild"));},_initConsole:function(){this._body=M(z(T.BODY_TEMPLATE,T.CHROME_CLASSES));this.get(b).appendChild(this._body);},_initFoot:function(){var L=o(T.CHROME_CLASSES,{id_guid:D.guid(),str_pause:this.get("strings.pause"),str_clear:this.get("strings.clear")});this._foot=M(z(T.FOOTER_TEMPLATE,L));this.get(b).appendChild(this._foot);},_isInLogLevel:function(AE,L){var Y=this.get("logLevel"),AD=L===i?T.LOG_LEVEL_ERROR:L===g?T.LOG_LEVEL_WARN:T.LOG_LEVEL_INFO;return Y>=AD;},_normalizeMessage:function(AE,Y,AD){var L={time:new Date(),message:AE,category:Y||this.get("defaultCategory"),sourceAndDetail:AD||this.get("defaultSource"),source:null,label:null,localTime:null,elapsedTime:null,totalTime:null};L.source=k.test(L.sourceAndDetail)?RegExp.$1:L.sourceAndDetail;L.label=L.category;L.localTime=L.time.toLocaleTimeString?L.time.toLocaleTimeString():(L.time+"");L.elapsedTime=L.time-this.get(N);L.totalTime=L.time-this.get(t);this._set(N,L.time);return L;},_schedulePrint:function(){if(!this.get(d)&&!this._timeout){this._timeout=D.later(this.get("printTimeout"),this,this.printBuffer);}},_addToConsole:function(Y){var L=this.get("newestOnTop"),AD=this._body,AE;AD.insertBefore(Y,L?AD.get("firstChild"):null);if(this.get("scrollIntoView")){AE=L?0:AD.get("scrollHeight");AD.set("scrollTop",AE);}},_htmlEscapeMessage:function(L){L=D.clone(L);L.message=this._encodeHTML(L.message);L.label=this._encodeHTML(L.label);L.source=this._encodeHTML(L.source);L.sourceAndDetail=this._encodeHTML(L.sourceAndDetail);L.category=this._encodeHTML(L.category);return L;},_trimOldEntries:function(){var AE=this._body;if(AE){var L=AE.queryAll(W+x),AD=L?L.size()-this.get("consoleLimit"):0;
+if(AD>0){if(this.get("newestOnTop")){for(var Y=L.size();AD<Y;AD++){AE.removeChild(L.item(AD));}}else{for(;AD>=0;--AD){AE.removeChild(L.item(AD));}}}}},_encodeHTML:function(L){return O(L)?L.replace(y,I).replace(K,j).replace(s,R):L;},_clearTimeout:function(){if(this._timeout){this._timeout.cancel();this._timeout=null;}},_onPauseClick:function(Y){var L=Y.target.get(A);this.set(d,L,{src:D.Widget.UI_SRC});},_onClearClick:function(L){this.clearConsole();},_setLogLevel:function(L){if(O(L)){L=L.toLowerCase();L=L===i?T.LOG_LEVEL_ERROR:L===g?T.LOG_LEVEL_WARN:T.LOG_LEVEL_INFO;}else{if(!AA(L)){L=T.LOG_LEVEL_INFO;}}return L;},_validateNewLogLevel:function(L){return L===T.LOG_LEVEL_INFO||L===T.LOG_LEVEL_WARN||L===T.LOG_LEVEL_ERROR;},_afterStringsChange:function(AE){var AG=AE.subAttrName?AE.subAttrName.split(W)[1]:null,L=this.get(b),AD=AE.prevVal,AF=AE.newVal,Y;if((!AG||AG===m)&&AD.title!==AF.title){Y=L.query(W+h);if(Y){Y.set(w,AF.title);}}if((!AG||AG===F)&&AD.pause!==AF.pause){Y=L.query(W+U);if(Y){Y.set(w,AF.pause);}}if((!AG||AG===q)&&AD.clear!==AF.clear){Y=L.query(W+AB);if(Y){Y.set("value",AF.clear);}}},_afterPausedChange:function(AD){var L=AD.newVal;if(AD.src!==D.Widget.SRC_UI){var Y=this._foot.queryAll("input[type=checkbox]."+Q);if(Y){Y.set(A,L);}}if(!L){this._schedulePrint();}else{if(this._timeout){clearTimeout(this._timeout);this._timeout=null;}}},_afterConsoleLimitChange:function(){this._trimOldEntries();},_onLogEvent:function(AE,L,AD){if(!this.get(f)&&this._isInLogLevel(AE,L,AD)){var Y=D.config.debug;D.config.debug=false;this.fire(l,{message:this._normalizeMessage.apply(this,arguments)});D.config.debug=Y;}},_defResetFn:function(){this.clearConsole();this.set(t,new Date());this.set(f,false);this.set(d,false);},_defEntryFn:function(L){if(L.message){this.buffer.push(L.message);this._schedulePrint();}}});D.Console=T;},"3.0.0pr2",{requires:["substitute","widget"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/console/console.js'
--- loggerhead/static/javascript/yui/build/console/console.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/console/console.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1151 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('console', function(Y) {
+
+/**
+ * A user interface for viewing log messages.
+ *
+ * @module console
+ */
+
+var getCN = Y.ClassNameManager.getClassName,
+    CONSOLE        = 'console',
+    ENTRY          = 'entry',
+    RESET          = 'reset',
+    CHECKED        = 'checked',
+    TITLE          = 'title',
+    PAUSE          = 'pause',
+    PAUSED         = 'paused',
+    CLEAR          = 'clear',
+    INFO           = 'info',
+    WARN           = 'warn',
+    ERROR          = 'error',
+    INNER_HTML     = 'innerHTML',
+    CLICK          = 'click',
+    CONTENT_BOX    = 'contentBox',
+    DISABLED       = 'disabled',
+    START_TIME     = 'startTime',
+    LAST_TIME      = 'lastTime',
+    ENTRY_TEMPLATE = 'entryTemplate',
+    RENDERED       = 'rendered',
+
+    DOT = '.',
+
+    C_ENTRY            = getCN(CONSOLE,ENTRY),
+    C_PAUSE            = getCN(CONSOLE,PAUSE),
+    C_CHECKBOX         = getCN(CONSOLE,'checkbox'),
+    C_BUTTON           = getCN(CONSOLE,'button'),
+    C_CLEAR            = getCN(CONSOLE,CLEAR),
+    C_PAUSE_LABEL      = getCN(CONSOLE,PAUSE,'label'),
+    C_ENTRY_META       = getCN(CONSOLE,ENTRY,'meta'),
+    C_ENTRY_CAT        = getCN(CONSOLE,ENTRY,'cat'),
+    C_ENTRY_SRC        = getCN(CONSOLE,ENTRY,'src'),
+    C_ENTRY_TIME       = getCN(CONSOLE,ENTRY,'time'),
+    C_ENTRY_CONTENT    = getCN(CONSOLE,ENTRY,'content'),
+    C_CONSOLE_HD       = getCN(CONSOLE,'hd'),
+    C_CONSOLE_BD       = getCN(CONSOLE,'bd'),
+    C_CONSOLE_FT       = getCN(CONSOLE,'ft'),
+    C_CONSOLE_CONTROLS = getCN(CONSOLE,'controls'),
+    C_CONSOLE_TITLE    = getCN(CONSOLE,TITLE),
+
+    RE_INLINE_SOURCE = /^(\S+)\s/,
+    RE_AMP = /&/g,
+    RE_LT  = /</g,
+    RE_GT  = />/g,
+
+    ESC_AMP = '&#38;',
+    ESC_LT  = '&#60;',
+    ESC_GT  = '&#62;',
+    
+    L = Y.Lang,
+    isString   = L.isString,
+    isNumber   = L.isNumber,
+    isObject   = L.isObject,
+    merge      = Y.merge,
+    substitute = Y.substitute,
+    create     = Y.Node.create;
+    
+/**
+ * Console creates a visualization for messages logged through calls to a YUI
+ * instance's <code>Y.log( message, category, source )</code> method.  The
+ * debug versions of YUI modules will include logging statements to offer some
+ * insight into the steps executed during that module's operation.  Including
+ * log statements in your code will cause those messages to also appear in the
+ * Console.  Use Console to aid in developing your page or application.
+ *
+ * Entry categories are also referred to as the log level, and entries are
+ * filtered against the configured logLevel.
+ *
+ * @class Console
+ * @extends Widget
+ */
+
+function Console() {
+    Console.superclass.constructor.apply(this,arguments);
+}
+
+Y.mix(Console, {
+
+    /**
+     * The identity of the widget.
+     *
+     * @property Console.NAME
+     * @type String
+     * @static
+     */
+    NAME : CONSOLE,
+
+    /**
+     * Static identifier for logLevel configuration setting to allow all
+     * incoming messages to generate Console entries.
+     *
+     * @property Console.LOG_LEVEL_INFO
+     * @type Number
+     * @static
+     */
+    LOG_LEVEL_INFO  : 3,
+
+    /**
+     * Static identifier for logLevel configuration setting to allow only
+     * incoming messages of logLevel &quot;warn&quot; or &quot;error&quot;
+     * to generate Console entries.
+     *
+     * @property Console.LOG_LEVEL_WARN
+     * @type Number
+     * @static
+     */
+    LOG_LEVEL_WARN  : 2,
+
+    /**
+     * Static identifier for logLevel configuration setting to allow only
+     * incoming messages of logLevel &quot;error&quot; to generate
+     * Console entries.
+     *
+     * @property Console.LOG_LEVEL_ERROR
+     * @type Number
+     * @static
+     */
+    LOG_LEVEL_ERROR : 1,
+
+    /**
+     * Map (object) of classNames used to populate the placeholders in the
+     * Console.ENTRY_TEMPLATE markup when rendering a new Console entry.
+     *
+     * <p>By default, the keys contained in the object are:</p>
+     * <ul>
+     *    <li>entry_class</li>
+     *    <li>entry_meta_class</li>
+     *    <li>entry_cat_class</li>
+     *    <li>entry_src_class</li>
+     *    <li>entry_time_class</li>
+     *    <li>entry_content_class</li>
+     * </ul>
+     *
+     * @property Console.ENTRY_CLASSES
+     * @type Object
+     * @static
+     */
+    ENTRY_CLASSES   : {
+        entry_class         : C_ENTRY,
+        entry_meta_class    : C_ENTRY_META,
+        entry_cat_class     : C_ENTRY_CAT,
+        entry_src_class     : C_ENTRY_SRC,
+        entry_time_class    : C_ENTRY_TIME,
+        entry_content_class : C_ENTRY_CONTENT
+    },
+
+    /**
+     * Map (object) of classNames used to populate the placeholders in the
+     * Console.HEADER_TEMPLATE, Console.BODY_TEMPLATE, and
+     * Console.FOOTER_TEMPLATE markup when rendering the Console UI.
+     *
+     * <p>By default, the keys contained in the object are:</p>
+     * <ul>
+     *   <li>console_hd_class</li>
+     *   <li>console_bd_class</li>
+     *   <li>console_ft_class</li>
+     *   <li>console_controls_class</li>
+     *   <li>console_checkbox_class</li>
+     *   <li>console_pause_class</li>
+     *   <li>console_pause_label_class</li>
+     *   <li>console_button_class</li>
+     *   <li>console_clear_class</li>
+     *   <li>console_title_class</li>
+     * </ul>
+     *
+     * @property Console.CHROME_CLASSES
+     * @type Object
+     * @static
+     */
+    CHROME_CLASSES  : {
+        console_hd_class       : C_CONSOLE_HD,
+        console_bd_class       : C_CONSOLE_BD,
+        console_ft_class       : C_CONSOLE_FT,
+        console_controls_class : C_CONSOLE_CONTROLS,
+        console_checkbox_class : C_CHECKBOX,
+        console_pause_class    : C_PAUSE,
+        console_pause_label_class : C_PAUSE_LABEL,
+        console_button_class   : C_BUTTON,
+        console_clear_class    : C_CLEAR,
+        console_title_class    : C_CONSOLE_TITLE
+    },
+
+    /**
+     * Markup template used to generate the DOM structure for the header
+     * section of the Console when it is rendered.  The template includes
+     * these {placeholder}s:
+     *
+     * <ul>
+     *   <li>console_hd_class - contributed by Console.CHROME_CLASSES</li>
+     *   <li>console_title_class - contributed by Console.CHROME_CLASSES</li>
+     *   <li>str_title - pulled from attribute strings.title</li>
+     * </ul>
+     *
+     * @property Console.HEADER_TEMPLATE
+     * @type String
+     * @static
+     */
+    HEADER_TEMPLATE :
+        '<div class="{console_hd_class}">'+
+            '<h4 class="{console_title_class}">{str_title}</h4>'+
+        '</div>',
+
+    /**
+     * Markup template used to generate the DOM structure for the Console body
+     * (where the messages are inserted) when it is rendered.  The template
+     * includes only the {placeholder} &quot;console_bd_class&quot;, which is
+     * constributed by Console.CHROME_CLASSES.
+     *
+     * @property Console.BODY_TEMPLATE
+     * @type String
+     * @static
+     */
+    BODY_TEMPLATE : '<div class="{console_bd_class}"></div>',
+
+    /**
+     * Markup template used to generate the DOM structure for the footer
+     * section of the Console when it is rendered.  The template includes
+     * many of the {placeholder}s from Console.CHROME_CLASSES as well as:
+     *
+     * <ul>
+     *   <li>id_guid - generated unique id, relates the label and checkbox</li>
+     *   <li>str_pause - pulled from attribute strings.pause</li>
+     *   <li>str_clear - pulled from attribute strings.clear</li>
+     * </ul>
+     *
+     * @property Console.HEADER_TEMPLATE
+     * @type String
+     * @static
+     */
+    FOOTER_TEMPLATE :
+        '<div class="{console_ft_class}">'+
+            '<div class="{console_controls_class}">'+
+                '<input type="checkbox" class="{console_checkbox_class} '+
+                        '{console_pause_class}" value="1" id="{id_guid}"> '+
+                '<label for="{id_guid}" class="{console_pause_label_class}">'+
+                    '{str_pause}</label>' +
+                '<input type="button" class="'+
+                    '{console_button_class} {console_clear_class}" '+
+                    'value="{str_clear}">'+
+            '</div>'+
+        '</div>',
+
+    /**
+     * Default markup template used to create the DOM structure for Console
+     * entries. The markup contains {placeholder}s for content and classes
+     * that are replaced via Y.substitute.  The default template contains
+     * the {placeholder}s identified in Console.ENTRY_CLASSES as well as the
+     * following placeholders that will be populated by the log entry data:
+     *
+     * <ul>
+     *   <li>cat_class</li>
+     *   <li>src_class</li>
+     *   <li>label</li>
+     *   <li>totalTime</li>
+     *   <li>elapsedTime</li>
+     *   <li>localTime</li>
+     *   <li>sourceAndDetail</li>
+     *   <li>message</li>
+     * </ul>
+     *
+     * @property Console.ENTRY_TEMPLATE
+     * @type String
+     * @static
+     */
+    ENTRY_TEMPLATE :
+        '<pre class="{entry_class} {cat_class} {src_class}">'+
+            '<div class="{entry_meta_class}">'+
+                '<p>'+
+                    '<span class="{entry_cat_class}">'+
+                        '{label}</span>'+
+                    '<span class="{entry_time_class}">'+
+                        ' {totalTime}ms (+{elapsedTime}) {localTime}:'+
+                    '</span>'+
+                '</p>'+
+                '<p class="{entry_src_class}">'+
+                    '{sourceAndDetail}'+
+                '</p>'+
+            '</div>'+
+            '<p class="{entry_content_class}">{message}</p>'+
+        '</pre>',
+
+    /**
+     * Static property used to define the default attribute configuration of
+     * the Widget.
+     *
+     * @property Console.ATTRS
+     * @Type Object
+     * @static
+     */
+    ATTRS : {
+
+        /**
+         * Name of the custom event that will communicate log messages.
+         *
+         * @attribute logEvent
+         * @type String
+         * @default "yui:log"
+         */
+        logEvent : {
+            value : 'yui:log',
+            writeOnce : true,
+            validator : isString
+        },
+
+        /**
+         * Collection of strings used to label elements in the Console UI.
+         * Default collection contains the following name:value pairs:
+         *
+         * <ul>
+         *   <li>title : &quot;Log Console&quot;</li>
+         *   <li>pause : &quot;Pause&quot;</li>
+         *   <li>clear : &quot;Clear&quot;</li>
+         * </ul>
+         *
+         * @attribute strings
+         * @type Object
+         */
+        strings : {
+            value : {
+                title : "Log Console",
+                pause : "Pause",
+                clear : "Clear"
+            }
+        },
+
+        /**
+         * Boolean to pause the outputting of new messages to the console.
+         * When paused, messages will accumulate in the buffer.
+         *
+         * @attribute paused
+         * @type boolean
+         * @default false
+         */
+        paused : {
+            value : false,
+            validator : L.isBoolean
+        },
+
+        /**
+         * If a category is not specified in the Y.log(..) statement, this
+         * category will be used. Category is also called &quot;log level&quot;.
+         *
+         * @attribute defaultCategory
+         * @type String
+         * @default "info"
+         */
+        defaultCategory : {
+            value : INFO,
+            validator : isString
+        },
+
+        /**
+         * If a source is not specified in the Y.log(..) statement, this
+         * source will be used.
+         *
+         * @attribute defaultSource
+         * @type String
+         * @default "global"
+         */
+        defaultSource   : {
+            value : 'global',
+            validator : isString
+        },
+
+        /**
+         * Markup template used to create the DOM structure for Console entries.
+         *
+         * @attribute entryTemplate
+         * @type String
+         * @default (see Console.ENTRY_TEMPLATE)
+         */
+        entryTemplate : {
+            value : '',
+            validator : isString
+        },
+
+        /**
+         * Minimum entry log level to render into the Console.  The initial
+         * logLevel value for all Console instances defaults from the
+         * Y.config.logLevel YUI configuration, or Console.LOG_LEVEL_INFO if
+         * that configuration is not set.
+         *
+         * Possible values are &quot;info&quot;, &quot;warn&quot;,
+         * &quot;error&quot; (case insensitive), or the corresponding statics
+         * Console.LOG_LEVEL_INFO and so on.
+         *
+         * @attribute logLevel
+         * @type String|Number
+         * @default Y.config.logLevel or Console.LOG_LEVEL_INFO
+         */
+        logLevel : {
+            value : Y.config.logLevel,
+            validator : function (v) {
+                return this._validateNewLogLevel(v);
+            },
+            set : function (v) {
+                return this._setLogLevel(v);
+            }
+        },
+
+        /**
+         * Millisecond timeout to maintain before emptying buffer of Console
+         * entries to the UI.
+         *
+         * @attribute printTimeout
+         * @type Number
+         * @default 100
+         */
+        printTimeout : {
+            value : 100,
+            validator : isNumber
+        },
+
+        /**
+         * Maximum number of Console entries allowed in the Console body at one
+         * time.  This is used to keep acquired messages from exploding the
+         * DOM tree and impacting page performance.
+         *
+         * @attribute consoleLimit
+         * @type Number
+         * @default 500
+         */
+        consoleLimit : {
+            value : 500,
+            validator : isNumber
+        },
+
+        /**
+         * New entries should display at the top of the Console or the bottom?
+         *
+         * @attribute newestOnTop
+         * @type Boolean
+         * @default true
+         */
+        newestOnTop : {
+            value : true
+        },
+
+        /**
+         * When new entries are added to the Console UI, should they be
+         * scrolled into view?
+         *
+         * @attribute scrollIntoView
+         * @type Boolean
+         * @default true
+         */
+        scrollIntoView : {
+            value : true
+        },
+
+        /**
+         * The baseline time for this Console instance, used to measure elapsed
+         * time from the moment the console module is <code>use</code>d to the
+         * moment each new entry is logged (not rendered).
+         *
+         * This value is reset by the instance method myConsole.reset().
+         *
+         * @attribute startTime
+         * @type Date
+         * @default The moment the console module is <code>use</code>d
+         */
+        startTime : {
+            value : new Date()
+        },
+
+        /**
+         * The precise time the last entry was logged.  Used to measure elapsed
+         * time between log messages.
+         *
+         * @attribute lastTime
+         * @type Date
+         * @default The moment the console module is <code>use</code>d
+         */
+        lastTime : {
+            value : new Date(),
+            readOnly: true
+        }
+
+    }
+
+});
+
+Y.extend(Console,Y.Widget,{
+
+    /**
+     * Reference to the Node instance containing the head contents.
+     *
+     * @property _head
+     * @type Node
+     * @default null
+     * @protected
+     */
+    _head    : null,
+
+    /**
+     * Reference to the Node instance that will house the console messages.
+     *
+     * @property _body
+     * @type Node
+     * @default null
+     * @protected
+     */
+    _body    : null,
+
+    /**
+     * Reference to the Node instance containing the footer contents.
+     *
+     * @property _head
+     * @type Node
+     * @default null
+     * @protected
+     */
+    _foot    : null,
+
+    /**
+     * Object API returned from <code>Y.later</code>. Holds the timer id
+     * returned by <code>setTimout</code> for scheduling of buffered messages.
+     *
+     * @property _timeout
+     * @type Object
+     * @default null
+     * @protected
+     */
+    _timeout : null,
+
+    /**
+     * Array of normalized message objects awaiting printing.
+     *
+     * @property buffer
+     * @type Array
+     * @default null
+     */
+    buffer   : null,
+
+    /**
+     * Wrapper for <code>Y.log</code>.
+     *
+     * @method log
+     * @param {Any*} * (all arguments passed through to <code>Y.log</code>)
+     */
+    log : function () {
+        return Y.log.apply(Y,arguments);
+    },
+
+    /**
+     * Clear the console of messages and flush the buffer of pending messages.
+     *
+     * @method clearConsole
+     * @chainable
+     */
+    clearConsole : function () {
+        // TODO: clear event listeners from console contents
+        this._body.set(INNER_HTML,'');
+
+        this._clearTimeout();
+
+        this.buffer = [];
+
+        return this;
+    },
+
+    /**
+     * Clears the console and resets internal timers.
+     *
+     * @method reset
+     * @chainable
+     */
+    reset : function () {
+        this.fire(RESET);
+        
+        return this;
+    },
+
+    /**
+     * Outputs all buffered messages to the console UI.
+     * 
+     * @method printBuffer
+     * @chainable
+     */
+    printBuffer: function () {
+        if (!this.get(PAUSED) && this.get('rendered')) {
+
+            this._clearTimeout();
+
+            var messages = this.buffer,
+                i,len;
+
+            this.buffer = [];
+
+            // TODO: use doc frag
+            for (i = 0, len = messages.length; i < len; ++i) {
+                this.printLogEntry(messages[i]);
+            }
+
+            this._trimOldEntries();
+        }
+
+        return this;
+    },
+
+    /**
+     * Prints the provided message to the console UI.
+     *
+     * @method printLogEntry
+     * @param m {Object} Normalized message object
+     * @chainable
+     */
+    printLogEntry : function (m) {
+        m = merge(
+                this._htmlEscapeMessage(m),
+                Console.ENTRY_CLASSES,
+                {
+                    cat_class : this.getClassName(ENTRY,m.category),
+                    src_class : this.getClassName(ENTRY,m.source)
+                });
+
+        var n = create(substitute(this.get('entryTemplate'),m));
+
+        this._addToConsole(n);
+
+        return this;
+    },
+
+    
+    /**
+     * Constructor code.  Set up the buffer and entry template, publish
+     * internal events, and subscribe to the configured logEvent.
+     * 
+     * @method initializer
+     * @protected
+     */
+    initializer : function () {
+        this.buffer    = [];
+
+        if (!this.get(ENTRY_TEMPLATE)) {
+            this.set(ENTRY_TEMPLATE,Console.ENTRY_TEMPLATE);
+        }
+
+        Y.on(this.get('logEvent'),Y.bind(this._onLogEvent,this));
+
+        /**
+         * Triggers the processing of an incoming message via the default logic
+         * in _defEntryFn.
+         *
+         * @event entry
+         * @param event {Event.Facade} An Event Facade object with the following attribute specific properties added:
+         *  <dl>
+         *      <dt>message</dt>
+         *          <dd>The message data normalized into an object literal (see _normalizeMessage)</dd>
+         *  </dl>
+         * @preventable _defEntryFn
+         */
+        this.publish(ENTRY, { defaultFn: this._defEntryFn });
+
+        /**
+         * Triggers the reset behavior via the default logic in _defResetFn.
+         *
+         * @event reset
+         * @param event {Event.Facade} Event Facade object
+         * @preventable _defResetFn
+         */
+        this.publish(RESET, { defaultFn: this._defResetFn });
+    },
+
+    /**
+     * Generate the Console UI.
+     *
+     * @method renderUI
+     * @protected
+     */
+    renderUI : function () {
+        this._initHead();
+        this._initConsole();
+        this._initFoot();
+    },
+
+    /**
+     * Sync the UI state to the current attribute state.
+     *
+     * @method syncUI
+     */
+    syncUI : function () {
+        this.set(PAUSED,this.get(PAUSED));
+    },
+
+    /**
+     * Set up event listeners to wire up the UI to the internal state.
+     *
+     * @method bindUI
+     * @protected
+     */
+    bindUI : function () {
+        this.get(CONTENT_BOX).query('input[type=checkbox].'+C_PAUSE).
+            on(CLICK,this._onPauseClick,this);
+
+        this.get(CONTENT_BOX).query('input[type=button].'+C_CLEAR).
+            on(CLICK,this._onClearClick,this);
+        
+        // Attribute changes
+        this.after('stringsChange',       this._afterStringsChange);
+        this.after('pausedChange',        this._afterPausedChange);
+        this.after('consoleLimitChange',  this._afterConsoleLimitChange);
+    },
+
+    
+    /**
+     * Create the DOM structure for the header elements.
+     *
+     * @method _initHead
+     * @protected
+     */
+    _initHead : function () {
+        var cb   = this.get(CONTENT_BOX),
+            info = merge(Console.CHROME_CLASSES, {
+                        str_title : this.get('strings.title')
+                    });
+
+        this._head = create(substitute(Console.HEADER_TEMPLATE,info));
+
+        cb.insertBefore(this._head,cb.get('firstChild'));
+    },
+
+    /**
+     * Create the DOM structure for the console body&#8212;where messages are
+     * rendered.
+     *
+     * @method _initConsole
+     * @protected
+     */
+    _initConsole : function () {
+        this._body = create(substitute(
+                            Console.BODY_TEMPLATE,
+                            Console.CHROME_CLASSES));
+
+        this.get(CONTENT_BOX).appendChild(this._body);
+    },
+
+    /**
+     * Create the DOM structure for the footer elements.
+     *
+     * @method _initFoot
+     * @protected
+     */
+    _initFoot : function () {
+        var info = merge(Console.CHROME_CLASSES, {
+                id_guid   : Y.guid(),
+                str_pause : this.get('strings.pause'),
+                str_clear : this.get('strings.clear')
+            });
+
+        this._foot = create(substitute(Console.FOOTER_TEMPLATE,info));
+
+        this.get(CONTENT_BOX).appendChild(this._foot);
+    },
+
+    /**
+     * Determine if incoming log messages are within the configured logLevel
+     * to be buffered for printing.
+     *
+     * @method _isInLogLevel
+     * @protected
+     */
+    _isInLogLevel : function (msg,cat) {
+        var lvl = this.get('logLevel'),
+            mlvl = cat === ERROR ? Console.LOG_LEVEL_ERROR :
+                    cat === WARN ? Console.LOG_LEVEL_WARN  :
+                                   Console.LOG_LEVEL_INFO;
+
+        return lvl >= mlvl;
+    },
+
+    /**
+     * Create a log entry message from the inputs including the following keys:
+     * <ul>
+     *     <li>time - this moment</li>
+     *     <li>message - leg message</li>
+     *     <li>category - aka logLevel</li>
+     *     <li>source - when provided, the widget or util calling Y.log</li>
+     *     <li>sourceAndDetail - same as source but can include instance info</li>
+     *     <li>label - logLevel/category label for the entry</li>
+     *     <li>localTime - readable version of time</li>
+     *     <li>elapsedTime - ms since last entry</li>
+     *     <li>totalTime - ms since Console was instantiated or reset</li>
+     * </ul>
+     *
+     * @mehod _normalizeMessage
+     * @param msg {String} the log message
+     * @param cat {String} OPTIONAL the category or logLevel of the message
+     * @param src {String} OPTIONAL the source widget or util of the message
+     * @return Object the message object
+     * @protected
+     */
+    _normalizeMessage : function (msg,cat,src) {
+        var m = {
+            time            : new Date(),
+            message         : msg,
+            category        : cat || this.get('defaultCategory'),
+            sourceAndDetail : src || this.get('defaultSource'),
+            source          : null,
+            label           : null,
+            localTime       : null,
+            elapsedTime     : null,
+            totalTime       : null
+        };
+
+        // Extract m.source "Foo" from m.sourceAndDetail "Foo bar baz"
+        m.source          = RE_INLINE_SOURCE.test(m.sourceAndDetail) ?
+                                RegExp.$1 : m.sourceAndDetail;
+        m.label           = m.category;
+        m.localTime       = m.time.toLocaleTimeString ? 
+                            m.time.toLocaleTimeString() : (m.time + '');
+        m.elapsedTime     = m.time - this.get(LAST_TIME);
+        m.totalTime       = m.time - this.get(START_TIME);
+
+        this._set(LAST_TIME,m.time);
+
+        return m;
+    },
+
+    /**
+     * Sets a timeout for buffered messages to be output to the console.
+     *
+     * @method _schedulePrint
+     * @protected
+     */
+    _schedulePrint : function () {
+        if (!this.get(PAUSED) && !this._timeout) {
+            this._timeout = Y.later(
+                                this.get('printTimeout'),
+                                this,this.printBuffer);
+        }
+    },
+
+    /**
+     * Inserts a Node into the console body at the top or bottom depending on
+     * the configuration value of newestOnTop.
+     *
+     * @method _addToConsole
+     * @param node {Node} the node to insert into the console body
+     * @protected
+     */
+    _addToConsole : function (node) {
+        var toTop = this.get('newestOnTop'),
+            bd    = this._body,
+            scrollTop;
+
+        bd.insertBefore(node,toTop ? bd.get('firstChild') : null);
+
+        if (this.get('scrollIntoView')) {
+            scrollTop = toTop ? 0 : bd.get('scrollHeight');
+
+            bd.set('scrollTop', scrollTop);
+        }
+    },
+
+    /**
+     * Performs HTML escaping on strings in the message object.
+     *
+     * @method _htmlEscapeMessage
+     * @param m {Object} the normalized message object
+     * @return Object a clone of the message object with proper escapement
+     * @protected
+     */
+    _htmlEscapeMessage : function (m) {
+        m = Y.clone(m);
+        m.message         = this._encodeHTML(m.message);
+        m.label           = this._encodeHTML(m.label);
+        m.source          = this._encodeHTML(m.source);
+        m.sourceAndDetail = this._encodeHTML(m.sourceAndDetail);
+        m.category        = this._encodeHTML(m.category);
+
+        return m;
+    },
+
+    /**
+     * Removes the oldest message entries from the UI to maintain the limit
+     * specified in the consoleLimit configuration.
+     *
+     * @method _trimOldEntries
+     * @protected
+     */
+    _trimOldEntries : function () {
+        var bd = this._body;
+
+        if (bd) {
+            var entries = bd.queryAll(DOT+C_ENTRY),
+                i = entries ? entries.size() - this.get('consoleLimit') : 0;
+
+            if (i > 0) {
+                if (this.get('newestOnTop')) {
+                    for (var l = entries.size(); i<l; i++) {
+                        bd.removeChild(entries.item(i));
+                    }
+                } else {
+                    for (;i>=0;--i) {
+                        bd.removeChild(entries.item(i));
+                    }
+                }
+            }
+        }
+    },
+
+    /**
+     * Returns the input string with ampersands (&amp;), &lt, and &gt; encoded
+     * as HTML entities.
+     *
+     * @method _encodeHTML
+     * @param s {String} the raw string
+     * @return String the encoded string
+     * @protected
+     */
+    _encodeHTML : function (s) {
+        return isString(s) ?
+            s.replace(RE_AMP,ESC_AMP).
+              replace(RE_LT, ESC_LT).
+              replace(RE_GT, ESC_GT) :
+            s;
+    },
+
+    /**
+     * Clears the timeout for printing buffered messages.
+     *
+     * @method _clearTimeout
+     * @protected
+     */
+    _clearTimeout : function () {
+        if (this._timeout) {
+            this._timeout.cancel();
+            this._timeout = null;
+        }
+    },
+
+    /**
+     * Event handler for clicking on the Pause checkbox to update the paused
+     * attribute.
+     *
+     * @method _onPauseClick
+     * @param e {Event} DOM event facade for the click event
+     * @protected
+     */
+    _onPauseClick : function (e) {
+        var paused = e.target.get(CHECKED);
+
+        this.set(PAUSED,paused,{ src: Y.Widget.UI_SRC });
+    },
+
+    /**
+     * Event handler for clicking on the Clear button.  Pass-through to
+     * <code>this.clearConsole()</code>.
+     *
+     * @method _onClearClick
+     * @param e {Event} DOM event facade for the click event
+     * @protected
+     */
+    _onClearClick : function (e) {
+        this.clearConsole();
+    },
+
+
+    /**
+     * Setter method for logLevel attribute.  Acceptable values are
+     * &quot;error&quot, &quot;warn&quot, &quot;info&quot, and
+     * Y.Console.LOG_LEVEL_ERROR, Y.Console.LOG_LEVEL_WARN, 
+     * Y.Console.LOG_LEVEL_INFO.  Any other value becomes
+     * Y.Console.LOG_LEVEL_INFO.
+     *
+     * @method _setLogLevel
+     * @param v {String|Number} String or numeric alias for the desired logLevel
+     * @return Number LOG_LEVEL_ERROR, _WARN, or _INFO
+     * @protected
+     */
+    _setLogLevel : function (v) {
+        if (isString(v)) {
+            v = v.toLowerCase();
+            v = v === ERROR ?
+                        Console.LOG_LEVEL_ERROR :
+                        v === WARN ?
+                            Console.LOG_LEVEL_WARN :
+                            Console.LOG_LEVEL_INFO;
+        } else if (!isNumber(v)) {
+            v = Console.LOG_LEVEL_INFO;
+        }
+
+        return v;
+    },
+
+    /**
+     * Verifies input logLevel is one of Y.Console.LOG_LEVEL_ERROR,
+     * Y.Console.LOG_LEVEL_WARN, or Y.Console.LOG_LEVEL_INFO.
+     *
+     * @method _validateNewLogLevel
+     * @param v {Number} requested logLevel
+     * @return Boolean
+     * @protected
+     */
+    _validateNewLogLevel : function (v) {
+        return v === Console.LOG_LEVEL_INFO ||
+               v === Console.LOG_LEVEL_WARN ||
+               v === Console.LOG_LEVEL_ERROR;
+    },
+
+    /**
+     * Updates the UI if changes are made to any of the strings in the strings
+     * attribute.
+     *
+     * @method _afterStringsChange
+     * @param e {Event} Custom event for the attribute change
+     * @protected
+     */
+    _afterStringsChange : function (e) {
+        var prop   = e.subAttrName ? e.subAttrName.split(DOT)[1] : null,
+            cb     = this.get(CONTENT_BOX),
+            before = e.prevVal,
+            after  = e.newVal,
+            el;
+
+        if ((!prop || prop === TITLE) && before.title !== after.title) {
+            el = cb.query(DOT+C_CONSOLE_TITLE);
+            if (el) {
+                el.set(INNER_HTML,after.title);
+            }
+        }
+
+        if ((!prop || prop === PAUSE) && before.pause !== after.pause) {
+            el = cb.query(DOT+C_PAUSE_LABEL);
+            if (el) {
+                el.set(INNER_HTML,after.pause);
+            }
+        }
+
+        if ((!prop || prop === CLEAR) && before.clear !== after.clear) {
+            el = cb.query(DOT+C_CLEAR);
+            if (el) {
+                el.set('value',after.clear);
+            }
+        }
+    },
+
+    /**
+     * Updates the UI and schedules or cancels the scheduled buffer printing
+     * operation.
+     *
+     * @method _afterPausedChange
+     * @param e {Event} Custom event for the attribute change
+     * @protected
+     */
+    _afterPausedChange : function (e) {
+        var paused = e.newVal;
+
+        if (e.src !== Y.Widget.SRC_UI) {
+            var node = this._foot.queryAll('input[type=checkbox].'+C_PAUSE);
+            if (node) {
+                node.set(CHECKED,paused);
+            }
+        }
+
+        if (!paused) {
+            this._schedulePrint();
+        } else if (this._timeout) {
+            clearTimeout(this._timeout);
+            this._timeout = null;
+        }
+    },
+
+    /**
+     * Calls this._trimOldEntries() in response to changes in the configured
+     * consoleLimit attribute.
+     * 
+     * @method _afterConsoleLimitChange
+     * @param e {Event} Custom event for the attribute change
+     * @protected
+     */
+    _afterConsoleLimitChange : function () {
+        this._trimOldEntries();
+    },
+
+
+    /**
+     * Responds to log events by normalizing qualifying messages and passing
+     * them along through the entry event for buffering etc.
+     * 
+     * @method _onLogEvent
+     * @param msg {String} the log message
+     * @param cat {String} OPTIONAL the category or logLevel of the message
+     * @param src {String} OPTIONAL the source of the message (e.g. widget name)
+     * @protected
+     */
+    _onLogEvent : function (msg,cat,src) {
+
+        if (!this.get(DISABLED) && this._isInLogLevel(msg,cat,src)) {
+
+            /* TODO: needed? */
+            var debug = Y.config.debug;
+            Y.config.debug = false;
+
+            this.fire(ENTRY, {
+                message : this._normalizeMessage.apply(this,arguments)
+            });
+
+            Y.config.debug = debug;
+        }
+    },
+
+    /**
+     * Clears the console, resets the startTime attribute, enables and
+     * unpauses the widget.
+     *
+     * @method _defResetFn
+     * @protected
+     */
+    _defResetFn : function () {
+        this.clearConsole();
+        this.set(START_TIME,new Date());
+        this.set(DISABLED,false);
+        this.set(PAUSED,false);
+    },
+
+    /**
+     * Buffers incoming message objects and schedules the printing.
+     *
+     * @method _defEntryFn
+     * @param e {Event} The Custom event carrying the message in its payload
+     * @protected
+     */
+    _defEntryFn : function (e) {
+        if (e.message) {
+            this.buffer.push(e.message);
+            this._schedulePrint();
+        }
+    }
+
+});
+
+Y.Console = Console;
+
+
+}, '3.0.0pr2' ,{requires:['substitute','widget']});

=== added directory 'loggerhead/static/javascript/yui/build/cookie'
=== added file 'loggerhead/static/javascript/yui/build/cookie/cookie-debug.js'
--- loggerhead/static/javascript/yui/build/cookie/cookie-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cookie/cookie-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,431 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * Utilities for cookie management
+ * @module cookie
+ * @beta
+ */
+
+YUI.add("cookie", function(Y){ 
+
+    //shortcuts
+    var L       = Y.Lang,
+        O       = Y.Object,
+        NULL    = null,
+        
+        //shortcuts to functions
+        isString    = L.isString,
+        isObject    = L.isObject,
+        isUndefined = L.isUndefined,
+        isFunction  = L.isFunction,
+        encode      = encodeURIComponent,
+        decode      = decodeURIComponent;
+        
+    /*
+     * Throws an error message.
+     */
+    function error(message){
+        throw new TypeError(message);
+    }        
+    
+    /**
+     * Cookie utility.
+     * @class Cookie
+     * @static
+     */
+    Y.Cookie = {
+                    
+        //-------------------------------------------------------------------------
+        // Private Methods
+        //-------------------------------------------------------------------------
+        
+        /**
+         * Creates a cookie string that can be assigned into document.cookie.
+         * @param {String} name The name of the cookie.
+         * @param {String} value The value of the cookie.
+         * @param {encodeValue} encodeValue True to encode the value, false to leave as-is.
+         * @param {Object} options (Optional) Options for the cookie.
+         * @return {String} The formatted cookie string.
+         * @method _createCookieString
+         * @private
+         * @static
+         */
+        _createCookieString : function (name /*:String*/, value /*:Variant*/, encodeValue /*:Boolean*/, options /*:Object*/) /*:String*/ {
+        
+            var text /*:String*/ = encode(name) + "=" + (encodeValue ? encode(value) : value);
+            
+        
+            if (isObject(options)){
+                //expiration date
+                if (options.expires instanceof Date){
+                    text += "; expires=" + options.expires.toGMTString();
+                }
+            
+                //path
+                if (isString(options.path) && options.path !== ""){
+                    text += "; path=" + options.path;
+                }
+        
+                //domain
+                if (isString(options.domain) && options.domain !== ""){
+                    text += "; domain=" + options.domain;
+                }
+                
+                //secure
+                if (options.secure === true){
+                    text += "; secure";
+                }
+            }
+            
+            return text;
+        },
+        
+        /**
+         * Formats a cookie value for an object containing multiple values.
+         * @param {Object} hash An object of key-value pairs to create a string for.
+         * @return {String} A string suitable for use as a cookie value.
+         * @method _createCookieHashString
+         * @private
+         * @static
+         */
+        _createCookieHashString : function (hash /*:Object*/) /*:String*/ {
+            if (!isObject(hash)){
+                error("Cookie._createCookieHashString(): Argument must be an object.");
+            }
+            
+            var text /*:Array*/ = [];
+            
+            O.each(hash, function(value, key){
+                if (!isFunction(value) && !isUndefined(value)){
+                    text.push(encode(key) + "=" + encode(String(value)));
+                }            
+            });
+            
+            return text.join("&");
+        },
+        
+        /**
+         * Parses a cookie hash string into an object.
+         * @param {String} text The cookie hash string to parse (format: n1=v1&n2=v2).
+         * @return {Object} An object containing entries for each cookie value.
+         * @method _parseCookieHash
+         * @private
+         * @static
+         */
+        _parseCookieHash : function (text /*:String*/) /*:Object*/ {
+        
+            var hashParts /*:Array*/ = text.split("&"),
+                hashPart /*:Array*/ = NULL,
+                hash /*:Object*/ = {};
+            
+            if (text.length){
+                for (var i=0, len=hashParts.length; i < len; i++){
+                    hashPart = hashParts[i].split("=");
+                    hash[decode(hashPart[0])] = decode(hashPart[1]);
+                }
+            }
+            
+            return hash;          
+        },    
+        
+        /**
+         * Parses a cookie string into an object representing all accessible cookies.
+         * @param {String} text The cookie string to parse.
+         * @param {Boolean} shouldDecode (Optional) Indicates if the cookie values should be decoded or not. Default is true.
+         * @return {Object} An object containing entries for each accessible cookie.
+         * @method _parseCookieString
+         * @private
+         * @static
+         */
+        _parseCookieString : function (text /*:String*/, shouldDecode /*:Boolean*/) /*:Object*/ {
+        
+            var cookies /*:Object*/ = {};        
+            
+            if (isString(text) && text.length > 0) {
+            
+                var decodeValue = (shouldDecode === false ? function(s){return s;} : decode);
+            
+                if (/[^=]+=[^=;]?(?:; [^=]+=[^=]?)?/.test(text)){            
+                    var cookieParts /*:Array*/ = text.split(/;\s/g),
+                        cookieName /*:String*/ = NULL,
+                        cookieValue /*:String*/ = NULL,
+                        cookieNameValue /*:Array*/ = NULL;
+                    
+                    for (var i=0, len=cookieParts.length; i < len; i++){
+                    
+                        //check for normally-formatted cookie (name-value)
+                        cookieNameValue = cookieParts[i].match(/([^=]+)=/i);
+                        if (cookieNameValue instanceof Array){
+                            cookieName = decode(cookieNameValue[1]);
+                            cookieValue = decodeValue(cookieParts[i].substring(cookieNameValue[1].length+1));
+                        } else {
+                            //means the cookie does not have an "=", so treat it as a boolean flag
+                            cookieName = decode(cookieParts[i]);
+                            cookieValue = cookieName;
+                        }
+                        cookies[cookieName] = cookieValue;
+                    }
+                }
+            }
+            
+            return cookies;
+        },    
+        
+        //-------------------------------------------------------------------------
+        // Public Methods
+        //-------------------------------------------------------------------------
+    
+        /**
+         * Returns the cookie value for the given name.
+         * @param {String} name The name of the cookie to retrieve.
+         * @param {Function} converter (Optional) A function to run on the value before returning
+         *      it. The function is not used if the cookie doesn't exist.
+         * @return {Variant} If no converter is specified, returns a string or null if
+         *      the cookie doesn't exist. If the converter is specified, returns the value
+         *      returned from the converter or null if the cookie doesn't exist.
+         * @method get
+         * @static
+         */
+        get : function (name /*:String*/, converter /*:Function*/) /*:Variant*/{
+            
+            var cookies /*:Object*/ = this._parseCookieString(document.cookie);        
+            
+            if (!isString(name) || name === ""){
+                error("Cookie.get(): Cookie name must be a non-empty string.");
+            }
+            
+            if (isUndefined(cookies[name])) {
+                return NULL;
+            }
+            
+            if (!isFunction(converter)){
+                return cookies[name];
+            } else {
+                return converter(cookies[name]);
+            }
+        },
+        
+        /**
+         * Returns the value of a subcookie.
+         * @param {String} name The name of the cookie to retrieve.
+         * @param {String} subName The name of the subcookie to retrieve.
+         * @param {Function} converter (Optional) A function to run on the value before returning
+         *      it. The function is not used if the cookie doesn't exist.
+         * @return {Variant} If the cookie doesn't exist, null is returned. If the subcookie
+         *      doesn't exist, null if also returned. If no converter is specified and the
+         *      subcookie exists, a string is returned. If a converter is specified and the
+         *      subcookie exists, the value returned from the converter is returned.
+         * @method getSub
+         * @static
+         */
+        getSub : function (name /*:String*/, subName /*:String*/, converter /*:Function*/) /*:Variant*/ {
+          
+            var hash /*:Variant*/ = this.getSubs(name);  
+    
+            if (hash !== NULL) {
+                
+                if (!isString(subName) || subName === ""){
+                    error("Cookie.getSub(): Subcookie name must be a non-empty string.");
+                }
+                
+                if (isUndefined(hash[subName])){
+                    return NULL;
+                }            
+            
+                if (!isFunction(converter)){
+                    return hash[subName];
+                } else {
+                    return converter(hash[subName]);
+                }
+            } else {
+                return NULL;
+            }
+        
+        },
+        
+        /**
+         * Returns an object containing name-value pairs stored in the cookie with the given name.
+         * @param {String} name The name of the cookie to retrieve.
+         * @return {Object} An object of name-value pairs if the cookie with the given name
+         *      exists, null if it does not.
+         * @method getSubs
+         * @static
+         */
+        getSubs : function (name /*:String*/) /*:Object*/ {
+            
+            //check cookie name
+            if (!isString(name) || name === ""){
+                error("Cookie.getSubs(): Cookie name must be a non-empty string.");
+            }
+            
+            var cookies = this._parseCookieString(document.cookie, false);
+            if (isString(cookies[name])){
+                return this._parseCookieHash(cookies[name]);
+            }
+            return NULL;
+        },
+        
+        /**
+         * Removes a cookie from the machine by setting its expiration date to
+         * sometime in the past.
+         * @param {String} name The name of the cookie to remove.
+         * @param {Object} options (Optional) An object containing one or more
+         *      cookie options: path (a string), domain (a string), 
+         *      and secure (true/false). The expires option will be overwritten
+         *      by the method.
+         * @return {String} The created cookie string.
+         * @method remove
+         * @static
+         */
+        remove : function (name /*:String*/, options /*:Object*/) /*:String*/ {
+            
+            //check cookie name
+            if (!isString(name) || name === ""){
+                error("Cookie.remove(): Cookie name must be a non-empty string.");
+            }
+            
+            //set options
+            options = options || {};
+            options.expires = new Date(0);
+            
+            //set cookie
+            return this.set(name, "", options);
+        },
+    
+        /**
+         * Removes a sub cookie with a given name.
+         * @param {String} name The name of the cookie in which the subcookie exists.
+         * @param {String} subName The name of the subcookie to remove.
+         * @param {Object} options (Optional) An object containing one or more
+         *      cookie options: path (a string), domain (a string), expires (a Date object),
+         *      and secure (true/false). This must be the same settings as the original
+         *      subcookie.
+         * @return {String} The created cookie string.
+         * @method removeSub
+         * @static
+         */
+        removeSub : function(name /*:String*/, subName /*:String*/, options /*:Object*/) /*:String*/ {
+        
+            //check cookie name
+            if (!isString(name) || name === ""){
+                error("Cookie.removeSub(): Cookie name must be a non-empty string.");
+            }
+            
+            //check subcookie name
+            if (!isString(subName) || subName === ""){
+                error("Cookie.removeSub(): Subcookie name must be a non-empty string.");
+            }
+            
+            //get all subcookies for this cookie
+            var subs = this.getSubs(name);
+            
+            //delete the indicated subcookie
+            if (isObject(subs) && O.owns(subs, subName)){
+                delete subs[subName];
+                
+                //reset the cookie
+                return this.setSubs(name, subs, options);
+            } else {
+                return "";
+            }
+            
+        },
+    
+        /**
+         * Sets a cookie with a given name and value.
+         * @param {String} name The name of the cookie to set.
+         * @param {Variant} value The value to set for the cookie.
+         * @param {Object} options (Optional) An object containing one or more
+         *      cookie options: path (a string), domain (a string), expires (a Date object),
+         *      and secure (true/false).
+         * @return {String} The created cookie string.
+         * @method set
+         * @static
+         */
+        set : function (name /*:String*/, value /*:Variant*/, options /*:Object*/) /*:String*/ {
+        
+            if (!isString(name)){
+                error("Cookie.set(): Cookie name must be a string.");
+            }
+            
+            if (isUndefined(value)){
+                error("Cookie.set(): Value cannot be undefined.");
+            }
+            
+        
+            var text /*:String*/ = this._createCookieString(name, value, true, options);
+            document.cookie = text;
+            return text;
+        },
+            
+        /**
+         * Sets a sub cookie with a given name to a particular value.
+         * @param {String} name The name of the cookie to set.
+         * @param {String} subName The name of the subcookie to set.
+         * @param {Variant} value The value to set.
+         * @param {Object} options (Optional) An object containing one or more
+         *      cookie options: path (a string), domain (a string), expires (a Date object),
+         *      and secure (true/false).
+         * @return {String} The created cookie string.
+         * @method setSub
+         * @static
+         */
+        setSub : function (name /*:String*/, subName /*:String*/, value /*:Variant*/, options /*:Object*/) /*:String*/ {
+
+            if (!isString(name) || name === ""){
+                error("Cookie.setSub(): Cookie name must be a non-empty string.");
+            }
+    
+            if (!isString(subName) || subName === ""){
+                error("Cookie.setSub(): Subcookie name must be a non-empty string.");
+            }
+            
+            if (isUndefined(value)){
+                error("Cookie.setSub(): Subcookie value cannot be undefined.");
+            }
+    
+            var hash /*:Object*/ = this.getSubs(name);
+            
+            if (!isObject(hash)){
+                hash = {};
+            }
+            
+            hash[subName] = value;        
+            
+            return this.setSubs(name, hash, options);
+            
+        },
+        
+        /**
+         * Sets a cookie with a given name to contain a hash of name-value pairs.
+         * @param {String} name The name of the cookie to set.
+         * @param {Object} value An object containing name-value pairs.
+         * @param {Object} options (Optional) An object containing one or more
+         *      cookie options: path (a string), domain (a string), expires (a Date object),
+         *      and secure (true/false).
+         * @return {String} The created cookie string.
+         * @method setSubs
+         * @static
+         */
+        setSubs : function (name /*:String*/, value /*:Object*/, options /*:Object*/) /*:String*/ {
+            
+            if (!isString(name)){
+                error("Cookie.setSubs(): Cookie name must be a string.");
+            }
+            
+            if (!isObject(value)){
+                error("Cookie.setSubs(): Cookie value must be an object.");
+            }
+        
+            var text /*:String*/ = this._createCookieString(name, this._createCookieHashString(value), false, options);
+            document.cookie = text;
+            return text;        
+        }     
+    
+    };
+}, "3.0.0");
+

=== added file 'loggerhead/static/javascript/yui/build/cookie/cookie-min.js'
--- loggerhead/static/javascript/yui/build/cookie/cookie-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cookie/cookie-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("cookie",function(B){var J=B.Lang,H=B.Object,F=null,C=J.isString,K=J.isObject,E=J.isUndefined,D=J.isFunction,G=encodeURIComponent,A=decodeURIComponent;function I(L){throw new TypeError(L);}B.Cookie={_createCookieString:function(M,O,N,L){var P=G(M)+"="+(N?G(O):O);if(K(L)){if(L.expires instanceof Date){P+="; expires="+L.expires.toGMTString();}if(C(L.path)&&L.path!==""){P+="; path="+L.path;}if(C(L.domain)&&L.domain!==""){P+="; domain="+L.domain;}if(L.secure===true){P+="; secure";}}return P;},_createCookieHashString:function(L){if(!K(L)){I("Cookie._createCookieHashString(): Argument must be an object.");}var M=[];H.each(L,function(O,N){if(!D(O)&&!E(O)){M.push(G(N)+"="+G(String(O)));}});return M.join("&");},_parseCookieHash:function(P){var O=P.split("&"),Q=F,N={};if(P.length){for(var M=0,L=O.length;M<L;M++){Q=O[M].split("=");N[A(Q[0])]=A(Q[1]);}}return N;},_parseCookieString:function(S,U){var T={};if(C(S)&&S.length>0){var L=(U===false?function(V){return V;}:A);if(/[^=]+=[^=;]?(?:; [^=]+=[^=]?)?/.test(S)){var Q=S.split(/;\s/g),R=F,M=F,O=F;for(var N=0,P=Q.length;N<P;N++){O=Q[N].match(/([^=]+)=/i);if(O instanceof Array){R=A(O[1]);M=L(Q[N].substring(O[1].length+1));}else{R=A(Q[N]);M=R;}T[R]=M;}}}return T;},get:function(L,M){var N=this._parseCookieString(document.cookie);if(!C(L)||L===""){I("Cookie.get(): Cookie name must be a non-empty string.");}if(E(N[L])){return F;}if(!D(M)){return N[L];}else{return M(N[L]);}},getSub:function(L,N,M){var O=this.getSubs(L);if(O!==F){if(!C(N)||N===""){I("Cookie.getSub(): Subcookie name must be a non-empty string.");}if(E(O[N])){return F;}if(!D(M)){return O[N];}else{return M(O[N]);}}else{return F;}},getSubs:function(L){if(!C(L)||L===""){I("Cookie.getSubs(): Cookie name must be a non-empty string.");}var M=this._parseCookieString(document.cookie,false);if(C(M[L])){return this._parseCookieHash(M[L]);}return F;},remove:function(M,L){if(!C(M)||M===""){I("Cookie.remove(): Cookie name must be a non-empty string.");}L=L||{};L.expires=new Date(0);return this.set(M,"",L);},removeSub:function(M,O,L){if(!C(M)||M===""){I("Cookie.removeSub(): Cookie name must be a non-empty string.");}if(!C(O)||O===""){I("Cookie.removeSub(): Subcookie name must be a non-empty string.");}var N=this.getSubs(M);if(K(N)&&H.owns(N,O)){delete N[O];return this.setSubs(M,N,L);}else{return"";}},set:function(M,N,L){if(!C(M)){I("Cookie.set(): Cookie name must be a string.");}if(E(N)){I("Cookie.set(): Value cannot be undefined.");}var O=this._createCookieString(M,N,true,L);document.cookie=O;return O;},setSub:function(M,O,N,L){if(!C(M)||M===""){I("Cookie.setSub(): Cookie name must be a non-empty string.");}if(!C(O)||O===""){I("Cookie.setSub(): Subcookie name must be a non-empty string.");}if(E(N)){I("Cookie.setSub(): Subcookie value cannot be undefined.");}var P=this.getSubs(M);if(!K(P)){P={};}P[O]=N;return this.setSubs(M,P,L);},setSubs:function(M,N,L){if(!C(M)){I("Cookie.setSubs(): Cookie name must be a string.");}if(!K(N)){I("Cookie.setSubs(): Cookie value must be an object.");}var O=this._createCookieString(M,this._createCookieHashString(N),false,L);document.cookie=O;return O;}};},"3.0.0");
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cookie/cookie.js'
--- loggerhead/static/javascript/yui/build/cookie/cookie.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cookie/cookie.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,431 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * Utilities for cookie management
+ * @module cookie
+ * @beta
+ */
+
+YUI.add("cookie", function(Y){ 
+
+    //shortcuts
+    var L       = Y.Lang,
+        O       = Y.Object,
+        NULL    = null,
+        
+        //shortcuts to functions
+        isString    = L.isString,
+        isObject    = L.isObject,
+        isUndefined = L.isUndefined,
+        isFunction  = L.isFunction,
+        encode      = encodeURIComponent,
+        decode      = decodeURIComponent;
+        
+    /*
+     * Throws an error message.
+     */
+    function error(message){
+        throw new TypeError(message);
+    }        
+    
+    /**
+     * Cookie utility.
+     * @class Cookie
+     * @static
+     */
+    Y.Cookie = {
+                    
+        //-------------------------------------------------------------------------
+        // Private Methods
+        //-------------------------------------------------------------------------
+        
+        /**
+         * Creates a cookie string that can be assigned into document.cookie.
+         * @param {String} name The name of the cookie.
+         * @param {String} value The value of the cookie.
+         * @param {encodeValue} encodeValue True to encode the value, false to leave as-is.
+         * @param {Object} options (Optional) Options for the cookie.
+         * @return {String} The formatted cookie string.
+         * @method _createCookieString
+         * @private
+         * @static
+         */
+        _createCookieString : function (name /*:String*/, value /*:Variant*/, encodeValue /*:Boolean*/, options /*:Object*/) /*:String*/ {
+        
+            var text /*:String*/ = encode(name) + "=" + (encodeValue ? encode(value) : value);
+            
+        
+            if (isObject(options)){
+                //expiration date
+                if (options.expires instanceof Date){
+                    text += "; expires=" + options.expires.toGMTString();
+                }
+            
+                //path
+                if (isString(options.path) && options.path !== ""){
+                    text += "; path=" + options.path;
+                }
+        
+                //domain
+                if (isString(options.domain) && options.domain !== ""){
+                    text += "; domain=" + options.domain;
+                }
+                
+                //secure
+                if (options.secure === true){
+                    text += "; secure";
+                }
+            }
+            
+            return text;
+        },
+        
+        /**
+         * Formats a cookie value for an object containing multiple values.
+         * @param {Object} hash An object of key-value pairs to create a string for.
+         * @return {String} A string suitable for use as a cookie value.
+         * @method _createCookieHashString
+         * @private
+         * @static
+         */
+        _createCookieHashString : function (hash /*:Object*/) /*:String*/ {
+            if (!isObject(hash)){
+                error("Cookie._createCookieHashString(): Argument must be an object.");
+            }
+            
+            var text /*:Array*/ = [];
+            
+            O.each(hash, function(value, key){
+                if (!isFunction(value) && !isUndefined(value)){
+                    text.push(encode(key) + "=" + encode(String(value)));
+                }            
+            });
+            
+            return text.join("&");
+        },
+        
+        /**
+         * Parses a cookie hash string into an object.
+         * @param {String} text The cookie hash string to parse (format: n1=v1&n2=v2).
+         * @return {Object} An object containing entries for each cookie value.
+         * @method _parseCookieHash
+         * @private
+         * @static
+         */
+        _parseCookieHash : function (text /*:String*/) /*:Object*/ {
+        
+            var hashParts /*:Array*/ = text.split("&"),
+                hashPart /*:Array*/ = NULL,
+                hash /*:Object*/ = {};
+            
+            if (text.length){
+                for (var i=0, len=hashParts.length; i < len; i++){
+                    hashPart = hashParts[i].split("=");
+                    hash[decode(hashPart[0])] = decode(hashPart[1]);
+                }
+            }
+            
+            return hash;          
+        },    
+        
+        /**
+         * Parses a cookie string into an object representing all accessible cookies.
+         * @param {String} text The cookie string to parse.
+         * @param {Boolean} shouldDecode (Optional) Indicates if the cookie values should be decoded or not. Default is true.
+         * @return {Object} An object containing entries for each accessible cookie.
+         * @method _parseCookieString
+         * @private
+         * @static
+         */
+        _parseCookieString : function (text /*:String*/, shouldDecode /*:Boolean*/) /*:Object*/ {
+        
+            var cookies /*:Object*/ = {};        
+            
+            if (isString(text) && text.length > 0) {
+            
+                var decodeValue = (shouldDecode === false ? function(s){return s;} : decode);
+            
+                if (/[^=]+=[^=;]?(?:; [^=]+=[^=]?)?/.test(text)){            
+                    var cookieParts /*:Array*/ = text.split(/;\s/g),
+                        cookieName /*:String*/ = NULL,
+                        cookieValue /*:String*/ = NULL,
+                        cookieNameValue /*:Array*/ = NULL;
+                    
+                    for (var i=0, len=cookieParts.length; i < len; i++){
+                    
+                        //check for normally-formatted cookie (name-value)
+                        cookieNameValue = cookieParts[i].match(/([^=]+)=/i);
+                        if (cookieNameValue instanceof Array){
+                            cookieName = decode(cookieNameValue[1]);
+                            cookieValue = decodeValue(cookieParts[i].substring(cookieNameValue[1].length+1));
+                        } else {
+                            //means the cookie does not have an "=", so treat it as a boolean flag
+                            cookieName = decode(cookieParts[i]);
+                            cookieValue = cookieName;
+                        }
+                        cookies[cookieName] = cookieValue;
+                    }
+                }
+            }
+            
+            return cookies;
+        },    
+        
+        //-------------------------------------------------------------------------
+        // Public Methods
+        //-------------------------------------------------------------------------
+    
+        /**
+         * Returns the cookie value for the given name.
+         * @param {String} name The name of the cookie to retrieve.
+         * @param {Function} converter (Optional) A function to run on the value before returning
+         *      it. The function is not used if the cookie doesn't exist.
+         * @return {Variant} If no converter is specified, returns a string or null if
+         *      the cookie doesn't exist. If the converter is specified, returns the value
+         *      returned from the converter or null if the cookie doesn't exist.
+         * @method get
+         * @static
+         */
+        get : function (name /*:String*/, converter /*:Function*/) /*:Variant*/{
+            
+            var cookies /*:Object*/ = this._parseCookieString(document.cookie);        
+            
+            if (!isString(name) || name === ""){
+                error("Cookie.get(): Cookie name must be a non-empty string.");
+            }
+            
+            if (isUndefined(cookies[name])) {
+                return NULL;
+            }
+            
+            if (!isFunction(converter)){
+                return cookies[name];
+            } else {
+                return converter(cookies[name]);
+            }
+        },
+        
+        /**
+         * Returns the value of a subcookie.
+         * @param {String} name The name of the cookie to retrieve.
+         * @param {String} subName The name of the subcookie to retrieve.
+         * @param {Function} converter (Optional) A function to run on the value before returning
+         *      it. The function is not used if the cookie doesn't exist.
+         * @return {Variant} If the cookie doesn't exist, null is returned. If the subcookie
+         *      doesn't exist, null if also returned. If no converter is specified and the
+         *      subcookie exists, a string is returned. If a converter is specified and the
+         *      subcookie exists, the value returned from the converter is returned.
+         * @method getSub
+         * @static
+         */
+        getSub : function (name /*:String*/, subName /*:String*/, converter /*:Function*/) /*:Variant*/ {
+          
+            var hash /*:Variant*/ = this.getSubs(name);  
+    
+            if (hash !== NULL) {
+                
+                if (!isString(subName) || subName === ""){
+                    error("Cookie.getSub(): Subcookie name must be a non-empty string.");
+                }
+                
+                if (isUndefined(hash[subName])){
+                    return NULL;
+                }            
+            
+                if (!isFunction(converter)){
+                    return hash[subName];
+                } else {
+                    return converter(hash[subName]);
+                }
+            } else {
+                return NULL;
+            }
+        
+        },
+        
+        /**
+         * Returns an object containing name-value pairs stored in the cookie with the given name.
+         * @param {String} name The name of the cookie to retrieve.
+         * @return {Object} An object of name-value pairs if the cookie with the given name
+         *      exists, null if it does not.
+         * @method getSubs
+         * @static
+         */
+        getSubs : function (name /*:String*/) /*:Object*/ {
+            
+            //check cookie name
+            if (!isString(name) || name === ""){
+                error("Cookie.getSubs(): Cookie name must be a non-empty string.");
+            }
+            
+            var cookies = this._parseCookieString(document.cookie, false);
+            if (isString(cookies[name])){
+                return this._parseCookieHash(cookies[name]);
+            }
+            return NULL;
+        },
+        
+        /**
+         * Removes a cookie from the machine by setting its expiration date to
+         * sometime in the past.
+         * @param {String} name The name of the cookie to remove.
+         * @param {Object} options (Optional) An object containing one or more
+         *      cookie options: path (a string), domain (a string), 
+         *      and secure (true/false). The expires option will be overwritten
+         *      by the method.
+         * @return {String} The created cookie string.
+         * @method remove
+         * @static
+         */
+        remove : function (name /*:String*/, options /*:Object*/) /*:String*/ {
+            
+            //check cookie name
+            if (!isString(name) || name === ""){
+                error("Cookie.remove(): Cookie name must be a non-empty string.");
+            }
+            
+            //set options
+            options = options || {};
+            options.expires = new Date(0);
+            
+            //set cookie
+            return this.set(name, "", options);
+        },
+    
+        /**
+         * Removes a sub cookie with a given name.
+         * @param {String} name The name of the cookie in which the subcookie exists.
+         * @param {String} subName The name of the subcookie to remove.
+         * @param {Object} options (Optional) An object containing one or more
+         *      cookie options: path (a string), domain (a string), expires (a Date object),
+         *      and secure (true/false). This must be the same settings as the original
+         *      subcookie.
+         * @return {String} The created cookie string.
+         * @method removeSub
+         * @static
+         */
+        removeSub : function(name /*:String*/, subName /*:String*/, options /*:Object*/) /*:String*/ {
+        
+            //check cookie name
+            if (!isString(name) || name === ""){
+                error("Cookie.removeSub(): Cookie name must be a non-empty string.");
+            }
+            
+            //check subcookie name
+            if (!isString(subName) || subName === ""){
+                error("Cookie.removeSub(): Subcookie name must be a non-empty string.");
+            }
+            
+            //get all subcookies for this cookie
+            var subs = this.getSubs(name);
+            
+            //delete the indicated subcookie
+            if (isObject(subs) && O.owns(subs, subName)){
+                delete subs[subName];
+                
+                //reset the cookie
+                return this.setSubs(name, subs, options);
+            } else {
+                return "";
+            }
+            
+        },
+    
+        /**
+         * Sets a cookie with a given name and value.
+         * @param {String} name The name of the cookie to set.
+         * @param {Variant} value The value to set for the cookie.
+         * @param {Object} options (Optional) An object containing one or more
+         *      cookie options: path (a string), domain (a string), expires (a Date object),
+         *      and secure (true/false).
+         * @return {String} The created cookie string.
+         * @method set
+         * @static
+         */
+        set : function (name /*:String*/, value /*:Variant*/, options /*:Object*/) /*:String*/ {
+        
+            if (!isString(name)){
+                error("Cookie.set(): Cookie name must be a string.");
+            }
+            
+            if (isUndefined(value)){
+                error("Cookie.set(): Value cannot be undefined.");
+            }
+            
+        
+            var text /*:String*/ = this._createCookieString(name, value, true, options);
+            document.cookie = text;
+            return text;
+        },
+            
+        /**
+         * Sets a sub cookie with a given name to a particular value.
+         * @param {String} name The name of the cookie to set.
+         * @param {String} subName The name of the subcookie to set.
+         * @param {Variant} value The value to set.
+         * @param {Object} options (Optional) An object containing one or more
+         *      cookie options: path (a string), domain (a string), expires (a Date object),
+         *      and secure (true/false).
+         * @return {String} The created cookie string.
+         * @method setSub
+         * @static
+         */
+        setSub : function (name /*:String*/, subName /*:String*/, value /*:Variant*/, options /*:Object*/) /*:String*/ {
+
+            if (!isString(name) || name === ""){
+                error("Cookie.setSub(): Cookie name must be a non-empty string.");
+            }
+    
+            if (!isString(subName) || subName === ""){
+                error("Cookie.setSub(): Subcookie name must be a non-empty string.");
+            }
+            
+            if (isUndefined(value)){
+                error("Cookie.setSub(): Subcookie value cannot be undefined.");
+            }
+    
+            var hash /*:Object*/ = this.getSubs(name);
+            
+            if (!isObject(hash)){
+                hash = {};
+            }
+            
+            hash[subName] = value;        
+            
+            return this.setSubs(name, hash, options);
+            
+        },
+        
+        /**
+         * Sets a cookie with a given name to contain a hash of name-value pairs.
+         * @param {String} name The name of the cookie to set.
+         * @param {Object} value An object containing name-value pairs.
+         * @param {Object} options (Optional) An object containing one or more
+         *      cookie options: path (a string), domain (a string), expires (a Date object),
+         *      and secure (true/false).
+         * @return {String} The created cookie string.
+         * @method setSubs
+         * @static
+         */
+        setSubs : function (name /*:String*/, value /*:Object*/, options /*:Object*/) /*:String*/ {
+            
+            if (!isString(name)){
+                error("Cookie.setSubs(): Cookie name must be a string.");
+            }
+            
+            if (!isObject(value)){
+                error("Cookie.setSubs(): Cookie value must be an object.");
+            }
+        
+            var text /*:String*/ = this._createCookieString(name, this._createCookieHashString(value), false, options);
+            document.cookie = text;
+            return text;        
+        }     
+    
+    };
+}, "3.0.0");
+

=== added directory 'loggerhead/static/javascript/yui/build/cssbase'
=== added file 'loggerhead/static/javascript/yui/build/cssbase/README'
--- loggerhead/static/javascript/yui/build/cssbase/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssbase/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,21 @@
+**** version 3.0.0 PR2 ***	
+
+  * No code changes.
+  * Minimized -min versions.
+  * Updated comments for DL DD.
+
+3.0.0PR1 - Initial release
+
+Module Name: "cssbase"
+Documentation: http://developer.yahoo.com/yui/3/cssbase
+
+CSS Base is an optional CSS file that complements YUI's 
+core CSS foundation (CSS Reset, CSS Fonts, and CSS Grids). 
+CSS Base applies a style foundation for HTML elements 
+that is consistent for A-grade browsers.
+
+CSS Base may also be useful as a template for your own 
+base file, or a snippets library for styling HTML elements.
+
+Many individual values within Base can be overwritten 
+locally by setting them to auto or inherit.

=== added file 'loggerhead/static/javascript/yui/build/cssbase/base-context-min.css'
--- loggerhead/static/javascript/yui/build/cssbase/base-context-min.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssbase/base-context-min.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-cssbase h1{font-size:138.5%;}.yui-cssbase h2{font-size:123.1%;}.yui-cssbase h3{font-size:108%;}.yui-cssbase h1,.yui-cssbase h2,.yui-cssbase h3{margin:1em 0;}.yui-cssbase h1,.yui-cssbase h2,.yui-cssbase h3,.yui-cssbase h4,.yui-cssbase h5,.yui-cssbase h6,.yui-cssbase strong{font-weight:bold;}.yui-cssbase abbr,.yui-cssbase acronym{border-bottom:1px dotted #000;cursor:help;}.yui-cssbase em{font-style:italic;}.yui-cssbase blockquote,.yui-cssbase ul,.yui-cssbase ol,.yui-cssbase dl{margin:1em;}.yui-cssbase ol,.yui-cssbase ul,.yui-cssbase dl{margin-left:2em;}.yui-cssbase ol li{list-style:decimal outside;}.yui-cssbase ul li{list-style:disc outside;}.yui-cssbase dl dd{margin-left:1em;}.yui-cssbase th,.yui-cssbase td{border:1px solid #000;padding:.5em;}.yui-cssbase th{font-weight:bold;text-align:center;}.yui-cssbase caption{margin-bottom:.5em;text-align:center;}.yui-cssbase p,.yui-cssbase fieldset,.yui-cssbase table,.yui-cssbase pre{margin-bottom:1em;}.yui-cssbase input[type=text],.yui-cssbase input[type=password],.yui-cssbase textarea{width:12.25em;*width:11.9em;}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssbase/base-context.css'
--- loggerhead/static/javascript/yui/build/cssbase/base-context.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssbase/base-context.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,79 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/* base.css, part of YUI's CSS Foundation */
+.yui-cssbase h1 {
+	/*18px via YUI Fonts CSS foundation*/
+	font-size:138.5%;  
+}
+.yui-cssbase h2 {
+	/*16px via YUI Fonts CSS foundation*/
+	font-size:123.1%; 
+}
+.yui-cssbase h3 {
+	/*14px via YUI Fonts CSS foundation*/
+	font-size:108%;  
+}
+.yui-cssbase h1,.yui-cssbase h2,.yui-cssbase h3 {
+	/* top & bottom margin based on font size */
+	margin:1em 0;
+}
+.yui-cssbase h1,.yui-cssbase h2,.yui-cssbase h3,.yui-cssbase h4,.yui-cssbase h5,.yui-cssbase h6,.yui-cssbase strong {
+	/*bringing boldness back to headers and the strong element*/
+	font-weight:bold; 
+}
+.yui-cssbase abbr,.yui-cssbase acronym {
+	/*indicating to users that more info is available */
+	border-bottom:1px dotted #000;
+	cursor:help;
+} 
+.yui-cssbase em {
+	/*bringing italics back to the em element*/
+	font-style:italic;
+}
+.yui-cssbase blockquote,.yui-cssbase ul,.yui-cssbase ol,.yui-cssbase dl {
+	/*giving blockquotes and lists room to breath*/
+	margin:1em;
+}
+.yui-cssbase ol,.yui-cssbase ul,.yui-cssbase dl {
+	/*bringing lists on to the page with breathing room */
+	margin-left:2em;
+}
+.yui-cssbase ol li {
+	/*giving OL's LIs generated numbers*/
+	list-style: decimal outside;	
+}
+.yui-cssbase ul li {
+	/*giving UL's LIs generated disc markers*/
+	list-style: disc outside;
+}
+.yui-cssbase dl dd {
+	/*providing spacing for definition terms*/
+	margin-left:1em;
+}
+.yui-cssbase th,.yui-cssbase td {
+	/*borders and padding to make the table readable*/
+	border:1px solid #000;
+	padding:.5em;
+}
+.yui-cssbase th {
+	/*distinguishing table headers from data cells*/
+	font-weight:bold;
+	text-align:center;
+}
+.yui-cssbase caption {
+	/*coordinated margin to match cell's padding*/
+	margin-bottom:.5em;
+	/*centered so it doesn't blend in to other content*/
+	text-align:center;
+}
+.yui-cssbase p,.yui-cssbase fieldset,.yui-cssbase table,.yui-cssbase pre {
+	/*so things don't run into each other*/
+	margin-bottom:1em;
+}
+/* setting a consistent width, 160px; 
+   control of type=file still not possible */
+.yui-cssbase input[type=text],.yui-cssbase input[type=password],.yui-cssbase textarea{width:12.25em;*width:11.9em;}

=== added file 'loggerhead/static/javascript/yui/build/cssbase/base-min.css'
--- loggerhead/static/javascript/yui/build/cssbase/base-min.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssbase/base-min.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+h1{font-size:138.5%;}h2{font-size:123.1%;}h3{font-size:108%;}h1,h2,h3{margin:1em 0;}h1,h2,h3,h4,h5,h6,strong{font-weight:bold;}abbr,acronym{border-bottom:1px dotted #000;cursor:help;}em{font-style:italic;}blockquote,ul,ol,dl{margin:1em;}ol,ul,dl{margin-left:2em;}ol li{list-style:decimal outside;}ul li{list-style:disc outside;}dl dd{margin-left:1em;}th,td{border:1px solid #000;padding:.5em;}th{font-weight:bold;text-align:center;}caption{margin-bottom:.5em;text-align:center;}p,fieldset,table,pre{margin-bottom:1em;}input[type=text],input[type=password],textarea{width:12.25em;*width:11.9em;}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssbase/base.css'
--- loggerhead/static/javascript/yui/build/cssbase/base.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssbase/base.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,79 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/* base.css, part of YUI's CSS Foundation */
+h1 {
+	/*18px via YUI Fonts CSS foundation*/
+	font-size:138.5%;  
+}
+h2 {
+	/*16px via YUI Fonts CSS foundation*/
+	font-size:123.1%; 
+}
+h3 {
+	/*14px via YUI Fonts CSS foundation*/
+	font-size:108%;  
+}
+h1,h2,h3 {
+	/* top & bottom margin based on font size */
+	margin:1em 0;
+}
+h1,h2,h3,h4,h5,h6,strong {
+	/*bringing boldness back to headers and the strong element*/
+	font-weight:bold; 
+}
+abbr,acronym {
+	/*indicating to users that more info is available */
+	border-bottom:1px dotted #000;
+	cursor:help;
+} 
+em {
+	/*bringing italics back to the em element*/
+	font-style:italic;
+}
+blockquote,ul,ol,dl {
+	/*giving blockquotes and lists room to breath*/
+	margin:1em;
+}
+ol,ul,dl {
+	/*bringing lists on to the page with breathing room */
+	margin-left:2em;
+}
+ol li {
+	/*giving OL's LIs generated numbers*/
+	list-style: decimal outside;	
+}
+ul li {
+	/*giving UL's LIs generated disc markers*/
+	list-style: disc outside;
+}
+dl dd {
+	/*providing spacing for definition terms*/
+	margin-left:1em;
+}
+th,td {
+	/*borders and padding to make the table readable*/
+	border:1px solid #000;
+	padding:.5em;
+}
+th {
+	/*distinguishing table headers from data cells*/
+	font-weight:bold;
+	text-align:center;
+}
+caption {
+	/*coordinated margin to match cell's padding*/
+	margin-bottom:.5em;
+	/*centered so it doesn't blend in to other content*/
+	text-align:center;
+}
+p,fieldset,table,pre {
+	/*so things don't run into each other*/
+	margin-bottom:1em;
+}
+/* setting a consistent width, 160px; 
+   control of type=file still not possible */
+input[type=text],input[type=password],textarea{width:12.25em;*width:11.9em;}

=== added directory 'loggerhead/static/javascript/yui/build/cssfonts'
=== added file 'loggerhead/static/javascript/yui/build/cssfonts/README'
--- loggerhead/static/javascript/yui/build/cssfonts/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssfonts/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,13 @@
+**** version 3.0.0 PR2 ***	
+
+  * No changes.
+
+3.0.0PR1 - Initial release
+
+Module Name: "cssfonts"
+Documentation: http://developer.yahoo.com/yui/3/cssfonts
+
+The foundational CSS Fonts provides cross-browser 
+typographical normalization and control while still 
+allowing users to choose and adjust their font size. 
+Both Standards and Quirks modes are supported in A-grade browsers.

=== added file 'loggerhead/static/javascript/yui/build/cssfonts/fonts-context-min.css'
--- loggerhead/static/javascript/yui/build/cssfonts/fonts-context-min.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssfonts/fonts-context-min.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-cssfonts body,.yui-cssfonts{font:13px/1.231 arial,helvetica,clean,sans-serif;*font-size:small;*font:x-small;}.yui-cssfonts select,.yui-cssfonts input,.yui-cssfonts button,.yui-cssfonts textarea{font:99% arial,helvetica,clean,sans-serif;}.yui-cssfonts table{font-size:inherit;font:100%;}.yui-cssfonts pre,.yui-cssfonts code,.yui-cssfonts kbd,.yui-cssfonts samp,.yui-cssfonts tt{font-family:monospace;*font-size:108%;line-height:100%;}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssfonts/fonts-context.css'
--- loggerhead/static/javascript/yui/build/cssfonts/fonts-context.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssfonts/fonts-context.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,46 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * Percents could work for IE, but for backCompat purposes, we are using keywords.
+ * x-small is for IE6/7 quirks mode.
+ */
+.yui-cssfonts body, .yui-cssfonts {
+	font:13px/1.231 arial,helvetica,clean,sans-serif;
+	*font-size:small; /* for IE */
+	*font:x-small; /* for IE in quirks mode */
+}
+
+/**
+ * Nudge down to get to 13px equivalent for these form elements
+ */ 
+.yui-cssfonts select,
+.yui-cssfonts input,
+.yui-cssfonts button,
+.yui-cssfonts textarea {
+	font:99% arial,helvetica,clean,sans-serif;
+}
+
+/**
+ * To help tables remember to inherit
+ */
+.yui-cssfonts table {
+	font-size:inherit;
+	font:100%;
+}
+
+/**
+ * Bump up IE to get to 13px equivalent for these fixed-width elements
+ */
+.yui-cssfonts pre,
+.yui-cssfonts code,
+.yui-cssfonts kbd,
+.yui-cssfonts samp,
+.yui-cssfonts tt {
+	font-family:monospace;
+	*font-size:108%;
+	line-height:100%;
+}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssfonts/fonts-min.css'
--- loggerhead/static/javascript/yui/build/cssfonts/fonts-min.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssfonts/fonts-min.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+body{font:13px/1.231 arial,helvetica,clean,sans-serif;*font-size:small;*font:x-small;}select,input,button,textarea{font:99% arial,helvetica,clean,sans-serif;}table{font-size:inherit;font:100%;}pre,code,kbd,samp,tt{font-family:monospace;*font-size:108%;line-height:100%;}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssfonts/fonts.css'
--- loggerhead/static/javascript/yui/build/cssfonts/fonts.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssfonts/fonts.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,46 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * Percents could work for IE, but for backCompat purposes, we are using keywords.
+ * x-small is for IE6/7 quirks mode.
+ */
+body {
+	font:13px/1.231 arial,helvetica,clean,sans-serif;
+	*font-size:small; /* for IE */
+	*font:x-small; /* for IE in quirks mode */
+}
+
+/**
+ * Nudge down to get to 13px equivalent for these form elements
+ */ 
+select,
+input,
+button,
+textarea {
+	font:99% arial,helvetica,clean,sans-serif;
+}
+
+/**
+ * To help tables remember to inherit
+ */
+table {
+	font-size:inherit;
+	font:100%;
+}
+
+/**
+ * Bump up IE to get to 13px equivalent for these fixed-width elements
+ */
+pre,
+code,
+kbd,
+samp,
+tt {
+	font-family:monospace;
+	*font-size:108%;
+	line-height:100%;
+}
\ No newline at end of file

=== added directory 'loggerhead/static/javascript/yui/build/cssgrids'
=== added file 'loggerhead/static/javascript/yui/build/cssgrids/README'
--- loggerhead/static/javascript/yui/build/cssgrids/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssgrids/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,34 @@
+**** version 3.0.0 PR2 ***
+
+    * Added self-clearing for templates (e.g. div.yui-t1) for 
+      cases when they are not within #bd. Per ticket 2201115
+    * Corrected ordering issue for "gb" per internal ticket 
+      2251219 and Sourceforge ticket 2131681
+    * Enabled nesting of gf within gc per internal ticket 
+      1458071 and Sourceforget ticket 1786723
+
+3.0.0PR1 - Initial release
+
+Module Name: "cssgrids"
+Documentation: http://developer.yahoo.com/yui/3/cssgrids
+
+The foundational CSS Grids offers four preset page widths, 
+six preset two-column source-order-independent content 
+templates, and the ability to stack and nest subdivided 
+regions of two, three, or four columns. The file provides 
+over 1000 page layout combinations. Other features include:
+
+    * Supports fluid 100-percent layouts, fluid- and 
+      fixed-width layouts at 750px, 950px, and 974px 
+      centered, and the ability to easily customize the 
+      width.
+    * Flexible in response to user initiated font-size 
+      adjustments.
+    * Template columns are source-order independent; put
+      your most important content earlier in your markup
+      for improved accessibility and SEO.
+    * Self-clearing footer. No matter which column is
+      longer, the footer stays below the longest.
+    * Accommodates IAB's Ad Unit Guidelines for common 
+      ad dimensions.
+

=== added file 'loggerhead/static/javascript/yui/build/cssgrids/grids-context-min.css'
--- loggerhead/static/javascript/yui/build/cssgrids/grids-context-min.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssgrids/grids-context-min.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-cssgrids body{text-align:center;margin-left:auto;margin-right:auto;}.yui-cssgrids .yui-d0,.yui-cssgrids .yui-d1,.yui-cssgrids .yui-d1f,.yui-cssgrids .yui-d2,.yui-cssgrids .yui-d2f,.yui-cssgrids .yui-d3,.yui-cssgrids .yui-d3f{margin:auto;text-align:left;width:57.69em;*width:56.25em;}.yui-cssgrids .yui-t1,.yui-cssgrids .yui-t2,.yui-cssgrids .yui-t3,.yui-cssgrids .yui-t4,.yui-cssgrids .yui-t5,.yui-cssgrids .yui-t6{margin:auto;text-align:left;width:100%;}.yui-cssgrids .yui-d0{margin:auto 10px;width:auto;}.yui-cssgrids .yui-d0f{width:100%;}.yui-cssgrids .yui-d2{width:73.076em;*width:71.25em;}.yui-cssgrids .yui-d2f{width:950px;}.yui-cssgrids .yui-d3{width:74.923em;*width:73.05em;}.yui-cssgrids .yui-d3f{width:974px;}.yui-cssgrids .yui-b{position:relative;}.yui-cssgrids .yui-b{_position:static;}.yui-cssgrids .yui-main .yui-b{position:static;}.yui-cssgrids .yui-main{width:100%;}.yui-cssgrids .yui-t1 .yui-main,.yui-cssgrids .yui-t2 .yui-main,.yui-cssgrids .yui-t3 .yui-main{float:right;margin-left:-25em;}.yui-cssgrids .yui-t4 .yui-main,.yui-cssgrids .yui-t5 .yui-main,.yui-cssgrids .yui-t6 .yui-main{float:left;margin-right:-25em;}.yui-cssgrids .yui-t1 .yui-b{float:left;width:12.30769em;*width:12.00em;}.yui-cssgrids .yui-t1 .yui-main .yui-b{margin-left:13.30769em;*margin-left:12.975em;}.yui-cssgrids .yui-t2 .yui-b{float:left;width:13.84615em;*width:13.50em;}.yui-cssgrids .yui-t2 .yui-main .yui-b{margin-left:14.84615em;*margin-left:14.475em;}.yui-cssgrids .yui-t3 .yui-b{float:left;width:23.0769em;*width:22.50em;}.yui-cssgrids .yui-t3 .yui-main .yui-b{margin-left:24.0769em;*margin-left:23.475em;}.yui-cssgrids .yui-t4 .yui-b{float:right;width:13.8456em;*width:13.50em;}.yui-cssgrids .yui-t4 .yui-main .yui-b{margin-right:14.8456em;*margin-right:14.475em;}.yui-cssgrids .yui-t5 .yui-b{float:right;width:18.4615em;*width:18.00em;}.yui-cssgrids .yui-t5 .yui-main .yui-b{margin-right:19.4615em;*margin-right:18.975em;}.yui-cssgrids .yui-t6 .yui-b{float:right;width:23.0769em;*width:22.50em;}.yui-cssgrids .yui-t6 .yui-main .yui-b{margin-right:24.0769em;*margin-right:23.475em;}.yui-cssgrids .yui-main .yui-b{float:none;width:auto;}.yui-cssgrids .yui-gb .yui-u,.yui-cssgrids .yui-g .yui-gb .yui-u,.yui-cssgrids .yui-gb .yui-g,.yui-cssgrids .yui-gb .yui-gb,.yui-cssgrids .yui-gb .yui-gc,.yui-cssgrids .yui-gb .yui-gd,.yui-cssgrids .yui-gb .yui-ge,.yui-cssgrids .yui-gb .yui-gf,.yui-cssgrids .yui-gc .yui-u,.yui-cssgrids .yui-gc .yui-g,.yui-cssgrids .yui-gd .yui-u{float:left;}.yui-cssgrids .yui-g .yui-u,.yui-cssgrids .yui-g .yui-g,.yui-cssgrids .yui-g .yui-gb,.yui-cssgrids .yui-g .yui-gc,.yui-cssgrids .yui-g .yui-gd,.yui-cssgrids .yui-g .yui-ge,.yui-cssgrids .yui-g .yui-gf,.yui-cssgrids .yui-gc .yui-u,.yui-cssgrids .yui-gd .yui-g,.yui-cssgrids .yui-g .yui-gc .yui-u,.yui-cssgrids .yui-ge .yui-u,.yui-cssgrids .yui-ge .yui-g,.yui-cssgrids .yui-gf .yui-g,.yui-cssgrids .yui-gf .yui-u{float:right;}.yui-cssgrids .yui-g div.first,.yui-cssgrids .yui-gb div.first,.yui-cssgrids .yui-gc div.first,.yui-cssgrids .yui-gd div.first,.yui-cssgrids .yui-ge div.first,.yui-cssgrids .yui-gf div.first,.yui-cssgrids .yui-g .yui-gc div.first,.yui-cssgrids .yui-g .yui-ge div.first,.yui-cssgrids .yui-gc div.first div.first{float:left;}.yui-cssgrids .yui-g .yui-u,.yui-cssgrids .yui-g .yui-g,.yui-cssgrids .yui-g .yui-gb,.yui-cssgrids .yui-g .yui-gc,.yui-cssgrids .yui-g .yui-gd,.yui-cssgrids .yui-g .yui-ge,.yui-cssgrids .yui-g .yui-gf{width:49.1%;}.yui-cssgrids .yui-gb .yui-u,.yui-cssgrids .yui-g .yui-gb .yui-u,.yui-cssgrids .yui-gb .yui-g,.yui-cssgrids .yui-gb .yui-gb,.yui-cssgrids .yui-gb .yui-gc,.yui-cssgrids .yui-gb .yui-gd,.yui-cssgrids .yui-gb .yui-ge,.yui-cssgrids .yui-gb .yui-gf,.yui-cssgrids .yui-gc .yui-u,.yui-cssgrids .yui-gc .yui-g,.yui-cssgrids .yui-gd .yui-u{width:32%;margin-left:2.0%;}.yui-cssgrids .yui-gb .yui-u{*width:31.8%;*margin-left:1.9%;}.yui-cssgrids .yui-gc div.first,.yui-cssgrids .yui-gd .yui-u{width:66%;_width:65.7%;}.yui-cssgrids .yui-gd div.first{width:32%;_width:31.5%;}.yui-cssgrids .yui-ge div.first,.yui-cssgrids .yui-gf .yui-u{width:74.2%;_width:74%;}.yui-cssgrids .yui-ge .yui-u,.yui-cssgrids .yui-gf div.first{width:24%;_width:23.8%;}.yui-cssgrids .yui-g .yui-gb div.first,.yui-cssgrids .yui-gb div.first,.yui-cssgrids .yui-gc div.first,.yui-cssgrids .yui-gd div.first{margin-left:0;}.yui-cssgrids .yui-g .yui-g .yui-u,.yui-cssgrids .yui-gb .yui-g .yui-u,.yui-cssgrids .yui-gc .yui-g .yui-u,.yui-cssgrids .yui-gd .yui-g .yui-u,.yui-cssgrids .yui-ge .yui-g .yui-u,.yui-cssgrids .yui-gf .yui-g .yui-u{width:49%;*width:48.1%;*margin-left:0;}.yui-cssgrids .yui-g .yui-gb div.first,.yui-cssgrids .yui-gb .yui-gb div.first{*margin-right:0;*width:32%;_width:31.7%;}.yui-cssgrids .yui-g .yui-gc div.first,.yui-cssgrids .yui-gd .yui-g{width:66%;}.yui-cssgrids .yui-gb .yui-g div.first{*margin-right:4%;_margin-right:1.3%;}.yui-cssgrids .yui-gb .yui-gc div.first,.yui-cssgrids .yui-gb .yui-gd div.first{*margin-right:0;}.yui-cssgrids .yui-gb .yui-gb .yui-u,.yui-cssgrids .yui-gb .yui-gc .yui-u{*margin-left:1.8%;_margin-left:4%;}.yui-cssgrids .yui-g .yui-gb .yui-u{_margin-left:1.0%;}.yui-cssgrids .yui-gb .yui-gd .yui-u{*width:66%;_width:61.2%;}.yui-cssgrids .yui-gb .yui-gd div.first{*width:31%;_width:29.5%;}.yui-cssgrids .yui-g .yui-gc .yui-u,.yui-cssgrids .yui-gb .yui-gc .yui-u{width:32%;_float:right;margin-right:0;_margin-left:0;}.yui-cssgrids .yui-gb .yui-gc div.first{width:66%;*float:left;*margin-left:0;}.yui-cssgrids .yui-gb .yui-ge .yui-u,.yui-cssgrids .yui-gb .yui-gf .yui-u{margin:0;}.yui-cssgrids .yui-gb .yui-gb .yui-u{_margin-left:.7%;}.yui-cssgrids .yui-gb .yui-g div.first,.yui-cssgrids .yui-gb .yui-gb div.first{*margin-left:0;}.yui-cssgrids .yui-gc .yui-g .yui-u,.yui-cssgrids .yui-gd .yui-g .yui-u{*width:48.1%;*margin-left:0;}.yui-cssgrids .yui-gb .yui-gd div.first{width:32%;}.yui-cssgrids .yui-g .yui-gd div.first{_width:29.9%;}.yui-cssgrids .yui-ge .yui-g{width:24%;}.yui-cssgrids .yui-gf .yui-g{width:74.2%;}.yui-cssgrids .yui-gb .yui-ge div.yui-u,.yui-cssgrids .yui-gb .yui-gf div.yui-u{float:right;}.yui-cssgrids .yui-gb .yui-ge div.first,.yui-cssgrids .yui-gb .yui-gf div.first{float:left;}.yui-cssgrids .yui-gb .yui-ge .yui-u,.yui-cssgrids .yui-gb .yui-gf div.first{*width:24%;_width:20%;}.yui-cssgrids .yui-gc .yui-gf .yui-u{width:74%;_width:73%;}.yui-cssgrids .yui-gc .yui-gf div.first{width:24%;}.yui-cssgrids .yui-gb .yui-ge div.first,.yui-cssgrids .yui-gb .yui-gf .yui-u{*width:73.5%;_width:65.5%;}.yui-cssgrids .yui-ge div.first .yui-gd .yui-u{width:65%;}.yui-cssgrids .yui-ge div.first .yui-gd div.first{width:32%;}.yui-cssgrids #bd:after,.yui-cssgrids .yui-g:after,.yui-cssgrids .yui-gb:after,.yui-cssgrids .yui-gc:after,.yui-cssgrids .yui-gd:after,.yui-cssgrids .yui-ge:after,.yui-cssgrids .yui-gf:after,.yui-cssgrids .yui-t1:after,.yui-cssgrids .yui-t2:after,.yui-cssgrids .yui-t3:after,.yui-cssgrids .yui-t4:after,.yui-cssgrids .yui-t5:after,.yui-cssgrids .yui-t6:after{content:".";display:block;height:0;clear:both;visibility:hidden;}.yui-cssgrids #bd,.yui-cssgrids .yui-g,.yui-cssgrids .yui-gb,.yui-cssgrids .yui-gc,.yui-cssgrids .yui-gd,.yui-cssgrids .yui-ge,.yui-cssgrids .yui-gf,.yui-cssgrids .yui-t1,.yui-cssgrids .yui-t2,.yui-cssgrids .yui-t3,.yui-cssgrids .yui-t4,.yui-cssgrids .yui-t5,.yui-cssgrids .yui-t6{zoom:1;}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssgrids/grids-context.css'
--- loggerhead/static/javascript/yui/build/cssgrids/grids-context.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssgrids/grids-context.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,490 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/*
+*
+* The YUI CSS Foundation uses the *property and _property CSS filter
+* techniques to shield a value from A-grade browsers [1] other than
+* IE6 & IE7 (*property) and IE6 (_property)
+*
+/
+Section: General Rules
+*/
+.yui-cssgrids body {
+	/* center the page */
+	text-align: center;
+	margin-left: auto;
+	margin-right: auto;
+}
+/*
+Section: Page Width Rules (#doc, #doc2, #doc3, #doc4)
+*/
+/*
+Subsection: General
+*/
+.yui-cssgrids .yui-d0, /* 100% */
+.yui-cssgrids .yui-d1, /* 750px */
+.yui-cssgrids .yui-d1f, /* 750px fixed */
+.yui-cssgrids .yui-d2, /* 950px */
+.yui-cssgrids .yui-d2f, /* 950px fixed */
+.yui-cssgrids .yui-d3, /* 974px */
+.yui-cssgrids .yui-d3f { /* 974px fixed */
+	margin: auto;
+	text-align: left;
+	width: 57.69em;
+	*width: 56.25em; /* doc1*/
+}
+
+.yui-cssgrids .yui-t1,
+.yui-cssgrids .yui-t2,
+.yui-cssgrids .yui-t3,
+.yui-cssgrids .yui-t4,
+.yui-cssgrids .yui-t5,
+.yui-cssgrids .yui-t6 {
+	margin: auto;
+	text-align: left;
+	width: 100%;
+}
+
+/*
+Subsection: 100% (doc)
+*/
+.yui-cssgrids .yui-d0 {
+	/* Left and Right margins are not a structural part of Grids. Without them Grids
+	works fine, but content bleeds to the very edge of the document, which often
+	impairs readability and usability. They are
+	provided because they prevent the content from "bleeding" into the browser's chrome.*/
+	margin: auto 10px;
+	width: auto;
+}
+.yui-cssgrids .yui-d0f {
+	width: 100%;
+}
+
+/*
+Subsection: 950 Centered (doc2)
+*/
+.yui-cssgrids .yui-d2 {
+	width: 73.076em;
+	*width: 71.25em;
+}
+.yui-cssgrids .yui-d2f {
+	width: 950px;
+}
+/*
+Subsection: 974 Centered (doc3)
+*/
+.yui-cssgrids .yui-d3 {
+	width: 74.923em;
+	*width: 73.05em;
+}
+.yui-cssgrids .yui-d3f {
+	width: 974px;
+}
+/*
+Section: Preset Template Rules (.yui-t[1-6])
+*/
+/*
+Subsection: General
+*/
+
+/* to preserve source-order independence for Gecko without breaking IE */
+.yui-cssgrids .yui-b {
+	position: relative;
+}
+.yui-cssgrids .yui-b {
+	_position: static;
+}
+.yui-cssgrids .yui-main .yui-b {
+	position: static;
+}
+.yui-cssgrids .yui-main {
+	width: 100%;
+}
+.yui-cssgrids .yui-t1 .yui-main,
+.yui-cssgrids .yui-t2 .yui-main,
+.yui-cssgrids .yui-t3 .yui-main {
+	float: right;
+	/* IE: preserve layout at narrow widths */
+	margin-left: -25em;
+}
+.yui-cssgrids .yui-t4 .yui-main,
+.yui-cssgrids .yui-t5 .yui-main,
+.yui-cssgrids .yui-t6 .yui-main {
+	float: left;
+	/* IE: preserve layout at narrow widths */
+	margin-right: -25em;
+}
+
+/* Subsection: For Specific Template Presets */
+
+/**
+* Nudge down to get to 13px equivalent for these form elements
+*/
+
+/*
+TODO Create t1-6's that are based on fixed widths
+*/
+/* t1 narrow block = left, equivalent of 160px */
+.yui-cssgrids .yui-t1 .yui-b {
+	float: left;
+	width: 12.30769em;
+	*width: 12.00em;
+}
+.yui-cssgrids .yui-t1 .yui-main .yui-b {
+	margin-left: 13.30769em;
+	*margin-left:12.975em;
+}
+/* t2 narrow block = left, equivalent of 180px */
+.yui-cssgrids .yui-t2 .yui-b {
+	float: left;
+	width: 13.84615em;
+	*width: 13.50em;
+}
+.yui-cssgrids .yui-t2 .yui-main .yui-b {
+	margin-left: 14.84615em;
+	*margin-left: 14.475em;
+}
+/* t3 narrow block = left, equivalent of 300px */
+.yui-cssgrids .yui-t3 .yui-b {
+	float: left;
+	width: 23.0769em;
+	*width: 22.50em;
+}
+.yui-cssgrids .yui-t3 .yui-main .yui-b {
+	margin-left: 24.0769em;
+	*margin-left: 23.475em;
+}
+/* t4 narrow block = right, equivalent of 180px */
+.yui-cssgrids .yui-t4 .yui-b {
+	float: right;
+	width: 13.8456em;
+	*width: 13.50em;
+}
+.yui-cssgrids .yui-t4 .yui-main .yui-b {
+	margin-right: 14.8456em;
+	*margin-right: 14.475em;
+}
+/* t5 narrow block = right, equivalent of 240px */
+.yui-cssgrids .yui-t5 .yui-b {
+	float: right;
+	width: 18.4615em;
+	*width: 18.00em;
+}
+.yui-cssgrids .yui-t5 .yui-main .yui-b {
+	margin-right: 19.4615em;
+	*margin-right: 18.975em;
+}
+/* t6 narrow block = equivalent of 300px */
+.yui-cssgrids .yui-t6 .yui-b {
+	float: right;
+	width: 23.0769em;
+	*width: 22.50em;
+}
+.yui-cssgrids .yui-t6 .yui-main .yui-b {
+	margin-right: 24.0769em;
+	*margin-right: 23.475em;
+}
+
+.yui-cssgrids .yui-main .yui-b {
+	float: none;
+	width: auto;
+}
+
+/*
+Section: Grids and Nesting Grids
+*/
+
+/*
+Subsection: Children generally take half the available space
+*/
+
+.yui-cssgrids .yui-gb .yui-u,
+.yui-cssgrids .yui-g .yui-gb .yui-u,
+.yui-cssgrids .yui-gb .yui-g,
+.yui-cssgrids .yui-gb .yui-gb,
+.yui-cssgrids .yui-gb .yui-gc,
+.yui-cssgrids .yui-gb .yui-gd,
+.yui-cssgrids .yui-gb .yui-ge,
+.yui-cssgrids .yui-gb .yui-gf,
+.yui-cssgrids .yui-gc .yui-u,
+.yui-cssgrids .yui-gc .yui-g,
+.yui-cssgrids .yui-gd .yui-u {
+	float: left;
+}
+
+/*Float units (and sub grids) to the right */
+.yui-cssgrids .yui-g .yui-u,
+.yui-cssgrids .yui-g .yui-g,
+.yui-cssgrids .yui-g .yui-gb,
+.yui-cssgrids .yui-g .yui-gc,
+.yui-cssgrids .yui-g .yui-gd,
+.yui-cssgrids .yui-g .yui-ge,
+.yui-cssgrids .yui-g .yui-gf,
+.yui-cssgrids .yui-gc .yui-u,
+.yui-cssgrids .yui-gd .yui-g,
+.yui-cssgrids .yui-g .yui-gc .yui-u,
+.yui-cssgrids .yui-ge .yui-u,
+.yui-cssgrids .yui-ge .yui-g,
+.yui-cssgrids .yui-gf .yui-g,
+.yui-cssgrids .yui-gf .yui-u {
+	float: right;
+}
+
+/*Float units (and sub grids) to the left */
+.yui-cssgrids .yui-g div.first,
+.yui-cssgrids .yui-gb div.first,
+.yui-cssgrids .yui-gc div.first,
+.yui-cssgrids .yui-gd div.first,
+.yui-cssgrids .yui-ge div.first,
+.yui-cssgrids .yui-gf div.first,
+.yui-cssgrids .yui-g .yui-gc div.first,
+.yui-cssgrids .yui-g .yui-ge div.first,
+.yui-cssgrids .yui-gc div.first div.first {
+	float: left;
+}
+
+.yui-cssgrids .yui-g .yui-u,
+.yui-cssgrids .yui-g .yui-g,
+.yui-cssgrids .yui-g .yui-gb,
+.yui-cssgrids .yui-g .yui-gc,
+.yui-cssgrids .yui-g .yui-gd,
+.yui-cssgrids .yui-g .yui-ge,
+.yui-cssgrids .yui-g .yui-gf {
+	width: 49.1%;
+}
+
+.yui-cssgrids .yui-gb .yui-u,
+.yui-cssgrids .yui-g .yui-gb .yui-u,
+.yui-cssgrids .yui-gb .yui-g,
+.yui-cssgrids .yui-gb .yui-gb,
+.yui-cssgrids .yui-gb .yui-gc,
+.yui-cssgrids .yui-gb .yui-gd,
+.yui-cssgrids .yui-gb .yui-ge,
+.yui-cssgrids .yui-gb .yui-gf,
+.yui-cssgrids .yui-gc .yui-u,
+.yui-cssgrids .yui-gc .yui-g,
+.yui-cssgrids .yui-gd .yui-u {
+	width: 32%;
+	margin-left: 2.0%;
+}
+
+/* Give IE some extra breathing room for 1/3-based rounding issues */
+.yui-cssgrids .yui-gb .yui-u {
+	*width: 31.8%;
+	*margin-left: 1.9%;
+}
+
+.yui-cssgrids .yui-gc div.first,
+.yui-cssgrids .yui-gd .yui-u {
+	width: 66%;
+	_width: 65.7%;
+}
+.yui-cssgrids .yui-gd div.first {
+	width: 32%;
+	_width: 31.5%;
+}
+
+.yui-cssgrids .yui-ge div.first,
+.yui-cssgrids .yui-gf .yui-u {
+	width: 74.2%;
+	_width: 74%;
+}
+
+.yui-cssgrids .yui-ge .yui-u,
+.yui-cssgrids .yui-gf div.first {
+	width: 24%;
+	_width: 23.8%;
+}
+
+.yui-cssgrids .yui-g .yui-gb div.first,
+.yui-cssgrids .yui-gb div.first,
+.yui-cssgrids .yui-gc div.first,
+.yui-cssgrids .yui-gd div.first {
+	margin-left: 0;
+}
+
+/*
+Section: Deep Nesting
+*/
+.yui-cssgrids .yui-g .yui-g .yui-u,
+.yui-cssgrids .yui-gb .yui-g .yui-u,
+.yui-cssgrids .yui-gc .yui-g .yui-u,
+.yui-cssgrids .yui-gd .yui-g .yui-u,
+.yui-cssgrids .yui-ge .yui-g .yui-u,
+.yui-cssgrids .yui-gf .yui-g .yui-u {
+	width: 49%;
+	*width: 48.1%;
+	*margin-left: 0;
+}
+
+.yui-cssgrids .yui-g .yui-gb div.first,
+.yui-cssgrids .yui-gb .yui-gb div.first {
+	*margin-right: 0;
+	*width: 32%;
+	_width: 31.7%;
+}
+
+.yui-cssgrids .yui-g .yui-gc div.first,
+.yui-cssgrids .yui-gd .yui-g {
+	width: 66%;
+}
+
+.yui-cssgrids .yui-gb .yui-g div.first {
+	*margin-right: 4%;
+	_margin-right: 1.3%;
+}
+
+.yui-cssgrids .yui-gb .yui-gc div.first,
+.yui-cssgrids .yui-gb .yui-gd div.first {
+	*margin-right: 0;
+}
+
+.yui-cssgrids .yui-gb .yui-gb .yui-u,
+.yui-cssgrids .yui-gb .yui-gc .yui-u {
+	*margin-left: 1.8%;
+	_margin-left: 4%;
+}
+
+.yui-cssgrids .yui-g .yui-gb .yui-u {
+	_margin-left: 1.0%;
+}
+
+.yui-cssgrids .yui-gb .yui-gd .yui-u {
+	*width: 66%;
+	_width: 61.2%;
+}
+.yui-cssgrids .yui-gb .yui-gd div.first {
+	*width: 31%;
+	_width: 29.5%;
+}
+
+.yui-cssgrids .yui-g .yui-gc .yui-u,
+.yui-cssgrids .yui-gb .yui-gc .yui-u {
+	width: 32%;
+	_float: right;
+	margin-right: 0;
+	_margin-left: 0;
+}
+.yui-cssgrids .yui-gb .yui-gc div.first {
+	width: 66%;
+	*float: left;
+	*margin-left: 0;
+}
+
+.yui-cssgrids .yui-gb .yui-ge .yui-u,
+.yui-cssgrids .yui-gb .yui-gf .yui-u {
+	margin: 0;
+}
+
+.yui-cssgrids .yui-gb .yui-gb .yui-u {
+	_margin-left: .7%;
+}
+
+.yui-cssgrids .yui-gb .yui-g div.first,
+.yui-cssgrids .yui-gb .yui-gb div.first {
+	*margin-left:0;
+}
+
+.yui-cssgrids .yui-gc .yui-g .yui-u,
+.yui-cssgrids .yui-gd .yui-g .yui-u {
+	*width: 48.1%;
+	*margin-left: 0;
+}
+
+.yui-cssgrids .yui-gb .yui-gd div.first {
+	width: 32%;
+}
+.yui-cssgrids .yui-g .yui-gd div.first {
+	_width: 29.9%;
+}
+
+.yui-cssgrids .yui-ge .yui-g {
+	width: 24%;
+}
+.yui-cssgrids .yui-gf .yui-g {
+	width: 74.2%;
+}
+
+.yui-cssgrids .yui-gb .yui-ge div.yui-u,
+.yui-cssgrids .yui-gb .yui-gf div.yui-u {
+	float: right;
+}
+.yui-cssgrids .yui-gb .yui-ge div.first,
+.yui-cssgrids .yui-gb .yui-gf div.first {
+	float: left;
+}
+
+/* Width Accommodation for Nested Contexts */
+.yui-cssgrids .yui-gb .yui-ge .yui-u,
+.yui-cssgrids .yui-gb .yui-gf div.first {
+	*width: 24%;
+	_width: 20%;
+}
+
+/* Width Accommodation for Nested Contexts */
+
+.yui-cssgrids .yui-gc .yui-gf .yui-u {
+	width: 74%;
+	_width: 73%;
+}
+
+.yui-cssgrids .yui-gc .yui-gf div.first {
+	width: 24%;
+}
+
+.yui-cssgrids .yui-gb .yui-ge div.first,
+.yui-cssgrids .yui-gb .yui-gf .yui-u {
+	*width: 73.5%;
+	_width: 65.5%;
+}
+
+/* Patch for GD within GE */
+.yui-cssgrids .yui-ge div.first .yui-gd .yui-u {
+	width: 65%;
+}
+.yui-cssgrids .yui-ge div.first .yui-gd div.first {
+	width: 32%;
+}
+
+/*
+Section: Clearing. zoom for IE, :after for others
+*/
+
+.yui-cssgrids #bd:after,
+.yui-cssgrids .yui-g:after,
+.yui-cssgrids .yui-gb:after,
+.yui-cssgrids .yui-gc:after,
+.yui-cssgrids .yui-gd:after,
+.yui-cssgrids .yui-ge:after,
+.yui-cssgrids .yui-gf:after,
+.yui-cssgrids .yui-t1:after,
+.yui-cssgrids .yui-t2:after,
+.yui-cssgrids .yui-t3:after,
+.yui-cssgrids .yui-t4:after,
+.yui-cssgrids .yui-t5:after,
+.yui-cssgrids .yui-t6:after {
+	content: ".";
+	display: block;
+	height: 0;
+	clear: both;
+	visibility: hidden;
+}
+.yui-cssgrids #bd,
+.yui-cssgrids .yui-g,
+.yui-cssgrids .yui-gb,
+.yui-cssgrids .yui-gc,
+.yui-cssgrids .yui-gd,
+.yui-cssgrids .yui-ge,
+.yui-cssgrids .yui-gf,
+.yui-cssgrids .yui-t1,
+.yui-cssgrids .yui-t2,
+.yui-cssgrids .yui-t3,
+.yui-cssgrids .yui-t4,
+.yui-cssgrids .yui-t5,
+.yui-cssgrids .yui-t6 {
+	zoom: 1;
+}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssgrids/grids-min.css'
--- loggerhead/static/javascript/yui/build/cssgrids/grids-min.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssgrids/grids-min.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+body{text-align:center;margin-left:auto;margin-right:auto;}.yui-d0,.yui-d1,.yui-d1f,.yui-d2,.yui-d2f,.yui-d3,.yui-d3f{margin:auto;text-align:left;width:57.69em;*width:56.25em;}.yui-t1,.yui-t2,.yui-t3,.yui-t4,.yui-t5,.yui-t6{margin:auto;text-align:left;width:100%;}.yui-d0{margin:auto 10px;width:auto;}.yui-d0f{width:100%;}.yui-d2{width:73.076em;*width:71.25em;}.yui-d2f{width:950px;}.yui-d3{width:74.923em;*width:73.05em;}.yui-d3f{width:974px;}.yui-b{position:relative;}.yui-b{_position:static;}.yui-main .yui-b{position:static;}.yui-main{width:100%;}.yui-t1 .yui-main,.yui-t2 .yui-main,.yui-t3 .yui-main{float:right;margin-left:-25em;}.yui-t4 .yui-main,.yui-t5 .yui-main,.yui-t6 .yui-main{float:left;margin-right:-25em;}.yui-t1 .yui-b{float:left;width:12.30769em;*width:12.00em;}.yui-t1 .yui-main .yui-b{margin-left:13.30769em;*margin-left:12.975em;}.yui-t2 .yui-b{float:left;width:13.84615em;*width:13.50em;}.yui-t2 .yui-main .yui-b{margin-left:14.84615em;*margin-left:14.475em;}.yui-t3 .yui-b{float:left;width:23.0769em;*width:22.50em;}.yui-t3 .yui-main .yui-b{margin-left:24.0769em;*margin-left:23.475em;}.yui-t4 .yui-b{float:right;width:13.8456em;*width:13.50em;}.yui-t4 .yui-main .yui-b{margin-right:14.8456em;*margin-right:14.475em;}.yui-t5 .yui-b{float:right;width:18.4615em;*width:18.00em;}.yui-t5 .yui-main .yui-b{margin-right:19.4615em;*margin-right:18.975em;}.yui-t6 .yui-b{float:right;width:23.0769em;*width:22.50em;}.yui-t6 .yui-main .yui-b{margin-right:24.0769em;*margin-right:23.475em;}.yui-main .yui-b{float:none;width:auto;}.yui-gb .yui-u,.yui-g .yui-gb .yui-u,.yui-gb .yui-g,.yui-gb .yui-gb,.yui-gb .yui-gc,.yui-gb .yui-gd,.yui-gb .yui-ge,.yui-gb .yui-gf,.yui-gc .yui-u,.yui-gc .yui-g,.yui-gd .yui-u{float:left;}.yui-g .yui-u,.yui-g .yui-g,.yui-g .yui-gb,.yui-g .yui-gc,.yui-g .yui-gd,.yui-g .yui-ge,.yui-g .yui-gf,.yui-gc .yui-u,.yui-gd .yui-g,.yui-g .yui-gc .yui-u,.yui-ge .yui-u,.yui-ge .yui-g,.yui-gf .yui-g,.yui-gf .yui-u{float:right;}.yui-g div.first,.yui-gb div.first,.yui-gc div.first,.yui-gd div.first,.yui-ge div.first,.yui-gf div.first,.yui-g .yui-gc div.first,.yui-g .yui-ge div.first,.yui-gc div.first div.first{float:left;}.yui-g .yui-u,.yui-g .yui-g,.yui-g .yui-gb,.yui-g .yui-gc,.yui-g .yui-gd,.yui-g .yui-ge,.yui-g .yui-gf{width:49.1%;}.yui-gb .yui-u,.yui-g .yui-gb .yui-u,.yui-gb .yui-g,.yui-gb .yui-gb,.yui-gb .yui-gc,.yui-gb .yui-gd,.yui-gb .yui-ge,.yui-gb .yui-gf,.yui-gc .yui-u,.yui-gc .yui-g,.yui-gd .yui-u{width:32%;margin-left:2.0%;}.yui-gb .yui-u{*width:31.8%;*margin-left:1.9%;}.yui-gc div.first,.yui-gd .yui-u{width:66%;_width:65.7%;}.yui-gd div.first{width:32%;_width:31.5%;}.yui-ge div.first,.yui-gf .yui-u{width:74.2%;_width:74%;}.yui-ge .yui-u,.yui-gf div.first{width:24%;_width:23.8%;}.yui-g .yui-gb div.first,.yui-gb div.first,.yui-gc div.first,.yui-gd div.first{margin-left:0;}.yui-g .yui-g .yui-u,.yui-gb .yui-g .yui-u,.yui-gc .yui-g .yui-u,.yui-gd .yui-g .yui-u,.yui-ge .yui-g .yui-u,.yui-gf .yui-g .yui-u{width:49%;*width:48.1%;*margin-left:0;}.yui-g .yui-gb div.first,.yui-gb .yui-gb div.first{*margin-right:0;*width:32%;_width:31.7%;}.yui-g .yui-gc div.first,.yui-gd .yui-g{width:66%;}.yui-gb .yui-g div.first{*margin-right:4%;_margin-right:1.3%;}.yui-gb .yui-gc div.first,.yui-gb .yui-gd div.first{*margin-right:0;}.yui-gb .yui-gb .yui-u,.yui-gb .yui-gc .yui-u{*margin-left:1.8%;_margin-left:4%;}.yui-g .yui-gb .yui-u{_margin-left:1.0%;}.yui-gb .yui-gd .yui-u{*width:66%;_width:61.2%;}.yui-gb .yui-gd div.first{*width:31%;_width:29.5%;}.yui-g .yui-gc .yui-u,.yui-gb .yui-gc .yui-u{width:32%;_float:right;margin-right:0;_margin-left:0;}.yui-gb .yui-gc div.first{width:66%;*float:left;*margin-left:0;}.yui-gb .yui-ge .yui-u,.yui-gb .yui-gf .yui-u{margin:0;}.yui-gb .yui-gb .yui-u{_margin-left:.7%;}.yui-gb .yui-g div.first,.yui-gb .yui-gb div.first{*margin-left:0;}.yui-gc .yui-g .yui-u,.yui-gd .yui-g .yui-u{*width:48.1%;*margin-left:0;}.yui-gb .yui-gd div.first{width:32%;}.yui-g .yui-gd div.first{_width:29.9%;}.yui-ge .yui-g{width:24%;}.yui-gf .yui-g{width:74.2%;}.yui-gb .yui-ge div.yui-u,.yui-gb .yui-gf div.yui-u{float:right;}.yui-gb .yui-ge div.first,.yui-gb .yui-gf div.first{float:left;}.yui-gb .yui-ge .yui-u,.yui-gb .yui-gf div.first{*width:24%;_width:20%;}.yui-gb .yui-ge div.first,.yui-gb .yui-gf .yui-u{*width:73.5%;_width:65.5%;}.yui-ge div.first .yui-gd .yui-u{width:65%;}.yui-ge div.first .yui-gd div.first{width:32%;}#bd:after,.yui-g:after,.yui-gb:after,.yui-gc:after,.yui-gd:after,.yui-ge:after,.yui-gf:after,.yui-t1:after,.yui-t2:after,.yui-t3:after,.yui-t4:after,.yui-t5:after,.yui-t6:after{content:".";display:block;height:0;clear:both;visibility:hidden;}#bd,.yui-g,.yui-gb,.yui-gc,.yui-gd,.yui-ge,.yui-gf,.yui-t1,.yui-t2,.yui-t3,.yui-t4,.yui-t5,.yui-t6{zoom:1;}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssgrids/grids.css'
--- loggerhead/static/javascript/yui/build/cssgrids/grids.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssgrids/grids.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,480 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/*
+*
+* The YUI CSS Foundation uses the *property and _property CSS filter
+* techniques to shield a value from A-grade browsers [1] other than
+* IE6 & IE7 (*property) and IE6 (_property)
+*
+/
+Section: General Rules
+*/
+body {
+	/* center the page */
+	text-align: center;
+	margin-left: auto;
+	margin-right: auto;
+}
+/*
+Section: Page Width Rules (#doc, #doc2, #doc3, #doc4)
+*/
+/*
+Subsection: General
+*/
+.yui-d0, /* 100% */
+.yui-d1, /* 750px */
+.yui-d1f, /* 750px fixed */
+.yui-d2, /* 950px */
+.yui-d2f, /* 950px fixed */
+.yui-d3, /* 974px */
+.yui-d3f { /* 974px fixed */
+	margin: auto;
+	text-align: left;
+	width: 57.69em;
+	*width: 56.25em; /* doc1*/
+}
+
+.yui-t1,
+.yui-t2,
+.yui-t3,
+.yui-t4,
+.yui-t5,
+.yui-t6 {
+	margin: auto;
+	text-align: left;
+	width: 100%;
+}
+
+/*
+Subsection: 100% (doc)
+*/
+.yui-d0 {
+	/* Left and Right margins are not a structural part of Grids. Without them Grids
+	works fine, but content bleeds to the very edge of the document, which often
+	impairs readability and usability. They are
+	provided because they prevent the content from "bleeding" into the browser's chrome.*/
+	margin: auto 10px;
+	width: auto;
+}
+.yui-d0f {
+	width: 100%;
+}
+
+/*
+Subsection: 950 Centered (doc2)
+*/
+.yui-d2 {
+	width: 73.076em;
+	*width: 71.25em;
+}
+.yui-d2f {
+	width: 950px;
+}
+/*
+Subsection: 974 Centered (doc3)
+*/
+.yui-d3 {
+	width: 74.923em;
+	*width: 73.05em;
+}
+.yui-d3f {
+	width: 974px;
+}
+/*
+Section: Preset Template Rules (.yui-t[1-6])
+*/
+/*
+Subsection: General
+*/
+
+/* to preserve source-order independence for Gecko without breaking IE */
+.yui-b {
+	position: relative;
+}
+.yui-b {
+	_position: static;
+}
+.yui-main .yui-b {
+	position: static;
+}
+.yui-main {
+	width: 100%;
+}
+.yui-t1 .yui-main,
+.yui-t2 .yui-main,
+.yui-t3 .yui-main {
+	float: right;
+	/* IE: preserve layout at narrow widths */
+	margin-left: -25em;
+}
+.yui-t4 .yui-main,
+.yui-t5 .yui-main,
+.yui-t6 .yui-main {
+	float: left;
+	/* IE: preserve layout at narrow widths */
+	margin-right: -25em;
+}
+
+/* Subsection: For Specific Template Presets */
+
+/**
+* Nudge down to get to 13px equivalent for these form elements
+*/
+
+/*
+TODO Create t1-6's that are based on fixed widths
+*/
+/* t1 narrow block = left, equivalent of 160px */
+.yui-t1 .yui-b {
+	float: left;
+	width: 12.30769em;
+	*width: 12.00em;
+}
+.yui-t1 .yui-main .yui-b {
+	margin-left: 13.30769em;
+	*margin-left:12.975em;
+}
+/* t2 narrow block = left, equivalent of 180px */
+.yui-t2 .yui-b {
+	float: left;
+	width: 13.84615em;
+	*width: 13.50em;
+}
+.yui-t2 .yui-main .yui-b {
+	margin-left: 14.84615em;
+	*margin-left: 14.475em;
+}
+/* t3 narrow block = left, equivalent of 300px */
+.yui-t3 .yui-b {
+	float: left;
+	width: 23.0769em;
+	*width: 22.50em;
+}
+.yui-t3 .yui-main .yui-b {
+	margin-left: 24.0769em;
+	*margin-left: 23.475em;
+}
+/* t4 narrow block = right, equivalent of 180px */
+.yui-t4 .yui-b {
+	float: right;
+	width: 13.8456em;
+	*width: 13.50em;
+}
+.yui-t4 .yui-main .yui-b {
+	margin-right: 14.8456em;
+	*margin-right: 14.475em;
+}
+/* t5 narrow block = right, equivalent of 240px */
+.yui-t5 .yui-b {
+	float: right;
+	width: 18.4615em;
+	*width: 18.00em;
+}
+.yui-t5 .yui-main .yui-b {
+	margin-right: 19.4615em;
+	*margin-right: 18.975em;
+}
+/* t6 narrow block = equivalent of 300px */
+.yui-t6 .yui-b {
+	float: right;
+	width: 23.0769em;
+	*width: 22.50em;
+}
+.yui-t6 .yui-main .yui-b {
+	margin-right: 24.0769em;
+	*margin-right: 23.475em;
+}
+
+.yui-main .yui-b {
+	float: none;
+	width: auto;
+}
+
+/*
+Section: Grids and Nesting Grids
+*/
+
+/*
+Subsection: Children generally take half the available space
+*/
+
+.yui-gb .yui-u,
+.yui-g .yui-gb .yui-u,
+.yui-gb .yui-g,
+.yui-gb .yui-gb,
+.yui-gb .yui-gc,
+.yui-gb .yui-gd,
+.yui-gb .yui-ge,
+.yui-gb .yui-gf,
+.yui-gc .yui-u,
+.yui-gc .yui-g,
+.yui-gd .yui-u {
+	float: left;
+}
+
+/*Float units (and sub grids) to the right */
+.yui-g .yui-u,
+.yui-g .yui-g,
+.yui-g .yui-gb,
+.yui-g .yui-gc,
+.yui-g .yui-gd,
+.yui-g .yui-ge,
+.yui-g .yui-gf,
+.yui-gc .yui-u,
+.yui-gd .yui-g,
+.yui-g .yui-gc .yui-u,
+.yui-ge .yui-u,
+.yui-ge .yui-g,
+.yui-gf .yui-g,
+.yui-gf .yui-u {
+	float: right;
+}
+
+/*Float units (and sub grids) to the left */
+.yui-g div.first,
+.yui-gb div.first,
+.yui-gc div.first,
+.yui-gd div.first,
+.yui-ge div.first,
+.yui-gf div.first,
+.yui-g .yui-gc div.first,
+.yui-g .yui-ge div.first,
+.yui-gc div.first div.first {
+	float: left;
+}
+
+.yui-g .yui-u,
+.yui-g .yui-g,
+.yui-g .yui-gb,
+.yui-g .yui-gc,
+.yui-g .yui-gd,
+.yui-g .yui-ge,
+.yui-g .yui-gf {
+	width: 49.1%;
+}
+
+.yui-gb .yui-u,
+.yui-g .yui-gb .yui-u,
+.yui-gb .yui-g,
+.yui-gb .yui-gb,
+.yui-gb .yui-gc,
+.yui-gb .yui-gd,
+.yui-gb .yui-ge,
+.yui-gb .yui-gf,
+.yui-gc .yui-u,
+.yui-gc .yui-g,
+.yui-gd .yui-u {
+	width: 32%;
+	margin-left: 2.0%;
+}
+
+/* Give IE some extra breathing room for 1/3-based rounding issues */
+.yui-gb .yui-u {
+	*width: 31.8%;
+	*margin-left: 1.9%;
+}
+
+.yui-gc div.first,
+.yui-gd .yui-u {
+	width: 66%;
+	_width: 65.7%;
+}
+.yui-gd div.first {
+	width: 32%;
+	_width: 31.5%;
+}
+
+.yui-ge div.first,
+.yui-gf .yui-u {
+	width: 74.2%;
+	_width: 74%;
+}
+
+.yui-ge .yui-u,
+.yui-gf div.first {
+	width: 24%;
+	_width: 23.8%;
+}
+
+.yui-g .yui-gb div.first,
+.yui-gb div.first,
+.yui-gc div.first,
+.yui-gd div.first {
+	margin-left: 0;
+}
+
+/*
+Section: Deep Nesting
+*/
+.yui-g .yui-g .yui-u,
+.yui-gb .yui-g .yui-u,
+.yui-gc .yui-g .yui-u,
+.yui-gd .yui-g .yui-u,
+.yui-ge .yui-g .yui-u,
+.yui-gf .yui-g .yui-u {
+	width: 49%;
+	*width: 48.1%;
+	*margin-left: 0;
+}
+
+.yui-g .yui-gb div.first,
+.yui-gb .yui-gb div.first {
+	*margin-right: 0;
+	*width: 32%;
+	_width: 31.7%;
+}
+
+.yui-g .yui-gc div.first,
+.yui-gd .yui-g {
+	width: 66%;
+}
+
+.yui-gb .yui-g div.first {
+	*margin-right: 4%;
+	_margin-right: 1.3%;
+}
+
+.yui-gb .yui-gc div.first,
+.yui-gb .yui-gd div.first {
+	*margin-right: 0;
+}
+
+.yui-gb .yui-gb .yui-u,
+.yui-gb .yui-gc .yui-u {
+	*margin-left: 1.8%;
+	_margin-left: 4%;
+}
+
+.yui-g .yui-gb .yui-u {
+	_margin-left: 1.0%;
+}
+
+.yui-gb .yui-gd .yui-u {
+	*width: 66%;
+	_width: 61.2%;
+}
+.yui-gb .yui-gd div.first {
+	*width: 31%;
+	_width: 29.5%;
+}
+
+.yui-g .yui-gc .yui-u,
+.yui-gb .yui-gc .yui-u {
+	width: 32%;
+	_float: right;
+	margin-right: 0;
+	_margin-left: 0;
+}
+.yui-gb .yui-gc div.first {
+	width: 66%;
+	*float: left;
+	*margin-left: 0;
+}
+
+.yui-gb .yui-ge .yui-u,
+.yui-gb .yui-gf .yui-u {
+	margin: 0;
+}
+
+.yui-gb .yui-gb .yui-u {
+	_margin-left: .7%;
+}
+
+.yui-gb .yui-g div.first,
+.yui-gb .yui-gb div.first {
+	*margin-left:0;
+}
+
+.yui-gc .yui-g .yui-u,
+.yui-gd .yui-g .yui-u {
+	*width: 48.1%;
+	*margin-left: 0;
+}
+
+.yui-gb .yui-gd div.first {
+	width: 32%;
+}
+.yui-g .yui-gd div.first {
+	_width: 29.9%;
+}
+
+.yui-ge .yui-g {
+	width: 24%;
+}
+.yui-gf .yui-g {
+	width: 74.2%;
+}
+
+.yui-gb .yui-ge div.yui-u,
+.yui-gb .yui-gf div.yui-u {
+	float: right;
+}
+.yui-gb .yui-ge div.first,
+.yui-gb .yui-gf div.first {
+	float: left;
+}
+
+/* Width Accommodation for Nested Contexts */
+.yui-gb .yui-ge .yui-u,
+.yui-gb .yui-gf div.first {
+	*width: 24%;
+	_width: 20%;
+}
+
+/* Width Accommodation for Nested Contexts */
+.yui-gb .yui-ge div.first,
+.yui-gb .yui-gf .yui-u {
+	*width: 73.5%;
+	_width: 65.5%;
+}
+
+/* Patch for GD within GE */
+.yui-ge div.first .yui-gd .yui-u {
+	width: 65%;
+}
+.yui-ge div.first .yui-gd div.first {
+	width: 32%;
+}
+
+/*
+Section: Clearing. zoom for IE, :after for others
+*/
+
+#bd:after,
+.yui-g:after,
+.yui-gb:after,
+.yui-gc:after,
+.yui-gd:after,
+.yui-ge:after,
+.yui-gf:after,
+.yui-t1:after,
+.yui-t2:after,
+.yui-t3:after,
+.yui-t4:after,
+.yui-t5:after,
+.yui-t6:after {
+	content: ".";
+	display: block;
+	height: 0;
+	clear: both;
+	visibility: hidden;
+}
+#bd,
+.yui-g,
+.yui-gb,
+.yui-gc,
+.yui-gd,
+.yui-ge,
+.yui-gf,
+.yui-t1,
+.yui-t2,
+.yui-t3,
+.yui-t4,
+.yui-t5,
+.yui-t6 {
+	zoom: 1;
+}
\ No newline at end of file

=== added directory 'loggerhead/static/javascript/yui/build/cssreset'
=== added file 'loggerhead/static/javascript/yui/build/cssreset/README'
--- loggerhead/static/javascript/yui/build/cssreset/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssreset/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,13 @@
+**** version 3.0.0 PR2 ***	
+
+  * No changes.
+
+3.0.0PR1 - Initial release
+
+Module Name: "cssreset"
+Documentation: http://developer.yahoo.com/yui/3/cssreset
+
+The foundational CSS Reset removes the inconsistent styling
+of HTML elements provided by browsers. This creates a 
+dependably flat foundation to built upon. With CSS Reset 
+loaded, begin writing the explicit CSS your project needs.
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssreset/reset-context-min.css'
--- loggerhead/static/javascript/yui/build/cssreset/reset-context-min.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssreset/reset-context-min.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-cssreset html{color:#000;background:#FFF;}.yui-cssreset body,.yui-cssreset div,.yui-cssreset dl,.yui-cssreset dt,.yui-cssreset dd,.yui-cssreset ul,.yui-cssreset ol,.yui-cssreset li,.yui-cssreset h1,.yui-cssreset h2,.yui-cssreset h3,.yui-cssreset h4,.yui-cssreset h5,.yui-cssreset h6,.yui-cssreset pre,.yui-cssreset code,.yui-cssreset form,.yui-cssreset fieldset,.yui-cssreset legend,.yui-cssreset input,.yui-cssreset textarea,.yui-cssreset p,.yui-cssreset blockquote,.yui-cssreset th,.yui-cssreset td{margin:0;padding:0;}.yui-cssreset table{border-collapse:collapse;border-spacing:0;}.yui-cssreset fieldset,.yui-cssreset img{border:0;}.yui-cssreset address,.yui-cssreset caption,.yui-cssreset cite,.yui-cssreset code,.yui-cssreset dfn,.yui-cssreset em,.yui-cssreset strong,.yui-cssreset th,.yui-cssreset var{font-style:normal;font-weight:normal;}.yui-cssreset li{list-style:none;}.yui-cssreset caption,.yui-cssreset th{text-align:left;}.yui-cssreset h1,.yui-cssreset h2,.yui-cssreset h3,.yui-cssreset h4,.yui-cssreset h5,.yui-cssreset h6{font-size:100%;font-weight:normal;}.yui-cssreset q:before,.yui-cssreset q:after{content:'';}.yui-cssreset abbr,.yui-cssreset acronym{border:0;font-variant:normal;}.yui-cssreset sup{vertical-align:text-top;}.yui-cssreset sub{vertical-align:text-bottom;}.yui-cssreset input,.yui-cssreset textarea,.yui-cssreset select{font-family:inherit;font-size:inherit;font-weight:inherit;}.yui-cssreset input,.yui-cssreset textarea,.yui-cssreset select{*font-size:100%;}.yui-cssreset legend{color:#000;}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssreset/reset-context.css'
--- loggerhead/static/javascript/yui/build/cssreset/reset-context.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssreset/reset-context.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,125 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/*e
+	TODO will need to remove settings on HTML since we can't namespace it.
+	TODO with the prefix, should I group by selector or property for weight savings?
+*/
+.yui-cssreset html{
+	color:#000;
+	background:#FFF;
+}
+/*
+	TODO remove settings on BODY since we can't namespace it.
+*/
+/*
+	TODO test putting a class on HEAD.
+		- Fails on FF. 
+*/
+.yui-cssreset body,
+.yui-cssreset div,
+.yui-cssreset dl,
+.yui-cssreset dt,
+.yui-cssreset dd,
+.yui-cssreset ul,
+.yui-cssreset ol,
+.yui-cssreset li,
+.yui-cssreset h1,
+.yui-cssreset h2,
+.yui-cssreset h3,
+.yui-cssreset h4,
+.yui-cssreset h5,
+.yui-cssreset h6,
+.yui-cssreset pre,
+.yui-cssreset code,
+.yui-cssreset form,
+.yui-cssreset fieldset,
+.yui-cssreset legend,
+.yui-cssreset input,
+.yui-cssreset textarea,
+.yui-cssreset p,
+.yui-cssreset blockquote,
+.yui-cssreset th,
+.yui-cssreset td {
+	margin:0;
+	padding:0;
+}
+.yui-cssreset table {
+	border-collapse:collapse;
+	border-spacing:0;
+}
+.yui-cssreset fieldset,
+.yui-cssreset img {
+	border:0;
+}
+/*
+	TODO think about hanlding inheritence differently, maybe letting IE6 fail a bit...
+*/
+.yui-cssreset address,
+.yui-cssreset caption,
+.yui-cssreset cite,
+.yui-cssreset code,
+.yui-cssreset dfn,
+.yui-cssreset em,
+.yui-cssreset strong,
+.yui-cssreset th,
+.yui-cssreset var {
+	font-style:normal;
+	font-weight:normal;
+}
+/*
+	TODO Figure out where this list-style rule is best set. Hedger has a request to investigate.
+*/
+.yui-cssreset li {
+	list-style:none;
+}
+
+.yui-cssreset caption,
+.yui-cssreset th {
+	text-align:left;
+}
+.yui-cssreset h1,
+.yui-cssreset h2,
+.yui-cssreset h3,
+.yui-cssreset h4,
+.yui-cssreset h5,
+.yui-cssreset h6 {
+	font-size:100%;
+	font-weight:normal;
+}
+.yui-cssreset q:before,
+.yui-cssreset q:after {
+	content:'';
+}
+.yui-cssreset abbr,
+.yui-cssreset acronym {
+	border:0;
+	font-variant:normal;
+}
+/* to preserve line-height and selector appearance */
+.yui-cssreset sup {
+	vertical-align:text-top;
+}
+.yui-cssreset sub {
+	vertical-align:text-bottom;
+}
+.yui-cssreset input,
+.yui-cssreset textarea,
+.yui-cssreset select {
+	font-family:inherit;
+	font-size:inherit;
+	font-weight:inherit;
+}
+/*to enable resizing for IE*/
+.yui-cssreset input,
+.yui-cssreset textarea,
+.yui-cssreset select {
+	*font-size:100%;
+}
+/*because legend doesn't inherit in IE */
+.yui-cssreset legend {
+	color:#000;
+}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssreset/reset-min.css'
--- loggerhead/static/javascript/yui/build/cssreset/reset-min.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssreset/reset-min.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+html{color:#000;background:#FFF;}body,div,dl,dt,dd,ul,ol,li,h1,h2,h3,h4,h5,h6,pre,code,form,fieldset,legend,input,textarea,p,blockquote,th,td{margin:0;padding:0;}table{border-collapse:collapse;border-spacing:0;}fieldset,img{border:0;}address,caption,cite,code,dfn,em,strong,th,var{font-style:normal;font-weight:normal;}li{list-style:none;}caption,th{text-align:left;}h1,h2,h3,h4,h5,h6{font-size:100%;font-weight:normal;}q:before,q:after{content:'';}abbr,acronym{border:0;font-variant:normal;}sup{vertical-align:text-top;}sub{vertical-align:text-bottom;}input,textarea,select{font-family:inherit;font-size:inherit;font-weight:inherit;}input,textarea,select{*font-size:100%;}legend{color:#000;}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/cssreset/reset.css'
--- loggerhead/static/javascript/yui/build/cssreset/reset.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/cssreset/reset.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,125 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/*
+	TODO will need to remove settings on HTML since we can't namespace it.
+	TODO with the prefix, should I group by selector or property for weight savings?
+*/
+html{
+	color:#000;
+	background:#FFF;
+}
+/*
+	TODO remove settings on BODY since we can't namespace it.
+*/
+/*
+	TODO test putting a class on HEAD.
+		- Fails on FF. 
+*/
+body,
+div,
+dl,
+dt,
+dd,
+ul,
+ol,
+li,
+h1,
+h2,
+h3,
+h4,
+h5,
+h6,
+pre,
+code,
+form,
+fieldset,
+legend,
+input,
+textarea,
+p,
+blockquote,
+th,
+td {
+	margin:0;
+	padding:0;
+}
+table {
+	border-collapse:collapse;
+	border-spacing:0;
+}
+fieldset,
+img {
+	border:0;
+}
+/*
+	TODO think about hanlding inheritence differently, maybe letting IE6 fail a bit...
+*/
+address,
+caption,
+cite,
+code,
+dfn,
+em,
+strong,
+th,
+var {
+	font-style:normal;
+	font-weight:normal;
+}
+/*
+	TODO Figure out where this list-style rule is best set. Hedger has a request to investigate.
+*/
+li {
+	list-style:none;
+}
+
+caption,
+th {
+	text-align:left;
+}
+h1,
+h2,
+h3,
+h4,
+h5,
+h6 {
+	font-size:100%;
+	font-weight:normal;
+}
+q:before,
+q:after {
+	content:'';
+}
+abbr,
+acronym {
+	border:0;
+	font-variant:normal;
+}
+/* to preserve line-height and selector appearance */
+sup {
+	vertical-align:text-top;
+}
+sub {
+	vertical-align:text-bottom;
+}
+input,
+textarea,
+select {
+	font-family:inherit;
+	font-size:inherit;
+	font-weight:inherit;
+}
+/*to enable resizing for IE*/
+input,
+textarea,
+select {
+	*font-size:100%;
+}
+/*because legend doesn't inherit in IE */
+legend {
+	color:#000;
+}
\ No newline at end of file

=== added directory 'loggerhead/static/javascript/yui/build/dd'
=== added file 'loggerhead/static/javascript/yui/build/dd/README'
--- loggerhead/static/javascript/yui/build/dd/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,59 @@
+**** version 3.0.0 PR2 ***
+
+Added bubbles config option to help with extending later.
+Updated _checkRegion to perform Bottom, Top, Left, Right validation instead of Top, Bottom, Left, Right
+
+**** version 3.0.0 PR1 ***
+
+Known Issues:
+
+    Firefox 2.x:
+        Proxy Drags with handles inside an element with overflow: hidden will not target properly.
+
+    All:
+        Scrolling Module not available as of this release.
+
+
+
+**** File Structure and Module Info ***
+
+
+Source Files:
+    ddm-base.js         ==> Base DragDrop Manager
+    ddm.js              ==> Adds shim support
+    ddm-drop.js         ==> Adds Drop support
+    drag.js             ==> Main drag class
+    proxy.js            ==> Adds proxy support to Drag
+    constrain.js        ==> Adds constrain support to drag
+    drop.js             ==> Drop Support
+    dd-plugin.js        ==> Node plugin for Drag
+    dd-drop-plugin.js   ==> Node plugin for Drop
+
+
+Module Names:
+    dd-ddm-base         ==> Base DragDrop Manager
+    dd-ddm              ==> Adds shim support
+    dd-ddm-drop         ==> Adds Drop support
+    dd-drag             ==> Main drag class
+    dd-proxy            ==> Adds proxy support to Drag
+    dd-constrain        ==> Adds constrain support to drag
+    dd-drop             ==> Drop Support
+    dd-plugin           ==> Node plugin for Drag
+    dd-drop-plugin      ==> Node plugin for Drop
+    dd                  ==> All Drag & Drop related code
+
+Build Files:
+    dd-ddm-base.js      ==> Base DragDrop Manager
+    dd-ddm.js           ==> Adds shim support
+    dd-ddm-drop.js      ==> Adds Drop support
+    dd-drag.js          ==> Main drag class
+    dd-proxy.js         ==> Adds proxy support to Drag
+    dd-constrain.js     ==> Adds constrain support to drag
+    dd-drop.js          ==> Drop Support
+    dd-plugin.js        ==> Node plugin for Drag
+    dd-drop-plugin.js   ==> Node plugin for Drop
+
+
+Rollup File:
+    dd.js  ==> dd-ddm-base, dd-ddm, dd-ddm-drop, dd-drag, dd-proxy, dd-constrain, dd-drop, dd-plugin, dd-drop-plugin
+

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-constrain-debug.js'
--- loggerhead/static/javascript/yui/build/dd/dd-constrain-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-constrain-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,389 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-constrain', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-constrain
+     */
+    /**
+     * This class extends the dd-drag module to add the constraining methods to it. It supports constraining to a region, node or viewport. It also
+     * supports tick based moves and XY axis constraints.
+     * @class DragConstrained
+     * @extends Drag
+     * @constructor
+     */
+
+    var DRAG_NODE = 'dragNode',
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth';
+
+
+    var C = function() {
+        C.superclass.constructor.apply(this, arguments);
+
+    };
+    
+    C.NAME = 'dragConstrained';
+
+    C.ATTRS = {
+        /**
+        * @attribute stickX
+        * @description Stick the drag movement to the X-Axis. Default: false
+        * @type Boolean
+        */        
+        stickX: {
+            value: false
+        },
+        /**
+        * @attribute stickY
+        * @description Stick the drag movement to the Y-Axis
+        * @type Boolean
+        */        
+        stickY: {
+            value: false
+        },
+        /**
+        * @attribute tickX
+        * @description The X tick offset the drag node should snap to on each drag move. False for no ticks. Default: false
+        * @type Number/false
+        */        
+        tickX: {
+            value: false
+        },
+        /**
+        * @attribute tickY
+        * @description The Y tick offset the drag node should snap to on each drag move. False for no ticks. Default: false
+        * @type Number/false
+        */        
+        tickY: {
+            value: false
+        },
+        /**
+        * @attribute tickXArray
+        * @description An array of page coordinates to use as X ticks for drag movement.
+        * @type Array
+        */
+        tickXArray: {
+            value: false
+        },
+        /**
+        * @attribute tickYArray
+        * @description An array of page coordinates to use as Y ticks for drag movement.
+        * @type Array
+        */
+        tickYArray: {
+            value: false
+        },
+        /**
+        * @attribute constrain2region
+        * @description An Object Literal containing a valid region (top, right, bottom, left) of page positions to constrain the drag node to.
+        * @type Object
+        */
+        constrain2region: {
+            value: false,
+            get: function(r) {
+                if (Y.Lang.isObject(r)) {
+                    var o = {};
+                    Y.mix(o, r);
+                    return o;
+                } else {
+                    return false;
+                }
+            },
+            set: function (r) {
+                if (Y.Lang.isObject(r)) {
+                    if (r.top && r.right && r.left && r.bottom) {
+                        var o = {};
+                        Y.mix(o, r);
+                        return o;
+                    } else {
+                        Y.log('constrain2region expecting a valid object with (top, right, bottom, left properties)', 'error', 'DragConstrain');
+                        return false;
+                    }
+                } else if (r !== false) {
+                    Y.log('constrain2region expecting an object', 'error', 'DragConstrain');
+                    return false;
+                }
+            }
+        },
+        /**
+        * @attribute gutter
+        * @description CSS style string for the gutter of a region (supports negative values): '5 0' (sets top and bottom to 5px, left and right to 0px), '1 2 3 4' (top 1px, right 2px, bottom 3px, left 4px)        
+        * @type String
+        */
+        gutter: {
+            value: '0',
+            set: function(gutter) {
+                return Y.DD.DDM.cssSizestoObject(gutter);
+            }
+        },
+        /**
+        * @attribute constrain2node
+        * @description Will attempt to constrain the drag node to the bounderies of this node.
+        * @type Object
+        */
+        constrain2node: {
+            value: false,
+            set: function(n) {
+                if (!this.get('constrain2region')) {
+                    var node = Y.Node.get(n);
+                    if (node) {
+                        return node;
+                    }
+                } else if (this.get('constrain2region') !== false) {
+                    Y.log('constrain2region found, can not have both. Node ignored', 'warn', 'DragConstrain');
+                }
+                return false;
+            }
+        },
+        /**
+        * @attribute constrain2view
+        * @description Will attempt to constrain the drag node to the bounderies of the viewport region.
+        * @type Object
+        */
+        constrain2view: {
+            value: false
+        }
+    };
+
+    var proto = {
+        start: function() {
+            C.superclass.start.apply(this, arguments);
+            this._regionCache = null;
+        },
+        /**
+        * @private
+        * @property _regionCache
+        * @description Store a cache of the region that we are constraining to
+        * @type Object
+        */
+        _regionCache: null,
+        /**
+        * @private
+        * @method _cacheRegion
+        * @description Get's the region and caches it, called from window.resize and when the cache is null
+        */
+        _cacheRegion: function() {
+            this._regionCache = this.get('constrain2node').get('region');
+        },
+        /**
+        * @method getRegion
+        * @description Get the active region: viewport, node, custom region
+        * @param {Boolean} inc Include the node's height and width
+        * @return {Object}
+        */
+        getRegion: function(inc) {
+            var r = {};
+            if (this.get('constrain2node')) {
+                if (!this._regionCache) {
+                    Y.on('resize', this._cacheRegion, this, true, window);
+                    this._cacheRegion();
+                }
+                r = Y.clone(this._regionCache);
+            } else if (this.get('constrain2region')) {
+                r = this.get('constrain2region');
+            } else if (this.get('constrain2view')) {
+                r = this.get('node').get('viewportRegion');
+            } else {
+                return false;
+            }
+            var g = this.get('gutter');
+            Y.each(g, function(i, n) {
+                if ((n == 'right') || (n == 'bottom')) {
+                    r[n] -= i;
+                } else {
+                    r[n] += i;
+                }
+            });
+            if (inc) {
+                var oh = this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                    ow = this.get(DRAG_NODE).get(OFFSET_WIDTH);
+                r.right = r.right - ow;
+                r.bottom = r.bottom - oh;
+            }
+            return r;
+        },
+        /**
+        * @private
+        * @method _checkRegion
+        * @description
+        * @param {Array} _xy The XY to check if it's in the current region, if it isn't inside the region, it will reset the xy array to be inside the region.
+        * @return {Array} The new XY that is inside the region
+        */
+        _checkRegion: function(_xy) {
+            var oxy = _xy,
+                r = this.getRegion(),
+                oh = this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                ow = this.get(DRAG_NODE).get(OFFSET_WIDTH);
+            
+                if (oxy[1] > (r.bottom - oh)) {
+                    _xy[1] = (r.bottom - oh);
+                }
+                if (r.top > oxy[1]) {
+                    _xy[1] = r.top;
+
+                }
+                if (oxy[0] > (r.right - ow)) {
+                    _xy[0] = (r.right - ow);
+                }
+                if (r.left > oxy[0]) {
+                    _xy[0] = r.left;
+                }
+
+            return _xy;
+        },
+        /**
+        * @method inRegion
+        * @description Checks if the XY passed or the dragNode is inside the active region.
+        * @param {Array} xy Optional XY to check, if not supplied this.get('dragNode').getXY() is used.
+        * @return {Boolean} True if the XY is inside the region, false otherwise.
+        */
+        inRegion: function(xy) {
+            xy = xy || this.get(DRAG_NODE).getXY();
+
+            var _xy = this._checkRegion([xy[0], xy[1]]),
+                inside = false;
+                if ((xy[0] === _xy[0]) && (xy[1] === _xy[1])) {
+                    inside = true;
+                }
+            return inside;
+        },
+        /**
+        * @private
+        * @method _align
+        * @description Override of Drag _align to account for region checking and tick checking
+        * @param {Array} xy The XY to check for ticks and region
+        * @return {Array} The modified XY coords.
+        */
+        _align: function(xy) {
+            var _xy = C.superclass._align.apply(this, arguments),
+                r = this.getRegion(true);
+
+            if (this.get('stickX')) {
+                _xy[1] = (this.startXY[1] - this.deltaXY[1]);
+            }
+            if (this.get('stickY')) {
+                _xy[0] = (this.startXY[0] - this.deltaXY[0]);
+            }
+
+
+            if (r) {
+                _xy = this._checkRegion(_xy);
+            }
+                
+            _xy = this._checkTicks(_xy, r);
+            return _xy;
+        },
+        /**
+        * @private
+        * @method _calcTicks
+        * @description Helper method to calculate the tick offsets for a given position
+        * @param {Number} pos The current X or Y position
+        * @param {Number} start The start X or Y position
+        * @param {Number} tick The X or Y tick increment
+        * @param {Number} off1 The min offset that we can't pass (region)
+        * @param {Number} off2 The max offset that we can't pass (region)
+        * @return {Number} The new position based on the tick calculation
+        */
+        _calcTicks: function(pos, start, tick, off1, off2) {
+            var ix = ((pos - start) / tick),
+                min = Math.floor(ix),
+                max = Math.ceil(ix);
+                if ((min !== 0) || (max !== 0)) {
+                    if ((ix >= min) && (ix <= max)) {
+                        pos = (start + (tick * min));
+                        if (off1 && off2) {
+                            if (pos < off1) {
+                                pos = (start + (tick * (min + 1)));
+                            }
+                            if (pos > off2) {
+                                pos = (start + (tick * (min - 1)));
+                            }
+                        }
+                    }
+                }
+                return pos;
+        },
+        /**
+        * @private
+        * @method _calcTickArray
+        * @description This method is used with the tickXArray and tickYArray config options
+        * @param {Number} pos The current X or Y position
+        * @param {Number} ticks The array containing our custom tick positions.
+        * @param {Number} off1 The min offset that we can't pass (region)
+        * @param {Number} off2 The max offset that we can't pass (region)
+        * @return The tick position
+        */
+        _calcTickArray: function(pos, ticks, off1, off2) {
+            var i = 0, len = ticks.length, next = 0;
+
+            if (!ticks || (ticks.length === 0)) {
+                return pos;
+            } else if (ticks[0] >= pos) {
+                return ticks[0];
+            } else {
+                for (i = 0; i < len; i++) {
+                    next = (i + 1);
+                    if (ticks[next] && ticks[next] >= pos) {
+                        var diff1 = pos - ticks[i],
+                            diff2 = ticks[next] - pos;
+                        var ret = (diff2 > diff1) ? ticks[i] : ticks[next];
+                        if (off1 && off2) {
+                            if (ret > off2) {
+                                if (ticks[i]) {
+                                    ret = ticks[i];
+                                } else {
+                                    ret = ticks[len - 1];
+                                }
+                            }
+                        }
+                        return ret;
+                    }
+                    
+                }
+                return ticks[ticks.length - 1];
+            }
+        },
+        /**
+        * @private
+        * @method _checkTicks
+        * @description This method delegates the proper helper method for tick calculations
+        * @param {Array} xy The XY coords for the Drag
+        * @param {Object} r The optional region that we are bound to.
+        * @return {Array} The calced XY coords
+        */
+        _checkTicks: function(xy, r) {
+            var lx = (this.startXY[0] - this.deltaXY[0]),
+                ly = (this.startXY[1] - this.deltaXY[1]),
+                xt = this.get('tickX'),
+                yt = this.get('tickY');
+                if (xt && !this.get('tickXArray')) {
+                    xy[0] = this._calcTicks(xy[0], lx, xt, r.left, r.right);
+                }
+                if (yt && !this.get('tickYArray')) {
+                    xy[1] = this._calcTicks(xy[1], ly, yt, r.top, r.bottom);
+                }
+                if (this.get('tickXArray')) {
+                    xy[0] = this._calcTickArray(xy[0], this.get('tickXArray'), r.left, r.right);
+                }
+                if (this.get('tickYArray')) {
+                    xy[1] = this._calcTickArray(xy[1], this.get('tickYArray'), r.top, r.bottom);
+                }
+
+            return xy;
+        }
+    };
+    //Extend DD.Drag
+    Y.extend(C, Y.DD.Drag, proto);
+    //Set this to DD.Drag for other extensions
+    Y.DD.Drag = C;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drag', 'dd-proxy'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-constrain-min.js'
--- loggerhead/static/javascript/yui/build/dd/dd-constrain-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-constrain-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dd-constrain",function(E){var A="dragNode",G="offsetHeight",F="offsetWidth";var D=function(){D.superclass.constructor.apply(this,arguments);};D.NAME="dragConstrained";D.ATTRS={stickX:{value:false},stickY:{value:false},tickX:{value:false},tickY:{value:false},tickXArray:{value:false},tickYArray:{value:false},constrain2region:{value:false,get:function(C){if(E.Lang.isObject(C)){var H={};E.mix(H,C);return H;}else{return false;}},set:function(C){if(E.Lang.isObject(C)){if(C.top&&C.right&&C.left&&C.bottom){var H={};E.mix(H,C);return H;}else{return false;}}else{if(C!==false){return false;}}}},gutter:{value:"0",set:function(C){return E.DD.DDM.cssSizestoObject(C);}},constrain2node:{value:false,set:function(H){if(!this.get("constrain2region")){var C=E.Node.get(H);if(C){return C;}}else{if(this.get("constrain2region")!==false){}}return false;}},constrain2view:{value:false}};var B={start:function(){D.superclass.start.apply(this,arguments);this._regionCache=null;},_regionCache:null,_cacheRegion:function(){this._regionCache=this.get("constrain2node").get("region");},getRegion:function(K){var I={};if(this.get("constrain2node")){if(!this._regionCache){E.on("resize",this._cacheRegion,this,true,window);this._cacheRegion();}I=E.clone(this._regionCache);}else{if(this.get("constrain2region")){I=this.get("constrain2region");}else{if(this.get("constrain2view")){I=this.get("node").get("viewportRegion");}else{return false;}}}var H=this.get("gutter");E.each(H,function(L,M){if((M=="right")||(M=="bottom")){I[M]-=L;}else{I[M]+=L;}});if(K){var J=this.get(A).get(G),C=this.get(A).get(F);I.right=I.right-C;I.bottom=I.bottom-J;}return I;},_checkRegion:function(C){var I=C,J=this.getRegion(),K=this.get(A).get(G),H=this.get(A).get(F);if(I[1]>(J.bottom-K)){C[1]=(J.bottom-K);}if(J.top>I[1]){C[1]=J.top;}if(I[0]>(J.right-H)){C[0]=(J.right-H);}if(J.left>I[0]){C[0]=J.left;}return C;},inRegion:function(I){I=I||this.get(A).getXY();var H=this._checkRegion([I[0],I[1]]),C=false;if((I[0]===H[0])&&(I[1]===H[1])){C=true;}return C;},_align:function(I){var C=D.superclass._align.apply(this,arguments),H=this.getRegion(true);if(this.get("stickX")){C[1]=(this.startXY[1]-this.deltaXY[1]);}if(this.get("stickY")){C[0]=(this.startXY[0]-this.deltaXY[0]);}if(H){C=this._checkRegion(C);}C=this._checkTicks(C,H);return C;},_calcTicks:function(N,M,J,L,K){var H=((N-M)/J),I=Math.floor(H),C=Math.ceil(H);if((I!==0)||(C!==0)){if((H>=I)&&(H<=C)){N=(M+(J*I));if(L&&K){if(N<L){N=(M+(J*(I+1)));}if(N>K){N=(M+(J*(I-1)));}}}}return N;},_calcTickArray:function(O,P,N,K){var H=0,L=P.length,J=0;if(!P||(P.length===0)){return O;}else{if(P[0]>=O){return P[0];}else{for(H=0;H<L;H++){J=(H+1);if(P[J]&&P[J]>=O){var I=O-P[H],C=P[J]-O;var M=(C>I)?P[H]:P[J];if(N&&K){if(M>K){if(P[H]){M=P[H];}else{M=P[L-1];}}}return M;}}return P[P.length-1];}}},_checkTicks:function(L,J){var K=(this.startXY[0]-this.deltaXY[0]),I=(this.startXY[1]-this.deltaXY[1]),C=this.get("tickX"),H=this.get("tickY");if(C&&!this.get("tickXArray")){L[0]=this._calcTicks(L[0],K,C,J.left,J.right);}if(H&&!this.get("tickYArray")){L[1]=this._calcTicks(L[1],I,H,J.top,J.bottom);}if(this.get("tickXArray")){L[0]=this._calcTickArray(L[0],this.get("tickXArray"),J.left,J.right);}if(this.get("tickYArray")){L[1]=this._calcTickArray(L[1],this.get("tickYArray"),J.top,J.bottom);}return L;}};E.extend(D,E.DD.Drag,B);E.DD.Drag=D;},"3.0.0pr2",{requires:["dd-drag","dd-proxy"],skinnable:false});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-constrain.js'
--- loggerhead/static/javascript/yui/build/dd/dd-constrain.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-constrain.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,386 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-constrain', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-constrain
+     */
+    /**
+     * This class extends the dd-drag module to add the constraining methods to it. It supports constraining to a region, node or viewport. It also
+     * supports tick based moves and XY axis constraints.
+     * @class DragConstrained
+     * @extends Drag
+     * @constructor
+     */
+
+    var DRAG_NODE = 'dragNode',
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth';
+
+
+    var C = function() {
+        C.superclass.constructor.apply(this, arguments);
+
+    };
+    
+    C.NAME = 'dragConstrained';
+
+    C.ATTRS = {
+        /**
+        * @attribute stickX
+        * @description Stick the drag movement to the X-Axis. Default: false
+        * @type Boolean
+        */        
+        stickX: {
+            value: false
+        },
+        /**
+        * @attribute stickY
+        * @description Stick the drag movement to the Y-Axis
+        * @type Boolean
+        */        
+        stickY: {
+            value: false
+        },
+        /**
+        * @attribute tickX
+        * @description The X tick offset the drag node should snap to on each drag move. False for no ticks. Default: false
+        * @type Number/false
+        */        
+        tickX: {
+            value: false
+        },
+        /**
+        * @attribute tickY
+        * @description The Y tick offset the drag node should snap to on each drag move. False for no ticks. Default: false
+        * @type Number/false
+        */        
+        tickY: {
+            value: false
+        },
+        /**
+        * @attribute tickXArray
+        * @description An array of page coordinates to use as X ticks for drag movement.
+        * @type Array
+        */
+        tickXArray: {
+            value: false
+        },
+        /**
+        * @attribute tickYArray
+        * @description An array of page coordinates to use as Y ticks for drag movement.
+        * @type Array
+        */
+        tickYArray: {
+            value: false
+        },
+        /**
+        * @attribute constrain2region
+        * @description An Object Literal containing a valid region (top, right, bottom, left) of page positions to constrain the drag node to.
+        * @type Object
+        */
+        constrain2region: {
+            value: false,
+            get: function(r) {
+                if (Y.Lang.isObject(r)) {
+                    var o = {};
+                    Y.mix(o, r);
+                    return o;
+                } else {
+                    return false;
+                }
+            },
+            set: function (r) {
+                if (Y.Lang.isObject(r)) {
+                    if (r.top && r.right && r.left && r.bottom) {
+                        var o = {};
+                        Y.mix(o, r);
+                        return o;
+                    } else {
+                        return false;
+                    }
+                } else if (r !== false) {
+                    return false;
+                }
+            }
+        },
+        /**
+        * @attribute gutter
+        * @description CSS style string for the gutter of a region (supports negative values): '5 0' (sets top and bottom to 5px, left and right to 0px), '1 2 3 4' (top 1px, right 2px, bottom 3px, left 4px)        
+        * @type String
+        */
+        gutter: {
+            value: '0',
+            set: function(gutter) {
+                return Y.DD.DDM.cssSizestoObject(gutter);
+            }
+        },
+        /**
+        * @attribute constrain2node
+        * @description Will attempt to constrain the drag node to the bounderies of this node.
+        * @type Object
+        */
+        constrain2node: {
+            value: false,
+            set: function(n) {
+                if (!this.get('constrain2region')) {
+                    var node = Y.Node.get(n);
+                    if (node) {
+                        return node;
+                    }
+                } else if (this.get('constrain2region') !== false) {
+                }
+                return false;
+            }
+        },
+        /**
+        * @attribute constrain2view
+        * @description Will attempt to constrain the drag node to the bounderies of the viewport region.
+        * @type Object
+        */
+        constrain2view: {
+            value: false
+        }
+    };
+
+    var proto = {
+        start: function() {
+            C.superclass.start.apply(this, arguments);
+            this._regionCache = null;
+        },
+        /**
+        * @private
+        * @property _regionCache
+        * @description Store a cache of the region that we are constraining to
+        * @type Object
+        */
+        _regionCache: null,
+        /**
+        * @private
+        * @method _cacheRegion
+        * @description Get's the region and caches it, called from window.resize and when the cache is null
+        */
+        _cacheRegion: function() {
+            this._regionCache = this.get('constrain2node').get('region');
+        },
+        /**
+        * @method getRegion
+        * @description Get the active region: viewport, node, custom region
+        * @param {Boolean} inc Include the node's height and width
+        * @return {Object}
+        */
+        getRegion: function(inc) {
+            var r = {};
+            if (this.get('constrain2node')) {
+                if (!this._regionCache) {
+                    Y.on('resize', this._cacheRegion, this, true, window);
+                    this._cacheRegion();
+                }
+                r = Y.clone(this._regionCache);
+            } else if (this.get('constrain2region')) {
+                r = this.get('constrain2region');
+            } else if (this.get('constrain2view')) {
+                r = this.get('node').get('viewportRegion');
+            } else {
+                return false;
+            }
+            var g = this.get('gutter');
+            Y.each(g, function(i, n) {
+                if ((n == 'right') || (n == 'bottom')) {
+                    r[n] -= i;
+                } else {
+                    r[n] += i;
+                }
+            });
+            if (inc) {
+                var oh = this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                    ow = this.get(DRAG_NODE).get(OFFSET_WIDTH);
+                r.right = r.right - ow;
+                r.bottom = r.bottom - oh;
+            }
+            return r;
+        },
+        /**
+        * @private
+        * @method _checkRegion
+        * @description
+        * @param {Array} _xy The XY to check if it's in the current region, if it isn't inside the region, it will reset the xy array to be inside the region.
+        * @return {Array} The new XY that is inside the region
+        */
+        _checkRegion: function(_xy) {
+            var oxy = _xy,
+                r = this.getRegion(),
+                oh = this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                ow = this.get(DRAG_NODE).get(OFFSET_WIDTH);
+            
+                if (oxy[1] > (r.bottom - oh)) {
+                    _xy[1] = (r.bottom - oh);
+                }
+                if (r.top > oxy[1]) {
+                    _xy[1] = r.top;
+
+                }
+                if (oxy[0] > (r.right - ow)) {
+                    _xy[0] = (r.right - ow);
+                }
+                if (r.left > oxy[0]) {
+                    _xy[0] = r.left;
+                }
+
+            return _xy;
+        },
+        /**
+        * @method inRegion
+        * @description Checks if the XY passed or the dragNode is inside the active region.
+        * @param {Array} xy Optional XY to check, if not supplied this.get('dragNode').getXY() is used.
+        * @return {Boolean} True if the XY is inside the region, false otherwise.
+        */
+        inRegion: function(xy) {
+            xy = xy || this.get(DRAG_NODE).getXY();
+
+            var _xy = this._checkRegion([xy[0], xy[1]]),
+                inside = false;
+                if ((xy[0] === _xy[0]) && (xy[1] === _xy[1])) {
+                    inside = true;
+                }
+            return inside;
+        },
+        /**
+        * @private
+        * @method _align
+        * @description Override of Drag _align to account for region checking and tick checking
+        * @param {Array} xy The XY to check for ticks and region
+        * @return {Array} The modified XY coords.
+        */
+        _align: function(xy) {
+            var _xy = C.superclass._align.apply(this, arguments),
+                r = this.getRegion(true);
+
+            if (this.get('stickX')) {
+                _xy[1] = (this.startXY[1] - this.deltaXY[1]);
+            }
+            if (this.get('stickY')) {
+                _xy[0] = (this.startXY[0] - this.deltaXY[0]);
+            }
+
+
+            if (r) {
+                _xy = this._checkRegion(_xy);
+            }
+                
+            _xy = this._checkTicks(_xy, r);
+            return _xy;
+        },
+        /**
+        * @private
+        * @method _calcTicks
+        * @description Helper method to calculate the tick offsets for a given position
+        * @param {Number} pos The current X or Y position
+        * @param {Number} start The start X or Y position
+        * @param {Number} tick The X or Y tick increment
+        * @param {Number} off1 The min offset that we can't pass (region)
+        * @param {Number} off2 The max offset that we can't pass (region)
+        * @return {Number} The new position based on the tick calculation
+        */
+        _calcTicks: function(pos, start, tick, off1, off2) {
+            var ix = ((pos - start) / tick),
+                min = Math.floor(ix),
+                max = Math.ceil(ix);
+                if ((min !== 0) || (max !== 0)) {
+                    if ((ix >= min) && (ix <= max)) {
+                        pos = (start + (tick * min));
+                        if (off1 && off2) {
+                            if (pos < off1) {
+                                pos = (start + (tick * (min + 1)));
+                            }
+                            if (pos > off2) {
+                                pos = (start + (tick * (min - 1)));
+                            }
+                        }
+                    }
+                }
+                return pos;
+        },
+        /**
+        * @private
+        * @method _calcTickArray
+        * @description This method is used with the tickXArray and tickYArray config options
+        * @param {Number} pos The current X or Y position
+        * @param {Number} ticks The array containing our custom tick positions.
+        * @param {Number} off1 The min offset that we can't pass (region)
+        * @param {Number} off2 The max offset that we can't pass (region)
+        * @return The tick position
+        */
+        _calcTickArray: function(pos, ticks, off1, off2) {
+            var i = 0, len = ticks.length, next = 0;
+
+            if (!ticks || (ticks.length === 0)) {
+                return pos;
+            } else if (ticks[0] >= pos) {
+                return ticks[0];
+            } else {
+                for (i = 0; i < len; i++) {
+                    next = (i + 1);
+                    if (ticks[next] && ticks[next] >= pos) {
+                        var diff1 = pos - ticks[i],
+                            diff2 = ticks[next] - pos;
+                        var ret = (diff2 > diff1) ? ticks[i] : ticks[next];
+                        if (off1 && off2) {
+                            if (ret > off2) {
+                                if (ticks[i]) {
+                                    ret = ticks[i];
+                                } else {
+                                    ret = ticks[len - 1];
+                                }
+                            }
+                        }
+                        return ret;
+                    }
+                    
+                }
+                return ticks[ticks.length - 1];
+            }
+        },
+        /**
+        * @private
+        * @method _checkTicks
+        * @description This method delegates the proper helper method for tick calculations
+        * @param {Array} xy The XY coords for the Drag
+        * @param {Object} r The optional region that we are bound to.
+        * @return {Array} The calced XY coords
+        */
+        _checkTicks: function(xy, r) {
+            var lx = (this.startXY[0] - this.deltaXY[0]),
+                ly = (this.startXY[1] - this.deltaXY[1]),
+                xt = this.get('tickX'),
+                yt = this.get('tickY');
+                if (xt && !this.get('tickXArray')) {
+                    xy[0] = this._calcTicks(xy[0], lx, xt, r.left, r.right);
+                }
+                if (yt && !this.get('tickYArray')) {
+                    xy[1] = this._calcTicks(xy[1], ly, yt, r.top, r.bottom);
+                }
+                if (this.get('tickXArray')) {
+                    xy[0] = this._calcTickArray(xy[0], this.get('tickXArray'), r.left, r.right);
+                }
+                if (this.get('tickYArray')) {
+                    xy[1] = this._calcTickArray(xy[1], this.get('tickYArray'), r.top, r.bottom);
+                }
+
+            return xy;
+        }
+    };
+    //Extend DD.Drag
+    Y.extend(C, Y.DD.Drag, proto);
+    //Set this to DD.Drag for other extensions
+    Y.DD.Drag = C;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drag', 'dd-proxy'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-ddm-base-debug.js'
--- loggerhead/static/javascript/yui/build/dd/dd-ddm-base-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-ddm-base-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,276 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-ddm-base', function(Y) {
+
+    /**
+     * Provides the base Drag Drop Manger required for making a Node draggable.
+     * @module dd
+     * @submodule dd-ddm-base
+     */     
+     /**
+     * Provides the base Drag Drop Manger required for making a Node draggable.
+     * @class DDM
+     * @extends Base
+     * @constructor
+     */
+    
+    var DDMBase = function() {
+        //debugger;
+        DDMBase.superclass.constructor.apply(this, arguments);
+    };
+
+    DDMBase.NAME = 'dragDropMgr';
+
+    DDMBase.ATTRS = {
+        /**
+        * @attribute clickPixelThresh
+        * @description The number of pixels to move to start a drag operation, default is 3.
+        * @type Number
+        */
+        clickPixelThresh: {
+            value: 3
+        },
+        /**
+        * @attribute clickTimeThresh
+        * @description The number of milliseconds a mousedown has to pass to start a drag operation, default is 1000.
+        * @type Number
+        */        
+        clickTimeThresh: {
+            value: 1000
+        },
+        /**
+        * @attribute dragMode
+        * @description This attribute only works if the dd-drop module is active. It will set the dragMode (point, intersect, strict) of all future Drag instances. 
+        * @type String
+        */        
+        dragMode: {
+            value: 'point',
+            set: function(mode) {
+                this._setDragMode(mode);
+            }           
+        }
+
+    };
+
+    Y.extend(DDMBase, Y.Base, {
+        /**
+        * @private
+        * @method _setDragMode
+        * @description Handler for dragMode attribute setter.
+        * @param String/Number The Number value or the String for the DragMode to default all future drag instances to.
+        * @return Number The Mode to be set
+        */
+        _setDragMode: function(mode) {
+            if (mode === null) {
+                mode = Y.DD.DDM.get('dragMode');
+            }
+            switch (mode) {
+                case 1:
+                case 'intersect':
+                    return 1;
+                case 2:
+                case 'strict':
+                    return 2;
+                case 0:
+                case 'point':
+                    return 0;
+            }
+            return 0;       
+        },
+        /**
+        * @property CSS_PREFIX
+        * @description The PREFIX to attach to all DD CSS class names
+        * @type {String}
+        */
+        CSS_PREFIX: 'yui-dd',
+        _activateTargets: function() {},        
+        /**
+        * @private
+        * @property _drags
+        * @description Holder for all registered drag elements.
+        * @type {Array}
+        */
+        _drags: [],
+        /**
+        * @property activeDrag
+        * @description A reference to the currently active draggable object.
+        * @type {Drag}
+        */
+        activeDrag: false,
+        /**
+        * @private
+        * @method _regDrag
+        * @description Adds a reference to the drag object to the DDM._drags array, called in the constructor of Drag.
+        * @param {Drag} d The Drag object
+        */
+        _regDrag: function(d) {
+            this._drags[this._drags.length] = d;
+        },
+        /**
+        * @private
+        * @method _unregDrag
+        * @description Remove this drag object from the DDM._drags array.
+        * @param {Drag} d The drag object.
+        */
+        _unregDrag: function(d) {
+            var tmp = [];
+            Y.each(this._drags, function(n, i) {
+                if (n !== d) {
+                    tmp[tmp.length] = n;
+                }
+            });
+            this._drags = tmp;
+        },
+        /**
+        * @private
+        * @method _init
+        * @description DDM's init method
+        */
+        initializer: function() {
+            Y.Node.get('document').on('mousemove', this._move, this, true);
+            Y.Node.get('document').on('mouseup', this._end, this, true);
+        },
+        /**
+        * @private
+        * @method _start
+        * @description Internal method used by Drag to signal the start of a drag operation
+        * @param {Number} x The x position of the drag element
+        * @param {Number} y The y position of the drag element
+        * @param {Number} w The width of the drag element
+        * @param {Number} h The height of the drag element
+        */
+        _start: function(x, y, w, h) {
+            this._startDrag.apply(this, arguments);
+        },
+        /**
+        * @private
+        * @method _startDrag
+        * @description Factory method to be overwritten by other DDM's
+        * @param {Number} x The x position of the drag element
+        * @param {Number} y The y position of the drag element
+        * @param {Number} w The width of the drag element
+        * @param {Number} h The height of the drag element
+        */
+        _startDrag: function() {},
+        /**
+        * @private
+        * @method _endDrag
+        * @description Factory method to be overwritten by other DDM's
+        */
+        _endDrag: function() {},
+        _dropMove: function() {},
+        /**
+        * @private
+        * @method _end
+        * @description Internal method used by Drag to signal the end of a drag operation
+        */
+        _end: function() {
+            //@TODO - Here we can get a (click - drag - click - release) interaction instead of a (mousedown - drag - mouseup - release) interaction
+            //Add as a config option??
+            if (this.activeDrag) {
+                this._endDrag();
+                this.activeDrag.end.call(this.activeDrag);
+                this.activeDrag = null;
+            }
+        },
+        /**
+        * @method stopDrag
+        * @description Method will forcefully stop a drag operation. For example calling this from inside an ESC keypress handler will stop this drag.
+        * @return {Self}
+        * @chainable
+        */       
+        stopDrag: function() {
+            if (this.activeDrag) {
+                this._end();
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method _move
+        * @description Internal listener for the mousemove DOM event to pass to the Drag's move method.
+        * @param {Event} ev The Dom mousemove Event
+        */
+        _move: function(ev) {
+            if (this.activeDrag) {
+                this.activeDrag._move.apply(this.activeDrag, arguments);
+                this._dropMove();
+            }
+        },
+        /**
+        * @method setXY
+        * @description A simple method to set the top and left position from offsets instead of page coordinates
+        * @param {Object} node The node to set the position of 
+        * @param {Array} xy The Array of left/top position to be set.
+        */
+        setXY: function(node, xy) {
+            var t = parseInt(node.getStyle('top'), 10),
+            l = parseInt(node.getStyle('left'), 10),
+            pos = node.getStyle('position');
+
+            if (pos === 'static') {
+                node.setStyle('position', 'relative');
+            }
+
+            // in case of 'auto'
+            if (isNaN(t)) { t = 0; }
+            if (isNaN(l)) { l = 0; }
+            
+            node.setStyle('top', (xy[1] + t) + 'px');
+            node.setStyle('left', (xy[0] + l) + 'px');
+            
+        },
+        /**
+        * //TODO Private, rename??...
+        * @private
+        * @method cssSizestoObject
+        * @description Helper method to use to set the gutter from the attribute setter.
+        * @param {String} gutter CSS style string for gutter: '5 0' (sets top and bottom to 5px, left and right to 0px), '1 2 3 4' (top 1px, right 2px, bottom 3px, left 4px)
+        * @return {Object} The gutter Object Literal.
+        */
+        cssSizestoObject: function(gutter) {
+            var x = gutter.split(' ');
+                
+            switch (x.length) {
+                case 1: x[1] = x[2] = x[3] = x[0]; break;
+                case 2: x[2] = x[0]; x[3] = x[1]; break;
+                case 3: x[3] = x[1]; break;
+            }
+
+            return {
+                top   : parseInt(x[0],10),
+                right : parseInt(x[1],10),
+                bottom: parseInt(x[2],10),
+                left  : parseInt(x[3],10)
+            };
+        },
+        /**
+        * @method getDrag
+        * @description Get a valid Drag instance back from a Node or a selector string, false otherwise
+        * @param {String/Object} node The Node instance or Selector string to check for a valid Drag Object
+        * @return {Object}
+        */
+        getDrag: function(node) {
+            var drag = false,
+                n = Y.Node.get(node);
+            if (n instanceof Y.Node) {
+                Y.each(this._drags, function(v, k) {
+                    if (n.compareTo(v.get('node'))) {
+                        drag = v;
+                    }
+                });
+            }
+            return drag;
+        }
+    });
+
+    Y.namespace('DD');
+    Y.DD.DDM = new DDMBase();
+
+
+
+}, '3.0.0pr2' ,{requires:['node', 'base'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-ddm-base-min.js'
--- loggerhead/static/javascript/yui/build/dd/dd-ddm-base-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-ddm-base-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dd-ddm-base",function(B){var A=function(){A.superclass.constructor.apply(this,arguments);};A.NAME="dragDropMgr";A.ATTRS={clickPixelThresh:{value:3},clickTimeThresh:{value:1000},dragMode:{value:"point",set:function(C){this._setDragMode(C);}}};B.extend(A,B.Base,{_setDragMode:function(C){if(C===null){C=B.DD.DDM.get("dragMode");}switch(C){case 1:case"intersect":return 1;case 2:case"strict":return 2;case 0:case"point":return 0;}return 0;},CSS_PREFIX:"yui-dd",_activateTargets:function(){},_drags:[],activeDrag:false,_regDrag:function(C){this._drags[this._drags.length]=C;},_unregDrag:function(D){var C=[];B.each(this._drags,function(F,E){if(F!==D){C[C.length]=F;}});this._drags=C;},initializer:function(){B.Node.get("document").on("mousemove",this._move,this,true);B.Node.get("document").on("mouseup",this._end,this,true);},_start:function(C,F,D,E){this._startDrag.apply(this,arguments);},_startDrag:function(){},_endDrag:function(){},_dropMove:function(){},_end:function(){if(this.activeDrag){this._endDrag();this.activeDrag.end.call(this.activeDrag);this.activeDrag=null;}},stopDrag:function(){if(this.activeDrag){this._end();}return this;},_move:function(C){if(this.activeDrag){this.activeDrag._move.apply(this.activeDrag,arguments);this._dropMove();}},setXY:function(E,F){var D=parseInt(E.getStyle("top"),10),C=parseInt(E.getStyle("left"),10),G=E.getStyle("position");if(G==="static"){E.setStyle("position","relative");}if(isNaN(D)){D=0;}if(isNaN(C)){C=0;}E.setStyle("top",(F[1]+D)+"px");E.setStyle("left",(F[0]+C)+"px");},cssSizestoObject:function(D){var C=D.split(" ");switch(C.length){case 1:C[1]=C[2]=C[3]=C[0];break;case 2:C[2]=C[0];C[3]=C[1];break;case 3:C[3]=C[1];break;}return{top:parseInt(C[0],10),right:parseInt(C[1],10),bottom:parseInt(C[2],10),left:parseInt(C[3],10)};},getDrag:function(D){var C=false,E=B.Node.get(D);if(E instanceof B.Node){B.each(this._drags,function(G,F){if(E.compareTo(G.get("node"))){C=G;}});}return C;}});B.namespace("DD");B.DD.DDM=new A();},"3.0.0pr2",{requires:["node","base"],skinnable:false});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-ddm-base.js'
--- loggerhead/static/javascript/yui/build/dd/dd-ddm-base.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-ddm-base.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,276 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-ddm-base', function(Y) {
+
+    /**
+     * Provides the base Drag Drop Manger required for making a Node draggable.
+     * @module dd
+     * @submodule dd-ddm-base
+     */     
+     /**
+     * Provides the base Drag Drop Manger required for making a Node draggable.
+     * @class DDM
+     * @extends Base
+     * @constructor
+     */
+    
+    var DDMBase = function() {
+        //debugger;
+        DDMBase.superclass.constructor.apply(this, arguments);
+    };
+
+    DDMBase.NAME = 'dragDropMgr';
+
+    DDMBase.ATTRS = {
+        /**
+        * @attribute clickPixelThresh
+        * @description The number of pixels to move to start a drag operation, default is 3.
+        * @type Number
+        */
+        clickPixelThresh: {
+            value: 3
+        },
+        /**
+        * @attribute clickTimeThresh
+        * @description The number of milliseconds a mousedown has to pass to start a drag operation, default is 1000.
+        * @type Number
+        */        
+        clickTimeThresh: {
+            value: 1000
+        },
+        /**
+        * @attribute dragMode
+        * @description This attribute only works if the dd-drop module is active. It will set the dragMode (point, intersect, strict) of all future Drag instances. 
+        * @type String
+        */        
+        dragMode: {
+            value: 'point',
+            set: function(mode) {
+                this._setDragMode(mode);
+            }           
+        }
+
+    };
+
+    Y.extend(DDMBase, Y.Base, {
+        /**
+        * @private
+        * @method _setDragMode
+        * @description Handler for dragMode attribute setter.
+        * @param String/Number The Number value or the String for the DragMode to default all future drag instances to.
+        * @return Number The Mode to be set
+        */
+        _setDragMode: function(mode) {
+            if (mode === null) {
+                mode = Y.DD.DDM.get('dragMode');
+            }
+            switch (mode) {
+                case 1:
+                case 'intersect':
+                    return 1;
+                case 2:
+                case 'strict':
+                    return 2;
+                case 0:
+                case 'point':
+                    return 0;
+            }
+            return 0;       
+        },
+        /**
+        * @property CSS_PREFIX
+        * @description The PREFIX to attach to all DD CSS class names
+        * @type {String}
+        */
+        CSS_PREFIX: 'yui-dd',
+        _activateTargets: function() {},        
+        /**
+        * @private
+        * @property _drags
+        * @description Holder for all registered drag elements.
+        * @type {Array}
+        */
+        _drags: [],
+        /**
+        * @property activeDrag
+        * @description A reference to the currently active draggable object.
+        * @type {Drag}
+        */
+        activeDrag: false,
+        /**
+        * @private
+        * @method _regDrag
+        * @description Adds a reference to the drag object to the DDM._drags array, called in the constructor of Drag.
+        * @param {Drag} d The Drag object
+        */
+        _regDrag: function(d) {
+            this._drags[this._drags.length] = d;
+        },
+        /**
+        * @private
+        * @method _unregDrag
+        * @description Remove this drag object from the DDM._drags array.
+        * @param {Drag} d The drag object.
+        */
+        _unregDrag: function(d) {
+            var tmp = [];
+            Y.each(this._drags, function(n, i) {
+                if (n !== d) {
+                    tmp[tmp.length] = n;
+                }
+            });
+            this._drags = tmp;
+        },
+        /**
+        * @private
+        * @method _init
+        * @description DDM's init method
+        */
+        initializer: function() {
+            Y.Node.get('document').on('mousemove', this._move, this, true);
+            Y.Node.get('document').on('mouseup', this._end, this, true);
+        },
+        /**
+        * @private
+        * @method _start
+        * @description Internal method used by Drag to signal the start of a drag operation
+        * @param {Number} x The x position of the drag element
+        * @param {Number} y The y position of the drag element
+        * @param {Number} w The width of the drag element
+        * @param {Number} h The height of the drag element
+        */
+        _start: function(x, y, w, h) {
+            this._startDrag.apply(this, arguments);
+        },
+        /**
+        * @private
+        * @method _startDrag
+        * @description Factory method to be overwritten by other DDM's
+        * @param {Number} x The x position of the drag element
+        * @param {Number} y The y position of the drag element
+        * @param {Number} w The width of the drag element
+        * @param {Number} h The height of the drag element
+        */
+        _startDrag: function() {},
+        /**
+        * @private
+        * @method _endDrag
+        * @description Factory method to be overwritten by other DDM's
+        */
+        _endDrag: function() {},
+        _dropMove: function() {},
+        /**
+        * @private
+        * @method _end
+        * @description Internal method used by Drag to signal the end of a drag operation
+        */
+        _end: function() {
+            //@TODO - Here we can get a (click - drag - click - release) interaction instead of a (mousedown - drag - mouseup - release) interaction
+            //Add as a config option??
+            if (this.activeDrag) {
+                this._endDrag();
+                this.activeDrag.end.call(this.activeDrag);
+                this.activeDrag = null;
+            }
+        },
+        /**
+        * @method stopDrag
+        * @description Method will forcefully stop a drag operation. For example calling this from inside an ESC keypress handler will stop this drag.
+        * @return {Self}
+        * @chainable
+        */       
+        stopDrag: function() {
+            if (this.activeDrag) {
+                this._end();
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method _move
+        * @description Internal listener for the mousemove DOM event to pass to the Drag's move method.
+        * @param {Event} ev The Dom mousemove Event
+        */
+        _move: function(ev) {
+            if (this.activeDrag) {
+                this.activeDrag._move.apply(this.activeDrag, arguments);
+                this._dropMove();
+            }
+        },
+        /**
+        * @method setXY
+        * @description A simple method to set the top and left position from offsets instead of page coordinates
+        * @param {Object} node The node to set the position of 
+        * @param {Array} xy The Array of left/top position to be set.
+        */
+        setXY: function(node, xy) {
+            var t = parseInt(node.getStyle('top'), 10),
+            l = parseInt(node.getStyle('left'), 10),
+            pos = node.getStyle('position');
+
+            if (pos === 'static') {
+                node.setStyle('position', 'relative');
+            }
+
+            // in case of 'auto'
+            if (isNaN(t)) { t = 0; }
+            if (isNaN(l)) { l = 0; }
+            
+            node.setStyle('top', (xy[1] + t) + 'px');
+            node.setStyle('left', (xy[0] + l) + 'px');
+            
+        },
+        /**
+        * //TODO Private, rename??...
+        * @private
+        * @method cssSizestoObject
+        * @description Helper method to use to set the gutter from the attribute setter.
+        * @param {String} gutter CSS style string for gutter: '5 0' (sets top and bottom to 5px, left and right to 0px), '1 2 3 4' (top 1px, right 2px, bottom 3px, left 4px)
+        * @return {Object} The gutter Object Literal.
+        */
+        cssSizestoObject: function(gutter) {
+            var x = gutter.split(' ');
+                
+            switch (x.length) {
+                case 1: x[1] = x[2] = x[3] = x[0]; break;
+                case 2: x[2] = x[0]; x[3] = x[1]; break;
+                case 3: x[3] = x[1]; break;
+            }
+
+            return {
+                top   : parseInt(x[0],10),
+                right : parseInt(x[1],10),
+                bottom: parseInt(x[2],10),
+                left  : parseInt(x[3],10)
+            };
+        },
+        /**
+        * @method getDrag
+        * @description Get a valid Drag instance back from a Node or a selector string, false otherwise
+        * @param {String/Object} node The Node instance or Selector string to check for a valid Drag Object
+        * @return {Object}
+        */
+        getDrag: function(node) {
+            var drag = false,
+                n = Y.Node.get(node);
+            if (n instanceof Y.Node) {
+                Y.each(this._drags, function(v, k) {
+                    if (n.compareTo(v.get('node'))) {
+                        drag = v;
+                    }
+                });
+            }
+            return drag;
+        }
+    });
+
+    Y.namespace('DD');
+    Y.DD.DDM = new DDMBase();
+
+
+
+}, '3.0.0pr2' ,{requires:['node', 'base'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-ddm-debug.js'
--- loggerhead/static/javascript/yui/build/dd/dd-ddm-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-ddm-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,121 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-ddm', function(Y) {
+
+    /**
+     * Extends the dd-ddm-base Class to add support for the viewport shim to allow a draggable node to drag to be dragged over an iframe or any other node that traps mousemove events.
+     * It is also required to have Drop Targets enabled, as the viewport shim will contain the shims for the Drop Targets.
+     * @module dd
+     * @submodule dd-ddm
+     * @for DDM
+     */
+    Y.mix(Y.DD.DDM, {
+        /**
+        * @private
+        * @property _pg
+        * @description The shim placed over the screen to track the mousemove event.
+        * @type {Node}
+        */
+        _pg: null,
+        /**
+        * @private
+        * @property _debugShim
+        * @description Set this to true to set the shims opacity to .5 for debugging it, default: false.
+        * @type {Boolean}
+        */
+        _debugShim: false,
+        _activateTargets: function() {},
+        _deactivateTargets: function() {},
+        _startDrag: function() {
+            if (this.activeDrag.get('useShim')) {
+                this._pg_activate();
+                this._activateTargets();
+            }
+        },
+        _endDrag: function() {
+            this._pg_deactivate();
+            this._deactivateTargets();
+        },
+        /**
+        * @private
+        * @method _pg_deactivate
+        * @description Deactivates the shim
+        */
+        _pg_deactivate: function() {
+            this._pg.setStyle('display', 'none');
+        },
+        /**
+        * @private
+        * @method _pg_activate
+        * @description Activates the shim
+        */
+        _pg_activate: function() {
+            this._pg_size();
+            this._pg.setStyles({
+                top: 0,
+                left: 0,
+                display: 'block',
+                opacity: ((this._debugShim) ? '.5' : '0')
+            });
+        },
+        /**
+        * @private
+        * @method _pg_size
+        * @description Sizes the shim on: activatation, window:scroll, window:resize
+        */
+        _pg_size: function() {
+            if (this.activeDrag) {
+                var b = Y.Node.get('body'),
+                h = b.get('docHeight'),
+                w = b.get('docWidth');
+                this._pg.setStyles({
+                    height: h + 'px',
+                    width: w + 'px'
+                });
+            }
+        },
+        /**
+        * @private
+        * @method _createPG
+        * @description Creates the shim and adds it's listeners to it.
+        */
+        _createPG: function() {
+            //var pg = Y.Node.create(['div']),
+            var pg = Y.Node.create('<div></div>'),
+            bd = Y.Node.get('body');
+            pg.setStyles({
+                top: '0',
+                left: '0',
+                position: 'absolute',
+                zIndex: '9999',
+                overflow: 'hidden',
+                //opacity: '0',
+                backgroundColor: 'red',
+                display: 'none',
+                height: '5px',
+                width: '5px'
+            });
+            if (bd.get('firstChild')) {
+                bd.insertBefore(pg, bd.get('firstChild'));
+            } else {
+                bd.appendChild(pg);
+            }
+            this._pg = pg;
+            this._pg.on('mouseup', this._end, this, true);
+            this._pg.on('mousemove', this._move, this, true);
+            
+            
+            Y.on('resize', this._pg_size, window, this, true);
+            Y.on('scroll', this._pg_size, window, this, true);
+        }   
+    }, true);
+
+    Y.DD.DDM._createPG();    
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-base'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-ddm-drop-debug.js'
--- loggerhead/static/javascript/yui/build/dd/dd-ddm-drop-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-ddm-drop-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,404 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-ddm-drop', function(Y) {
+
+    /**
+     * Extends the dd-ddm Class to add support for the placement of Drop Target shims inside the viewport shim. It also handles all Drop Target related events and interactions.
+     * @module dd
+     * @submodule dd-ddm-drop
+     * @for DDM
+     */
+
+    //TODO CSS class name for the bestMatch..
+    Y.mix(Y.DD.DDM, {
+        /**
+        * @private
+        * @property _noShim
+        * @description This flag turns off the use of the mouseover/mouseout shim. It should not be used unless you know what you are doing.
+        * @type {Boolean}
+        */
+        _noShim: false,
+        /**
+        * @private
+        * @property _activeShims
+        * @description Placeholder for all active shims on the page
+        * @type {Array}
+        */
+        _activeShims: [],
+        /**
+        * @private
+        * @method _hasActiveShim
+        * @description This method checks the _activeShims Object to see if there is a shim active.
+        * @return {Boolean}
+        */
+        _hasActiveShim: function() {
+            if (this._noShim) {
+                return true;
+            }
+            return this._activeShims.length;
+        },
+        /**
+        * @private
+        * @method _addActiveShim 
+        * @description Adds a Drop Target to the list of active shims
+        * @param {Object} d The Drop instance to add to the list.
+        */
+        _addActiveShim: function(d) {
+            this._activeShims[this._activeShims.length] = d;
+        },
+        /**
+        * @private
+        * @method _removeActiveShim 
+        * @description Removes a Drop Target to the list of active shims
+        * @param {Object} d The Drop instance to remove from the list.
+        */
+        _removeActiveShim: function(d) {
+            var s = [];
+            Y.each(this._activeShims, function(v, k) {
+                if (v._yuid !== d._yuid) {
+                    s[s.length] = v;
+                }
+                
+            });
+            this._activeShims = s;
+        },
+        /**
+        * @method syncActiveShims
+        * @description This method will sync the position of the shims on the Drop Targets that are currently active.
+        * @param {Boolean} force Resize/sync all Targets.
+        * @return {Array} drops The list of Drop Targets that was just synced.
+        */
+        syncActiveShims: function(force) {
+            var drops = ((force) ? this.targets : this._lookup());
+            Y.each(drops, function(v, k) {
+                v.sizeShim.call(v);
+            }, this);
+
+            return drops;
+        },
+        /**
+        * @private
+        * @property mode
+        * @description The mode that the drag operations will run in 0 for Point, 1 for Intersect, 2 for Strict
+        * @type Number
+        */
+        mode: 0,
+        /**
+        * @private
+        * @property POINT
+        * @description In point mode, a Drop is targeted by the cursor being over the Target
+        * @type Number
+        */
+        POINT: 0,
+        /**
+        * @private
+        * @property INTERSECT
+        * @description In intersect mode, a Drop is targeted by "part" of the drag node being over the Target
+        * @type Number
+        */
+        INTERSECT: 1,
+        /**
+        * @private
+        * @property STRICT
+        * @description In strict mode, a Drop is targeted by the "entire" drag node being over the Target
+        * @type Number
+        */
+        STRICT: 2,
+        /**
+        * @property useHash
+        * @description Should we only check targets that are in the viewport on drags (for performance), default: true
+        * @type {Boolean}
+        */
+        useHash: true,
+        /**
+        * @property activeDrop
+        * @description A reference to the active Drop Target
+        * @type {Object}
+        */
+        activeDrop: null,
+        /**
+        * @property validDrops
+        * @description An array of the valid Drop Targets for this interaction.
+        * @type {Array}
+        */
+        //TODO Change array/object literals to be in sync..
+        validDrops: [],
+        /**
+        * @property otherDrops
+        * @description An object literal of Other Drop Targets that we encountered during this interaction (in the case of overlapping Drop Targets)
+        * @type {Object}
+        */
+        otherDrops: {},
+        /**
+        * @property targets
+        * @description All of the Targets
+        * @type {Array}
+        */
+        targets: [],
+        /**
+        * @private 
+        * @method _addValid
+        * @description Add a Drop Target to the list of Valid Targets. This list get's regenerated on each new drag operation.
+        * @param {Object} drop
+        * @return {Self}
+        * @chainable
+        */
+        _addValid: function(drop) {
+            this.validDrops[this.validDrops.length] = drop;
+            return this;
+        },
+        /**
+        * @private 
+        * @method _removeValid
+        * @description Removes a Drop Target from the list of Valid Targets. This list get's regenerated on each new drag operation.
+        * @param {Object} drop
+        * @return {Self}
+        * @chainable
+        */
+        _removeValid: function(drop) {
+            var drops = [];
+            Y.each(this.validDrops, function(v, k) {
+                if (v !== drop) {
+                    drops[drops.length] = v
+                }
+            });
+
+            this.validDrops = drops;
+            return this;
+        },
+        /**
+        * @method isOverTarget
+        * @description Check to see if the Drag element is over the target, method varies on current mode
+        * @param {Object} drop The drop to check against
+        * @return {Boolean}
+        */
+        isOverTarget: function(drop) {
+            //if (Y.Lang.isObject(this.activeDrag) && drop) { //TODO, check this check..
+            if (this.activeDrag && drop) {
+                var xy = this.activeDrag.mouseXY;
+                if (xy) {
+                    if (this.activeDrag.get('dragMode') == this.STRICT) {
+                        return this.activeDrag.get('dragNode').inRegion(drop.region, true, this.activeDrag.region);
+                    } else {
+                        if (drop && drop.shim) {
+                            return drop.shim.intersect({
+                                top: xy[1],
+                                bottom: xy[1],
+                                left: xy[0], 
+                                right: xy[0]
+                            }, drop.region).inRegion;
+                        } else {
+                            return false;
+                        }
+                    }
+                } else {
+                    return false;
+                }
+            } else {
+                return false;
+            }
+        },
+        /**
+        * @method clearCache
+        * @description Clears the cache data used for this interaction.
+        */
+        clearCache: function() {
+            this.validDrops = [];
+            this.otherDrops = {};
+            this._activeShims = [];
+        },
+        /**
+        * @private
+        * @method _activateTargets
+        * @description Clear the cache and activate the shims of all the targets
+        */
+        _activateTargets: function() {
+            this.clearCache();
+            Y.each(this.targets, function(v, k) {
+                v._activateShim.apply(v, []);
+            }, this);
+            this._handleTargetOver();
+            
+        },
+        /**
+        * @method getBestMatch
+        * @description This method will gather the area for all potential targets and see which has the hightest covered area and return it.
+        * @param {Array} drops An Array of drops to scan for the best match.
+        * @param {Boolean} all If present, it returns an Array. First item is best match, second is an Array of the other items in the original Array.
+        * @return {Object or Array} 
+        */
+        getBestMatch: function(drops, all) {
+            var biggest = null, area = 0;
+
+            Y.each(drops, function(v, k) {
+                var inter = this.activeDrag.get('dragNode').intersect(v.get('node'));
+                v.region.area = inter.area;
+
+                if (inter.inRegion) {
+                    if (inter.area > area) {
+                        area = inter.area;
+                        biggest = v;
+                    }
+                }
+            }, this);
+            if (all) {
+                var out = [];
+                //TODO Sort the others in numeric order by area covered..
+                Y.each(drops, function(v, k) {
+                    if (v !== biggest) {
+                        out[out.length] = v;
+                    }
+                }, this);
+                return [biggest, out];
+            } else {
+                return biggest;
+            }
+        },
+        /**
+        * @private
+        * @method _deactivateTargets
+        * @description This method fires the drop:hit, drag:drophit, drag:dropmiss methods and deactivates the shims..
+        */
+        _deactivateTargets: function() {
+            var other = [],
+                activeDrag = this.activeDrag,
+                activeDrop = this.activeDrop;
+            
+            //TODO why is this check so hard??
+            if (activeDrag && activeDrop && this.otherDrops[activeDrop]) {
+                if (!activeDrag.get('dragMode')) {
+                    //TODO otherDrops -- private..
+                    other = this.otherDrops;
+                    delete other[activeDrop];
+                } else {
+                    var tmp = this.getBestMatch(this.otherDrops, true);
+                    activeDrop = tmp[0];
+                    other = tmp[1];
+                }
+                activeDrag.get('node').removeClass(this.CSS_PREFIX + '-drag-over')
+                if (activeDrop) {
+                    activeDrop.fire('drop:hit', { drag: activeDrag, drop: activeDrop, others: other });
+                    activeDrag.fire('drag:drophit', { drag: activeDrag,  drop: activeDrop, others: other });
+                }
+            } else if (activeDrag) {
+                activeDrag.get('node').removeClass(this.CSS_PREFIX + '-drag-over')
+                activeDrag.fire('drag:dropmiss', { pageX: activeDrag.lastXY[0], pageY: activeDrag.lastXY[1] });
+            } else {
+                Y.log('No Active Drag', 'warn', 'dd-ddm');
+            }
+            
+            this.activeDrop = null;
+
+            Y.each(this.targets, function(v, k) {
+                v._deactivateShim.apply(v, []);
+            }, this);
+        },
+        /**
+        * @private
+        * @method _dropMove
+        * @description This method is called when the move method is called on the Drag Object.
+        */
+        _dropMove: function() {
+            if (this._hasActiveShim()) {
+                //Y.log('We have an active shim, check targets', 'info', 'dd-ddm');
+                this._handleTargetOver();
+            } else {
+                Y.each(this.otherDrops, function(v, k) {
+                    v._handleOut.apply(v, []);
+                });
+            }
+        },
+        /**
+        * @private
+        * @method _lookup
+        * @description Filters the list of Drops down to those in the viewport.
+        * @return {Array} The valid Drop Targets that are in the viewport.
+        */
+        _lookup: function() {
+            if (!this.useHash) {
+                return this.validDrops;
+            }
+            var drops = [];
+            //Only scan drop shims that are in the Viewport
+            Y.each(this.validDrops, function(v, k) {
+                if (v.shim && v.shim.inViewportRegion(false, v.region)) {
+                    drops[drops.length] = v;
+                }
+            });
+            return drops;
+                
+        },
+        /**
+        * @private
+        * @method _handleTargetOver
+        * @description This method execs _handleTargetOver on all valid Drop Targets
+        * @param {Boolean} force Force it to run the first time.
+        */
+        _handleTargetOver: function() {
+            var drops = this._lookup();
+            Y.each(drops, function(v, k) {
+                v._handleTargetOver.call(v);
+            }, this);
+        },
+        /**
+        * @private
+        * @method _regTarget
+        * @description Add the passed in Target to the targets collection
+        * @param {Object} t The Target to add to the targets collection
+        */
+        _regTarget: function(t) {
+            this.targets[this.targets.length] = t;
+        },
+        /**
+        * @private
+        * @method _unregTarget
+        * @description Remove the passed in Target from the targets collection
+        * @param {Object} drop The Target to remove from the targets collection
+        */
+        _unregTarget: function(drop) {
+            var targets = [];
+            Y.each(this.targets, function(v, k) {
+                if (v != drop) {
+                    targets[targets.length] = v;
+                }
+            }, this);
+            this.targets = targets;
+
+            var vdrops = [];
+            Y.each(this.validDrops, function(v, k) {
+                if (v !== drop) {
+                    vdrops[vdrops.length] = v
+                }
+            });
+
+            this.validDrops = vdrops;
+        },
+        /**
+        * @method getDrop
+        * @description Get a valid Drop instance back from a Node or a selector string, false otherwise
+        * @param {String/Object} node The Node instance or Selector string to check for a valid Drop Object
+        * @return {Object}
+        */
+        getDrop: function(node) {
+            var drop = false,
+                n = Y.Node.get(node);
+            if (n instanceof Y.Node) {
+                Y.each(this.targets, function(v, k) {
+                    if (n.compareTo(v.get('node'))) {
+                        drop = v;
+                    }
+                });
+            }
+            return drop;
+        }
+    }, true);
+    
+
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-ddm-drop-min.js'
--- loggerhead/static/javascript/yui/build/dd/dd-ddm-drop-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-ddm-drop-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dd-ddm-drop",function(A){A.mix(A.DD.DDM,{_noShim:false,_activeShims:[],_hasActiveShim:function(){if(this._noShim){return true;}return this._activeShims.length;},_addActiveShim:function(B){this._activeShims[this._activeShims.length]=B;},_removeActiveShim:function(C){var B=[];A.each(this._activeShims,function(E,D){if(E._yuid!==C._yuid){B[B.length]=E;}});this._activeShims=B;},syncActiveShims:function(B){var C=((B)?this.targets:this._lookup());A.each(C,function(E,D){E.sizeShim.call(E);},this);return C;},mode:0,POINT:0,INTERSECT:1,STRICT:2,useHash:true,activeDrop:null,validDrops:[],otherDrops:{},targets:[],_addValid:function(B){this.validDrops[this.validDrops.length]=B;return this;},_removeValid:function(B){var C=[];A.each(this.validDrops,function(E,D){if(E!==B){C[C.length]=E;}});this.validDrops=C;return this;},isOverTarget:function(B){if(this.activeDrag&&B){var C=this.activeDrag.mouseXY;if(C){if(this.activeDrag.get("dragMode")==this.STRICT){return this.activeDrag.get("dragNode").inRegion(B.region,true,this.activeDrag.region);}else{if(B&&B.shim){return B.shim.intersect({top:C[1],bottom:C[1],left:C[0],right:C[0]},B.region).inRegion;}else{return false;}}}else{return false;}}else{return false;}},clearCache:function(){this.validDrops=[];this.otherDrops={};this._activeShims=[];},_activateTargets:function(){this.clearCache();A.each(this.targets,function(C,B){C._activateShim.apply(C,[]);},this);this._handleTargetOver();},getBestMatch:function(F,D){var C=null,E=0;A.each(F,function(I,H){var G=this.activeDrag.get("dragNode").intersect(I.get("node"));I.region.area=G.area;if(G.inRegion){if(G.area>E){E=G.area;C=I;}}},this);if(D){var B=[];A.each(F,function(H,G){if(H!==C){B[B.length]=H;}},this);return[C,B];}else{return C;}},_deactivateTargets:function(){var B=[],E=this.activeDrag,D=this.activeDrop;if(E&&D&&this.otherDrops[D]){if(!E.get("dragMode")){B=this.otherDrops;delete B[D];}else{var C=this.getBestMatch(this.otherDrops,true);D=C[0];B=C[1];}E.get("node").removeClass(this.CSS_PREFIX+"-drag-over");if(D){D.fire("drop:hit",{drag:E,drop:D,others:B});E.fire("drag:drophit",{drag:E,drop:D,others:B});}}else{if(E){E.get("node").removeClass(this.CSS_PREFIX+"-drag-over");E.fire("drag:dropmiss",{pageX:E.lastXY[0],pageY:E.lastXY[1]});}else{}}this.activeDrop=null;A.each(this.targets,function(G,F){G._deactivateShim.apply(G,[]);},this);},_dropMove:function(){if(this._hasActiveShim()){this._handleTargetOver();}else{A.each(this.otherDrops,function(C,B){C._handleOut.apply(C,[]);});}},_lookup:function(){if(!this.useHash){return this.validDrops;}var B=[];A.each(this.validDrops,function(D,C){if(D.shim&&D.shim.inViewportRegion(false,D.region)){B[B.length]=D;}});return B;},_handleTargetOver:function(){var B=this._lookup();A.each(B,function(D,C){D._handleTargetOver.call(D);},this);},_regTarget:function(B){this.targets[this.targets.length]=B;},_unregTarget:function(C){var B=[];A.each(this.targets,function(F,E){if(F!=C){B[B.length]=F;}},this);this.targets=B;var D=[];A.each(this.validDrops,function(F,E){if(F!==C){D[D.length]=F;}});this.validDrops=D;},getDrop:function(C){var B=false,D=A.Node.get(C);if(D instanceof A.Node){A.each(this.targets,function(F,E){if(D.compareTo(F.get("node"))){B=F;}});}return B;}},true);},"3.0.0pr2",{requires:["dd-ddm"],skinnable:false});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-ddm-drop.js'
--- loggerhead/static/javascript/yui/build/dd/dd-ddm-drop.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-ddm-drop.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,402 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-ddm-drop', function(Y) {
+
+    /**
+     * Extends the dd-ddm Class to add support for the placement of Drop Target shims inside the viewport shim. It also handles all Drop Target related events and interactions.
+     * @module dd
+     * @submodule dd-ddm-drop
+     * @for DDM
+     */
+
+    //TODO CSS class name for the bestMatch..
+    Y.mix(Y.DD.DDM, {
+        /**
+        * @private
+        * @property _noShim
+        * @description This flag turns off the use of the mouseover/mouseout shim. It should not be used unless you know what you are doing.
+        * @type {Boolean}
+        */
+        _noShim: false,
+        /**
+        * @private
+        * @property _activeShims
+        * @description Placeholder for all active shims on the page
+        * @type {Array}
+        */
+        _activeShims: [],
+        /**
+        * @private
+        * @method _hasActiveShim
+        * @description This method checks the _activeShims Object to see if there is a shim active.
+        * @return {Boolean}
+        */
+        _hasActiveShim: function() {
+            if (this._noShim) {
+                return true;
+            }
+            return this._activeShims.length;
+        },
+        /**
+        * @private
+        * @method _addActiveShim 
+        * @description Adds a Drop Target to the list of active shims
+        * @param {Object} d The Drop instance to add to the list.
+        */
+        _addActiveShim: function(d) {
+            this._activeShims[this._activeShims.length] = d;
+        },
+        /**
+        * @private
+        * @method _removeActiveShim 
+        * @description Removes a Drop Target to the list of active shims
+        * @param {Object} d The Drop instance to remove from the list.
+        */
+        _removeActiveShim: function(d) {
+            var s = [];
+            Y.each(this._activeShims, function(v, k) {
+                if (v._yuid !== d._yuid) {
+                    s[s.length] = v;
+                }
+                
+            });
+            this._activeShims = s;
+        },
+        /**
+        * @method syncActiveShims
+        * @description This method will sync the position of the shims on the Drop Targets that are currently active.
+        * @param {Boolean} force Resize/sync all Targets.
+        * @return {Array} drops The list of Drop Targets that was just synced.
+        */
+        syncActiveShims: function(force) {
+            var drops = ((force) ? this.targets : this._lookup());
+            Y.each(drops, function(v, k) {
+                v.sizeShim.call(v);
+            }, this);
+
+            return drops;
+        },
+        /**
+        * @private
+        * @property mode
+        * @description The mode that the drag operations will run in 0 for Point, 1 for Intersect, 2 for Strict
+        * @type Number
+        */
+        mode: 0,
+        /**
+        * @private
+        * @property POINT
+        * @description In point mode, a Drop is targeted by the cursor being over the Target
+        * @type Number
+        */
+        POINT: 0,
+        /**
+        * @private
+        * @property INTERSECT
+        * @description In intersect mode, a Drop is targeted by "part" of the drag node being over the Target
+        * @type Number
+        */
+        INTERSECT: 1,
+        /**
+        * @private
+        * @property STRICT
+        * @description In strict mode, a Drop is targeted by the "entire" drag node being over the Target
+        * @type Number
+        */
+        STRICT: 2,
+        /**
+        * @property useHash
+        * @description Should we only check targets that are in the viewport on drags (for performance), default: true
+        * @type {Boolean}
+        */
+        useHash: true,
+        /**
+        * @property activeDrop
+        * @description A reference to the active Drop Target
+        * @type {Object}
+        */
+        activeDrop: null,
+        /**
+        * @property validDrops
+        * @description An array of the valid Drop Targets for this interaction.
+        * @type {Array}
+        */
+        //TODO Change array/object literals to be in sync..
+        validDrops: [],
+        /**
+        * @property otherDrops
+        * @description An object literal of Other Drop Targets that we encountered during this interaction (in the case of overlapping Drop Targets)
+        * @type {Object}
+        */
+        otherDrops: {},
+        /**
+        * @property targets
+        * @description All of the Targets
+        * @type {Array}
+        */
+        targets: [],
+        /**
+        * @private 
+        * @method _addValid
+        * @description Add a Drop Target to the list of Valid Targets. This list get's regenerated on each new drag operation.
+        * @param {Object} drop
+        * @return {Self}
+        * @chainable
+        */
+        _addValid: function(drop) {
+            this.validDrops[this.validDrops.length] = drop;
+            return this;
+        },
+        /**
+        * @private 
+        * @method _removeValid
+        * @description Removes a Drop Target from the list of Valid Targets. This list get's regenerated on each new drag operation.
+        * @param {Object} drop
+        * @return {Self}
+        * @chainable
+        */
+        _removeValid: function(drop) {
+            var drops = [];
+            Y.each(this.validDrops, function(v, k) {
+                if (v !== drop) {
+                    drops[drops.length] = v
+                }
+            });
+
+            this.validDrops = drops;
+            return this;
+        },
+        /**
+        * @method isOverTarget
+        * @description Check to see if the Drag element is over the target, method varies on current mode
+        * @param {Object} drop The drop to check against
+        * @return {Boolean}
+        */
+        isOverTarget: function(drop) {
+            //if (Y.Lang.isObject(this.activeDrag) && drop) { //TODO, check this check..
+            if (this.activeDrag && drop) {
+                var xy = this.activeDrag.mouseXY;
+                if (xy) {
+                    if (this.activeDrag.get('dragMode') == this.STRICT) {
+                        return this.activeDrag.get('dragNode').inRegion(drop.region, true, this.activeDrag.region);
+                    } else {
+                        if (drop && drop.shim) {
+                            return drop.shim.intersect({
+                                top: xy[1],
+                                bottom: xy[1],
+                                left: xy[0], 
+                                right: xy[0]
+                            }, drop.region).inRegion;
+                        } else {
+                            return false;
+                        }
+                    }
+                } else {
+                    return false;
+                }
+            } else {
+                return false;
+            }
+        },
+        /**
+        * @method clearCache
+        * @description Clears the cache data used for this interaction.
+        */
+        clearCache: function() {
+            this.validDrops = [];
+            this.otherDrops = {};
+            this._activeShims = [];
+        },
+        /**
+        * @private
+        * @method _activateTargets
+        * @description Clear the cache and activate the shims of all the targets
+        */
+        _activateTargets: function() {
+            this.clearCache();
+            Y.each(this.targets, function(v, k) {
+                v._activateShim.apply(v, []);
+            }, this);
+            this._handleTargetOver();
+            
+        },
+        /**
+        * @method getBestMatch
+        * @description This method will gather the area for all potential targets and see which has the hightest covered area and return it.
+        * @param {Array} drops An Array of drops to scan for the best match.
+        * @param {Boolean} all If present, it returns an Array. First item is best match, second is an Array of the other items in the original Array.
+        * @return {Object or Array} 
+        */
+        getBestMatch: function(drops, all) {
+            var biggest = null, area = 0;
+
+            Y.each(drops, function(v, k) {
+                var inter = this.activeDrag.get('dragNode').intersect(v.get('node'));
+                v.region.area = inter.area;
+
+                if (inter.inRegion) {
+                    if (inter.area > area) {
+                        area = inter.area;
+                        biggest = v;
+                    }
+                }
+            }, this);
+            if (all) {
+                var out = [];
+                //TODO Sort the others in numeric order by area covered..
+                Y.each(drops, function(v, k) {
+                    if (v !== biggest) {
+                        out[out.length] = v;
+                    }
+                }, this);
+                return [biggest, out];
+            } else {
+                return biggest;
+            }
+        },
+        /**
+        * @private
+        * @method _deactivateTargets
+        * @description This method fires the drop:hit, drag:drophit, drag:dropmiss methods and deactivates the shims..
+        */
+        _deactivateTargets: function() {
+            var other = [],
+                activeDrag = this.activeDrag,
+                activeDrop = this.activeDrop;
+            
+            //TODO why is this check so hard??
+            if (activeDrag && activeDrop && this.otherDrops[activeDrop]) {
+                if (!activeDrag.get('dragMode')) {
+                    //TODO otherDrops -- private..
+                    other = this.otherDrops;
+                    delete other[activeDrop];
+                } else {
+                    var tmp = this.getBestMatch(this.otherDrops, true);
+                    activeDrop = tmp[0];
+                    other = tmp[1];
+                }
+                activeDrag.get('node').removeClass(this.CSS_PREFIX + '-drag-over')
+                if (activeDrop) {
+                    activeDrop.fire('drop:hit', { drag: activeDrag, drop: activeDrop, others: other });
+                    activeDrag.fire('drag:drophit', { drag: activeDrag,  drop: activeDrop, others: other });
+                }
+            } else if (activeDrag) {
+                activeDrag.get('node').removeClass(this.CSS_PREFIX + '-drag-over')
+                activeDrag.fire('drag:dropmiss', { pageX: activeDrag.lastXY[0], pageY: activeDrag.lastXY[1] });
+            } else {
+            }
+            
+            this.activeDrop = null;
+
+            Y.each(this.targets, function(v, k) {
+                v._deactivateShim.apply(v, []);
+            }, this);
+        },
+        /**
+        * @private
+        * @method _dropMove
+        * @description This method is called when the move method is called on the Drag Object.
+        */
+        _dropMove: function() {
+            if (this._hasActiveShim()) {
+                this._handleTargetOver();
+            } else {
+                Y.each(this.otherDrops, function(v, k) {
+                    v._handleOut.apply(v, []);
+                });
+            }
+        },
+        /**
+        * @private
+        * @method _lookup
+        * @description Filters the list of Drops down to those in the viewport.
+        * @return {Array} The valid Drop Targets that are in the viewport.
+        */
+        _lookup: function() {
+            if (!this.useHash) {
+                return this.validDrops;
+            }
+            var drops = [];
+            //Only scan drop shims that are in the Viewport
+            Y.each(this.validDrops, function(v, k) {
+                if (v.shim && v.shim.inViewportRegion(false, v.region)) {
+                    drops[drops.length] = v;
+                }
+            });
+            return drops;
+                
+        },
+        /**
+        * @private
+        * @method _handleTargetOver
+        * @description This method execs _handleTargetOver on all valid Drop Targets
+        * @param {Boolean} force Force it to run the first time.
+        */
+        _handleTargetOver: function() {
+            var drops = this._lookup();
+            Y.each(drops, function(v, k) {
+                v._handleTargetOver.call(v);
+            }, this);
+        },
+        /**
+        * @private
+        * @method _regTarget
+        * @description Add the passed in Target to the targets collection
+        * @param {Object} t The Target to add to the targets collection
+        */
+        _regTarget: function(t) {
+            this.targets[this.targets.length] = t;
+        },
+        /**
+        * @private
+        * @method _unregTarget
+        * @description Remove the passed in Target from the targets collection
+        * @param {Object} drop The Target to remove from the targets collection
+        */
+        _unregTarget: function(drop) {
+            var targets = [];
+            Y.each(this.targets, function(v, k) {
+                if (v != drop) {
+                    targets[targets.length] = v;
+                }
+            }, this);
+            this.targets = targets;
+
+            var vdrops = [];
+            Y.each(this.validDrops, function(v, k) {
+                if (v !== drop) {
+                    vdrops[vdrops.length] = v
+                }
+            });
+
+            this.validDrops = vdrops;
+        },
+        /**
+        * @method getDrop
+        * @description Get a valid Drop instance back from a Node or a selector string, false otherwise
+        * @param {String/Object} node The Node instance or Selector string to check for a valid Drop Object
+        * @return {Object}
+        */
+        getDrop: function(node) {
+            var drop = false,
+                n = Y.Node.get(node);
+            if (n instanceof Y.Node) {
+                Y.each(this.targets, function(v, k) {
+                    if (n.compareTo(v.get('node'))) {
+                        drop = v;
+                    }
+                });
+            }
+            return drop;
+        }
+    }, true);
+    
+
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-ddm-min.js'
--- loggerhead/static/javascript/yui/build/dd/dd-ddm-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-ddm-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dd-ddm",function(A){A.mix(A.DD.DDM,{_pg:null,_debugShim:false,_activateTargets:function(){},_deactivateTargets:function(){},_startDrag:function(){if(this.activeDrag.get("useShim")){this._pg_activate();this._activateTargets();}},_endDrag:function(){this._pg_deactivate();this._deactivateTargets();},_pg_deactivate:function(){this._pg.setStyle("display","none");},_pg_activate:function(){this._pg_size();this._pg.setStyles({top:0,left:0,display:"block",opacity:((this._debugShim)?".5":"0")});},_pg_size:function(){if(this.activeDrag){var B=A.Node.get("body"),D=B.get("docHeight"),C=B.get("docWidth");this._pg.setStyles({height:D+"px",width:C+"px"});}},_createPG:function(){var C=A.Node.create("<div></div>"),B=A.Node.get("body");C.setStyles({top:"0",left:"0",position:"absolute",zIndex:"9999",overflow:"hidden",backgroundColor:"red",display:"none",height:"5px",width:"5px"});if(B.get("firstChild")){B.insertBefore(C,B.get("firstChild"));}else{B.appendChild(C);}this._pg=C;this._pg.on("mouseup",this._end,this,true);this._pg.on("mousemove",this._move,this,true);A.on("resize",this._pg_size,window,this,true);A.on("scroll",this._pg_size,window,this,true);}},true);A.DD.DDM._createPG();},"3.0.0pr2",{requires:["dd-ddm-base"],skinnable:false});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-ddm.js'
--- loggerhead/static/javascript/yui/build/dd/dd-ddm.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-ddm.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,121 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-ddm', function(Y) {
+
+    /**
+     * Extends the dd-ddm-base Class to add support for the viewport shim to allow a draggable node to drag to be dragged over an iframe or any other node that traps mousemove events.
+     * It is also required to have Drop Targets enabled, as the viewport shim will contain the shims for the Drop Targets.
+     * @module dd
+     * @submodule dd-ddm
+     * @for DDM
+     */
+    Y.mix(Y.DD.DDM, {
+        /**
+        * @private
+        * @property _pg
+        * @description The shim placed over the screen to track the mousemove event.
+        * @type {Node}
+        */
+        _pg: null,
+        /**
+        * @private
+        * @property _debugShim
+        * @description Set this to true to set the shims opacity to .5 for debugging it, default: false.
+        * @type {Boolean}
+        */
+        _debugShim: false,
+        _activateTargets: function() {},
+        _deactivateTargets: function() {},
+        _startDrag: function() {
+            if (this.activeDrag.get('useShim')) {
+                this._pg_activate();
+                this._activateTargets();
+            }
+        },
+        _endDrag: function() {
+            this._pg_deactivate();
+            this._deactivateTargets();
+        },
+        /**
+        * @private
+        * @method _pg_deactivate
+        * @description Deactivates the shim
+        */
+        _pg_deactivate: function() {
+            this._pg.setStyle('display', 'none');
+        },
+        /**
+        * @private
+        * @method _pg_activate
+        * @description Activates the shim
+        */
+        _pg_activate: function() {
+            this._pg_size();
+            this._pg.setStyles({
+                top: 0,
+                left: 0,
+                display: 'block',
+                opacity: ((this._debugShim) ? '.5' : '0')
+            });
+        },
+        /**
+        * @private
+        * @method _pg_size
+        * @description Sizes the shim on: activatation, window:scroll, window:resize
+        */
+        _pg_size: function() {
+            if (this.activeDrag) {
+                var b = Y.Node.get('body'),
+                h = b.get('docHeight'),
+                w = b.get('docWidth');
+                this._pg.setStyles({
+                    height: h + 'px',
+                    width: w + 'px'
+                });
+            }
+        },
+        /**
+        * @private
+        * @method _createPG
+        * @description Creates the shim and adds it's listeners to it.
+        */
+        _createPG: function() {
+            //var pg = Y.Node.create(['div']),
+            var pg = Y.Node.create('<div></div>'),
+            bd = Y.Node.get('body');
+            pg.setStyles({
+                top: '0',
+                left: '0',
+                position: 'absolute',
+                zIndex: '9999',
+                overflow: 'hidden',
+                //opacity: '0',
+                backgroundColor: 'red',
+                display: 'none',
+                height: '5px',
+                width: '5px'
+            });
+            if (bd.get('firstChild')) {
+                bd.insertBefore(pg, bd.get('firstChild'));
+            } else {
+                bd.appendChild(pg);
+            }
+            this._pg = pg;
+            this._pg.on('mouseup', this._end, this, true);
+            this._pg.on('mousemove', this._move, this, true);
+            
+            
+            Y.on('resize', this._pg_size, window, this, true);
+            Y.on('scroll', this._pg_size, window, this, true);
+        }   
+    }, true);
+
+    Y.DD.DDM._createPG();    
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-base'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-debug.js'
--- loggerhead/static/javascript/yui/build/dd/dd-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,2881 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-ddm-base', function(Y) {
+
+    /**
+     * Provides the base Drag Drop Manger required for making a Node draggable.
+     * @module dd
+     * @submodule dd-ddm-base
+     */     
+     /**
+     * Provides the base Drag Drop Manger required for making a Node draggable.
+     * @class DDM
+     * @extends Base
+     * @constructor
+     */
+    
+    var DDMBase = function() {
+        //debugger;
+        DDMBase.superclass.constructor.apply(this, arguments);
+    };
+
+    DDMBase.NAME = 'dragDropMgr';
+
+    DDMBase.ATTRS = {
+        /**
+        * @attribute clickPixelThresh
+        * @description The number of pixels to move to start a drag operation, default is 3.
+        * @type Number
+        */
+        clickPixelThresh: {
+            value: 3
+        },
+        /**
+        * @attribute clickTimeThresh
+        * @description The number of milliseconds a mousedown has to pass to start a drag operation, default is 1000.
+        * @type Number
+        */        
+        clickTimeThresh: {
+            value: 1000
+        },
+        /**
+        * @attribute dragMode
+        * @description This attribute only works if the dd-drop module is active. It will set the dragMode (point, intersect, strict) of all future Drag instances. 
+        * @type String
+        */        
+        dragMode: {
+            value: 'point',
+            set: function(mode) {
+                this._setDragMode(mode);
+            }           
+        }
+
+    };
+
+    Y.extend(DDMBase, Y.Base, {
+        /**
+        * @private
+        * @method _setDragMode
+        * @description Handler for dragMode attribute setter.
+        * @param String/Number The Number value or the String for the DragMode to default all future drag instances to.
+        * @return Number The Mode to be set
+        */
+        _setDragMode: function(mode) {
+            if (mode === null) {
+                mode = Y.DD.DDM.get('dragMode');
+            }
+            switch (mode) {
+                case 1:
+                case 'intersect':
+                    return 1;
+                case 2:
+                case 'strict':
+                    return 2;
+                case 0:
+                case 'point':
+                    return 0;
+            }
+            return 0;       
+        },
+        /**
+        * @property CSS_PREFIX
+        * @description The PREFIX to attach to all DD CSS class names
+        * @type {String}
+        */
+        CSS_PREFIX: 'yui-dd',
+        _activateTargets: function() {},        
+        /**
+        * @private
+        * @property _drags
+        * @description Holder for all registered drag elements.
+        * @type {Array}
+        */
+        _drags: [],
+        /**
+        * @property activeDrag
+        * @description A reference to the currently active draggable object.
+        * @type {Drag}
+        */
+        activeDrag: false,
+        /**
+        * @private
+        * @method _regDrag
+        * @description Adds a reference to the drag object to the DDM._drags array, called in the constructor of Drag.
+        * @param {Drag} d The Drag object
+        */
+        _regDrag: function(d) {
+            this._drags[this._drags.length] = d;
+        },
+        /**
+        * @private
+        * @method _unregDrag
+        * @description Remove this drag object from the DDM._drags array.
+        * @param {Drag} d The drag object.
+        */
+        _unregDrag: function(d) {
+            var tmp = [];
+            Y.each(this._drags, function(n, i) {
+                if (n !== d) {
+                    tmp[tmp.length] = n;
+                }
+            });
+            this._drags = tmp;
+        },
+        /**
+        * @private
+        * @method _init
+        * @description DDM's init method
+        */
+        initializer: function() {
+            Y.Node.get('document').on('mousemove', this._move, this, true);
+            Y.Node.get('document').on('mouseup', this._end, this, true);
+        },
+        /**
+        * @private
+        * @method _start
+        * @description Internal method used by Drag to signal the start of a drag operation
+        * @param {Number} x The x position of the drag element
+        * @param {Number} y The y position of the drag element
+        * @param {Number} w The width of the drag element
+        * @param {Number} h The height of the drag element
+        */
+        _start: function(x, y, w, h) {
+            this._startDrag.apply(this, arguments);
+        },
+        /**
+        * @private
+        * @method _startDrag
+        * @description Factory method to be overwritten by other DDM's
+        * @param {Number} x The x position of the drag element
+        * @param {Number} y The y position of the drag element
+        * @param {Number} w The width of the drag element
+        * @param {Number} h The height of the drag element
+        */
+        _startDrag: function() {},
+        /**
+        * @private
+        * @method _endDrag
+        * @description Factory method to be overwritten by other DDM's
+        */
+        _endDrag: function() {},
+        _dropMove: function() {},
+        /**
+        * @private
+        * @method _end
+        * @description Internal method used by Drag to signal the end of a drag operation
+        */
+        _end: function() {
+            //@TODO - Here we can get a (click - drag - click - release) interaction instead of a (mousedown - drag - mouseup - release) interaction
+            //Add as a config option??
+            if (this.activeDrag) {
+                this._endDrag();
+                this.activeDrag.end.call(this.activeDrag);
+                this.activeDrag = null;
+            }
+        },
+        /**
+        * @method stopDrag
+        * @description Method will forcefully stop a drag operation. For example calling this from inside an ESC keypress handler will stop this drag.
+        * @return {Self}
+        * @chainable
+        */       
+        stopDrag: function() {
+            if (this.activeDrag) {
+                this._end();
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method _move
+        * @description Internal listener for the mousemove DOM event to pass to the Drag's move method.
+        * @param {Event} ev The Dom mousemove Event
+        */
+        _move: function(ev) {
+            if (this.activeDrag) {
+                this.activeDrag._move.apply(this.activeDrag, arguments);
+                this._dropMove();
+            }
+        },
+        /**
+        * @method setXY
+        * @description A simple method to set the top and left position from offsets instead of page coordinates
+        * @param {Object} node The node to set the position of 
+        * @param {Array} xy The Array of left/top position to be set.
+        */
+        setXY: function(node, xy) {
+            var t = parseInt(node.getStyle('top'), 10),
+            l = parseInt(node.getStyle('left'), 10),
+            pos = node.getStyle('position');
+
+            if (pos === 'static') {
+                node.setStyle('position', 'relative');
+            }
+
+            // in case of 'auto'
+            if (isNaN(t)) { t = 0; }
+            if (isNaN(l)) { l = 0; }
+            
+            node.setStyle('top', (xy[1] + t) + 'px');
+            node.setStyle('left', (xy[0] + l) + 'px');
+            
+        },
+        /**
+        * //TODO Private, rename??...
+        * @private
+        * @method cssSizestoObject
+        * @description Helper method to use to set the gutter from the attribute setter.
+        * @param {String} gutter CSS style string for gutter: '5 0' (sets top and bottom to 5px, left and right to 0px), '1 2 3 4' (top 1px, right 2px, bottom 3px, left 4px)
+        * @return {Object} The gutter Object Literal.
+        */
+        cssSizestoObject: function(gutter) {
+            var x = gutter.split(' ');
+                
+            switch (x.length) {
+                case 1: x[1] = x[2] = x[3] = x[0]; break;
+                case 2: x[2] = x[0]; x[3] = x[1]; break;
+                case 3: x[3] = x[1]; break;
+            }
+
+            return {
+                top   : parseInt(x[0],10),
+                right : parseInt(x[1],10),
+                bottom: parseInt(x[2],10),
+                left  : parseInt(x[3],10)
+            };
+        },
+        /**
+        * @method getDrag
+        * @description Get a valid Drag instance back from a Node or a selector string, false otherwise
+        * @param {String/Object} node The Node instance or Selector string to check for a valid Drag Object
+        * @return {Object}
+        */
+        getDrag: function(node) {
+            var drag = false,
+                n = Y.Node.get(node);
+            if (n instanceof Y.Node) {
+                Y.each(this._drags, function(v, k) {
+                    if (n.compareTo(v.get('node'))) {
+                        drag = v;
+                    }
+                });
+            }
+            return drag;
+        }
+    });
+
+    Y.namespace('DD');
+    Y.DD.DDM = new DDMBase();
+
+
+
+}, '3.0.0pr2' ,{requires:['node', 'base'], skinnable:false});
+YUI.add('dd-ddm', function(Y) {
+
+    /**
+     * Extends the dd-ddm-base Class to add support for the viewport shim to allow a draggable node to drag to be dragged over an iframe or any other node that traps mousemove events.
+     * It is also required to have Drop Targets enabled, as the viewport shim will contain the shims for the Drop Targets.
+     * @module dd
+     * @submodule dd-ddm
+     * @for DDM
+     */
+    Y.mix(Y.DD.DDM, {
+        /**
+        * @private
+        * @property _pg
+        * @description The shim placed over the screen to track the mousemove event.
+        * @type {Node}
+        */
+        _pg: null,
+        /**
+        * @private
+        * @property _debugShim
+        * @description Set this to true to set the shims opacity to .5 for debugging it, default: false.
+        * @type {Boolean}
+        */
+        _debugShim: false,
+        _activateTargets: function() {},
+        _deactivateTargets: function() {},
+        _startDrag: function() {
+            if (this.activeDrag.get('useShim')) {
+                this._pg_activate();
+                this._activateTargets();
+            }
+        },
+        _endDrag: function() {
+            this._pg_deactivate();
+            this._deactivateTargets();
+        },
+        /**
+        * @private
+        * @method _pg_deactivate
+        * @description Deactivates the shim
+        */
+        _pg_deactivate: function() {
+            this._pg.setStyle('display', 'none');
+        },
+        /**
+        * @private
+        * @method _pg_activate
+        * @description Activates the shim
+        */
+        _pg_activate: function() {
+            this._pg_size();
+            this._pg.setStyles({
+                top: 0,
+                left: 0,
+                display: 'block',
+                opacity: ((this._debugShim) ? '.5' : '0')
+            });
+        },
+        /**
+        * @private
+        * @method _pg_size
+        * @description Sizes the shim on: activatation, window:scroll, window:resize
+        */
+        _pg_size: function() {
+            if (this.activeDrag) {
+                var b = Y.Node.get('body'),
+                h = b.get('docHeight'),
+                w = b.get('docWidth');
+                this._pg.setStyles({
+                    height: h + 'px',
+                    width: w + 'px'
+                });
+            }
+        },
+        /**
+        * @private
+        * @method _createPG
+        * @description Creates the shim and adds it's listeners to it.
+        */
+        _createPG: function() {
+            //var pg = Y.Node.create(['div']),
+            var pg = Y.Node.create('<div></div>'),
+            bd = Y.Node.get('body');
+            pg.setStyles({
+                top: '0',
+                left: '0',
+                position: 'absolute',
+                zIndex: '9999',
+                overflow: 'hidden',
+                //opacity: '0',
+                backgroundColor: 'red',
+                display: 'none',
+                height: '5px',
+                width: '5px'
+            });
+            if (bd.get('firstChild')) {
+                bd.insertBefore(pg, bd.get('firstChild'));
+            } else {
+                bd.appendChild(pg);
+            }
+            this._pg = pg;
+            this._pg.on('mouseup', this._end, this, true);
+            this._pg.on('mousemove', this._move, this, true);
+            
+            
+            Y.on('resize', this._pg_size, window, this, true);
+            Y.on('scroll', this._pg_size, window, this, true);
+        }   
+    }, true);
+
+    Y.DD.DDM._createPG();    
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-base'], skinnable:false});
+YUI.add('dd-ddm-drop', function(Y) {
+
+    /**
+     * Extends the dd-ddm Class to add support for the placement of Drop Target shims inside the viewport shim. It also handles all Drop Target related events and interactions.
+     * @module dd
+     * @submodule dd-ddm-drop
+     * @for DDM
+     */
+
+    //TODO CSS class name for the bestMatch..
+    Y.mix(Y.DD.DDM, {
+        /**
+        * @private
+        * @property _noShim
+        * @description This flag turns off the use of the mouseover/mouseout shim. It should not be used unless you know what you are doing.
+        * @type {Boolean}
+        */
+        _noShim: false,
+        /**
+        * @private
+        * @property _activeShims
+        * @description Placeholder for all active shims on the page
+        * @type {Array}
+        */
+        _activeShims: [],
+        /**
+        * @private
+        * @method _hasActiveShim
+        * @description This method checks the _activeShims Object to see if there is a shim active.
+        * @return {Boolean}
+        */
+        _hasActiveShim: function() {
+            if (this._noShim) {
+                return true;
+            }
+            return this._activeShims.length;
+        },
+        /**
+        * @private
+        * @method _addActiveShim 
+        * @description Adds a Drop Target to the list of active shims
+        * @param {Object} d The Drop instance to add to the list.
+        */
+        _addActiveShim: function(d) {
+            this._activeShims[this._activeShims.length] = d;
+        },
+        /**
+        * @private
+        * @method _removeActiveShim 
+        * @description Removes a Drop Target to the list of active shims
+        * @param {Object} d The Drop instance to remove from the list.
+        */
+        _removeActiveShim: function(d) {
+            var s = [];
+            Y.each(this._activeShims, function(v, k) {
+                if (v._yuid !== d._yuid) {
+                    s[s.length] = v;
+                }
+                
+            });
+            this._activeShims = s;
+        },
+        /**
+        * @method syncActiveShims
+        * @description This method will sync the position of the shims on the Drop Targets that are currently active.
+        * @param {Boolean} force Resize/sync all Targets.
+        * @return {Array} drops The list of Drop Targets that was just synced.
+        */
+        syncActiveShims: function(force) {
+            var drops = ((force) ? this.targets : this._lookup());
+            Y.each(drops, function(v, k) {
+                v.sizeShim.call(v);
+            }, this);
+
+            return drops;
+        },
+        /**
+        * @private
+        * @property mode
+        * @description The mode that the drag operations will run in 0 for Point, 1 for Intersect, 2 for Strict
+        * @type Number
+        */
+        mode: 0,
+        /**
+        * @private
+        * @property POINT
+        * @description In point mode, a Drop is targeted by the cursor being over the Target
+        * @type Number
+        */
+        POINT: 0,
+        /**
+        * @private
+        * @property INTERSECT
+        * @description In intersect mode, a Drop is targeted by "part" of the drag node being over the Target
+        * @type Number
+        */
+        INTERSECT: 1,
+        /**
+        * @private
+        * @property STRICT
+        * @description In strict mode, a Drop is targeted by the "entire" drag node being over the Target
+        * @type Number
+        */
+        STRICT: 2,
+        /**
+        * @property useHash
+        * @description Should we only check targets that are in the viewport on drags (for performance), default: true
+        * @type {Boolean}
+        */
+        useHash: true,
+        /**
+        * @property activeDrop
+        * @description A reference to the active Drop Target
+        * @type {Object}
+        */
+        activeDrop: null,
+        /**
+        * @property validDrops
+        * @description An array of the valid Drop Targets for this interaction.
+        * @type {Array}
+        */
+        //TODO Change array/object literals to be in sync..
+        validDrops: [],
+        /**
+        * @property otherDrops
+        * @description An object literal of Other Drop Targets that we encountered during this interaction (in the case of overlapping Drop Targets)
+        * @type {Object}
+        */
+        otherDrops: {},
+        /**
+        * @property targets
+        * @description All of the Targets
+        * @type {Array}
+        */
+        targets: [],
+        /**
+        * @private 
+        * @method _addValid
+        * @description Add a Drop Target to the list of Valid Targets. This list get's regenerated on each new drag operation.
+        * @param {Object} drop
+        * @return {Self}
+        * @chainable
+        */
+        _addValid: function(drop) {
+            this.validDrops[this.validDrops.length] = drop;
+            return this;
+        },
+        /**
+        * @private 
+        * @method _removeValid
+        * @description Removes a Drop Target from the list of Valid Targets. This list get's regenerated on each new drag operation.
+        * @param {Object} drop
+        * @return {Self}
+        * @chainable
+        */
+        _removeValid: function(drop) {
+            var drops = [];
+            Y.each(this.validDrops, function(v, k) {
+                if (v !== drop) {
+                    drops[drops.length] = v
+                }
+            });
+
+            this.validDrops = drops;
+            return this;
+        },
+        /**
+        * @method isOverTarget
+        * @description Check to see if the Drag element is over the target, method varies on current mode
+        * @param {Object} drop The drop to check against
+        * @return {Boolean}
+        */
+        isOverTarget: function(drop) {
+            //if (Y.Lang.isObject(this.activeDrag) && drop) { //TODO, check this check..
+            if (this.activeDrag && drop) {
+                var xy = this.activeDrag.mouseXY;
+                if (xy) {
+                    if (this.activeDrag.get('dragMode') == this.STRICT) {
+                        return this.activeDrag.get('dragNode').inRegion(drop.region, true, this.activeDrag.region);
+                    } else {
+                        if (drop && drop.shim) {
+                            return drop.shim.intersect({
+                                top: xy[1],
+                                bottom: xy[1],
+                                left: xy[0], 
+                                right: xy[0]
+                            }, drop.region).inRegion;
+                        } else {
+                            return false;
+                        }
+                    }
+                } else {
+                    return false;
+                }
+            } else {
+                return false;
+            }
+        },
+        /**
+        * @method clearCache
+        * @description Clears the cache data used for this interaction.
+        */
+        clearCache: function() {
+            this.validDrops = [];
+            this.otherDrops = {};
+            this._activeShims = [];
+        },
+        /**
+        * @private
+        * @method _activateTargets
+        * @description Clear the cache and activate the shims of all the targets
+        */
+        _activateTargets: function() {
+            this.clearCache();
+            Y.each(this.targets, function(v, k) {
+                v._activateShim.apply(v, []);
+            }, this);
+            this._handleTargetOver();
+            
+        },
+        /**
+        * @method getBestMatch
+        * @description This method will gather the area for all potential targets and see which has the hightest covered area and return it.
+        * @param {Array} drops An Array of drops to scan for the best match.
+        * @param {Boolean} all If present, it returns an Array. First item is best match, second is an Array of the other items in the original Array.
+        * @return {Object or Array} 
+        */
+        getBestMatch: function(drops, all) {
+            var biggest = null, area = 0;
+
+            Y.each(drops, function(v, k) {
+                var inter = this.activeDrag.get('dragNode').intersect(v.get('node'));
+                v.region.area = inter.area;
+
+                if (inter.inRegion) {
+                    if (inter.area > area) {
+                        area = inter.area;
+                        biggest = v;
+                    }
+                }
+            }, this);
+            if (all) {
+                var out = [];
+                //TODO Sort the others in numeric order by area covered..
+                Y.each(drops, function(v, k) {
+                    if (v !== biggest) {
+                        out[out.length] = v;
+                    }
+                }, this);
+                return [biggest, out];
+            } else {
+                return biggest;
+            }
+        },
+        /**
+        * @private
+        * @method _deactivateTargets
+        * @description This method fires the drop:hit, drag:drophit, drag:dropmiss methods and deactivates the shims..
+        */
+        _deactivateTargets: function() {
+            var other = [],
+                activeDrag = this.activeDrag,
+                activeDrop = this.activeDrop;
+            
+            //TODO why is this check so hard??
+            if (activeDrag && activeDrop && this.otherDrops[activeDrop]) {
+                if (!activeDrag.get('dragMode')) {
+                    //TODO otherDrops -- private..
+                    other = this.otherDrops;
+                    delete other[activeDrop];
+                } else {
+                    var tmp = this.getBestMatch(this.otherDrops, true);
+                    activeDrop = tmp[0];
+                    other = tmp[1];
+                }
+                activeDrag.get('node').removeClass(this.CSS_PREFIX + '-drag-over')
+                if (activeDrop) {
+                    activeDrop.fire('drop:hit', { drag: activeDrag, drop: activeDrop, others: other });
+                    activeDrag.fire('drag:drophit', { drag: activeDrag,  drop: activeDrop, others: other });
+                }
+            } else if (activeDrag) {
+                activeDrag.get('node').removeClass(this.CSS_PREFIX + '-drag-over')
+                activeDrag.fire('drag:dropmiss', { pageX: activeDrag.lastXY[0], pageY: activeDrag.lastXY[1] });
+            } else {
+                Y.log('No Active Drag', 'warn', 'dd-ddm');
+            }
+            
+            this.activeDrop = null;
+
+            Y.each(this.targets, function(v, k) {
+                v._deactivateShim.apply(v, []);
+            }, this);
+        },
+        /**
+        * @private
+        * @method _dropMove
+        * @description This method is called when the move method is called on the Drag Object.
+        */
+        _dropMove: function() {
+            if (this._hasActiveShim()) {
+                //Y.log('We have an active shim, check targets', 'info', 'dd-ddm');
+                this._handleTargetOver();
+            } else {
+                Y.each(this.otherDrops, function(v, k) {
+                    v._handleOut.apply(v, []);
+                });
+            }
+        },
+        /**
+        * @private
+        * @method _lookup
+        * @description Filters the list of Drops down to those in the viewport.
+        * @return {Array} The valid Drop Targets that are in the viewport.
+        */
+        _lookup: function() {
+            if (!this.useHash) {
+                return this.validDrops;
+            }
+            var drops = [];
+            //Only scan drop shims that are in the Viewport
+            Y.each(this.validDrops, function(v, k) {
+                if (v.shim && v.shim.inViewportRegion(false, v.region)) {
+                    drops[drops.length] = v;
+                }
+            });
+            return drops;
+                
+        },
+        /**
+        * @private
+        * @method _handleTargetOver
+        * @description This method execs _handleTargetOver on all valid Drop Targets
+        * @param {Boolean} force Force it to run the first time.
+        */
+        _handleTargetOver: function() {
+            var drops = this._lookup();
+            Y.each(drops, function(v, k) {
+                v._handleTargetOver.call(v);
+            }, this);
+        },
+        /**
+        * @private
+        * @method _regTarget
+        * @description Add the passed in Target to the targets collection
+        * @param {Object} t The Target to add to the targets collection
+        */
+        _regTarget: function(t) {
+            this.targets[this.targets.length] = t;
+        },
+        /**
+        * @private
+        * @method _unregTarget
+        * @description Remove the passed in Target from the targets collection
+        * @param {Object} drop The Target to remove from the targets collection
+        */
+        _unregTarget: function(drop) {
+            var targets = [];
+            Y.each(this.targets, function(v, k) {
+                if (v != drop) {
+                    targets[targets.length] = v;
+                }
+            }, this);
+            this.targets = targets;
+
+            var vdrops = [];
+            Y.each(this.validDrops, function(v, k) {
+                if (v !== drop) {
+                    vdrops[vdrops.length] = v
+                }
+            });
+
+            this.validDrops = vdrops;
+        },
+        /**
+        * @method getDrop
+        * @description Get a valid Drop instance back from a Node or a selector string, false otherwise
+        * @param {String/Object} node The Node instance or Selector string to check for a valid Drop Object
+        * @return {Object}
+        */
+        getDrop: function(node) {
+            var drop = false,
+                n = Y.Node.get(node);
+            if (n instanceof Y.Node) {
+                Y.each(this.targets, function(v, k) {
+                    if (n.compareTo(v.get('node'))) {
+                        drop = v;
+                    }
+                });
+            }
+            return drop;
+        }
+    }, true);
+    
+
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm'], skinnable:false});
+YUI.add('dd-drag', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-drag
+     */     
+    /**
+     * This class provides the ability to drag a Node.
+     * @class Drag
+     * @extends Base
+     * @constructor
+     */
+
+    var DDM = Y.DD.DDM,
+        NODE = 'node',
+        DRAG_NODE = 'dragNode',
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth',        
+        MOUSE_UP = 'mouseup',
+        MOUSE_DOWN = 'mousedown',
+        DRAG_START = 'dragstart',
+        /**
+        * @event drag:mouseDown
+        * @description Handles the mousedown DOM event, checks to see if you have a valid handle then starts the drag timers.
+        * @preventable _handleMouseDown
+        * @param {Event} ev The mousedown event.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_MOUSE_DOWN = 'drag:mouseDown',
+        /**
+        * @event drag:afterMouseDown
+        * @description Fires after the mousedown event has been cleared.
+        * @param {Event} ev The mousedown event.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_AFTER_MOUSE_DOWN = 'drag:afterMouseDown',
+        /**
+        * @event drag:removeHandle
+        * @description Fires after a handle is removed.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_REMOVE_HANDLE = 'drag:removeHandle',
+        /**
+        * @event drag:addHandle
+        * @description Fires after a handle is added.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_ADD_HANDLE = 'drag:addHandle',
+        /**
+        * @event drag:removeInvalid
+        * @description Fires after an invalid selector is removed.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_REMOVE_INVALID = 'drag:removeInvalid',
+        /**
+        * @event drag:addInvalid
+        * @description Fires after an invalid selector is added.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_ADD_INVALID = 'drag:addInvalid',
+        /**
+        * @event drag:start
+        * @description Fires at the start of a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_START = 'drag:start',
+        /**
+        * @event drag:end
+        * @description Fires at the end of a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_END = 'drag:end',
+        /**
+        * @event drag:drag
+        * @description Fires every mousemove during a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DRAG = 'drag:drag';
+
+
+        /**
+        * @event drag:over
+        * @description Fires when this node is over a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:enter
+        * @description Fires when this node enters a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:exit
+        * @description Fires when this node exits a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:drophit
+        * @description Fires when this node is dropped on a valid Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:dropmiss
+        * @description Fires when this node is dropped on an invalid Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+    
+    var Drag = function() {
+        Drag.superclass.constructor.apply(this, arguments);
+
+        DDM._regDrag(this);
+    };
+
+    Drag.NAME = 'drag';
+
+    Drag.ATTRS = {
+        /**
+        * @attribute node
+        * @description Y.Node instanace to use as the element to initiate a drag operation
+        * @type Node
+        */
+        node: {
+            set: function(node) {
+                var n = Y.get(node);
+                if (!n) {
+                    Y.fail('DD.Drag: Invalid Node Given: ' + node);
+                } else {
+                    n = n.item(0);
+                }
+                return n;
+            }
+        },
+        /**
+        * @attribute dragNode
+        * @description Y.Node instanace to use as the draggable element, defaults to node
+        * @type Node
+        */
+        dragNode: {
+            set: function(node) {
+                var n = Y.Node.get(node);
+                if (!n) {
+                    Y.fail('DD.Drag: Invalid dragNode Given: ' + node);
+                }
+                return n;
+            }
+        },
+        /**
+        * @attribute offsetNode
+        * @description Offset the drag element by the difference in cursor position: default true
+        * @type Boolean
+        */
+        offsetNode: {
+            value: true
+        },
+        /**
+        * @attribute clickPixelThresh
+        * @description The number of pixels to move to start a drag operation, default is 3.
+        * @type Number
+        */
+        clickPixelThresh: {
+            value: DDM.get('clickPixelThresh')
+        },
+        /**
+        * @attribute clickTimeThresh
+        * @description The number of milliseconds a mousedown has to pass to start a drag operation, default is 1000.
+        * @type Number
+        */
+        clickTimeThresh: {
+            value: DDM.get('clickTimeThresh')
+        },
+        /**
+        * @attribute lock
+        * @description Set to lock this drag element so that it can't be dragged: default false.
+        * @type Boolean
+        */
+        lock: {
+            value: false,
+            set: function(lock) {
+                if (lock) {
+                    this.get(NODE).addClass(DDM.CSS_PREFIX + '-locked');
+                } else {
+                    this.get(NODE).removeClass(DDM.CSS_PREFIX + '-locked');
+                }
+            }
+        },
+        /**
+        * @attribute data
+        * @description A payload holder to store arbitrary data about this drag object, can be used to store any value.
+        * @type Mixed
+        */
+        data: {
+            value: false
+        },
+        /**
+        * @attribute move
+        * @description If this is false, the drag element will not move with the cursor: default true. Can be used to "resize" the element.
+        * @type Boolean
+        */
+        move: {
+            value: true
+        },
+        /**
+        * @attribute useShim
+        * @description Use the protective shim on all drag operations: default true. Only works with dd-ddm, not dd-ddm-base.
+        * @type Boolean
+        */
+        useShim: {
+            value: true
+        },
+        /**
+        * @attribute activeHandle
+        * @description This config option is set by Drag to inform you of which handle fired the drag event (in the case that there are several handles): default false.
+        * @type Node
+        */
+        activeHandle: {
+            value: false
+        },
+        /**
+        * @attribute primaryButtonOnly
+        * @description By default a drag operation will only begin if the mousedown occurred with the primary mouse button. Setting this to false will allow for all mousedown events to trigger a drag.
+        * @type Boolean
+        */
+        primaryButtonOnly: {
+            value: true
+        },
+        /**
+        * @attribute dragging
+        * @description This attribute is not meant to be used by the implementor, it is meant to be used as an Event tracker so you can listen for it to change.
+        * @type Boolean
+        */
+        dragging: {
+            value: false
+        },
+        parent: {
+            value: false
+        },
+        /**
+        * @attribute target
+        * @description This attribute only works if the dd-drop module has been loaded. It will make this node a drop target as well as draggable.
+        * @type Boolean
+        */
+        target: {
+            value: false,
+            set: function(config) {
+                this._handleTarget(config);
+            }
+        },
+        /**
+        * @attribute dragMode
+        * @description This attribute only works if the dd-drop module is active. It will set the dragMode (point, intersect, strict) of this Drag instance.
+        * @type String
+        */
+        dragMode: {
+            value: null,
+            set: function(mode) {
+                return DDM._setDragMode(mode);
+            }
+        },
+        /**
+        * @attribute groups
+        * @description Array of groups to add this drag into.
+        * @type Array
+        */
+        groups: {
+            value: ['default'],
+            get: function() {
+                if (!this._groups) {
+                    this._groups = {};
+                }
+                var ret = [];
+                Y.each(this._groups, function(v, k) {
+                    ret[ret.length] = k;
+                });
+                return ret;
+            },
+            set: function(g) {
+                this._groups = {};
+                Y.each(g, function(v, k) {
+                    this._groups[v] = true;
+                }, this);
+            }
+        },
+        /**
+        * @attribute handles
+        * @description Array of valid handles to add. Adding something here will set all handles, even if previously added with addHandle
+        * @type Array
+        */
+        handles: {
+            value: null,
+            set: function(g) {
+                if (g) {
+                    this._handles = {};
+                    Y.each(g, function(v, k) {
+                        this._handles[v] = true;
+                    }, this);
+                } else {
+                    this._handles = null;
+                }
+                return g;
+            }
+        },
+        /**
+        * @attribute bubbles
+        * @description Controls the default bubble parent for this Drag instance. Default: Y.DD.DDM. Set to false to disable bubbling.
+        * @type Object
+        */
+        bubbles: {
+            writeOnce: true,
+            value: Y.DD.DDM
+        }
+    };
+
+    Y.extend(Drag, Y.Base, {
+        /**
+        * @method addToGroup
+        * @description Add this Drag instance to a group, this should be used for on-the-fly group additions.
+        * @param {String} g The group to add this Drag Instance to.
+        * @return {Self}
+        * @chainable
+        */
+        addToGroup: function(g) {
+            this._groups[g] = true;
+            DDM._activateTargets();
+            return this;
+        },
+        /**
+        * @method removeFromGroup
+        * @description Remove this Drag instance from a group, this should be used for on-the-fly group removals.
+        * @param {String} g The group to remove this Drag Instance from.
+        * @return {Self}
+        * @chainable
+        */
+        removeFromGroup: function(g) {
+            delete this._groups[g];
+            DDM._activateTargets();
+            return this;
+        },
+        /**
+        * @property target
+        * @description This will be a reference to the Drop instance associated with this drag if the target: true config attribute is set..
+        * @type {Object}
+        */
+        target: null,
+        /**
+        * @private
+        * @method _handleTarget
+        * @description Attribute handler for the target config attribute.
+        * @param {Boolean/Object}
+        * @return {Boolean/Object}
+        */
+        _handleTarget: function(config) {
+            if (Y.DD.Drop) {
+                if (config === false) {
+                    if (this.target) {
+                        DDM._unregTarget(this.target);
+                        this.target = null;
+                    }
+                    return false;
+                } else {
+                    if (!Y.Lang.isObject(config)) {
+                        config = {};
+                    }
+                    config.bubbles = this.get('bubbles');
+                    config.node = this.get(NODE);
+                    this.target = new Y.DD.Drop(config);
+                }
+            } else {
+                return false;
+            }
+        },
+        /**
+        * @private
+        * @property _groups
+        * @description Storage Array for the groups this drag belongs to.
+        * @type {Array}
+        */
+        _groups: null,
+        /**
+        * @private
+        * @method _createEvents
+        * @description This method creates all the events for this Event Target and publishes them so we get Event Bubbling.
+        */
+        _createEvents: function() {
+            
+            this.publish(EV_MOUSE_DOWN, {
+                defaultFn: this._handleMouseDown,
+                queuable: true,
+                emitFacade: true,
+                bubbles: true
+            });
+            
+            var ev = [
+                EV_AFTER_MOUSE_DOWN,
+                EV_REMOVE_HANDLE,
+                EV_ADD_HANDLE,
+                EV_REMOVE_INVALID,
+                EV_ADD_INVALID,
+                EV_START,
+                EV_END,
+                EV_DRAG,
+                'drag:drophit',
+                'drag:dropmiss',
+                'drag:over',
+                'drag:enter',
+                'drag:exit'
+            ];
+            
+            Y.each(ev, function(v, k) {
+                this.publish(v, {
+                    type: v,
+                    emitFacade: true,
+                    bubbles: true,
+                    preventable: false,
+                    queuable: true
+                });
+            }, this);
+
+            if (this.get('bubbles')) {
+                this.addTarget(this.get('bubbles'));
+            }
+            
+           
+        },
+        /**
+        * @private
+        * @property _ev_md
+        * @description A private reference to the mousedown DOM event
+        * @type {Event}
+        */
+        _ev_md: null,
+        /**
+        * @private
+        * @property _startTime
+        * @description The getTime of the mousedown event. Not used, just here in case someone wants/needs to use it.
+        * @type Date
+        */
+        _startTime: null,
+        /**
+        * @private
+        * @property _endTime
+        * @description The getTime of the mouseup event. Not used, just here in case someone wants/needs to use it.
+        * @type Date
+        */
+        _endTime: null,
+        /**
+        * @private
+        * @property _handles
+        * @description A private hash of the valid drag handles
+        * @type {Object}
+        */
+        _handles: null,
+        /**
+        * @private
+        * @property _invalids
+        * @description A private hash of the invalid selector strings
+        * @type {Object}
+        */
+        _invalids: null,
+        /**
+        * @private
+        * @property _invalidsDefault
+        * @description A private hash of the default invalid selector strings: {'textarea': true, 'input': true, 'a': true, 'button': true}
+        * @type {Object}
+        */
+        _invalidsDefault: {'textarea': true, 'input': true, 'a': true, 'button': true},
+        /**
+        * @private
+        * @property _dragThreshMet
+        * @description Private flag to see if the drag threshhold was met
+        * @type {Boolean}
+        */
+        _dragThreshMet: null,
+        /**
+        * @private
+        * @property _fromTimeout
+        * @description Flag to determine if the drag operation came from a timeout
+        * @type {Boolean}
+        */
+        _fromTimeout: null,
+        /**
+        * @private
+        * @property _clickTimeout
+        * @description Holder for the setTimeout call
+        * @type {Boolean}
+        */
+        _clickTimeout: null,
+        /**
+        * @property deltaXY
+        * @description The offset of the mouse position to the element's position
+        * @type {Array}
+        */
+        deltaXY: null,
+        /**
+        * @property startXY
+        * @description The initial mouse position
+        * @type {Array}
+        */
+        startXY: null,
+        /**
+        * @property nodeXY
+        * @description The initial element position
+        * @type {Array}
+        */
+        nodeXY: null,
+        /**
+        * @property lastXY
+        * @description The position of the element as it's moving (for offset calculations)
+        * @type {Array}
+        */
+        lastXY: null,
+        realXY: null,
+        /**
+        * @property mouseXY
+        * @description The XY coords of the mousemove
+        * @type {Array}
+        */
+        mouseXY: null,
+        /**
+        * @property region
+        * @description A region object associated with this drag, used for checking regions while dragging.
+        * @type Object
+        */
+        region: null,       
+        /**
+        * @private
+        * @method _handleMouseUp
+        * @description Handler for the mouseup DOM event
+        * @param {Event}
+        */
+        _handleMouseUp: function(ev) {
+            this._fixIEMouseUp();
+            if (DDM.activeDrag) {
+                DDM._end();
+            }
+        },
+        /** 
+        * @private
+        * @method _fixDragStart
+        * @description The function we use as the ondragstart handler when we start a drag in Internet Explorer. This keeps IE from blowing up on images as drag handles.
+        */
+        _fixDragStart: function(e) {
+            e.preventDefault();
+        },
+        /** 
+        * @private
+        * @method _ieSelectFix
+        * @description The function we use as the onselectstart handler when we start a drag in Internet Explorer
+        */
+        _ieSelectFix: function() {
+            return false;
+        },
+        /** 
+        * @private
+        * @property _ieSelectBack
+        * @description We will hold a copy of the current "onselectstart" method on this property, and reset it after we are done using it.
+        */
+        _ieSelectBack: null,
+        /**
+        * @private
+        * @method _fixIEMouseDown
+        * @description This method copies the onselectstart listner on the document to the _ieSelectFix property
+        */
+        _fixIEMouseDown: function() {
+            if (Y.UA.ie) {
+                this._ieSelectBack = Y.config.doc.body.onselectstart;
+                Y.config.doc.body.onselectstart = this._ieSelectFix;
+            }           
+        },
+        /**
+        * @private
+        * @method _fixIEMouseUp
+        * @description This method copies the _ieSelectFix property back to the onselectstart listner on the document.
+        */
+        _fixIEMouseUp: function() {
+            if (Y.UA.ie) {
+                Y.config.doc.body.onselectstart = this._ieSelectBack;
+            }           
+        },
+        /**
+        * @private
+        * @method _handleMouseDownEvent
+        * @description Handler for the mousedown DOM event
+        * @param {Event}
+        */
+        _handleMouseDownEvent: function(ev) {
+            this.fire(EV_MOUSE_DOWN, { ev: ev });
+        },
+        /**
+        * @private
+        * @method _handleMouseDown
+        * @description Handler for the mousedown DOM event
+        * @param {Event}
+        */
+        _handleMouseDown: function(e) {
+            var ev = e.ev;
+            Y.log('_handleMouseDown', 'info', 'dd-drag');
+            this._dragThreshMet = false;
+            this._ev_md = ev;
+            
+            if (this.get('primaryButtonOnly') && ev.button > 1) {
+                Y.log('Mousedown was not produced by the primary button', 'warn', 'dd-drag');
+                return false;
+            }
+            if (this.validClick(ev)) {
+                this._fixIEMouseDown();
+                ev.halt();
+                this._setStartPosition([ev.pageX, ev.pageY]);
+
+                DDM.activeDrag = this;
+
+                var self = this;
+                this._clickTimeout = setTimeout(function() {
+                    self._timeoutCheck.call(self);
+                }, this.get('clickTimeThresh'));
+            }
+            this.fire(EV_AFTER_MOUSE_DOWN, { ev: ev });
+        },
+        /**
+        * @method validClick
+        * @description Method first checks to see if we have handles, if so it validates the click against the handle. Then if it finds a valid handle, it checks it against the invalid handles list. Returns true if a good handle was used, false otherwise.
+        * @param {Event}
+        * @return {Boolean}
+        */
+        validClick: function(ev) {
+            var r = false,
+            tar = ev.target,
+            hTest = null;
+            if (this._handles) {
+                Y.log('validClick: We have handles', 'info', 'dd-drag');
+                Y.each(this._handles, function(i, n) {
+                    if (Y.Lang.isString(n)) {
+                        //Am I this or am I inside this
+                        if (tar.test(n + ', ' + n + ' *') && !hTest) {
+                            Y.log('Valid Selector found: ' + n, 'info', 'dd-drag');
+                            hTest = n;
+                            r = true;
+                        }
+                    }
+                });
+            } else {
+                if (this.get(NODE).contains(tar) || this.get(NODE).compareTo(tar)) {
+                    Y.log('validClick: We have a valid click', 'info', 'dd-drag');
+                    r = true;
+                }
+            }
+            if (r) {
+                Y.log('validClick: Check invalid selectors', 'info', 'dd-drag');
+                if (this._invalids) {
+                    Y.each(this._invalids, function(i, n) {
+                        if (Y.Lang.isString(n)) {
+                            //Am I this or am I inside this
+                            if (tar.test(n + ', ' + n + ' *')) {
+                                Y.log('Invalid Selector found: (' + (n + ', ' + n + ' *') + ')', 'warn', 'dd-drag');
+                                r = false;
+                            }
+                        }
+                    });
+                }
+            }
+            if (r) {
+                if (hTest) {
+                    var els = ev.currentTarget.queryAll(hTest),
+                        set = false;
+                    els.each(function(n, i) {
+                        if ((n.contains(tar) || n.compareTo(tar)) && !set) {
+                            set = true;
+                            this.set('activeHandle', els.item(i));
+                        }
+                    }, this);
+                } else {
+                    this.set('activeHandle', this.get(NODE));
+                }
+            }
+            return r;
+        },
+        /**
+        * @private
+        * @method _setStartPosition
+        * @description Sets the current position of the Element and calculates the offset
+        * @param {Array} xy The XY coords to set the position to.
+        */
+        _setStartPosition: function(xy) {
+            this.startXY = xy;
+            
+            this.nodeXY = this.get(NODE).getXY();
+            this.lastXY = this.nodeXY;
+            this.realXY = this.nodeXY;
+
+            if (this.get('offsetNode')) {
+                this.deltaXY = [(this.startXY[0] - this.nodeXY[0]), (this.startXY[1] - this.nodeXY[1])];
+            } else {
+                this.deltaXY = [0, 0];
+            }
+        },
+        /**
+        * @private
+        * @method _timeoutCheck
+        * @description The method passed to setTimeout to determine if the clickTimeThreshold was met.
+        */
+        _timeoutCheck: function() {
+            if (!this.get('lock')) {
+                Y.log("timeout threshold met", "info", "dd-drag");
+                this._fromTimeout = true;
+                this._dragThreshMet = true;
+                this.start();
+                this._moveNode([this._ev_md.pageX, this._ev_md.pageY], true);
+            }
+        },
+        /**
+        * @method removeHandle
+        * @description Remove a Selector added by addHandle
+        * @param {String} str The selector for the handle to be removed. 
+        * @return {Self}
+        * @chainable
+        */
+        removeHandle: function(str) {
+            if (this._handles[str]) {
+                delete this._handles[str];
+                this.fire(EV_REMOVE_HANDLE, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method addHandle
+        * @description Add a handle to a drag element. Drag only initiates when a mousedown happens on this element.
+        * @param {String} str The selector to test for a valid handle. Must be a child of the element.
+        * @return {Self}
+        * @chainable
+        */
+        addHandle: function(str) {
+            if (!this._handles) {
+                this._handles = {};
+            }
+            if (Y.Lang.isString(str)) {
+                this._handles[str] = true;
+                this.fire(EV_ADD_HANDLE, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method removeInvalid
+        * @description Remove an invalid handle added by addInvalid
+        * @param {String} str The invalid handle to remove from the internal list.
+        * @return {Self}
+        * @chainable
+        */
+        removeInvalid: function(str) {
+            if (this._invalids[str]) {
+                this._invalids[str] = null;
+                delete this._invalids[str];
+                this.fire(EV_REMOVE_INVALID, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method addInvalid
+        * @description Add a selector string to test the handle against. If the test passes the drag operation will not continue.
+        * @param {String} str The selector to test against to determine if this is an invalid drag handle.
+        * @return {Self}
+        * @chainable
+        */
+        addInvalid: function(str) {
+            if (Y.Lang.isString(str)) {
+                this._invalids[str] = true;
+                this.fire(EV_ADD_INVALID, { handle: str });
+            } else {
+                Y.log('Selector needs to be a string..', 'warn', 'dd-drag');
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Internal init handler
+        */
+        initializer: function() {
+            //TODO give the node instance a copy of this object
+            //Not supported in PR1 due to Y.Node.get calling a new under the hood.
+            //this.get(NODE).dd = this;
+
+            if (!this.get(NODE).get('id')) {
+                var id = Y.stamp(this.get(NODE));
+                this.get(NODE).set('id', id);
+            }
+            
+
+            this._invalids = Y.clone(this._invalidsDefault, true);
+
+            this._createEvents();
+            
+            if (!this.get(DRAG_NODE)) {
+                this.set(DRAG_NODE, this.get(NODE));
+            }
+            this._prep();
+            this._dragThreshMet = false;
+        },
+        /**
+        * @private
+        * @method _prep
+        * @description Attach event listners and add classname
+        */
+        _prep: function() {
+            var node = this.get(NODE);
+            node.addClass(DDM.CSS_PREFIX + '-draggable');
+            node.on(MOUSE_DOWN, this._handleMouseDownEvent, this, true);
+            node.on(MOUSE_UP, this._handleMouseUp, this, true);
+            node.on(DRAG_START, this._fixDragStart, this, true);
+        },
+        /**
+        * @private
+        * @method _unprep
+        * @description Detach event listners and remove classname
+        */
+        _unprep: function() {
+            var node = this.get(NODE);
+            node.removeClass(DDM.CSS_PREFIX + '-draggable');
+            node.detach(MOUSE_DOWN, this._handleMouseDownEvent, this, true);
+            node.detach(MOUSE_UP, this._handleMouseUp, this, true);
+            node.detach(DRAG_START, this._fixDragStart, this, true);
+        },
+        /**
+        * @method start
+        * @description Starts the drag operation
+        * @return {Self}
+        * @chainable
+        */
+        start: function() {
+            if (!this.get('lock') && !this.get('dragging')) {
+                this.set('dragging', true);
+                DDM._start(this.deltaXY, [this.get(NODE).get(OFFSET_HEIGHT), this.get(NODE).get(OFFSET_WIDTH)]);
+                Y.log('startDrag', 'info', 'dd-drag');
+                this.get(NODE).addClass(DDM.CSS_PREFIX + '-dragging');
+                this.fire(EV_START, { pageX: this.nodeXY[0], pageY: this.nodeXY[1] });
+                this.get(DRAG_NODE).on(MOUSE_UP, this._handleMouseUp, this, true);
+                var xy = this.nodeXY;
+
+                this._startTime = (new Date()).getTime();
+                
+                this.region = {
+                    '0': xy[0], 
+                    '1': xy[1],
+                    area: 0,
+                    top: xy[1],
+                    right: xy[0] + this.get(NODE).get(OFFSET_WIDTH),
+                    bottom: xy[1] + this.get(NODE).get(OFFSET_HEIGHT),
+                    left: xy[0]
+                };
+                
+            }
+            return this;
+        },
+        /**
+        * @method end
+        * @description Ends the drag operation
+        * @return {Self}
+        * @chainable
+        */
+        end: function() {
+            this._endTime = (new Date()).getTime();
+            clearTimeout(this._clickTimeout);
+            this._dragThreshMet = false;
+            this._fromTimeout = false;
+            if (!this.get('lock') && this.get('dragging')) {
+                Y.log('endDrag', 'info', 'dd-drag');
+                this.fire(EV_END, { pageX: this.lastXY[0], pageY: this.lastXY[1] });
+            }
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-dragging');
+            this.set('dragging', false);
+            this.deltaXY = [0, 0];
+            this.get(DRAG_NODE).detach(MOUSE_UP, this._handleMouseUp, this, true);
+
+            return this;
+        },
+        /**
+        * @private
+        * @method _align
+        * @description Calculates the offsets and set's the XY that the element will move to.
+        * @param {Array} xy The xy coords to align with.
+        * @return Array
+        * @type {Array}
+        */
+        _align: function(xy) {
+            return [xy[0] - this.deltaXY[0], xy[1] - this.deltaXY[1]];
+        },
+        /**
+        * @private
+        * @method _moveNode
+        * @description This method performs the actual element move.
+        * @param {Array} eXY The XY to move the element to, usually comes from the mousemove DOM event.
+        * @param {Boolean} noFire If true, the drag:drag event will not fire.
+        */
+        _moveNode: function(eXY, noFire) {
+            var xy = this._align(eXY), diffXY = [], diffXY2 = [];
+
+            //This will probably kill your machine ;)
+            //Y.log('dragging..', 'info', 'dd-drag');
+            diffXY[0] = (xy[0] - this.lastXY[0]);
+            diffXY[1] = (xy[1] - this.lastXY[1]);
+
+            diffXY2[0] = (xy[0] - this.nodeXY[0]);
+            diffXY2[1] = (xy[1] - this.nodeXY[1]);
+
+
+            if (this.get('move')) {
+                if (Y.UA.opera) {
+                    this.get(DRAG_NODE).setXY(xy);
+                } else {
+                    DDM.setXY(this.get(DRAG_NODE), diffXY);
+                }
+                this.realXY = xy;
+            }
+
+            this.region = {
+                '0': xy[0], 
+                '1': xy[1],
+                area: 0,
+                top: xy[1],
+                right: xy[0] + this.get(DRAG_NODE).get(OFFSET_WIDTH),
+                bottom: xy[1] + this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                left: xy[0]
+            };
+
+            var startXY = this.nodeXY;
+            if (!noFire) {
+                this.fire(EV_DRAG, {
+                    pageX: xy[0],
+                    pageY: xy[1],
+                    info: {
+                        start: startXY,
+                        xy: xy,
+                        delta: diffXY,
+                        offset: diffXY2
+                    } 
+                });
+            }
+            
+            this.lastXY = xy;
+        },
+        /**
+        * @private
+        * @method _move
+        * @description Fired from DragDropMgr (DDM) on mousemove.
+        * @param {Event} ev The mousemove DOM event
+        */
+        _move: function(ev) {
+            if (this.get('lock')) {
+                Y.log('Drag Locked', 'warn', 'dd-drag');
+                return false;
+            } else {
+                this.mouseXY = [ev.pageX, ev.pageY];
+                if (!this._dragThreshMet) {
+                    var diffX = Math.abs(this.startXY[0] - ev.pageX);
+                    var diffY = Math.abs(this.startXY[1] - ev.pageY);
+                    Y.log("diffX: " + diffX + ", diffY: " + diffY, 'info', 'dd-drag');
+                    if (diffX > this.get('clickPixelThresh') || diffY > this.get('clickPixelThresh')) {
+                        Y.log("pixel threshold met", "info", "dd-drag");
+                        this._dragThreshMet = true;
+                        this.start();
+                        this._moveNode([ev.pageX, ev.pageY]);
+                    }
+                
+                } else {
+                    clearTimeout(this._clickTimeout);
+                    this._moveNode([ev.pageX, ev.pageY]);
+                }
+            }
+        },
+        /**
+        * @method stopDrag
+        * @description Method will forcefully stop a drag operation. For example calling this from inside an ESC keypress handler will stop this drag.
+        * @return {Self}
+        * @chainable
+        */
+        stopDrag: function() {
+            if (this.get('dragging')) {
+                Y.log('stopDrag called', 'warn', 'dd-drag');
+                DDM._end();
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method destructor
+        * @description Lifecycle destructor, unreg the drag from the DDM and remove listeners
+        */
+        destructor: function() {
+            DDM._unregDrag(this);
+
+            this._unprep();
+            if (this.target) {
+                this.target.destroy();
+            }
+        }
+    });
+    Y.namespace('DD');    
+    Y.DD.Drag = Drag;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-base'], skinnable:false});
+YUI.add('dd-proxy', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-proxy
+     */
+    /**
+     * This class extends dd-drag to allow for creating a proxy drag node, instead of dragging the original node.
+     * @class Proxy
+     * @extends Drag
+     * @constructor
+     */
+    var DDM = Y.DD.DDM,
+        NODE = 'node',
+        DRAG_NODE = 'dragNode',
+        PROXY = 'proxy';
+     
+
+    var Proxy = function() {
+        Proxy.superclass.constructor.apply(this, arguments);
+
+    };
+
+    Proxy.NAME = 'dragProxy';
+
+    Proxy.ATTRS = {
+        /**
+        * @attribute moveOnEnd
+        * @description Move the original node at the end of the drag. Default: true
+        * @type Boolean
+        */
+        moveOnEnd: {
+            value: true
+        },
+        /**
+        * @attribute resizeFrame
+        * @description Make the Proxy node assume the size of the original node. Default: true
+        * @type Boolean
+        */
+        resizeFrame: {
+            value: true
+        },
+        /**
+        * @attribute proxy
+        * @description Make this Draggable instance a Proxy instance. Default: false
+        * @type Boolean
+        */
+        proxy: {
+            value: false
+        },        
+        /**
+        * @attribute positionProxy
+        * @description Make the Proxy node appear in the same place as the original node. Default: true
+        * @type Boolean
+        */
+        positionProxy: {
+            value: true
+        },
+        /**
+        * @attribute borderStyle
+        * @description The default border style for the border of the proxy. Default: 1px solid #808080
+        * @type Boolean
+        */
+        borderStyle: {
+            value: '1px solid #808080'
+        }
+    };
+
+    var proto = {
+        /**
+        * @private
+        * @method _createFrame
+        * @description Create the proxy element if it doesn't already exist and set the DD.DDM._proxy value
+        */
+        _createFrame: function() {
+            if (!DDM._proxy) {
+                DDM._proxy = true;
+                var p = Y.Node.create('<div></div>');
+
+                p.setStyles({
+                    position: 'absolute',
+                    display: 'none',
+                    zIndex: '999',
+                    top: '-999px',
+                    left: '-999px',
+                    border: this.get('borderStyle')
+                });
+
+                var b = Y.Node.get('body');
+                b.insertBefore(p, b.get('firstChild'));
+                p.set('id', Y.stamp(p));
+                p.addClass(DDM.CSS_PREFIX + '-proxy');
+                DDM._proxy = p;
+            }
+        },
+        /**
+        * @private
+        * @method _setFrame
+        * @description If resizeProxy is set to true (default) it will resize the proxy element to match the size of the Drag Element.
+        * If positionProxy is set to true (default) it will position the proxy element in the same location as the Drag Element.
+        */
+        _setFrame: function() {
+            var n = this.get(NODE);
+            if (this.get('resizeFrame')) {
+                DDM._proxy.setStyles({
+                    height: n.get('offsetHeight') + 'px',
+                    width: n.get('offsetWidth') + 'px'
+                });
+            }
+            this.get(DRAG_NODE).setStyles({
+                visibility: 'hidden',
+                display: 'block',
+                border: this.get('borderStyle')
+            });
+
+            if (this.get('positionProxy')) {
+                this.get(DRAG_NODE).setXY(this.nodeXY);
+            }
+            this.get(DRAG_NODE).setStyle('visibility', 'visible');
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Lifecycle method
+        */
+        initializer: function() {
+            if (this.get(PROXY)) {
+                this._createFrame();
+            }
+        },
+        /**
+        * @method start
+        * @description Starts the drag operation and sets the dragNode config option.
+        */       
+        start: function() {
+            if (!this.get('lock')) {
+                if (this.get(PROXY)) {
+                    if (this.get(DRAG_NODE).compareTo(this.get(NODE))) {
+                        this.set(DRAG_NODE, DDM._proxy);
+                    }
+                } else {
+                    this.set(DRAG_NODE, this.get(NODE));
+                }
+            }
+            Proxy.superclass.start.apply(this);
+            if (this.get(PROXY)) {
+                this._setFrame();
+            }
+        },
+        /**
+        * @method end
+        * @description Ends the drag operation, if moveOnEnd is set it will position the Drag Element to the new location of the proxy.
+        */        
+        end: function() {
+            if (this.get(PROXY) && this.get('dragging')) {
+                if (this.get('moveOnEnd')) {
+                    this.get(NODE).setXY(this.lastXY);
+                }
+                this.get(DRAG_NODE).setStyle('display', 'none');
+            }
+            Proxy.superclass.end.apply(this);
+        }
+    };
+    //Extend DD.Drag
+    Y.extend(Proxy, Y.DD.Drag, proto);
+    //Set this new class as DD.Drag for other extensions
+    Y.DD.Drag = Proxy;    
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm', 'dd-drag'], skinnable:false});
+YUI.add('dd-constrain', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-constrain
+     */
+    /**
+     * This class extends the dd-drag module to add the constraining methods to it. It supports constraining to a region, node or viewport. It also
+     * supports tick based moves and XY axis constraints.
+     * @class DragConstrained
+     * @extends Drag
+     * @constructor
+     */
+
+    var DRAG_NODE = 'dragNode',
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth';
+
+
+    var C = function() {
+        C.superclass.constructor.apply(this, arguments);
+
+    };
+    
+    C.NAME = 'dragConstrained';
+
+    C.ATTRS = {
+        /**
+        * @attribute stickX
+        * @description Stick the drag movement to the X-Axis. Default: false
+        * @type Boolean
+        */        
+        stickX: {
+            value: false
+        },
+        /**
+        * @attribute stickY
+        * @description Stick the drag movement to the Y-Axis
+        * @type Boolean
+        */        
+        stickY: {
+            value: false
+        },
+        /**
+        * @attribute tickX
+        * @description The X tick offset the drag node should snap to on each drag move. False for no ticks. Default: false
+        * @type Number/false
+        */        
+        tickX: {
+            value: false
+        },
+        /**
+        * @attribute tickY
+        * @description The Y tick offset the drag node should snap to on each drag move. False for no ticks. Default: false
+        * @type Number/false
+        */        
+        tickY: {
+            value: false
+        },
+        /**
+        * @attribute tickXArray
+        * @description An array of page coordinates to use as X ticks for drag movement.
+        * @type Array
+        */
+        tickXArray: {
+            value: false
+        },
+        /**
+        * @attribute tickYArray
+        * @description An array of page coordinates to use as Y ticks for drag movement.
+        * @type Array
+        */
+        tickYArray: {
+            value: false
+        },
+        /**
+        * @attribute constrain2region
+        * @description An Object Literal containing a valid region (top, right, bottom, left) of page positions to constrain the drag node to.
+        * @type Object
+        */
+        constrain2region: {
+            value: false,
+            get: function(r) {
+                if (Y.Lang.isObject(r)) {
+                    var o = {};
+                    Y.mix(o, r);
+                    return o;
+                } else {
+                    return false;
+                }
+            },
+            set: function (r) {
+                if (Y.Lang.isObject(r)) {
+                    if (r.top && r.right && r.left && r.bottom) {
+                        var o = {};
+                        Y.mix(o, r);
+                        return o;
+                    } else {
+                        Y.log('constrain2region expecting a valid object with (top, right, bottom, left properties)', 'error', 'DragConstrain');
+                        return false;
+                    }
+                } else if (r !== false) {
+                    Y.log('constrain2region expecting an object', 'error', 'DragConstrain');
+                    return false;
+                }
+            }
+        },
+        /**
+        * @attribute gutter
+        * @description CSS style string for the gutter of a region (supports negative values): '5 0' (sets top and bottom to 5px, left and right to 0px), '1 2 3 4' (top 1px, right 2px, bottom 3px, left 4px)        
+        * @type String
+        */
+        gutter: {
+            value: '0',
+            set: function(gutter) {
+                return Y.DD.DDM.cssSizestoObject(gutter);
+            }
+        },
+        /**
+        * @attribute constrain2node
+        * @description Will attempt to constrain the drag node to the bounderies of this node.
+        * @type Object
+        */
+        constrain2node: {
+            value: false,
+            set: function(n) {
+                if (!this.get('constrain2region')) {
+                    var node = Y.Node.get(n);
+                    if (node) {
+                        return node;
+                    }
+                } else if (this.get('constrain2region') !== false) {
+                    Y.log('constrain2region found, can not have both. Node ignored', 'warn', 'DragConstrain');
+                }
+                return false;
+            }
+        },
+        /**
+        * @attribute constrain2view
+        * @description Will attempt to constrain the drag node to the bounderies of the viewport region.
+        * @type Object
+        */
+        constrain2view: {
+            value: false
+        }
+    };
+
+    var proto = {
+        start: function() {
+            C.superclass.start.apply(this, arguments);
+            this._regionCache = null;
+        },
+        /**
+        * @private
+        * @property _regionCache
+        * @description Store a cache of the region that we are constraining to
+        * @type Object
+        */
+        _regionCache: null,
+        /**
+        * @private
+        * @method _cacheRegion
+        * @description Get's the region and caches it, called from window.resize and when the cache is null
+        */
+        _cacheRegion: function() {
+            this._regionCache = this.get('constrain2node').get('region');
+        },
+        /**
+        * @method getRegion
+        * @description Get the active region: viewport, node, custom region
+        * @param {Boolean} inc Include the node's height and width
+        * @return {Object}
+        */
+        getRegion: function(inc) {
+            var r = {};
+            if (this.get('constrain2node')) {
+                if (!this._regionCache) {
+                    Y.on('resize', this._cacheRegion, this, true, window);
+                    this._cacheRegion();
+                }
+                r = Y.clone(this._regionCache);
+            } else if (this.get('constrain2region')) {
+                r = this.get('constrain2region');
+            } else if (this.get('constrain2view')) {
+                r = this.get('node').get('viewportRegion');
+            } else {
+                return false;
+            }
+            var g = this.get('gutter');
+            Y.each(g, function(i, n) {
+                if ((n == 'right') || (n == 'bottom')) {
+                    r[n] -= i;
+                } else {
+                    r[n] += i;
+                }
+            });
+            if (inc) {
+                var oh = this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                    ow = this.get(DRAG_NODE).get(OFFSET_WIDTH);
+                r.right = r.right - ow;
+                r.bottom = r.bottom - oh;
+            }
+            return r;
+        },
+        /**
+        * @private
+        * @method _checkRegion
+        * @description
+        * @param {Array} _xy The XY to check if it's in the current region, if it isn't inside the region, it will reset the xy array to be inside the region.
+        * @return {Array} The new XY that is inside the region
+        */
+        _checkRegion: function(_xy) {
+            var oxy = _xy,
+                r = this.getRegion(),
+                oh = this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                ow = this.get(DRAG_NODE).get(OFFSET_WIDTH);
+            
+                if (oxy[1] > (r.bottom - oh)) {
+                    _xy[1] = (r.bottom - oh);
+                }
+                if (r.top > oxy[1]) {
+                    _xy[1] = r.top;
+
+                }
+                if (oxy[0] > (r.right - ow)) {
+                    _xy[0] = (r.right - ow);
+                }
+                if (r.left > oxy[0]) {
+                    _xy[0] = r.left;
+                }
+
+            return _xy;
+        },
+        /**
+        * @method inRegion
+        * @description Checks if the XY passed or the dragNode is inside the active region.
+        * @param {Array} xy Optional XY to check, if not supplied this.get('dragNode').getXY() is used.
+        * @return {Boolean} True if the XY is inside the region, false otherwise.
+        */
+        inRegion: function(xy) {
+            xy = xy || this.get(DRAG_NODE).getXY();
+
+            var _xy = this._checkRegion([xy[0], xy[1]]),
+                inside = false;
+                if ((xy[0] === _xy[0]) && (xy[1] === _xy[1])) {
+                    inside = true;
+                }
+            return inside;
+        },
+        /**
+        * @private
+        * @method _align
+        * @description Override of Drag _align to account for region checking and tick checking
+        * @param {Array} xy The XY to check for ticks and region
+        * @return {Array} The modified XY coords.
+        */
+        _align: function(xy) {
+            var _xy = C.superclass._align.apply(this, arguments),
+                r = this.getRegion(true);
+
+            if (this.get('stickX')) {
+                _xy[1] = (this.startXY[1] - this.deltaXY[1]);
+            }
+            if (this.get('stickY')) {
+                _xy[0] = (this.startXY[0] - this.deltaXY[0]);
+            }
+
+
+            if (r) {
+                _xy = this._checkRegion(_xy);
+            }
+                
+            _xy = this._checkTicks(_xy, r);
+            return _xy;
+        },
+        /**
+        * @private
+        * @method _calcTicks
+        * @description Helper method to calculate the tick offsets for a given position
+        * @param {Number} pos The current X or Y position
+        * @param {Number} start The start X or Y position
+        * @param {Number} tick The X or Y tick increment
+        * @param {Number} off1 The min offset that we can't pass (region)
+        * @param {Number} off2 The max offset that we can't pass (region)
+        * @return {Number} The new position based on the tick calculation
+        */
+        _calcTicks: function(pos, start, tick, off1, off2) {
+            var ix = ((pos - start) / tick),
+                min = Math.floor(ix),
+                max = Math.ceil(ix);
+                if ((min !== 0) || (max !== 0)) {
+                    if ((ix >= min) && (ix <= max)) {
+                        pos = (start + (tick * min));
+                        if (off1 && off2) {
+                            if (pos < off1) {
+                                pos = (start + (tick * (min + 1)));
+                            }
+                            if (pos > off2) {
+                                pos = (start + (tick * (min - 1)));
+                            }
+                        }
+                    }
+                }
+                return pos;
+        },
+        /**
+        * @private
+        * @method _calcTickArray
+        * @description This method is used with the tickXArray and tickYArray config options
+        * @param {Number} pos The current X or Y position
+        * @param {Number} ticks The array containing our custom tick positions.
+        * @param {Number} off1 The min offset that we can't pass (region)
+        * @param {Number} off2 The max offset that we can't pass (region)
+        * @return The tick position
+        */
+        _calcTickArray: function(pos, ticks, off1, off2) {
+            var i = 0, len = ticks.length, next = 0;
+
+            if (!ticks || (ticks.length === 0)) {
+                return pos;
+            } else if (ticks[0] >= pos) {
+                return ticks[0];
+            } else {
+                for (i = 0; i < len; i++) {
+                    next = (i + 1);
+                    if (ticks[next] && ticks[next] >= pos) {
+                        var diff1 = pos - ticks[i],
+                            diff2 = ticks[next] - pos;
+                        var ret = (diff2 > diff1) ? ticks[i] : ticks[next];
+                        if (off1 && off2) {
+                            if (ret > off2) {
+                                if (ticks[i]) {
+                                    ret = ticks[i];
+                                } else {
+                                    ret = ticks[len - 1];
+                                }
+                            }
+                        }
+                        return ret;
+                    }
+                    
+                }
+                return ticks[ticks.length - 1];
+            }
+        },
+        /**
+        * @private
+        * @method _checkTicks
+        * @description This method delegates the proper helper method for tick calculations
+        * @param {Array} xy The XY coords for the Drag
+        * @param {Object} r The optional region that we are bound to.
+        * @return {Array} The calced XY coords
+        */
+        _checkTicks: function(xy, r) {
+            var lx = (this.startXY[0] - this.deltaXY[0]),
+                ly = (this.startXY[1] - this.deltaXY[1]),
+                xt = this.get('tickX'),
+                yt = this.get('tickY');
+                if (xt && !this.get('tickXArray')) {
+                    xy[0] = this._calcTicks(xy[0], lx, xt, r.left, r.right);
+                }
+                if (yt && !this.get('tickYArray')) {
+                    xy[1] = this._calcTicks(xy[1], ly, yt, r.top, r.bottom);
+                }
+                if (this.get('tickXArray')) {
+                    xy[0] = this._calcTickArray(xy[0], this.get('tickXArray'), r.left, r.right);
+                }
+                if (this.get('tickYArray')) {
+                    xy[1] = this._calcTickArray(xy[1], this.get('tickYArray'), r.top, r.bottom);
+                }
+
+            return xy;
+        }
+    };
+    //Extend DD.Drag
+    Y.extend(C, Y.DD.Drag, proto);
+    //Set this to DD.Drag for other extensions
+    Y.DD.Drag = C;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drag', 'dd-proxy'], skinnable:false});
+YUI.add('dd-plugin', function(Y) {
+
+       /**
+        * This is a simple Drag plugin that can be attached to a Node via the plug method.
+        * @module dd-plugin
+        * @submodule dd-plugin
+        */
+       /**
+        * This is a simple Drag plugin that can be attached to a Node via the plug method.
+        * @class DragPlugin
+        * @extends Drag
+        * @constructor
+        * @namespace plugin
+        */
+
+
+        var Drag = function(config) {
+            config.node = config.owner;
+            Drag.superclass.constructor.apply(this, arguments);
+        };
+        
+        /**
+        * @property NAME
+        * @description dd-plugin
+        * @type {String}
+        */
+        Drag.NAME = "dd-plugin";
+        /**
+        * @property NS
+        * @description The Drag instance will be placed on the Node instance under the dd namespace. It can be accessed via Node.dd;
+        * @type {String}
+        */
+        Drag.NS = "dd";
+
+
+        Y.extend(Drag, Y.DD.Drag);
+        Y.namespace('plugin');
+        Y.plugin.Drag = Drag;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drag'], skinnable:false, optional:['dd-constrain', 'dd-proxy']});
+YUI.add('dd-drop', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-drop
+     */     
+    /**
+     * This class provides the ability to create a Drop Target.
+     * @class Drop
+     * @extends Base
+     * @constructor
+     */
+
+    var NODE = 'node',
+        DDM = Y.DD.DDM,
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth',
+        /**
+        * @event drop:over
+        * @description Fires when a drag element is over this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_OVER = 'drop:over',
+        /**
+        * @event drop:enter
+        * @description Fires when a drag element enters this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_ENTER = 'drop:enter',
+        /**
+        * @event drop:exit
+        * @description Fires when a drag element exits this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_EXIT = 'drop:exit';
+
+        /**
+        * @event drop:hit
+        * @description Fires when a draggable node is dropped on this Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        
+
+    var Drop = function() {
+        Drop.superclass.constructor.apply(this, arguments);
+
+        this._createShim();
+        DDM._regTarget(this);
+        /* TODO
+        if (Dom.getStyle(this.el, 'position') == 'fixed') {
+            Event.on(window, 'scroll', function() {
+                this.activateShim();
+            }, this, true);
+        }
+        */
+    };
+
+    Drop.NAME = 'drop';
+
+    Drop.ATTRS = {
+        /**
+        * @attribute node
+        * @description Y.Node instanace to use as the element to make a Drop Target
+        * @type Node
+        */        
+        node: {
+            set: function(node) {
+                var n = Y.Node.get(node);
+                if (!n) {
+                    Y.fail('DD.Drop: Invalid Node Given: ' + node);
+                }
+                return n;               
+            }
+        },
+        /**
+        * @attribute groups
+        * @description Array of groups to add this drop into.
+        * @type Array
+        */        
+        groups: {
+            value: ['default'],
+            set: function(g) {
+                this._groups = {};
+                Y.each(g, function(v, k) {
+                    this._groups[v] = true;
+                }, this);
+            }
+        },   
+        /**
+        * @attribute padding
+        * @description CSS style padding to make the Drop Target bigger than the node.
+        * @type String
+        */
+        padding: {
+            value: '0',
+            set: function(p) {
+                return DDM.cssSizestoObject(p);
+            }
+        },
+        /**
+        * @attribute lock
+        * @description Set to lock this drop element.
+        * @type Boolean
+        */        
+        lock: {
+            value: false,
+            set: function(lock) {
+                if (lock) {
+                    this.get(NODE).addClass(DDM.CSS_PREFIX + '-drop-locked');
+                } else {
+                    this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-locked');
+                }
+            }
+        },
+        /**
+        * @attribute bubbles
+        * @description Controls the default bubble parent for this Drop instance. Default: Y.DD.DDM. Set to false to disable bubbling.
+        * @type Object
+        */
+        bubbles: {
+            writeOnce: true,
+            value: Y.DD.DDM
+        }
+
+    };
+
+    Y.extend(Drop, Y.Base, {
+        /**
+        * @private
+        * @method _createEvents
+        * @description This method creates all the events for this Event Target and publishes them so we get Event Bubbling.
+        */
+        _createEvents: function() {
+            
+            var ev = [
+                EV_DROP_OVER,
+                EV_DROP_ENTER,
+                EV_DROP_EXIT,
+                'drop:hit'
+            ];
+
+            Y.each(ev, function(v, k) {
+                this.publish(v, {
+                    type: v,
+                    emitFacade: true,
+                    preventable: false,
+                    bubbles: true,
+                    queuable: true
+                });
+            }, this);
+
+            if (this.get('bubbles')) {
+                this.addTarget(this.get('bubbles'));
+            }
+            
+        },
+        /**
+        * @private
+        * @property _valid
+        * @description Flag for determining if the target is valid in this operation.
+        * @type Boolean
+        */
+        _valid: null,
+        /**
+        * @private
+        * @property _groups
+        * @description The groups this target belongs to.
+        * @type Array
+        */
+        _groups: null,
+        /**
+        * @property shim
+        * @description Node reference to the targets shim
+        * @type {Object}
+        */
+        shim: null,
+        /**
+        * @property region
+        * @description A region object associated with this target, used for checking regions while dragging.
+        * @type Object
+        */
+        region: null,
+        /**
+        * @property overTarget
+        * @description This flag is tripped when a drag element is over this target.
+        * @type Boolean
+        */
+        overTarget: null,
+        /**
+        * @method inGroup
+        * @description Check if this target is in one of the supplied groups.
+        * @param {Array} groups The groups to check against
+        * @return Boolean
+        */
+        inGroup: function(groups) {
+            this._valid = false;
+            var ret = false;
+            Y.each(groups, function(v, k) {
+                if (this._groups[v]) {
+                    ret = true;
+                    this._valid = true;
+                }
+            }, this);
+            return ret;
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Private lifecycle method
+        */
+        initializer: function() {
+            this._createEvents();
+            var node = this.get(NODE);
+            if (!node.get('id')) {
+                var id = Y.stamp(node);
+                node.set('id', id);
+            }
+            node.addClass(DDM.CSS_PREFIX + '-drop');
+        },
+        /**
+        * @private
+        * @method destructor
+        * @description Lifecycle destructor, unreg the drag from the DDM and remove listeners
+        */
+        destructor: function() {
+            DDM._unregTarget(this);
+            if (this.shim) {
+                this.shim.get('parentNode').removeChild(this.shim);
+                this.shim = null;
+            }
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop');
+        },        
+        /**
+        * @private
+        * @method _deactivateShim
+        * @description Removes classes from the target, resets some flags and sets the shims deactive position [-999, -999]
+        */
+        _deactivateShim: function() {
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-active-valid');
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-over');
+            this.shim.setStyles({
+                top: '-999px',
+                left: '-999px'
+            });
+            this.overTarget = false;
+        },
+        /**
+        * @private
+        * @method _activateShim
+        * @description Activates the shim and adds some interaction CSS classes
+        */
+        _activateShim: function() {
+            if (!DDM.activeDrag) {
+                return false; //Nothing is dragging, no reason to activate.
+            }
+            if (this.get(NODE) === DDM.activeDrag.get(NODE)) {
+                return false;
+            }
+            if (this.get('lock')) {
+                return false;
+            }
+            var node = this.get(NODE);
+            //TODO Visibility Check..
+            //if (this.inGroup(DDM.activeDrag.get('groups')) && this.get(NODE).isVisible()) {
+            if (this.inGroup(DDM.activeDrag.get('groups'))) {
+                node.removeClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+                node.addClass(DDM.CSS_PREFIX + '-drop-active-valid');
+                DDM._addValid(this);
+                this.overTarget = false;
+                this.sizeShim();
+            } else {
+                DDM._removeValid(this);
+                node.removeClass(DDM.CSS_PREFIX + '-drop-active-valid');
+                node.addClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+            }
+        },
+        /**
+        * @method sizeShim
+        * @description Positions and sizes the shim with the raw data from the node, this can be used to programatically adjust the Targets shim for Animation..
+        */
+        sizeShim: function() {
+            if (!DDM.activeDrag) {
+                return false; //Nothing is dragging, no reason to activate.
+            }
+            if (this.get(NODE) === DDM.activeDrag.get(NODE)) {
+                return false;
+            }
+            if (this.get('lock')) {
+                return false;
+            }
+            var node = this.get(NODE),
+                nh = node.get(OFFSET_HEIGHT),
+                nw = node.get(OFFSET_WIDTH),
+                xy = node.getXY(),
+                p = this.get('padding');
+
+
+            //Apply padding
+            nw = nw + p.left + p.right;
+            nh = nh + p.top + p.bottom;
+            xy[0] = xy[0] - p.left;
+            xy[1] = xy[1] - p.top;
+            
+
+            if (DDM.activeDrag.get('dragMode') === DDM.INTERSECT) {
+                //Intersect Mode, make the shim bigger
+                var dd = DDM.activeDrag,
+                    dH = dd.get(NODE).get(OFFSET_HEIGHT),
+                    dW = dd.get(NODE).get(OFFSET_WIDTH);
+                
+                nh = (nh + dH);
+                nw = (nw + dW);
+                xy[0] = xy[0] - (dW - dd.deltaXY[0]);
+                xy[1] = xy[1] - (dH - dd.deltaXY[1]);
+
+            }
+            
+            //Set the style on the shim
+            this.shim.setStyles({
+                height: nh + 'px',
+                width: nw + 'px',
+                top: xy[1] + 'px',
+                left: xy[0] + 'px'
+            });
+            
+            //Create the region to be used by intersect when a drag node is over us.
+            this.region = {
+                '0': xy[0], 
+                '1': xy[1],
+                area: 0,
+                top: xy[1],
+                right: xy[0] + nw,
+                bottom: xy[1] + nh,
+                left: xy[0]
+            };
+        },
+        /**
+        * @private
+        * @method _createShim
+        * @description Creates the Target shim and adds it to the DDM's playground..
+        */
+        _createShim: function() {
+            //var s = Y.Node.create(['div', { id: this.get(NODE).get('id') + '_shim' }]);
+            var s = Y.Node.create('<div id="' + this.get(NODE).get('id') + '_shim"></div>');
+            s.setStyles({
+                height: this.get(NODE).get(OFFSET_HEIGHT) + 'px',
+                width: this.get(NODE).get(OFFSET_WIDTH) + 'px',
+                backgroundColor: 'yellow',
+                opacity: '.5',
+                zIndex: 999,
+                overflow: 'hidden',
+                top: '-900px',
+                left: '-900px',
+                position:  'absolute'
+            });
+            DDM._pg.appendChild(s);
+            this.shim = s;
+
+            s.on('mouseover', this._handleOverEvent, this, true);
+            s.on('mouseout', this._handleOutEvent, this, true);
+        },
+        /**
+        * @private
+        * @method _handleOverTarget
+        * @description This handles the over target call made from this object or from the DDM
+        */
+        _handleTargetOver: function() {
+            if (DDM.isOverTarget(this)) {
+                this.get(NODE).addClass(DDM.CSS_PREFIX + '-drop-over');
+                DDM.activeDrop = this;
+                DDM.otherDrops[this] = this;
+                if (this.overTarget) {
+                    DDM.activeDrag.fire('drag:over', { drop: this, drag: DDM.activeDrag });
+                    this.fire(EV_DROP_OVER, { drop: this, drag: DDM.activeDrag });
+                } else {
+                    this.overTarget = true;
+                    this.fire(EV_DROP_ENTER, { drop: this, drag: DDM.activeDrag });
+                    DDM.activeDrag.fire('drag:enter', { drop: this, drag: DDM.activeDrag });
+                    DDM.activeDrag.get(NODE).addClass(DDM.CSS_PREFIX + '-drag-over');
+                    DDM._handleTargetOver();
+                }
+            } else {
+                this._handleOut();
+            }
+            
+        },
+        /**
+        * @private
+        * @method _handleOverEvent
+        * @description Handles the mouseover DOM event on the Target Shim
+        */
+        _handleOverEvent: function() {
+            DDM._addActiveShim(this);
+        },
+        /**
+        * @private
+        * @method _handleOut
+        * @description Handles the mouseout DOM event on the Target Shim
+        */
+        _handleOutEvent: function() {
+            DDM._removeActiveShim(this);
+        },
+        /**
+        * @private
+        * @method _handleOut
+        * @description Handles out of target calls/checks
+        */
+        _handleOut: function() {
+            if (!DDM.isOverTarget(this)) {
+                if (this.overTarget) {
+                    this.overTarget = false;
+                    DDM._removeActiveShim(this);
+                    if (DDM.activeDrag) {
+                        this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-over');
+                        DDM.activeDrag.get(NODE).removeClass(DDM.CSS_PREFIX + '-drag-over');
+                        this.fire(EV_DROP_EXIT);
+                        DDM.activeDrag.fire('drag:exit', { drop: this });
+                        delete DDM.otherDrops[this];
+                    }
+                }
+            }
+        }
+    });
+
+    Y.DD.Drop = Drop;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-drop', 'dd-drag'], skinnable:false});
+YUI.add('dd-drop-plugin', function(Y) {
+
+       /**
+        * This is a simple Drop plugin that can be attached to a Node via the plug method.
+        * @module dd-plugin
+        * @submodule dd-drop-plugin
+        */
+       /**
+        * This is a simple Drop plugin that can be attached to a Node via the plug method.
+        * @class DropPlugin
+        * @extends Drop
+        * @constructor
+        * @namespace plugin
+        */
+
+
+        var Drop = function(config) {
+            config.node = config.owner;
+            Drop.superclass.constructor.apply(this, arguments);
+        };
+        
+        /**
+        * @property NAME
+        * @description dd-drop-plugin
+        * @type {String}
+        */
+        Drop.NAME = "dd-drop-plugin";
+        /**
+        * @property NS
+        * @description The Drop instance will be placed on the Node instance under the drop namespace. It can be accessed via Node.drop;
+        * @type {String}
+        */
+        Drop.NS = "drop";
+
+
+        Y.extend(Drop, Y.DD.Drop);
+        Y.namespace('plugin');
+        Y.plugin.Drop = Drop;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drop'], skinnable:false});
+
+
+YUI.add('dd', function(Y){}, '3.0.0pr2' ,{use:['dd-ddm-base', 'dd-ddm', 'dd-ddm-drop', 'dd-drag', 'dd-proxy', 'dd-constrain', 'dd-plugin', 'dd-drop', 'dd-drop-plugin'], skinnable:false});
+

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-drag-debug.js'
--- loggerhead/static/javascript/yui/build/dd/dd-drag-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-drag-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1020 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-drag', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-drag
+     */     
+    /**
+     * This class provides the ability to drag a Node.
+     * @class Drag
+     * @extends Base
+     * @constructor
+     */
+
+    var DDM = Y.DD.DDM,
+        NODE = 'node',
+        DRAG_NODE = 'dragNode',
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth',        
+        MOUSE_UP = 'mouseup',
+        MOUSE_DOWN = 'mousedown',
+        DRAG_START = 'dragstart',
+        /**
+        * @event drag:mouseDown
+        * @description Handles the mousedown DOM event, checks to see if you have a valid handle then starts the drag timers.
+        * @preventable _handleMouseDown
+        * @param {Event} ev The mousedown event.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_MOUSE_DOWN = 'drag:mouseDown',
+        /**
+        * @event drag:afterMouseDown
+        * @description Fires after the mousedown event has been cleared.
+        * @param {Event} ev The mousedown event.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_AFTER_MOUSE_DOWN = 'drag:afterMouseDown',
+        /**
+        * @event drag:removeHandle
+        * @description Fires after a handle is removed.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_REMOVE_HANDLE = 'drag:removeHandle',
+        /**
+        * @event drag:addHandle
+        * @description Fires after a handle is added.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_ADD_HANDLE = 'drag:addHandle',
+        /**
+        * @event drag:removeInvalid
+        * @description Fires after an invalid selector is removed.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_REMOVE_INVALID = 'drag:removeInvalid',
+        /**
+        * @event drag:addInvalid
+        * @description Fires after an invalid selector is added.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_ADD_INVALID = 'drag:addInvalid',
+        /**
+        * @event drag:start
+        * @description Fires at the start of a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_START = 'drag:start',
+        /**
+        * @event drag:end
+        * @description Fires at the end of a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_END = 'drag:end',
+        /**
+        * @event drag:drag
+        * @description Fires every mousemove during a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DRAG = 'drag:drag';
+
+
+        /**
+        * @event drag:over
+        * @description Fires when this node is over a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:enter
+        * @description Fires when this node enters a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:exit
+        * @description Fires when this node exits a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:drophit
+        * @description Fires when this node is dropped on a valid Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:dropmiss
+        * @description Fires when this node is dropped on an invalid Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+    
+    var Drag = function() {
+        Drag.superclass.constructor.apply(this, arguments);
+
+        DDM._regDrag(this);
+    };
+
+    Drag.NAME = 'drag';
+
+    Drag.ATTRS = {
+        /**
+        * @attribute node
+        * @description Y.Node instanace to use as the element to initiate a drag operation
+        * @type Node
+        */
+        node: {
+            set: function(node) {
+                var n = Y.get(node);
+                if (!n) {
+                    Y.fail('DD.Drag: Invalid Node Given: ' + node);
+                } else {
+                    n = n.item(0);
+                }
+                return n;
+            }
+        },
+        /**
+        * @attribute dragNode
+        * @description Y.Node instanace to use as the draggable element, defaults to node
+        * @type Node
+        */
+        dragNode: {
+            set: function(node) {
+                var n = Y.Node.get(node);
+                if (!n) {
+                    Y.fail('DD.Drag: Invalid dragNode Given: ' + node);
+                }
+                return n;
+            }
+        },
+        /**
+        * @attribute offsetNode
+        * @description Offset the drag element by the difference in cursor position: default true
+        * @type Boolean
+        */
+        offsetNode: {
+            value: true
+        },
+        /**
+        * @attribute clickPixelThresh
+        * @description The number of pixels to move to start a drag operation, default is 3.
+        * @type Number
+        */
+        clickPixelThresh: {
+            value: DDM.get('clickPixelThresh')
+        },
+        /**
+        * @attribute clickTimeThresh
+        * @description The number of milliseconds a mousedown has to pass to start a drag operation, default is 1000.
+        * @type Number
+        */
+        clickTimeThresh: {
+            value: DDM.get('clickTimeThresh')
+        },
+        /**
+        * @attribute lock
+        * @description Set to lock this drag element so that it can't be dragged: default false.
+        * @type Boolean
+        */
+        lock: {
+            value: false,
+            set: function(lock) {
+                if (lock) {
+                    this.get(NODE).addClass(DDM.CSS_PREFIX + '-locked');
+                } else {
+                    this.get(NODE).removeClass(DDM.CSS_PREFIX + '-locked');
+                }
+            }
+        },
+        /**
+        * @attribute data
+        * @description A payload holder to store arbitrary data about this drag object, can be used to store any value.
+        * @type Mixed
+        */
+        data: {
+            value: false
+        },
+        /**
+        * @attribute move
+        * @description If this is false, the drag element will not move with the cursor: default true. Can be used to "resize" the element.
+        * @type Boolean
+        */
+        move: {
+            value: true
+        },
+        /**
+        * @attribute useShim
+        * @description Use the protective shim on all drag operations: default true. Only works with dd-ddm, not dd-ddm-base.
+        * @type Boolean
+        */
+        useShim: {
+            value: true
+        },
+        /**
+        * @attribute activeHandle
+        * @description This config option is set by Drag to inform you of which handle fired the drag event (in the case that there are several handles): default false.
+        * @type Node
+        */
+        activeHandle: {
+            value: false
+        },
+        /**
+        * @attribute primaryButtonOnly
+        * @description By default a drag operation will only begin if the mousedown occurred with the primary mouse button. Setting this to false will allow for all mousedown events to trigger a drag.
+        * @type Boolean
+        */
+        primaryButtonOnly: {
+            value: true
+        },
+        /**
+        * @attribute dragging
+        * @description This attribute is not meant to be used by the implementor, it is meant to be used as an Event tracker so you can listen for it to change.
+        * @type Boolean
+        */
+        dragging: {
+            value: false
+        },
+        parent: {
+            value: false
+        },
+        /**
+        * @attribute target
+        * @description This attribute only works if the dd-drop module has been loaded. It will make this node a drop target as well as draggable.
+        * @type Boolean
+        */
+        target: {
+            value: false,
+            set: function(config) {
+                this._handleTarget(config);
+            }
+        },
+        /**
+        * @attribute dragMode
+        * @description This attribute only works if the dd-drop module is active. It will set the dragMode (point, intersect, strict) of this Drag instance.
+        * @type String
+        */
+        dragMode: {
+            value: null,
+            set: function(mode) {
+                return DDM._setDragMode(mode);
+            }
+        },
+        /**
+        * @attribute groups
+        * @description Array of groups to add this drag into.
+        * @type Array
+        */
+        groups: {
+            value: ['default'],
+            get: function() {
+                if (!this._groups) {
+                    this._groups = {};
+                }
+                var ret = [];
+                Y.each(this._groups, function(v, k) {
+                    ret[ret.length] = k;
+                });
+                return ret;
+            },
+            set: function(g) {
+                this._groups = {};
+                Y.each(g, function(v, k) {
+                    this._groups[v] = true;
+                }, this);
+            }
+        },
+        /**
+        * @attribute handles
+        * @description Array of valid handles to add. Adding something here will set all handles, even if previously added with addHandle
+        * @type Array
+        */
+        handles: {
+            value: null,
+            set: function(g) {
+                if (g) {
+                    this._handles = {};
+                    Y.each(g, function(v, k) {
+                        this._handles[v] = true;
+                    }, this);
+                } else {
+                    this._handles = null;
+                }
+                return g;
+            }
+        },
+        /**
+        * @attribute bubbles
+        * @description Controls the default bubble parent for this Drag instance. Default: Y.DD.DDM. Set to false to disable bubbling.
+        * @type Object
+        */
+        bubbles: {
+            writeOnce: true,
+            value: Y.DD.DDM
+        }
+    };
+
+    Y.extend(Drag, Y.Base, {
+        /**
+        * @method addToGroup
+        * @description Add this Drag instance to a group, this should be used for on-the-fly group additions.
+        * @param {String} g The group to add this Drag Instance to.
+        * @return {Self}
+        * @chainable
+        */
+        addToGroup: function(g) {
+            this._groups[g] = true;
+            DDM._activateTargets();
+            return this;
+        },
+        /**
+        * @method removeFromGroup
+        * @description Remove this Drag instance from a group, this should be used for on-the-fly group removals.
+        * @param {String} g The group to remove this Drag Instance from.
+        * @return {Self}
+        * @chainable
+        */
+        removeFromGroup: function(g) {
+            delete this._groups[g];
+            DDM._activateTargets();
+            return this;
+        },
+        /**
+        * @property target
+        * @description This will be a reference to the Drop instance associated with this drag if the target: true config attribute is set..
+        * @type {Object}
+        */
+        target: null,
+        /**
+        * @private
+        * @method _handleTarget
+        * @description Attribute handler for the target config attribute.
+        * @param {Boolean/Object}
+        * @return {Boolean/Object}
+        */
+        _handleTarget: function(config) {
+            if (Y.DD.Drop) {
+                if (config === false) {
+                    if (this.target) {
+                        DDM._unregTarget(this.target);
+                        this.target = null;
+                    }
+                    return false;
+                } else {
+                    if (!Y.Lang.isObject(config)) {
+                        config = {};
+                    }
+                    config.bubbles = this.get('bubbles');
+                    config.node = this.get(NODE);
+                    this.target = new Y.DD.Drop(config);
+                }
+            } else {
+                return false;
+            }
+        },
+        /**
+        * @private
+        * @property _groups
+        * @description Storage Array for the groups this drag belongs to.
+        * @type {Array}
+        */
+        _groups: null,
+        /**
+        * @private
+        * @method _createEvents
+        * @description This method creates all the events for this Event Target and publishes them so we get Event Bubbling.
+        */
+        _createEvents: function() {
+            
+            this.publish(EV_MOUSE_DOWN, {
+                defaultFn: this._handleMouseDown,
+                queuable: true,
+                emitFacade: true,
+                bubbles: true
+            });
+            
+            var ev = [
+                EV_AFTER_MOUSE_DOWN,
+                EV_REMOVE_HANDLE,
+                EV_ADD_HANDLE,
+                EV_REMOVE_INVALID,
+                EV_ADD_INVALID,
+                EV_START,
+                EV_END,
+                EV_DRAG,
+                'drag:drophit',
+                'drag:dropmiss',
+                'drag:over',
+                'drag:enter',
+                'drag:exit'
+            ];
+            
+            Y.each(ev, function(v, k) {
+                this.publish(v, {
+                    type: v,
+                    emitFacade: true,
+                    bubbles: true,
+                    preventable: false,
+                    queuable: true
+                });
+            }, this);
+
+            if (this.get('bubbles')) {
+                this.addTarget(this.get('bubbles'));
+            }
+            
+           
+        },
+        /**
+        * @private
+        * @property _ev_md
+        * @description A private reference to the mousedown DOM event
+        * @type {Event}
+        */
+        _ev_md: null,
+        /**
+        * @private
+        * @property _startTime
+        * @description The getTime of the mousedown event. Not used, just here in case someone wants/needs to use it.
+        * @type Date
+        */
+        _startTime: null,
+        /**
+        * @private
+        * @property _endTime
+        * @description The getTime of the mouseup event. Not used, just here in case someone wants/needs to use it.
+        * @type Date
+        */
+        _endTime: null,
+        /**
+        * @private
+        * @property _handles
+        * @description A private hash of the valid drag handles
+        * @type {Object}
+        */
+        _handles: null,
+        /**
+        * @private
+        * @property _invalids
+        * @description A private hash of the invalid selector strings
+        * @type {Object}
+        */
+        _invalids: null,
+        /**
+        * @private
+        * @property _invalidsDefault
+        * @description A private hash of the default invalid selector strings: {'textarea': true, 'input': true, 'a': true, 'button': true}
+        * @type {Object}
+        */
+        _invalidsDefault: {'textarea': true, 'input': true, 'a': true, 'button': true},
+        /**
+        * @private
+        * @property _dragThreshMet
+        * @description Private flag to see if the drag threshhold was met
+        * @type {Boolean}
+        */
+        _dragThreshMet: null,
+        /**
+        * @private
+        * @property _fromTimeout
+        * @description Flag to determine if the drag operation came from a timeout
+        * @type {Boolean}
+        */
+        _fromTimeout: null,
+        /**
+        * @private
+        * @property _clickTimeout
+        * @description Holder for the setTimeout call
+        * @type {Boolean}
+        */
+        _clickTimeout: null,
+        /**
+        * @property deltaXY
+        * @description The offset of the mouse position to the element's position
+        * @type {Array}
+        */
+        deltaXY: null,
+        /**
+        * @property startXY
+        * @description The initial mouse position
+        * @type {Array}
+        */
+        startXY: null,
+        /**
+        * @property nodeXY
+        * @description The initial element position
+        * @type {Array}
+        */
+        nodeXY: null,
+        /**
+        * @property lastXY
+        * @description The position of the element as it's moving (for offset calculations)
+        * @type {Array}
+        */
+        lastXY: null,
+        realXY: null,
+        /**
+        * @property mouseXY
+        * @description The XY coords of the mousemove
+        * @type {Array}
+        */
+        mouseXY: null,
+        /**
+        * @property region
+        * @description A region object associated with this drag, used for checking regions while dragging.
+        * @type Object
+        */
+        region: null,       
+        /**
+        * @private
+        * @method _handleMouseUp
+        * @description Handler for the mouseup DOM event
+        * @param {Event}
+        */
+        _handleMouseUp: function(ev) {
+            this._fixIEMouseUp();
+            if (DDM.activeDrag) {
+                DDM._end();
+            }
+        },
+        /** 
+        * @private
+        * @method _fixDragStart
+        * @description The function we use as the ondragstart handler when we start a drag in Internet Explorer. This keeps IE from blowing up on images as drag handles.
+        */
+        _fixDragStart: function(e) {
+            e.preventDefault();
+        },
+        /** 
+        * @private
+        * @method _ieSelectFix
+        * @description The function we use as the onselectstart handler when we start a drag in Internet Explorer
+        */
+        _ieSelectFix: function() {
+            return false;
+        },
+        /** 
+        * @private
+        * @property _ieSelectBack
+        * @description We will hold a copy of the current "onselectstart" method on this property, and reset it after we are done using it.
+        */
+        _ieSelectBack: null,
+        /**
+        * @private
+        * @method _fixIEMouseDown
+        * @description This method copies the onselectstart listner on the document to the _ieSelectFix property
+        */
+        _fixIEMouseDown: function() {
+            if (Y.UA.ie) {
+                this._ieSelectBack = Y.config.doc.body.onselectstart;
+                Y.config.doc.body.onselectstart = this._ieSelectFix;
+            }           
+        },
+        /**
+        * @private
+        * @method _fixIEMouseUp
+        * @description This method copies the _ieSelectFix property back to the onselectstart listner on the document.
+        */
+        _fixIEMouseUp: function() {
+            if (Y.UA.ie) {
+                Y.config.doc.body.onselectstart = this._ieSelectBack;
+            }           
+        },
+        /**
+        * @private
+        * @method _handleMouseDownEvent
+        * @description Handler for the mousedown DOM event
+        * @param {Event}
+        */
+        _handleMouseDownEvent: function(ev) {
+            this.fire(EV_MOUSE_DOWN, { ev: ev });
+        },
+        /**
+        * @private
+        * @method _handleMouseDown
+        * @description Handler for the mousedown DOM event
+        * @param {Event}
+        */
+        _handleMouseDown: function(e) {
+            var ev = e.ev;
+            Y.log('_handleMouseDown', 'info', 'dd-drag');
+            this._dragThreshMet = false;
+            this._ev_md = ev;
+            
+            if (this.get('primaryButtonOnly') && ev.button > 1) {
+                Y.log('Mousedown was not produced by the primary button', 'warn', 'dd-drag');
+                return false;
+            }
+            if (this.validClick(ev)) {
+                this._fixIEMouseDown();
+                ev.halt();
+                this._setStartPosition([ev.pageX, ev.pageY]);
+
+                DDM.activeDrag = this;
+
+                var self = this;
+                this._clickTimeout = setTimeout(function() {
+                    self._timeoutCheck.call(self);
+                }, this.get('clickTimeThresh'));
+            }
+            this.fire(EV_AFTER_MOUSE_DOWN, { ev: ev });
+        },
+        /**
+        * @method validClick
+        * @description Method first checks to see if we have handles, if so it validates the click against the handle. Then if it finds a valid handle, it checks it against the invalid handles list. Returns true if a good handle was used, false otherwise.
+        * @param {Event}
+        * @return {Boolean}
+        */
+        validClick: function(ev) {
+            var r = false,
+            tar = ev.target,
+            hTest = null;
+            if (this._handles) {
+                Y.log('validClick: We have handles', 'info', 'dd-drag');
+                Y.each(this._handles, function(i, n) {
+                    if (Y.Lang.isString(n)) {
+                        //Am I this or am I inside this
+                        if (tar.test(n + ', ' + n + ' *') && !hTest) {
+                            Y.log('Valid Selector found: ' + n, 'info', 'dd-drag');
+                            hTest = n;
+                            r = true;
+                        }
+                    }
+                });
+            } else {
+                if (this.get(NODE).contains(tar) || this.get(NODE).compareTo(tar)) {
+                    Y.log('validClick: We have a valid click', 'info', 'dd-drag');
+                    r = true;
+                }
+            }
+            if (r) {
+                Y.log('validClick: Check invalid selectors', 'info', 'dd-drag');
+                if (this._invalids) {
+                    Y.each(this._invalids, function(i, n) {
+                        if (Y.Lang.isString(n)) {
+                            //Am I this or am I inside this
+                            if (tar.test(n + ', ' + n + ' *')) {
+                                Y.log('Invalid Selector found: (' + (n + ', ' + n + ' *') + ')', 'warn', 'dd-drag');
+                                r = false;
+                            }
+                        }
+                    });
+                }
+            }
+            if (r) {
+                if (hTest) {
+                    var els = ev.currentTarget.queryAll(hTest),
+                        set = false;
+                    els.each(function(n, i) {
+                        if ((n.contains(tar) || n.compareTo(tar)) && !set) {
+                            set = true;
+                            this.set('activeHandle', els.item(i));
+                        }
+                    }, this);
+                } else {
+                    this.set('activeHandle', this.get(NODE));
+                }
+            }
+            return r;
+        },
+        /**
+        * @private
+        * @method _setStartPosition
+        * @description Sets the current position of the Element and calculates the offset
+        * @param {Array} xy The XY coords to set the position to.
+        */
+        _setStartPosition: function(xy) {
+            this.startXY = xy;
+            
+            this.nodeXY = this.get(NODE).getXY();
+            this.lastXY = this.nodeXY;
+            this.realXY = this.nodeXY;
+
+            if (this.get('offsetNode')) {
+                this.deltaXY = [(this.startXY[0] - this.nodeXY[0]), (this.startXY[1] - this.nodeXY[1])];
+            } else {
+                this.deltaXY = [0, 0];
+            }
+        },
+        /**
+        * @private
+        * @method _timeoutCheck
+        * @description The method passed to setTimeout to determine if the clickTimeThreshold was met.
+        */
+        _timeoutCheck: function() {
+            if (!this.get('lock')) {
+                Y.log("timeout threshold met", "info", "dd-drag");
+                this._fromTimeout = true;
+                this._dragThreshMet = true;
+                this.start();
+                this._moveNode([this._ev_md.pageX, this._ev_md.pageY], true);
+            }
+        },
+        /**
+        * @method removeHandle
+        * @description Remove a Selector added by addHandle
+        * @param {String} str The selector for the handle to be removed. 
+        * @return {Self}
+        * @chainable
+        */
+        removeHandle: function(str) {
+            if (this._handles[str]) {
+                delete this._handles[str];
+                this.fire(EV_REMOVE_HANDLE, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method addHandle
+        * @description Add a handle to a drag element. Drag only initiates when a mousedown happens on this element.
+        * @param {String} str The selector to test for a valid handle. Must be a child of the element.
+        * @return {Self}
+        * @chainable
+        */
+        addHandle: function(str) {
+            if (!this._handles) {
+                this._handles = {};
+            }
+            if (Y.Lang.isString(str)) {
+                this._handles[str] = true;
+                this.fire(EV_ADD_HANDLE, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method removeInvalid
+        * @description Remove an invalid handle added by addInvalid
+        * @param {String} str The invalid handle to remove from the internal list.
+        * @return {Self}
+        * @chainable
+        */
+        removeInvalid: function(str) {
+            if (this._invalids[str]) {
+                this._invalids[str] = null;
+                delete this._invalids[str];
+                this.fire(EV_REMOVE_INVALID, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method addInvalid
+        * @description Add a selector string to test the handle against. If the test passes the drag operation will not continue.
+        * @param {String} str The selector to test against to determine if this is an invalid drag handle.
+        * @return {Self}
+        * @chainable
+        */
+        addInvalid: function(str) {
+            if (Y.Lang.isString(str)) {
+                this._invalids[str] = true;
+                this.fire(EV_ADD_INVALID, { handle: str });
+            } else {
+                Y.log('Selector needs to be a string..', 'warn', 'dd-drag');
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Internal init handler
+        */
+        initializer: function() {
+            //TODO give the node instance a copy of this object
+            //Not supported in PR1 due to Y.Node.get calling a new under the hood.
+            //this.get(NODE).dd = this;
+
+            if (!this.get(NODE).get('id')) {
+                var id = Y.stamp(this.get(NODE));
+                this.get(NODE).set('id', id);
+            }
+            
+
+            this._invalids = Y.clone(this._invalidsDefault, true);
+
+            this._createEvents();
+            
+            if (!this.get(DRAG_NODE)) {
+                this.set(DRAG_NODE, this.get(NODE));
+            }
+            this._prep();
+            this._dragThreshMet = false;
+        },
+        /**
+        * @private
+        * @method _prep
+        * @description Attach event listners and add classname
+        */
+        _prep: function() {
+            var node = this.get(NODE);
+            node.addClass(DDM.CSS_PREFIX + '-draggable');
+            node.on(MOUSE_DOWN, this._handleMouseDownEvent, this, true);
+            node.on(MOUSE_UP, this._handleMouseUp, this, true);
+            node.on(DRAG_START, this._fixDragStart, this, true);
+        },
+        /**
+        * @private
+        * @method _unprep
+        * @description Detach event listners and remove classname
+        */
+        _unprep: function() {
+            var node = this.get(NODE);
+            node.removeClass(DDM.CSS_PREFIX + '-draggable');
+            node.detach(MOUSE_DOWN, this._handleMouseDownEvent, this, true);
+            node.detach(MOUSE_UP, this._handleMouseUp, this, true);
+            node.detach(DRAG_START, this._fixDragStart, this, true);
+        },
+        /**
+        * @method start
+        * @description Starts the drag operation
+        * @return {Self}
+        * @chainable
+        */
+        start: function() {
+            if (!this.get('lock') && !this.get('dragging')) {
+                this.set('dragging', true);
+                DDM._start(this.deltaXY, [this.get(NODE).get(OFFSET_HEIGHT), this.get(NODE).get(OFFSET_WIDTH)]);
+                Y.log('startDrag', 'info', 'dd-drag');
+                this.get(NODE).addClass(DDM.CSS_PREFIX + '-dragging');
+                this.fire(EV_START, { pageX: this.nodeXY[0], pageY: this.nodeXY[1] });
+                this.get(DRAG_NODE).on(MOUSE_UP, this._handleMouseUp, this, true);
+                var xy = this.nodeXY;
+
+                this._startTime = (new Date()).getTime();
+                
+                this.region = {
+                    '0': xy[0], 
+                    '1': xy[1],
+                    area: 0,
+                    top: xy[1],
+                    right: xy[0] + this.get(NODE).get(OFFSET_WIDTH),
+                    bottom: xy[1] + this.get(NODE).get(OFFSET_HEIGHT),
+                    left: xy[0]
+                };
+                
+            }
+            return this;
+        },
+        /**
+        * @method end
+        * @description Ends the drag operation
+        * @return {Self}
+        * @chainable
+        */
+        end: function() {
+            this._endTime = (new Date()).getTime();
+            clearTimeout(this._clickTimeout);
+            this._dragThreshMet = false;
+            this._fromTimeout = false;
+            if (!this.get('lock') && this.get('dragging')) {
+                Y.log('endDrag', 'info', 'dd-drag');
+                this.fire(EV_END, { pageX: this.lastXY[0], pageY: this.lastXY[1] });
+            }
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-dragging');
+            this.set('dragging', false);
+            this.deltaXY = [0, 0];
+            this.get(DRAG_NODE).detach(MOUSE_UP, this._handleMouseUp, this, true);
+
+            return this;
+        },
+        /**
+        * @private
+        * @method _align
+        * @description Calculates the offsets and set's the XY that the element will move to.
+        * @param {Array} xy The xy coords to align with.
+        * @return Array
+        * @type {Array}
+        */
+        _align: function(xy) {
+            return [xy[0] - this.deltaXY[0], xy[1] - this.deltaXY[1]];
+        },
+        /**
+        * @private
+        * @method _moveNode
+        * @description This method performs the actual element move.
+        * @param {Array} eXY The XY to move the element to, usually comes from the mousemove DOM event.
+        * @param {Boolean} noFire If true, the drag:drag event will not fire.
+        */
+        _moveNode: function(eXY, noFire) {
+            var xy = this._align(eXY), diffXY = [], diffXY2 = [];
+
+            //This will probably kill your machine ;)
+            //Y.log('dragging..', 'info', 'dd-drag');
+            diffXY[0] = (xy[0] - this.lastXY[0]);
+            diffXY[1] = (xy[1] - this.lastXY[1]);
+
+            diffXY2[0] = (xy[0] - this.nodeXY[0]);
+            diffXY2[1] = (xy[1] - this.nodeXY[1]);
+
+
+            if (this.get('move')) {
+                if (Y.UA.opera) {
+                    this.get(DRAG_NODE).setXY(xy);
+                } else {
+                    DDM.setXY(this.get(DRAG_NODE), diffXY);
+                }
+                this.realXY = xy;
+            }
+
+            this.region = {
+                '0': xy[0], 
+                '1': xy[1],
+                area: 0,
+                top: xy[1],
+                right: xy[0] + this.get(DRAG_NODE).get(OFFSET_WIDTH),
+                bottom: xy[1] + this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                left: xy[0]
+            };
+
+            var startXY = this.nodeXY;
+            if (!noFire) {
+                this.fire(EV_DRAG, {
+                    pageX: xy[0],
+                    pageY: xy[1],
+                    info: {
+                        start: startXY,
+                        xy: xy,
+                        delta: diffXY,
+                        offset: diffXY2
+                    } 
+                });
+            }
+            
+            this.lastXY = xy;
+        },
+        /**
+        * @private
+        * @method _move
+        * @description Fired from DragDropMgr (DDM) on mousemove.
+        * @param {Event} ev The mousemove DOM event
+        */
+        _move: function(ev) {
+            if (this.get('lock')) {
+                Y.log('Drag Locked', 'warn', 'dd-drag');
+                return false;
+            } else {
+                this.mouseXY = [ev.pageX, ev.pageY];
+                if (!this._dragThreshMet) {
+                    var diffX = Math.abs(this.startXY[0] - ev.pageX);
+                    var diffY = Math.abs(this.startXY[1] - ev.pageY);
+                    Y.log("diffX: " + diffX + ", diffY: " + diffY, 'info', 'dd-drag');
+                    if (diffX > this.get('clickPixelThresh') || diffY > this.get('clickPixelThresh')) {
+                        Y.log("pixel threshold met", "info", "dd-drag");
+                        this._dragThreshMet = true;
+                        this.start();
+                        this._moveNode([ev.pageX, ev.pageY]);
+                    }
+                
+                } else {
+                    clearTimeout(this._clickTimeout);
+                    this._moveNode([ev.pageX, ev.pageY]);
+                }
+            }
+        },
+        /**
+        * @method stopDrag
+        * @description Method will forcefully stop a drag operation. For example calling this from inside an ESC keypress handler will stop this drag.
+        * @return {Self}
+        * @chainable
+        */
+        stopDrag: function() {
+            if (this.get('dragging')) {
+                Y.log('stopDrag called', 'warn', 'dd-drag');
+                DDM._end();
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method destructor
+        * @description Lifecycle destructor, unreg the drag from the DDM and remove listeners
+        */
+        destructor: function() {
+            DDM._unregDrag(this);
+
+            this._unprep();
+            if (this.target) {
+                this.target.destroy();
+            }
+        }
+    });
+    Y.namespace('DD');    
+    Y.DD.Drag = Drag;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-base'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-drag-min.js'
--- loggerhead/static/javascript/yui/build/dd/dd-drag-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-drag-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dd-drag",function(D){var E=D.DD.DDM,S="node",M="dragNode",C="offsetHeight",J="offsetWidth",Q="mouseup",O="mousedown",L="dragstart",G="drag:mouseDown",B="drag:afterMouseDown",F="drag:removeHandle",K="drag:addHandle",P="drag:removeInvalid",R="drag:addInvalid",I="drag:start",H="drag:end",N="drag:drag";var A=function(){A.superclass.constructor.apply(this,arguments);E._regDrag(this);};A.NAME="drag";A.ATTRS={node:{set:function(T){var U=D.get(T);if(!U){D.fail("DD.Drag: Invalid Node Given: "+T);}else{U=U.item(0);}return U;}},dragNode:{set:function(T){var U=D.Node.get(T);if(!U){D.fail("DD.Drag: Invalid dragNode Given: "+T);}return U;}},offsetNode:{value:true},clickPixelThresh:{value:E.get("clickPixelThresh")},clickTimeThresh:{value:E.get("clickTimeThresh")},lock:{value:false,set:function(T){if(T){this.get(S).addClass(E.CSS_PREFIX+"-locked");}else{this.get(S).removeClass(E.CSS_PREFIX+"-locked");}}},data:{value:false},move:{value:true},useShim:{value:true},activeHandle:{value:false},primaryButtonOnly:{value:true},dragging:{value:false},parent:{value:false},target:{value:false,set:function(T){this._handleTarget(T);}},dragMode:{value:null,set:function(T){return E._setDragMode(T);}},groups:{value:["default"],get:function(){if(!this._groups){this._groups={};}var T=[];D.each(this._groups,function(V,U){T[T.length]=U;});return T;},set:function(T){this._groups={};D.each(T,function(V,U){this._groups[V]=true;},this);}},handles:{value:null,set:function(T){if(T){this._handles={};D.each(T,function(V,U){this._handles[V]=true;},this);}else{this._handles=null;}return T;}},bubbles:{writeOnce:true,value:D.DD.DDM}};D.extend(A,D.Base,{addToGroup:function(T){this._groups[T]=true;E._activateTargets();return this;},removeFromGroup:function(T){delete this._groups[T];E._activateTargets();return this;},target:null,_handleTarget:function(T){if(D.DD.Drop){if(T===false){if(this.target){E._unregTarget(this.target);this.target=null;}return false;}else{if(!D.Lang.isObject(T)){T={};}T.bubbles=this.get("bubbles");T.node=this.get(S);this.target=new D.DD.Drop(T);}}else{return false;}},_groups:null,_createEvents:function(){this.publish(G,{defaultFn:this._handleMouseDown,queuable:true,emitFacade:true,bubbles:true});var T=[B,F,K,P,R,I,H,N,"drag:drophit","drag:dropmiss","drag:over","drag:enter","drag:exit"];D.each(T,function(V,U){this.publish(V,{type:V,emitFacade:true,bubbles:true,preventable:false,queuable:true});},this);if(this.get("bubbles")){this.addTarget(this.get("bubbles"));}},_ev_md:null,_startTime:null,_endTime:null,_handles:null,_invalids:null,_invalidsDefault:{"textarea":true,"input":true,"a":true,"button":true},_dragThreshMet:null,_fromTimeout:null,_clickTimeout:null,deltaXY:null,startXY:null,nodeXY:null,lastXY:null,realXY:null,mouseXY:null,region:null,_handleMouseUp:function(T){this._fixIEMouseUp();if(E.activeDrag){E._end();}},_fixDragStart:function(T){T.preventDefault();},_ieSelectFix:function(){return false;},_ieSelectBack:null,_fixIEMouseDown:function(){if(D.UA.ie){this._ieSelectBack=D.config.doc.body.onselectstart;D.config.doc.body.onselectstart=this._ieSelectFix;}},_fixIEMouseUp:function(){if(D.UA.ie){D.config.doc.body.onselectstart=this._ieSelectBack;}},_handleMouseDownEvent:function(T){this.fire(G,{ev:T});},_handleMouseDown:function(V){var U=V.ev;this._dragThreshMet=false;this._ev_md=U;if(this.get("primaryButtonOnly")&&U.button>1){return false;}if(this.validClick(U)){this._fixIEMouseDown();U.halt();this._setStartPosition([U.pageX,U.pageY]);E.activeDrag=this;var T=this;this._clickTimeout=setTimeout(function(){T._timeoutCheck.call(T);},this.get("clickTimeThresh"));}this.fire(B,{ev:U});},validClick:function(X){var W=false,T=X.target,V=null;if(this._handles){D.each(this._handles,function(Z,a){if(D.Lang.isString(a)){if(T.test(a+", "+a+" *")&&!V){V=a;W=true;}}});}else{if(this.get(S).contains(T)||this.get(S).compareTo(T)){W=true;}}if(W){if(this._invalids){D.each(this._invalids,function(Z,a){if(D.Lang.isString(a)){if(T.test(a+", "+a+" *")){W=false;}}});}}if(W){if(V){var U=X.currentTarget.queryAll(V),Y=false;U.each(function(a,Z){if((a.contains(T)||a.compareTo(T))&&!Y){Y=true;this.set("activeHandle",U.item(Z));}},this);}else{this.set("activeHandle",this.get(S));}}return W;},_setStartPosition:function(T){this.startXY=T;this.nodeXY=this.get(S).getXY();this.lastXY=this.nodeXY;this.realXY=this.nodeXY;if(this.get("offsetNode")){this.deltaXY=[(this.startXY[0]-this.nodeXY[0]),(this.startXY[1]-this.nodeXY[1])];}else{this.deltaXY=[0,0];}},_timeoutCheck:function(){if(!this.get("lock")){this._fromTimeout=true;this._dragThreshMet=true;this.start();this._moveNode([this._ev_md.pageX,this._ev_md.pageY],true);}},removeHandle:function(T){if(this._handles[T]){delete this._handles[T];this.fire(F,{handle:T});}return this;},addHandle:function(T){if(!this._handles){this._handles={};}if(D.Lang.isString(T)){this._handles[T]=true;this.fire(K,{handle:T});}return this;},removeInvalid:function(T){if(this._invalids[T]){this._invalids[T]=null;delete this._invalids[T];this.fire(P,{handle:T});}return this;},addInvalid:function(T){if(D.Lang.isString(T)){this._invalids[T]=true;this.fire(R,{handle:T});}else{}return this;},initializer:function(){if(!this.get(S).get("id")){var T=D.stamp(this.get(S));this.get(S).set("id",T);}this._invalids=D.clone(this._invalidsDefault,true);this._createEvents();if(!this.get(M)){this.set(M,this.get(S));}this._prep();this._dragThreshMet=false;},_prep:function(){var T=this.get(S);T.addClass(E.CSS_PREFIX+"-draggable");T.on(O,this._handleMouseDownEvent,this,true);T.on(Q,this._handleMouseUp,this,true);T.on(L,this._fixDragStart,this,true);},_unprep:function(){var T=this.get(S);T.removeClass(E.CSS_PREFIX+"-draggable");T.detach(O,this._handleMouseDownEvent,this,true);T.detach(Q,this._handleMouseUp,this,true);T.detach(L,this._fixDragStart,this,true);},start:function(){if(!this.get("lock")&&!this.get("dragging")){this.set("dragging",true);E._start(this.deltaXY,[this.get(S).get(C),this.get(S).get(J)]);this.get(S).addClass(E.CSS_PREFIX+"-dragging");
+this.fire(I,{pageX:this.nodeXY[0],pageY:this.nodeXY[1]});this.get(M).on(Q,this._handleMouseUp,this,true);var T=this.nodeXY;this._startTime=(new Date()).getTime();this.region={"0":T[0],"1":T[1],area:0,top:T[1],right:T[0]+this.get(S).get(J),bottom:T[1]+this.get(S).get(C),left:T[0]};}return this;},end:function(){this._endTime=(new Date()).getTime();clearTimeout(this._clickTimeout);this._dragThreshMet=false;this._fromTimeout=false;if(!this.get("lock")&&this.get("dragging")){this.fire(H,{pageX:this.lastXY[0],pageY:this.lastXY[1]});}this.get(S).removeClass(E.CSS_PREFIX+"-dragging");this.set("dragging",false);this.deltaXY=[0,0];this.get(M).detach(Q,this._handleMouseUp,this,true);return this;},_align:function(T){return[T[0]-this.deltaXY[0],T[1]-this.deltaXY[1]];},_moveNode:function(T,Y){var X=this._align(T),U=[],V=[];U[0]=(X[0]-this.lastXY[0]);U[1]=(X[1]-this.lastXY[1]);V[0]=(X[0]-this.nodeXY[0]);V[1]=(X[1]-this.nodeXY[1]);if(this.get("move")){if(D.UA.opera){this.get(M).setXY(X);}else{E.setXY(this.get(M),U);}this.realXY=X;}this.region={"0":X[0],"1":X[1],area:0,top:X[1],right:X[0]+this.get(M).get(J),bottom:X[1]+this.get(M).get(C),left:X[0]};var W=this.nodeXY;if(!Y){this.fire(N,{pageX:X[0],pageY:X[1],info:{start:W,xy:X,delta:U,offset:V}});}this.lastXY=X;},_move:function(V){if(this.get("lock")){return false;}else{this.mouseXY=[V.pageX,V.pageY];if(!this._dragThreshMet){var U=Math.abs(this.startXY[0]-V.pageX);var T=Math.abs(this.startXY[1]-V.pageY);if(U>this.get("clickPixelThresh")||T>this.get("clickPixelThresh")){this._dragThreshMet=true;this.start();this._moveNode([V.pageX,V.pageY]);}}else{clearTimeout(this._clickTimeout);this._moveNode([V.pageX,V.pageY]);}}},stopDrag:function(){if(this.get("dragging")){E._end();}return this;},destructor:function(){E._unregDrag(this);this._unprep();if(this.target){this.target.destroy();}}});D.namespace("DD");D.DD.Drag=A;},"3.0.0pr2",{requires:["dd-ddm-base"],skinnable:false});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-drag.js'
--- loggerhead/static/javascript/yui/build/dd/dd-drag.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-drag.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1004 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-drag', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-drag
+     */     
+    /**
+     * This class provides the ability to drag a Node.
+     * @class Drag
+     * @extends Base
+     * @constructor
+     */
+
+    var DDM = Y.DD.DDM,
+        NODE = 'node',
+        DRAG_NODE = 'dragNode',
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth',        
+        MOUSE_UP = 'mouseup',
+        MOUSE_DOWN = 'mousedown',
+        DRAG_START = 'dragstart',
+        /**
+        * @event drag:mouseDown
+        * @description Handles the mousedown DOM event, checks to see if you have a valid handle then starts the drag timers.
+        * @preventable _handleMouseDown
+        * @param {Event} ev The mousedown event.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_MOUSE_DOWN = 'drag:mouseDown',
+        /**
+        * @event drag:afterMouseDown
+        * @description Fires after the mousedown event has been cleared.
+        * @param {Event} ev The mousedown event.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_AFTER_MOUSE_DOWN = 'drag:afterMouseDown',
+        /**
+        * @event drag:removeHandle
+        * @description Fires after a handle is removed.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_REMOVE_HANDLE = 'drag:removeHandle',
+        /**
+        * @event drag:addHandle
+        * @description Fires after a handle is added.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_ADD_HANDLE = 'drag:addHandle',
+        /**
+        * @event drag:removeInvalid
+        * @description Fires after an invalid selector is removed.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_REMOVE_INVALID = 'drag:removeInvalid',
+        /**
+        * @event drag:addInvalid
+        * @description Fires after an invalid selector is added.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_ADD_INVALID = 'drag:addInvalid',
+        /**
+        * @event drag:start
+        * @description Fires at the start of a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_START = 'drag:start',
+        /**
+        * @event drag:end
+        * @description Fires at the end of a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_END = 'drag:end',
+        /**
+        * @event drag:drag
+        * @description Fires every mousemove during a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DRAG = 'drag:drag';
+
+
+        /**
+        * @event drag:over
+        * @description Fires when this node is over a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:enter
+        * @description Fires when this node enters a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:exit
+        * @description Fires when this node exits a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:drophit
+        * @description Fires when this node is dropped on a valid Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:dropmiss
+        * @description Fires when this node is dropped on an invalid Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+    
+    var Drag = function() {
+        Drag.superclass.constructor.apply(this, arguments);
+
+        DDM._regDrag(this);
+    };
+
+    Drag.NAME = 'drag';
+
+    Drag.ATTRS = {
+        /**
+        * @attribute node
+        * @description Y.Node instanace to use as the element to initiate a drag operation
+        * @type Node
+        */
+        node: {
+            set: function(node) {
+                var n = Y.get(node);
+                if (!n) {
+                    Y.fail('DD.Drag: Invalid Node Given: ' + node);
+                } else {
+                    n = n.item(0);
+                }
+                return n;
+            }
+        },
+        /**
+        * @attribute dragNode
+        * @description Y.Node instanace to use as the draggable element, defaults to node
+        * @type Node
+        */
+        dragNode: {
+            set: function(node) {
+                var n = Y.Node.get(node);
+                if (!n) {
+                    Y.fail('DD.Drag: Invalid dragNode Given: ' + node);
+                }
+                return n;
+            }
+        },
+        /**
+        * @attribute offsetNode
+        * @description Offset the drag element by the difference in cursor position: default true
+        * @type Boolean
+        */
+        offsetNode: {
+            value: true
+        },
+        /**
+        * @attribute clickPixelThresh
+        * @description The number of pixels to move to start a drag operation, default is 3.
+        * @type Number
+        */
+        clickPixelThresh: {
+            value: DDM.get('clickPixelThresh')
+        },
+        /**
+        * @attribute clickTimeThresh
+        * @description The number of milliseconds a mousedown has to pass to start a drag operation, default is 1000.
+        * @type Number
+        */
+        clickTimeThresh: {
+            value: DDM.get('clickTimeThresh')
+        },
+        /**
+        * @attribute lock
+        * @description Set to lock this drag element so that it can't be dragged: default false.
+        * @type Boolean
+        */
+        lock: {
+            value: false,
+            set: function(lock) {
+                if (lock) {
+                    this.get(NODE).addClass(DDM.CSS_PREFIX + '-locked');
+                } else {
+                    this.get(NODE).removeClass(DDM.CSS_PREFIX + '-locked');
+                }
+            }
+        },
+        /**
+        * @attribute data
+        * @description A payload holder to store arbitrary data about this drag object, can be used to store any value.
+        * @type Mixed
+        */
+        data: {
+            value: false
+        },
+        /**
+        * @attribute move
+        * @description If this is false, the drag element will not move with the cursor: default true. Can be used to "resize" the element.
+        * @type Boolean
+        */
+        move: {
+            value: true
+        },
+        /**
+        * @attribute useShim
+        * @description Use the protective shim on all drag operations: default true. Only works with dd-ddm, not dd-ddm-base.
+        * @type Boolean
+        */
+        useShim: {
+            value: true
+        },
+        /**
+        * @attribute activeHandle
+        * @description This config option is set by Drag to inform you of which handle fired the drag event (in the case that there are several handles): default false.
+        * @type Node
+        */
+        activeHandle: {
+            value: false
+        },
+        /**
+        * @attribute primaryButtonOnly
+        * @description By default a drag operation will only begin if the mousedown occurred with the primary mouse button. Setting this to false will allow for all mousedown events to trigger a drag.
+        * @type Boolean
+        */
+        primaryButtonOnly: {
+            value: true
+        },
+        /**
+        * @attribute dragging
+        * @description This attribute is not meant to be used by the implementor, it is meant to be used as an Event tracker so you can listen for it to change.
+        * @type Boolean
+        */
+        dragging: {
+            value: false
+        },
+        parent: {
+            value: false
+        },
+        /**
+        * @attribute target
+        * @description This attribute only works if the dd-drop module has been loaded. It will make this node a drop target as well as draggable.
+        * @type Boolean
+        */
+        target: {
+            value: false,
+            set: function(config) {
+                this._handleTarget(config);
+            }
+        },
+        /**
+        * @attribute dragMode
+        * @description This attribute only works if the dd-drop module is active. It will set the dragMode (point, intersect, strict) of this Drag instance.
+        * @type String
+        */
+        dragMode: {
+            value: null,
+            set: function(mode) {
+                return DDM._setDragMode(mode);
+            }
+        },
+        /**
+        * @attribute groups
+        * @description Array of groups to add this drag into.
+        * @type Array
+        */
+        groups: {
+            value: ['default'],
+            get: function() {
+                if (!this._groups) {
+                    this._groups = {};
+                }
+                var ret = [];
+                Y.each(this._groups, function(v, k) {
+                    ret[ret.length] = k;
+                });
+                return ret;
+            },
+            set: function(g) {
+                this._groups = {};
+                Y.each(g, function(v, k) {
+                    this._groups[v] = true;
+                }, this);
+            }
+        },
+        /**
+        * @attribute handles
+        * @description Array of valid handles to add. Adding something here will set all handles, even if previously added with addHandle
+        * @type Array
+        */
+        handles: {
+            value: null,
+            set: function(g) {
+                if (g) {
+                    this._handles = {};
+                    Y.each(g, function(v, k) {
+                        this._handles[v] = true;
+                    }, this);
+                } else {
+                    this._handles = null;
+                }
+                return g;
+            }
+        },
+        /**
+        * @attribute bubbles
+        * @description Controls the default bubble parent for this Drag instance. Default: Y.DD.DDM. Set to false to disable bubbling.
+        * @type Object
+        */
+        bubbles: {
+            writeOnce: true,
+            value: Y.DD.DDM
+        }
+    };
+
+    Y.extend(Drag, Y.Base, {
+        /**
+        * @method addToGroup
+        * @description Add this Drag instance to a group, this should be used for on-the-fly group additions.
+        * @param {String} g The group to add this Drag Instance to.
+        * @return {Self}
+        * @chainable
+        */
+        addToGroup: function(g) {
+            this._groups[g] = true;
+            DDM._activateTargets();
+            return this;
+        },
+        /**
+        * @method removeFromGroup
+        * @description Remove this Drag instance from a group, this should be used for on-the-fly group removals.
+        * @param {String} g The group to remove this Drag Instance from.
+        * @return {Self}
+        * @chainable
+        */
+        removeFromGroup: function(g) {
+            delete this._groups[g];
+            DDM._activateTargets();
+            return this;
+        },
+        /**
+        * @property target
+        * @description This will be a reference to the Drop instance associated with this drag if the target: true config attribute is set..
+        * @type {Object}
+        */
+        target: null,
+        /**
+        * @private
+        * @method _handleTarget
+        * @description Attribute handler for the target config attribute.
+        * @param {Boolean/Object}
+        * @return {Boolean/Object}
+        */
+        _handleTarget: function(config) {
+            if (Y.DD.Drop) {
+                if (config === false) {
+                    if (this.target) {
+                        DDM._unregTarget(this.target);
+                        this.target = null;
+                    }
+                    return false;
+                } else {
+                    if (!Y.Lang.isObject(config)) {
+                        config = {};
+                    }
+                    config.bubbles = this.get('bubbles');
+                    config.node = this.get(NODE);
+                    this.target = new Y.DD.Drop(config);
+                }
+            } else {
+                return false;
+            }
+        },
+        /**
+        * @private
+        * @property _groups
+        * @description Storage Array for the groups this drag belongs to.
+        * @type {Array}
+        */
+        _groups: null,
+        /**
+        * @private
+        * @method _createEvents
+        * @description This method creates all the events for this Event Target and publishes them so we get Event Bubbling.
+        */
+        _createEvents: function() {
+            
+            this.publish(EV_MOUSE_DOWN, {
+                defaultFn: this._handleMouseDown,
+                queuable: true,
+                emitFacade: true,
+                bubbles: true
+            });
+            
+            var ev = [
+                EV_AFTER_MOUSE_DOWN,
+                EV_REMOVE_HANDLE,
+                EV_ADD_HANDLE,
+                EV_REMOVE_INVALID,
+                EV_ADD_INVALID,
+                EV_START,
+                EV_END,
+                EV_DRAG,
+                'drag:drophit',
+                'drag:dropmiss',
+                'drag:over',
+                'drag:enter',
+                'drag:exit'
+            ];
+            
+            Y.each(ev, function(v, k) {
+                this.publish(v, {
+                    type: v,
+                    emitFacade: true,
+                    bubbles: true,
+                    preventable: false,
+                    queuable: true
+                });
+            }, this);
+
+            if (this.get('bubbles')) {
+                this.addTarget(this.get('bubbles'));
+            }
+            
+           
+        },
+        /**
+        * @private
+        * @property _ev_md
+        * @description A private reference to the mousedown DOM event
+        * @type {Event}
+        */
+        _ev_md: null,
+        /**
+        * @private
+        * @property _startTime
+        * @description The getTime of the mousedown event. Not used, just here in case someone wants/needs to use it.
+        * @type Date
+        */
+        _startTime: null,
+        /**
+        * @private
+        * @property _endTime
+        * @description The getTime of the mouseup event. Not used, just here in case someone wants/needs to use it.
+        * @type Date
+        */
+        _endTime: null,
+        /**
+        * @private
+        * @property _handles
+        * @description A private hash of the valid drag handles
+        * @type {Object}
+        */
+        _handles: null,
+        /**
+        * @private
+        * @property _invalids
+        * @description A private hash of the invalid selector strings
+        * @type {Object}
+        */
+        _invalids: null,
+        /**
+        * @private
+        * @property _invalidsDefault
+        * @description A private hash of the default invalid selector strings: {'textarea': true, 'input': true, 'a': true, 'button': true}
+        * @type {Object}
+        */
+        _invalidsDefault: {'textarea': true, 'input': true, 'a': true, 'button': true},
+        /**
+        * @private
+        * @property _dragThreshMet
+        * @description Private flag to see if the drag threshhold was met
+        * @type {Boolean}
+        */
+        _dragThreshMet: null,
+        /**
+        * @private
+        * @property _fromTimeout
+        * @description Flag to determine if the drag operation came from a timeout
+        * @type {Boolean}
+        */
+        _fromTimeout: null,
+        /**
+        * @private
+        * @property _clickTimeout
+        * @description Holder for the setTimeout call
+        * @type {Boolean}
+        */
+        _clickTimeout: null,
+        /**
+        * @property deltaXY
+        * @description The offset of the mouse position to the element's position
+        * @type {Array}
+        */
+        deltaXY: null,
+        /**
+        * @property startXY
+        * @description The initial mouse position
+        * @type {Array}
+        */
+        startXY: null,
+        /**
+        * @property nodeXY
+        * @description The initial element position
+        * @type {Array}
+        */
+        nodeXY: null,
+        /**
+        * @property lastXY
+        * @description The position of the element as it's moving (for offset calculations)
+        * @type {Array}
+        */
+        lastXY: null,
+        realXY: null,
+        /**
+        * @property mouseXY
+        * @description The XY coords of the mousemove
+        * @type {Array}
+        */
+        mouseXY: null,
+        /**
+        * @property region
+        * @description A region object associated with this drag, used for checking regions while dragging.
+        * @type Object
+        */
+        region: null,       
+        /**
+        * @private
+        * @method _handleMouseUp
+        * @description Handler for the mouseup DOM event
+        * @param {Event}
+        */
+        _handleMouseUp: function(ev) {
+            this._fixIEMouseUp();
+            if (DDM.activeDrag) {
+                DDM._end();
+            }
+        },
+        /** 
+        * @private
+        * @method _fixDragStart
+        * @description The function we use as the ondragstart handler when we start a drag in Internet Explorer. This keeps IE from blowing up on images as drag handles.
+        */
+        _fixDragStart: function(e) {
+            e.preventDefault();
+        },
+        /** 
+        * @private
+        * @method _ieSelectFix
+        * @description The function we use as the onselectstart handler when we start a drag in Internet Explorer
+        */
+        _ieSelectFix: function() {
+            return false;
+        },
+        /** 
+        * @private
+        * @property _ieSelectBack
+        * @description We will hold a copy of the current "onselectstart" method on this property, and reset it after we are done using it.
+        */
+        _ieSelectBack: null,
+        /**
+        * @private
+        * @method _fixIEMouseDown
+        * @description This method copies the onselectstart listner on the document to the _ieSelectFix property
+        */
+        _fixIEMouseDown: function() {
+            if (Y.UA.ie) {
+                this._ieSelectBack = Y.config.doc.body.onselectstart;
+                Y.config.doc.body.onselectstart = this._ieSelectFix;
+            }           
+        },
+        /**
+        * @private
+        * @method _fixIEMouseUp
+        * @description This method copies the _ieSelectFix property back to the onselectstart listner on the document.
+        */
+        _fixIEMouseUp: function() {
+            if (Y.UA.ie) {
+                Y.config.doc.body.onselectstart = this._ieSelectBack;
+            }           
+        },
+        /**
+        * @private
+        * @method _handleMouseDownEvent
+        * @description Handler for the mousedown DOM event
+        * @param {Event}
+        */
+        _handleMouseDownEvent: function(ev) {
+            this.fire(EV_MOUSE_DOWN, { ev: ev });
+        },
+        /**
+        * @private
+        * @method _handleMouseDown
+        * @description Handler for the mousedown DOM event
+        * @param {Event}
+        */
+        _handleMouseDown: function(e) {
+            var ev = e.ev;
+            this._dragThreshMet = false;
+            this._ev_md = ev;
+            
+            if (this.get('primaryButtonOnly') && ev.button > 1) {
+                return false;
+            }
+            if (this.validClick(ev)) {
+                this._fixIEMouseDown();
+                ev.halt();
+                this._setStartPosition([ev.pageX, ev.pageY]);
+
+                DDM.activeDrag = this;
+
+                var self = this;
+                this._clickTimeout = setTimeout(function() {
+                    self._timeoutCheck.call(self);
+                }, this.get('clickTimeThresh'));
+            }
+            this.fire(EV_AFTER_MOUSE_DOWN, { ev: ev });
+        },
+        /**
+        * @method validClick
+        * @description Method first checks to see if we have handles, if so it validates the click against the handle. Then if it finds a valid handle, it checks it against the invalid handles list. Returns true if a good handle was used, false otherwise.
+        * @param {Event}
+        * @return {Boolean}
+        */
+        validClick: function(ev) {
+            var r = false,
+            tar = ev.target,
+            hTest = null;
+            if (this._handles) {
+                Y.each(this._handles, function(i, n) {
+                    if (Y.Lang.isString(n)) {
+                        //Am I this or am I inside this
+                        if (tar.test(n + ', ' + n + ' *') && !hTest) {
+                            hTest = n;
+                            r = true;
+                        }
+                    }
+                });
+            } else {
+                if (this.get(NODE).contains(tar) || this.get(NODE).compareTo(tar)) {
+                    r = true;
+                }
+            }
+            if (r) {
+                if (this._invalids) {
+                    Y.each(this._invalids, function(i, n) {
+                        if (Y.Lang.isString(n)) {
+                            //Am I this or am I inside this
+                            if (tar.test(n + ', ' + n + ' *')) {
+                                r = false;
+                            }
+                        }
+                    });
+                }
+            }
+            if (r) {
+                if (hTest) {
+                    var els = ev.currentTarget.queryAll(hTest),
+                        set = false;
+                    els.each(function(n, i) {
+                        if ((n.contains(tar) || n.compareTo(tar)) && !set) {
+                            set = true;
+                            this.set('activeHandle', els.item(i));
+                        }
+                    }, this);
+                } else {
+                    this.set('activeHandle', this.get(NODE));
+                }
+            }
+            return r;
+        },
+        /**
+        * @private
+        * @method _setStartPosition
+        * @description Sets the current position of the Element and calculates the offset
+        * @param {Array} xy The XY coords to set the position to.
+        */
+        _setStartPosition: function(xy) {
+            this.startXY = xy;
+            
+            this.nodeXY = this.get(NODE).getXY();
+            this.lastXY = this.nodeXY;
+            this.realXY = this.nodeXY;
+
+            if (this.get('offsetNode')) {
+                this.deltaXY = [(this.startXY[0] - this.nodeXY[0]), (this.startXY[1] - this.nodeXY[1])];
+            } else {
+                this.deltaXY = [0, 0];
+            }
+        },
+        /**
+        * @private
+        * @method _timeoutCheck
+        * @description The method passed to setTimeout to determine if the clickTimeThreshold was met.
+        */
+        _timeoutCheck: function() {
+            if (!this.get('lock')) {
+                this._fromTimeout = true;
+                this._dragThreshMet = true;
+                this.start();
+                this._moveNode([this._ev_md.pageX, this._ev_md.pageY], true);
+            }
+        },
+        /**
+        * @method removeHandle
+        * @description Remove a Selector added by addHandle
+        * @param {String} str The selector for the handle to be removed. 
+        * @return {Self}
+        * @chainable
+        */
+        removeHandle: function(str) {
+            if (this._handles[str]) {
+                delete this._handles[str];
+                this.fire(EV_REMOVE_HANDLE, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method addHandle
+        * @description Add a handle to a drag element. Drag only initiates when a mousedown happens on this element.
+        * @param {String} str The selector to test for a valid handle. Must be a child of the element.
+        * @return {Self}
+        * @chainable
+        */
+        addHandle: function(str) {
+            if (!this._handles) {
+                this._handles = {};
+            }
+            if (Y.Lang.isString(str)) {
+                this._handles[str] = true;
+                this.fire(EV_ADD_HANDLE, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method removeInvalid
+        * @description Remove an invalid handle added by addInvalid
+        * @param {String} str The invalid handle to remove from the internal list.
+        * @return {Self}
+        * @chainable
+        */
+        removeInvalid: function(str) {
+            if (this._invalids[str]) {
+                this._invalids[str] = null;
+                delete this._invalids[str];
+                this.fire(EV_REMOVE_INVALID, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method addInvalid
+        * @description Add a selector string to test the handle against. If the test passes the drag operation will not continue.
+        * @param {String} str The selector to test against to determine if this is an invalid drag handle.
+        * @return {Self}
+        * @chainable
+        */
+        addInvalid: function(str) {
+            if (Y.Lang.isString(str)) {
+                this._invalids[str] = true;
+                this.fire(EV_ADD_INVALID, { handle: str });
+            } else {
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Internal init handler
+        */
+        initializer: function() {
+            //TODO give the node instance a copy of this object
+            //Not supported in PR1 due to Y.Node.get calling a new under the hood.
+            //this.get(NODE).dd = this;
+
+            if (!this.get(NODE).get('id')) {
+                var id = Y.stamp(this.get(NODE));
+                this.get(NODE).set('id', id);
+            }
+            
+
+            this._invalids = Y.clone(this._invalidsDefault, true);
+
+            this._createEvents();
+            
+            if (!this.get(DRAG_NODE)) {
+                this.set(DRAG_NODE, this.get(NODE));
+            }
+            this._prep();
+            this._dragThreshMet = false;
+        },
+        /**
+        * @private
+        * @method _prep
+        * @description Attach event listners and add classname
+        */
+        _prep: function() {
+            var node = this.get(NODE);
+            node.addClass(DDM.CSS_PREFIX + '-draggable');
+            node.on(MOUSE_DOWN, this._handleMouseDownEvent, this, true);
+            node.on(MOUSE_UP, this._handleMouseUp, this, true);
+            node.on(DRAG_START, this._fixDragStart, this, true);
+        },
+        /**
+        * @private
+        * @method _unprep
+        * @description Detach event listners and remove classname
+        */
+        _unprep: function() {
+            var node = this.get(NODE);
+            node.removeClass(DDM.CSS_PREFIX + '-draggable');
+            node.detach(MOUSE_DOWN, this._handleMouseDownEvent, this, true);
+            node.detach(MOUSE_UP, this._handleMouseUp, this, true);
+            node.detach(DRAG_START, this._fixDragStart, this, true);
+        },
+        /**
+        * @method start
+        * @description Starts the drag operation
+        * @return {Self}
+        * @chainable
+        */
+        start: function() {
+            if (!this.get('lock') && !this.get('dragging')) {
+                this.set('dragging', true);
+                DDM._start(this.deltaXY, [this.get(NODE).get(OFFSET_HEIGHT), this.get(NODE).get(OFFSET_WIDTH)]);
+                this.get(NODE).addClass(DDM.CSS_PREFIX + '-dragging');
+                this.fire(EV_START, { pageX: this.nodeXY[0], pageY: this.nodeXY[1] });
+                this.get(DRAG_NODE).on(MOUSE_UP, this._handleMouseUp, this, true);
+                var xy = this.nodeXY;
+
+                this._startTime = (new Date()).getTime();
+                
+                this.region = {
+                    '0': xy[0], 
+                    '1': xy[1],
+                    area: 0,
+                    top: xy[1],
+                    right: xy[0] + this.get(NODE).get(OFFSET_WIDTH),
+                    bottom: xy[1] + this.get(NODE).get(OFFSET_HEIGHT),
+                    left: xy[0]
+                };
+                
+            }
+            return this;
+        },
+        /**
+        * @method end
+        * @description Ends the drag operation
+        * @return {Self}
+        * @chainable
+        */
+        end: function() {
+            this._endTime = (new Date()).getTime();
+            clearTimeout(this._clickTimeout);
+            this._dragThreshMet = false;
+            this._fromTimeout = false;
+            if (!this.get('lock') && this.get('dragging')) {
+                this.fire(EV_END, { pageX: this.lastXY[0], pageY: this.lastXY[1] });
+            }
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-dragging');
+            this.set('dragging', false);
+            this.deltaXY = [0, 0];
+            this.get(DRAG_NODE).detach(MOUSE_UP, this._handleMouseUp, this, true);
+
+            return this;
+        },
+        /**
+        * @private
+        * @method _align
+        * @description Calculates the offsets and set's the XY that the element will move to.
+        * @param {Array} xy The xy coords to align with.
+        * @return Array
+        * @type {Array}
+        */
+        _align: function(xy) {
+            return [xy[0] - this.deltaXY[0], xy[1] - this.deltaXY[1]];
+        },
+        /**
+        * @private
+        * @method _moveNode
+        * @description This method performs the actual element move.
+        * @param {Array} eXY The XY to move the element to, usually comes from the mousemove DOM event.
+        * @param {Boolean} noFire If true, the drag:drag event will not fire.
+        */
+        _moveNode: function(eXY, noFire) {
+            var xy = this._align(eXY), diffXY = [], diffXY2 = [];
+
+            //This will probably kill your machine ;)
+            diffXY[0] = (xy[0] - this.lastXY[0]);
+            diffXY[1] = (xy[1] - this.lastXY[1]);
+
+            diffXY2[0] = (xy[0] - this.nodeXY[0]);
+            diffXY2[1] = (xy[1] - this.nodeXY[1]);
+
+
+            if (this.get('move')) {
+                if (Y.UA.opera) {
+                    this.get(DRAG_NODE).setXY(xy);
+                } else {
+                    DDM.setXY(this.get(DRAG_NODE), diffXY);
+                }
+                this.realXY = xy;
+            }
+
+            this.region = {
+                '0': xy[0], 
+                '1': xy[1],
+                area: 0,
+                top: xy[1],
+                right: xy[0] + this.get(DRAG_NODE).get(OFFSET_WIDTH),
+                bottom: xy[1] + this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                left: xy[0]
+            };
+
+            var startXY = this.nodeXY;
+            if (!noFire) {
+                this.fire(EV_DRAG, {
+                    pageX: xy[0],
+                    pageY: xy[1],
+                    info: {
+                        start: startXY,
+                        xy: xy,
+                        delta: diffXY,
+                        offset: diffXY2
+                    } 
+                });
+            }
+            
+            this.lastXY = xy;
+        },
+        /**
+        * @private
+        * @method _move
+        * @description Fired from DragDropMgr (DDM) on mousemove.
+        * @param {Event} ev The mousemove DOM event
+        */
+        _move: function(ev) {
+            if (this.get('lock')) {
+                return false;
+            } else {
+                this.mouseXY = [ev.pageX, ev.pageY];
+                if (!this._dragThreshMet) {
+                    var diffX = Math.abs(this.startXY[0] - ev.pageX);
+                    var diffY = Math.abs(this.startXY[1] - ev.pageY);
+                    if (diffX > this.get('clickPixelThresh') || diffY > this.get('clickPixelThresh')) {
+                        this._dragThreshMet = true;
+                        this.start();
+                        this._moveNode([ev.pageX, ev.pageY]);
+                    }
+                
+                } else {
+                    clearTimeout(this._clickTimeout);
+                    this._moveNode([ev.pageX, ev.pageY]);
+                }
+            }
+        },
+        /**
+        * @method stopDrag
+        * @description Method will forcefully stop a drag operation. For example calling this from inside an ESC keypress handler will stop this drag.
+        * @return {Self}
+        * @chainable
+        */
+        stopDrag: function() {
+            if (this.get('dragging')) {
+                DDM._end();
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method destructor
+        * @description Lifecycle destructor, unreg the drag from the DDM and remove listeners
+        */
+        destructor: function() {
+            DDM._unregDrag(this);
+
+            this._unprep();
+            if (this.target) {
+                this.target.destroy();
+            }
+        }
+    });
+    Y.namespace('DD');    
+    Y.DD.Drag = Drag;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-base'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-drop-debug.js'
--- loggerhead/static/javascript/yui/build/dd/dd-drop-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-drop-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,441 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-drop', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-drop
+     */     
+    /**
+     * This class provides the ability to create a Drop Target.
+     * @class Drop
+     * @extends Base
+     * @constructor
+     */
+
+    var NODE = 'node',
+        DDM = Y.DD.DDM,
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth',
+        /**
+        * @event drop:over
+        * @description Fires when a drag element is over this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_OVER = 'drop:over',
+        /**
+        * @event drop:enter
+        * @description Fires when a drag element enters this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_ENTER = 'drop:enter',
+        /**
+        * @event drop:exit
+        * @description Fires when a drag element exits this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_EXIT = 'drop:exit';
+
+        /**
+        * @event drop:hit
+        * @description Fires when a draggable node is dropped on this Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        
+
+    var Drop = function() {
+        Drop.superclass.constructor.apply(this, arguments);
+
+        this._createShim();
+        DDM._regTarget(this);
+        /* TODO
+        if (Dom.getStyle(this.el, 'position') == 'fixed') {
+            Event.on(window, 'scroll', function() {
+                this.activateShim();
+            }, this, true);
+        }
+        */
+    };
+
+    Drop.NAME = 'drop';
+
+    Drop.ATTRS = {
+        /**
+        * @attribute node
+        * @description Y.Node instanace to use as the element to make a Drop Target
+        * @type Node
+        */        
+        node: {
+            set: function(node) {
+                var n = Y.Node.get(node);
+                if (!n) {
+                    Y.fail('DD.Drop: Invalid Node Given: ' + node);
+                }
+                return n;               
+            }
+        },
+        /**
+        * @attribute groups
+        * @description Array of groups to add this drop into.
+        * @type Array
+        */        
+        groups: {
+            value: ['default'],
+            set: function(g) {
+                this._groups = {};
+                Y.each(g, function(v, k) {
+                    this._groups[v] = true;
+                }, this);
+            }
+        },   
+        /**
+        * @attribute padding
+        * @description CSS style padding to make the Drop Target bigger than the node.
+        * @type String
+        */
+        padding: {
+            value: '0',
+            set: function(p) {
+                return DDM.cssSizestoObject(p);
+            }
+        },
+        /**
+        * @attribute lock
+        * @description Set to lock this drop element.
+        * @type Boolean
+        */        
+        lock: {
+            value: false,
+            set: function(lock) {
+                if (lock) {
+                    this.get(NODE).addClass(DDM.CSS_PREFIX + '-drop-locked');
+                } else {
+                    this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-locked');
+                }
+            }
+        },
+        /**
+        * @attribute bubbles
+        * @description Controls the default bubble parent for this Drop instance. Default: Y.DD.DDM. Set to false to disable bubbling.
+        * @type Object
+        */
+        bubbles: {
+            writeOnce: true,
+            value: Y.DD.DDM
+        }
+
+    };
+
+    Y.extend(Drop, Y.Base, {
+        /**
+        * @private
+        * @method _createEvents
+        * @description This method creates all the events for this Event Target and publishes them so we get Event Bubbling.
+        */
+        _createEvents: function() {
+            
+            var ev = [
+                EV_DROP_OVER,
+                EV_DROP_ENTER,
+                EV_DROP_EXIT,
+                'drop:hit'
+            ];
+
+            Y.each(ev, function(v, k) {
+                this.publish(v, {
+                    type: v,
+                    emitFacade: true,
+                    preventable: false,
+                    bubbles: true,
+                    queuable: true
+                });
+            }, this);
+
+            if (this.get('bubbles')) {
+                this.addTarget(this.get('bubbles'));
+            }
+            
+        },
+        /**
+        * @private
+        * @property _valid
+        * @description Flag for determining if the target is valid in this operation.
+        * @type Boolean
+        */
+        _valid: null,
+        /**
+        * @private
+        * @property _groups
+        * @description The groups this target belongs to.
+        * @type Array
+        */
+        _groups: null,
+        /**
+        * @property shim
+        * @description Node reference to the targets shim
+        * @type {Object}
+        */
+        shim: null,
+        /**
+        * @property region
+        * @description A region object associated with this target, used for checking regions while dragging.
+        * @type Object
+        */
+        region: null,
+        /**
+        * @property overTarget
+        * @description This flag is tripped when a drag element is over this target.
+        * @type Boolean
+        */
+        overTarget: null,
+        /**
+        * @method inGroup
+        * @description Check if this target is in one of the supplied groups.
+        * @param {Array} groups The groups to check against
+        * @return Boolean
+        */
+        inGroup: function(groups) {
+            this._valid = false;
+            var ret = false;
+            Y.each(groups, function(v, k) {
+                if (this._groups[v]) {
+                    ret = true;
+                    this._valid = true;
+                }
+            }, this);
+            return ret;
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Private lifecycle method
+        */
+        initializer: function() {
+            this._createEvents();
+            var node = this.get(NODE);
+            if (!node.get('id')) {
+                var id = Y.stamp(node);
+                node.set('id', id);
+            }
+            node.addClass(DDM.CSS_PREFIX + '-drop');
+        },
+        /**
+        * @private
+        * @method destructor
+        * @description Lifecycle destructor, unreg the drag from the DDM and remove listeners
+        */
+        destructor: function() {
+            DDM._unregTarget(this);
+            if (this.shim) {
+                this.shim.get('parentNode').removeChild(this.shim);
+                this.shim = null;
+            }
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop');
+        },        
+        /**
+        * @private
+        * @method _deactivateShim
+        * @description Removes classes from the target, resets some flags and sets the shims deactive position [-999, -999]
+        */
+        _deactivateShim: function() {
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-active-valid');
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-over');
+            this.shim.setStyles({
+                top: '-999px',
+                left: '-999px'
+            });
+            this.overTarget = false;
+        },
+        /**
+        * @private
+        * @method _activateShim
+        * @description Activates the shim and adds some interaction CSS classes
+        */
+        _activateShim: function() {
+            if (!DDM.activeDrag) {
+                return false; //Nothing is dragging, no reason to activate.
+            }
+            if (this.get(NODE) === DDM.activeDrag.get(NODE)) {
+                return false;
+            }
+            if (this.get('lock')) {
+                return false;
+            }
+            var node = this.get(NODE);
+            //TODO Visibility Check..
+            //if (this.inGroup(DDM.activeDrag.get('groups')) && this.get(NODE).isVisible()) {
+            if (this.inGroup(DDM.activeDrag.get('groups'))) {
+                node.removeClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+                node.addClass(DDM.CSS_PREFIX + '-drop-active-valid');
+                DDM._addValid(this);
+                this.overTarget = false;
+                this.sizeShim();
+            } else {
+                DDM._removeValid(this);
+                node.removeClass(DDM.CSS_PREFIX + '-drop-active-valid');
+                node.addClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+            }
+        },
+        /**
+        * @method sizeShim
+        * @description Positions and sizes the shim with the raw data from the node, this can be used to programatically adjust the Targets shim for Animation..
+        */
+        sizeShim: function() {
+            if (!DDM.activeDrag) {
+                return false; //Nothing is dragging, no reason to activate.
+            }
+            if (this.get(NODE) === DDM.activeDrag.get(NODE)) {
+                return false;
+            }
+            if (this.get('lock')) {
+                return false;
+            }
+            var node = this.get(NODE),
+                nh = node.get(OFFSET_HEIGHT),
+                nw = node.get(OFFSET_WIDTH),
+                xy = node.getXY(),
+                p = this.get('padding');
+
+
+            //Apply padding
+            nw = nw + p.left + p.right;
+            nh = nh + p.top + p.bottom;
+            xy[0] = xy[0] - p.left;
+            xy[1] = xy[1] - p.top;
+            
+
+            if (DDM.activeDrag.get('dragMode') === DDM.INTERSECT) {
+                //Intersect Mode, make the shim bigger
+                var dd = DDM.activeDrag,
+                    dH = dd.get(NODE).get(OFFSET_HEIGHT),
+                    dW = dd.get(NODE).get(OFFSET_WIDTH);
+                
+                nh = (nh + dH);
+                nw = (nw + dW);
+                xy[0] = xy[0] - (dW - dd.deltaXY[0]);
+                xy[1] = xy[1] - (dH - dd.deltaXY[1]);
+
+            }
+            
+            //Set the style on the shim
+            this.shim.setStyles({
+                height: nh + 'px',
+                width: nw + 'px',
+                top: xy[1] + 'px',
+                left: xy[0] + 'px'
+            });
+            
+            //Create the region to be used by intersect when a drag node is over us.
+            this.region = {
+                '0': xy[0], 
+                '1': xy[1],
+                area: 0,
+                top: xy[1],
+                right: xy[0] + nw,
+                bottom: xy[1] + nh,
+                left: xy[0]
+            };
+        },
+        /**
+        * @private
+        * @method _createShim
+        * @description Creates the Target shim and adds it to the DDM's playground..
+        */
+        _createShim: function() {
+            //var s = Y.Node.create(['div', { id: this.get(NODE).get('id') + '_shim' }]);
+            var s = Y.Node.create('<div id="' + this.get(NODE).get('id') + '_shim"></div>');
+            s.setStyles({
+                height: this.get(NODE).get(OFFSET_HEIGHT) + 'px',
+                width: this.get(NODE).get(OFFSET_WIDTH) + 'px',
+                backgroundColor: 'yellow',
+                opacity: '.5',
+                zIndex: 999,
+                overflow: 'hidden',
+                top: '-900px',
+                left: '-900px',
+                position:  'absolute'
+            });
+            DDM._pg.appendChild(s);
+            this.shim = s;
+
+            s.on('mouseover', this._handleOverEvent, this, true);
+            s.on('mouseout', this._handleOutEvent, this, true);
+        },
+        /**
+        * @private
+        * @method _handleOverTarget
+        * @description This handles the over target call made from this object or from the DDM
+        */
+        _handleTargetOver: function() {
+            if (DDM.isOverTarget(this)) {
+                this.get(NODE).addClass(DDM.CSS_PREFIX + '-drop-over');
+                DDM.activeDrop = this;
+                DDM.otherDrops[this] = this;
+                if (this.overTarget) {
+                    DDM.activeDrag.fire('drag:over', { drop: this, drag: DDM.activeDrag });
+                    this.fire(EV_DROP_OVER, { drop: this, drag: DDM.activeDrag });
+                } else {
+                    this.overTarget = true;
+                    this.fire(EV_DROP_ENTER, { drop: this, drag: DDM.activeDrag });
+                    DDM.activeDrag.fire('drag:enter', { drop: this, drag: DDM.activeDrag });
+                    DDM.activeDrag.get(NODE).addClass(DDM.CSS_PREFIX + '-drag-over');
+                    DDM._handleTargetOver();
+                }
+            } else {
+                this._handleOut();
+            }
+            
+        },
+        /**
+        * @private
+        * @method _handleOverEvent
+        * @description Handles the mouseover DOM event on the Target Shim
+        */
+        _handleOverEvent: function() {
+            DDM._addActiveShim(this);
+        },
+        /**
+        * @private
+        * @method _handleOut
+        * @description Handles the mouseout DOM event on the Target Shim
+        */
+        _handleOutEvent: function() {
+            DDM._removeActiveShim(this);
+        },
+        /**
+        * @private
+        * @method _handleOut
+        * @description Handles out of target calls/checks
+        */
+        _handleOut: function() {
+            if (!DDM.isOverTarget(this)) {
+                if (this.overTarget) {
+                    this.overTarget = false;
+                    DDM._removeActiveShim(this);
+                    if (DDM.activeDrag) {
+                        this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-over');
+                        DDM.activeDrag.get(NODE).removeClass(DDM.CSS_PREFIX + '-drag-over');
+                        this.fire(EV_DROP_EXIT);
+                        DDM.activeDrag.fire('drag:exit', { drop: this });
+                        delete DDM.otherDrops[this];
+                    }
+                }
+            }
+        }
+    });
+
+    Y.DD.Drop = Drop;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-drop', 'dd-drag'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-drop-min.js'
--- loggerhead/static/javascript/yui/build/dd/dd-drop-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-drop-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dd-drop",function(A){var B="node",G=A.DD.DDM,F="offsetHeight",C="offsetWidth",I="drop:over",H="drop:enter",D="drop:exit";var E=function(){E.superclass.constructor.apply(this,arguments);this._createShim();G._regTarget(this);};E.NAME="drop";E.ATTRS={node:{set:function(J){var K=A.Node.get(J);if(!K){A.fail("DD.Drop: Invalid Node Given: "+J);}return K;}},groups:{value:["default"],set:function(J){this._groups={};A.each(J,function(L,K){this._groups[L]=true;},this);}},padding:{value:"0",set:function(J){return G.cssSizestoObject(J);}},lock:{value:false,set:function(J){if(J){this.get(B).addClass(G.CSS_PREFIX+"-drop-locked");}else{this.get(B).removeClass(G.CSS_PREFIX+"-drop-locked");}}},bubbles:{writeOnce:true,value:A.DD.DDM}};A.extend(E,A.Base,{_createEvents:function(){var J=[I,H,D,"drop:hit"];A.each(J,function(L,K){this.publish(L,{type:L,emitFacade:true,preventable:false,bubbles:true,queuable:true});},this);if(this.get("bubbles")){this.addTarget(this.get("bubbles"));}},_valid:null,_groups:null,shim:null,region:null,overTarget:null,inGroup:function(J){this._valid=false;var K=false;A.each(J,function(M,L){if(this._groups[M]){K=true;this._valid=true;}},this);return K;},initializer:function(){this._createEvents();var J=this.get(B);if(!J.get("id")){var K=A.stamp(J);J.set("id",K);}J.addClass(G.CSS_PREFIX+"-drop");},destructor:function(){G._unregTarget(this);if(this.shim){this.shim.get("parentNode").removeChild(this.shim);this.shim=null;}this.get(B).removeClass(G.CSS_PREFIX+"-drop");},_deactivateShim:function(){this.get(B).removeClass(G.CSS_PREFIX+"-drop-active-valid");this.get(B).removeClass(G.CSS_PREFIX+"-drop-active-invalid");this.get(B).removeClass(G.CSS_PREFIX+"-drop-over");this.shim.setStyles({top:"-999px",left:"-999px"});this.overTarget=false;},_activateShim:function(){if(!G.activeDrag){return false;}if(this.get(B)===G.activeDrag.get(B)){return false;}if(this.get("lock")){return false;}var J=this.get(B);if(this.inGroup(G.activeDrag.get("groups"))){J.removeClass(G.CSS_PREFIX+"-drop-active-invalid");J.addClass(G.CSS_PREFIX+"-drop-active-valid");G._addValid(this);this.overTarget=false;this.sizeShim();}else{G._removeValid(this);J.removeClass(G.CSS_PREFIX+"-drop-active-valid");J.addClass(G.CSS_PREFIX+"-drop-active-invalid");}},sizeShim:function(){if(!G.activeDrag){return false;}if(this.get(B)===G.activeDrag.get(B)){return false;}if(this.get("lock")){return false;}var O=this.get(B),M=O.get(F),K=O.get(C),Q=O.getXY(),P=this.get("padding");K=K+P.left+P.right;M=M+P.top+P.bottom;Q[0]=Q[0]-P.left;Q[1]=Q[1]-P.top;if(G.activeDrag.get("dragMode")===G.INTERSECT){var J=G.activeDrag,N=J.get(B).get(F),L=J.get(B).get(C);M=(M+N);K=(K+L);Q[0]=Q[0]-(L-J.deltaXY[0]);Q[1]=Q[1]-(N-J.deltaXY[1]);}this.shim.setStyles({height:M+"px",width:K+"px",top:Q[1]+"px",left:Q[0]+"px"});this.region={"0":Q[0],"1":Q[1],area:0,top:Q[1],right:Q[0]+K,bottom:Q[1]+M,left:Q[0]};},_createShim:function(){var J=A.Node.create('<div id="'+this.get(B).get("id")+'_shim"></div>');J.setStyles({height:this.get(B).get(F)+"px",width:this.get(B).get(C)+"px",backgroundColor:"yellow",opacity:".5",zIndex:999,overflow:"hidden",top:"-900px",left:"-900px",position:"absolute"});G._pg.appendChild(J);this.shim=J;J.on("mouseover",this._handleOverEvent,this,true);J.on("mouseout",this._handleOutEvent,this,true);},_handleTargetOver:function(){if(G.isOverTarget(this)){this.get(B).addClass(G.CSS_PREFIX+"-drop-over");G.activeDrop=this;G.otherDrops[this]=this;if(this.overTarget){G.activeDrag.fire("drag:over",{drop:this,drag:G.activeDrag});this.fire(I,{drop:this,drag:G.activeDrag});}else{this.overTarget=true;this.fire(H,{drop:this,drag:G.activeDrag});G.activeDrag.fire("drag:enter",{drop:this,drag:G.activeDrag});G.activeDrag.get(B).addClass(G.CSS_PREFIX+"-drag-over");G._handleTargetOver();}}else{this._handleOut();}},_handleOverEvent:function(){G._addActiveShim(this);},_handleOutEvent:function(){G._removeActiveShim(this);},_handleOut:function(){if(!G.isOverTarget(this)){if(this.overTarget){this.overTarget=false;G._removeActiveShim(this);if(G.activeDrag){this.get(B).removeClass(G.CSS_PREFIX+"-drop-over");G.activeDrag.get(B).removeClass(G.CSS_PREFIX+"-drag-over");this.fire(D);G.activeDrag.fire("drag:exit",{drop:this});delete G.otherDrops[this];}}}}});A.DD.Drop=E;},"3.0.0pr2",{requires:["dd-ddm-drop","dd-drag"],skinnable:false});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-drop-plugin-debug.js'
--- loggerhead/static/javascript/yui/build/dd/dd-drop-plugin-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-drop-plugin-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,48 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-drop-plugin', function(Y) {
+
+       /**
+        * This is a simple Drop plugin that can be attached to a Node via the plug method.
+        * @module dd-plugin
+        * @submodule dd-drop-plugin
+        */
+       /**
+        * This is a simple Drop plugin that can be attached to a Node via the plug method.
+        * @class DropPlugin
+        * @extends Drop
+        * @constructor
+        * @namespace plugin
+        */
+
+
+        var Drop = function(config) {
+            config.node = config.owner;
+            Drop.superclass.constructor.apply(this, arguments);
+        };
+        
+        /**
+        * @property NAME
+        * @description dd-drop-plugin
+        * @type {String}
+        */
+        Drop.NAME = "dd-drop-plugin";
+        /**
+        * @property NS
+        * @description The Drop instance will be placed on the Node instance under the drop namespace. It can be accessed via Node.drop;
+        * @type {String}
+        */
+        Drop.NS = "drop";
+
+
+        Y.extend(Drop, Y.DD.Drop);
+        Y.namespace('plugin');
+        Y.plugin.Drop = Drop;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drop'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-drop-plugin-min.js'
--- loggerhead/static/javascript/yui/build/dd/dd-drop-plugin-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-drop-plugin-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dd-drop-plugin",function(A){var B=function(C){C.node=C.owner;B.superclass.constructor.apply(this,arguments);};B.NAME="dd-drop-plugin";B.NS="drop";A.extend(B,A.DD.Drop);A.namespace("plugin");A.plugin.Drop=B;},"3.0.0pr2",{requires:["dd-drop"],skinnable:false});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-drop-plugin.js'
--- loggerhead/static/javascript/yui/build/dd/dd-drop-plugin.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-drop-plugin.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,48 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-drop-plugin', function(Y) {
+
+       /**
+        * This is a simple Drop plugin that can be attached to a Node via the plug method.
+        * @module dd-plugin
+        * @submodule dd-drop-plugin
+        */
+       /**
+        * This is a simple Drop plugin that can be attached to a Node via the plug method.
+        * @class DropPlugin
+        * @extends Drop
+        * @constructor
+        * @namespace plugin
+        */
+
+
+        var Drop = function(config) {
+            config.node = config.owner;
+            Drop.superclass.constructor.apply(this, arguments);
+        };
+        
+        /**
+        * @property NAME
+        * @description dd-drop-plugin
+        * @type {String}
+        */
+        Drop.NAME = "dd-drop-plugin";
+        /**
+        * @property NS
+        * @description The Drop instance will be placed on the Node instance under the drop namespace. It can be accessed via Node.drop;
+        * @type {String}
+        */
+        Drop.NS = "drop";
+
+
+        Y.extend(Drop, Y.DD.Drop);
+        Y.namespace('plugin');
+        Y.plugin.Drop = Drop;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drop'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-drop.js'
--- loggerhead/static/javascript/yui/build/dd/dd-drop.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-drop.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,441 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-drop', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-drop
+     */     
+    /**
+     * This class provides the ability to create a Drop Target.
+     * @class Drop
+     * @extends Base
+     * @constructor
+     */
+
+    var NODE = 'node',
+        DDM = Y.DD.DDM,
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth',
+        /**
+        * @event drop:over
+        * @description Fires when a drag element is over this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_OVER = 'drop:over',
+        /**
+        * @event drop:enter
+        * @description Fires when a drag element enters this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_ENTER = 'drop:enter',
+        /**
+        * @event drop:exit
+        * @description Fires when a drag element exits this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_EXIT = 'drop:exit';
+
+        /**
+        * @event drop:hit
+        * @description Fires when a draggable node is dropped on this Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        
+
+    var Drop = function() {
+        Drop.superclass.constructor.apply(this, arguments);
+
+        this._createShim();
+        DDM._regTarget(this);
+        /* TODO
+        if (Dom.getStyle(this.el, 'position') == 'fixed') {
+            Event.on(window, 'scroll', function() {
+                this.activateShim();
+            }, this, true);
+        }
+        */
+    };
+
+    Drop.NAME = 'drop';
+
+    Drop.ATTRS = {
+        /**
+        * @attribute node
+        * @description Y.Node instanace to use as the element to make a Drop Target
+        * @type Node
+        */        
+        node: {
+            set: function(node) {
+                var n = Y.Node.get(node);
+                if (!n) {
+                    Y.fail('DD.Drop: Invalid Node Given: ' + node);
+                }
+                return n;               
+            }
+        },
+        /**
+        * @attribute groups
+        * @description Array of groups to add this drop into.
+        * @type Array
+        */        
+        groups: {
+            value: ['default'],
+            set: function(g) {
+                this._groups = {};
+                Y.each(g, function(v, k) {
+                    this._groups[v] = true;
+                }, this);
+            }
+        },   
+        /**
+        * @attribute padding
+        * @description CSS style padding to make the Drop Target bigger than the node.
+        * @type String
+        */
+        padding: {
+            value: '0',
+            set: function(p) {
+                return DDM.cssSizestoObject(p);
+            }
+        },
+        /**
+        * @attribute lock
+        * @description Set to lock this drop element.
+        * @type Boolean
+        */        
+        lock: {
+            value: false,
+            set: function(lock) {
+                if (lock) {
+                    this.get(NODE).addClass(DDM.CSS_PREFIX + '-drop-locked');
+                } else {
+                    this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-locked');
+                }
+            }
+        },
+        /**
+        * @attribute bubbles
+        * @description Controls the default bubble parent for this Drop instance. Default: Y.DD.DDM. Set to false to disable bubbling.
+        * @type Object
+        */
+        bubbles: {
+            writeOnce: true,
+            value: Y.DD.DDM
+        }
+
+    };
+
+    Y.extend(Drop, Y.Base, {
+        /**
+        * @private
+        * @method _createEvents
+        * @description This method creates all the events for this Event Target and publishes them so we get Event Bubbling.
+        */
+        _createEvents: function() {
+            
+            var ev = [
+                EV_DROP_OVER,
+                EV_DROP_ENTER,
+                EV_DROP_EXIT,
+                'drop:hit'
+            ];
+
+            Y.each(ev, function(v, k) {
+                this.publish(v, {
+                    type: v,
+                    emitFacade: true,
+                    preventable: false,
+                    bubbles: true,
+                    queuable: true
+                });
+            }, this);
+
+            if (this.get('bubbles')) {
+                this.addTarget(this.get('bubbles'));
+            }
+            
+        },
+        /**
+        * @private
+        * @property _valid
+        * @description Flag for determining if the target is valid in this operation.
+        * @type Boolean
+        */
+        _valid: null,
+        /**
+        * @private
+        * @property _groups
+        * @description The groups this target belongs to.
+        * @type Array
+        */
+        _groups: null,
+        /**
+        * @property shim
+        * @description Node reference to the targets shim
+        * @type {Object}
+        */
+        shim: null,
+        /**
+        * @property region
+        * @description A region object associated with this target, used for checking regions while dragging.
+        * @type Object
+        */
+        region: null,
+        /**
+        * @property overTarget
+        * @description This flag is tripped when a drag element is over this target.
+        * @type Boolean
+        */
+        overTarget: null,
+        /**
+        * @method inGroup
+        * @description Check if this target is in one of the supplied groups.
+        * @param {Array} groups The groups to check against
+        * @return Boolean
+        */
+        inGroup: function(groups) {
+            this._valid = false;
+            var ret = false;
+            Y.each(groups, function(v, k) {
+                if (this._groups[v]) {
+                    ret = true;
+                    this._valid = true;
+                }
+            }, this);
+            return ret;
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Private lifecycle method
+        */
+        initializer: function() {
+            this._createEvents();
+            var node = this.get(NODE);
+            if (!node.get('id')) {
+                var id = Y.stamp(node);
+                node.set('id', id);
+            }
+            node.addClass(DDM.CSS_PREFIX + '-drop');
+        },
+        /**
+        * @private
+        * @method destructor
+        * @description Lifecycle destructor, unreg the drag from the DDM and remove listeners
+        */
+        destructor: function() {
+            DDM._unregTarget(this);
+            if (this.shim) {
+                this.shim.get('parentNode').removeChild(this.shim);
+                this.shim = null;
+            }
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop');
+        },        
+        /**
+        * @private
+        * @method _deactivateShim
+        * @description Removes classes from the target, resets some flags and sets the shims deactive position [-999, -999]
+        */
+        _deactivateShim: function() {
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-active-valid');
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-over');
+            this.shim.setStyles({
+                top: '-999px',
+                left: '-999px'
+            });
+            this.overTarget = false;
+        },
+        /**
+        * @private
+        * @method _activateShim
+        * @description Activates the shim and adds some interaction CSS classes
+        */
+        _activateShim: function() {
+            if (!DDM.activeDrag) {
+                return false; //Nothing is dragging, no reason to activate.
+            }
+            if (this.get(NODE) === DDM.activeDrag.get(NODE)) {
+                return false;
+            }
+            if (this.get('lock')) {
+                return false;
+            }
+            var node = this.get(NODE);
+            //TODO Visibility Check..
+            //if (this.inGroup(DDM.activeDrag.get('groups')) && this.get(NODE).isVisible()) {
+            if (this.inGroup(DDM.activeDrag.get('groups'))) {
+                node.removeClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+                node.addClass(DDM.CSS_PREFIX + '-drop-active-valid');
+                DDM._addValid(this);
+                this.overTarget = false;
+                this.sizeShim();
+            } else {
+                DDM._removeValid(this);
+                node.removeClass(DDM.CSS_PREFIX + '-drop-active-valid');
+                node.addClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+            }
+        },
+        /**
+        * @method sizeShim
+        * @description Positions and sizes the shim with the raw data from the node, this can be used to programatically adjust the Targets shim for Animation..
+        */
+        sizeShim: function() {
+            if (!DDM.activeDrag) {
+                return false; //Nothing is dragging, no reason to activate.
+            }
+            if (this.get(NODE) === DDM.activeDrag.get(NODE)) {
+                return false;
+            }
+            if (this.get('lock')) {
+                return false;
+            }
+            var node = this.get(NODE),
+                nh = node.get(OFFSET_HEIGHT),
+                nw = node.get(OFFSET_WIDTH),
+                xy = node.getXY(),
+                p = this.get('padding');
+
+
+            //Apply padding
+            nw = nw + p.left + p.right;
+            nh = nh + p.top + p.bottom;
+            xy[0] = xy[0] - p.left;
+            xy[1] = xy[1] - p.top;
+            
+
+            if (DDM.activeDrag.get('dragMode') === DDM.INTERSECT) {
+                //Intersect Mode, make the shim bigger
+                var dd = DDM.activeDrag,
+                    dH = dd.get(NODE).get(OFFSET_HEIGHT),
+                    dW = dd.get(NODE).get(OFFSET_WIDTH);
+                
+                nh = (nh + dH);
+                nw = (nw + dW);
+                xy[0] = xy[0] - (dW - dd.deltaXY[0]);
+                xy[1] = xy[1] - (dH - dd.deltaXY[1]);
+
+            }
+            
+            //Set the style on the shim
+            this.shim.setStyles({
+                height: nh + 'px',
+                width: nw + 'px',
+                top: xy[1] + 'px',
+                left: xy[0] + 'px'
+            });
+            
+            //Create the region to be used by intersect when a drag node is over us.
+            this.region = {
+                '0': xy[0], 
+                '1': xy[1],
+                area: 0,
+                top: xy[1],
+                right: xy[0] + nw,
+                bottom: xy[1] + nh,
+                left: xy[0]
+            };
+        },
+        /**
+        * @private
+        * @method _createShim
+        * @description Creates the Target shim and adds it to the DDM's playground..
+        */
+        _createShim: function() {
+            //var s = Y.Node.create(['div', { id: this.get(NODE).get('id') + '_shim' }]);
+            var s = Y.Node.create('<div id="' + this.get(NODE).get('id') + '_shim"></div>');
+            s.setStyles({
+                height: this.get(NODE).get(OFFSET_HEIGHT) + 'px',
+                width: this.get(NODE).get(OFFSET_WIDTH) + 'px',
+                backgroundColor: 'yellow',
+                opacity: '.5',
+                zIndex: 999,
+                overflow: 'hidden',
+                top: '-900px',
+                left: '-900px',
+                position:  'absolute'
+            });
+            DDM._pg.appendChild(s);
+            this.shim = s;
+
+            s.on('mouseover', this._handleOverEvent, this, true);
+            s.on('mouseout', this._handleOutEvent, this, true);
+        },
+        /**
+        * @private
+        * @method _handleOverTarget
+        * @description This handles the over target call made from this object or from the DDM
+        */
+        _handleTargetOver: function() {
+            if (DDM.isOverTarget(this)) {
+                this.get(NODE).addClass(DDM.CSS_PREFIX + '-drop-over');
+                DDM.activeDrop = this;
+                DDM.otherDrops[this] = this;
+                if (this.overTarget) {
+                    DDM.activeDrag.fire('drag:over', { drop: this, drag: DDM.activeDrag });
+                    this.fire(EV_DROP_OVER, { drop: this, drag: DDM.activeDrag });
+                } else {
+                    this.overTarget = true;
+                    this.fire(EV_DROP_ENTER, { drop: this, drag: DDM.activeDrag });
+                    DDM.activeDrag.fire('drag:enter', { drop: this, drag: DDM.activeDrag });
+                    DDM.activeDrag.get(NODE).addClass(DDM.CSS_PREFIX + '-drag-over');
+                    DDM._handleTargetOver();
+                }
+            } else {
+                this._handleOut();
+            }
+            
+        },
+        /**
+        * @private
+        * @method _handleOverEvent
+        * @description Handles the mouseover DOM event on the Target Shim
+        */
+        _handleOverEvent: function() {
+            DDM._addActiveShim(this);
+        },
+        /**
+        * @private
+        * @method _handleOut
+        * @description Handles the mouseout DOM event on the Target Shim
+        */
+        _handleOutEvent: function() {
+            DDM._removeActiveShim(this);
+        },
+        /**
+        * @private
+        * @method _handleOut
+        * @description Handles out of target calls/checks
+        */
+        _handleOut: function() {
+            if (!DDM.isOverTarget(this)) {
+                if (this.overTarget) {
+                    this.overTarget = false;
+                    DDM._removeActiveShim(this);
+                    if (DDM.activeDrag) {
+                        this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-over');
+                        DDM.activeDrag.get(NODE).removeClass(DDM.CSS_PREFIX + '-drag-over');
+                        this.fire(EV_DROP_EXIT);
+                        DDM.activeDrag.fire('drag:exit', { drop: this });
+                        delete DDM.otherDrops[this];
+                    }
+                }
+            }
+        }
+    });
+
+    Y.DD.Drop = Drop;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-drop', 'dd-drag'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-min.js'
--- loggerhead/static/javascript/yui/build/dd/dd-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,11 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dd-ddm-base",function(B){var A=function(){A.superclass.constructor.apply(this,arguments);};A.NAME="dragDropMgr";A.ATTRS={clickPixelThresh:{value:3},clickTimeThresh:{value:1000},dragMode:{value:"point",set:function(C){this._setDragMode(C);}}};B.extend(A,B.Base,{_setDragMode:function(C){if(C===null){C=B.DD.DDM.get("dragMode");}switch(C){case 1:case"intersect":return 1;case 2:case"strict":return 2;case 0:case"point":return 0;}return 0;},CSS_PREFIX:"yui-dd",_activateTargets:function(){},_drags:[],activeDrag:false,_regDrag:function(C){this._drags[this._drags.length]=C;},_unregDrag:function(D){var C=[];B.each(this._drags,function(F,E){if(F!==D){C[C.length]=F;}});this._drags=C;},initializer:function(){B.Node.get("document").on("mousemove",this._move,this,true);B.Node.get("document").on("mouseup",this._end,this,true);},_start:function(C,F,D,E){this._startDrag.apply(this,arguments);},_startDrag:function(){},_endDrag:function(){},_dropMove:function(){},_end:function(){if(this.activeDrag){this._endDrag();this.activeDrag.end.call(this.activeDrag);this.activeDrag=null;}},stopDrag:function(){if(this.activeDrag){this._end();}return this;},_move:function(C){if(this.activeDrag){this.activeDrag._move.apply(this.activeDrag,arguments);this._dropMove();}},setXY:function(E,F){var D=parseInt(E.getStyle("top"),10),C=parseInt(E.getStyle("left"),10),G=E.getStyle("position");if(G==="static"){E.setStyle("position","relative");}if(isNaN(D)){D=0;}if(isNaN(C)){C=0;}E.setStyle("top",(F[1]+D)+"px");E.setStyle("left",(F[0]+C)+"px");},cssSizestoObject:function(D){var C=D.split(" ");switch(C.length){case 1:C[1]=C[2]=C[3]=C[0];break;case 2:C[2]=C[0];C[3]=C[1];break;case 3:C[3]=C[1];break;}return{top:parseInt(C[0],10),right:parseInt(C[1],10),bottom:parseInt(C[2],10),left:parseInt(C[3],10)};},getDrag:function(D){var C=false,E=B.Node.get(D);if(E instanceof B.Node){B.each(this._drags,function(G,F){if(E.compareTo(G.get("node"))){C=G;}});}return C;}});B.namespace("DD");B.DD.DDM=new A();},"3.0.0pr2",{requires:["node","base"],skinnable:false});YUI.add("dd-ddm",function(A){A.mix(A.DD.DDM,{_pg:null,_debugShim:false,_activateTargets:function(){},_deactivateTargets:function(){},_startDrag:function(){if(this.activeDrag.get("useShim")){this._pg_activate();this._activateTargets();}},_endDrag:function(){this._pg_deactivate();this._deactivateTargets();},_pg_deactivate:function(){this._pg.setStyle("display","none");},_pg_activate:function(){this._pg_size();this._pg.setStyles({top:0,left:0,display:"block",opacity:((this._debugShim)?".5":"0")});},_pg_size:function(){if(this.activeDrag){var B=A.Node.get("body"),D=B.get("docHeight"),C=B.get("docWidth");this._pg.setStyles({height:D+"px",width:C+"px"});}},_createPG:function(){var C=A.Node.create("<div></div>"),B=A.Node.get("body");C.setStyles({top:"0",left:"0",position:"absolute",zIndex:"9999",overflow:"hidden",backgroundColor:"red",display:"none",height:"5px",width:"5px"});if(B.get("firstChild")){B.insertBefore(C,B.get("firstChild"));}else{B.appendChild(C);}this._pg=C;this._pg.on("mouseup",this._end,this,true);this._pg.on("mousemove",this._move,this,true);A.on("resize",this._pg_size,window,this,true);A.on("scroll",this._pg_size,window,this,true);}},true);A.DD.DDM._createPG();},"3.0.0pr2",{requires:["dd-ddm-base"],skinnable:false});YUI.add("dd-ddm-drop",function(A){A.mix(A.DD.DDM,{_noShim:false,_activeShims:[],_hasActiveShim:function(){if(this._noShim){return true;}return this._activeShims.length;},_addActiveShim:function(B){this._activeShims[this._activeShims.length]=B;},_removeActiveShim:function(C){var B=[];A.each(this._activeShims,function(E,D){if(E._yuid!==C._yuid){B[B.length]=E;}});this._activeShims=B;},syncActiveShims:function(B){var C=((B)?this.targets:this._lookup());A.each(C,function(E,D){E.sizeShim.call(E);},this);return C;},mode:0,POINT:0,INTERSECT:1,STRICT:2,useHash:true,activeDrop:null,validDrops:[],otherDrops:{},targets:[],_addValid:function(B){this.validDrops[this.validDrops.length]=B;return this;},_removeValid:function(B){var C=[];A.each(this.validDrops,function(E,D){if(E!==B){C[C.length]=E;}});this.validDrops=C;return this;},isOverTarget:function(B){if(this.activeDrag&&B){var C=this.activeDrag.mouseXY;if(C){if(this.activeDrag.get("dragMode")==this.STRICT){return this.activeDrag.get("dragNode").inRegion(B.region,true,this.activeDrag.region);}else{if(B&&B.shim){return B.shim.intersect({top:C[1],bottom:C[1],left:C[0],right:C[0]},B.region).inRegion;}else{return false;}}}else{return false;}}else{return false;}},clearCache:function(){this.validDrops=[];this.otherDrops={};this._activeShims=[];},_activateTargets:function(){this.clearCache();A.each(this.targets,function(C,B){C._activateShim.apply(C,[]);},this);this._handleTargetOver();},getBestMatch:function(F,D){var C=null,E=0;A.each(F,function(I,H){var G=this.activeDrag.get("dragNode").intersect(I.get("node"));I.region.area=G.area;if(G.inRegion){if(G.area>E){E=G.area;C=I;}}},this);if(D){var B=[];A.each(F,function(H,G){if(H!==C){B[B.length]=H;}},this);return[C,B];}else{return C;}},_deactivateTargets:function(){var B=[],E=this.activeDrag,D=this.activeDrop;if(E&&D&&this.otherDrops[D]){if(!E.get("dragMode")){B=this.otherDrops;delete B[D];}else{var C=this.getBestMatch(this.otherDrops,true);D=C[0];B=C[1];}E.get("node").removeClass(this.CSS_PREFIX+"-drag-over");if(D){D.fire("drop:hit",{drag:E,drop:D,others:B});E.fire("drag:drophit",{drag:E,drop:D,others:B});}}else{if(E){E.get("node").removeClass(this.CSS_PREFIX+"-drag-over");E.fire("drag:dropmiss",{pageX:E.lastXY[0],pageY:E.lastXY[1]});}else{}}this.activeDrop=null;A.each(this.targets,function(G,F){G._deactivateShim.apply(G,[]);},this);},_dropMove:function(){if(this._hasActiveShim()){this._handleTargetOver();}else{A.each(this.otherDrops,function(C,B){C._handleOut.apply(C,[]);});}},_lookup:function(){if(!this.useHash){return this.validDrops;}var B=[];A.each(this.validDrops,function(D,C){if(D.shim&&D.shim.inViewportRegion(false,D.region)){B[B.length]=D;}});return B;},_handleTargetOver:function(){var B=this._lookup();
+A.each(B,function(D,C){D._handleTargetOver.call(D);},this);},_regTarget:function(B){this.targets[this.targets.length]=B;},_unregTarget:function(C){var B=[];A.each(this.targets,function(F,E){if(F!=C){B[B.length]=F;}},this);this.targets=B;var D=[];A.each(this.validDrops,function(F,E){if(F!==C){D[D.length]=F;}});this.validDrops=D;},getDrop:function(C){var B=false,D=A.Node.get(C);if(D instanceof A.Node){A.each(this.targets,function(F,E){if(D.compareTo(F.get("node"))){B=F;}});}return B;}},true);},"3.0.0pr2",{requires:["dd-ddm"],skinnable:false});YUI.add("dd-drag",function(D){var E=D.DD.DDM,S="node",M="dragNode",C="offsetHeight",J="offsetWidth",Q="mouseup",O="mousedown",L="dragstart",G="drag:mouseDown",B="drag:afterMouseDown",F="drag:removeHandle",K="drag:addHandle",P="drag:removeInvalid",R="drag:addInvalid",I="drag:start",H="drag:end",N="drag:drag";var A=function(){A.superclass.constructor.apply(this,arguments);E._regDrag(this);};A.NAME="drag";A.ATTRS={node:{set:function(T){var U=D.get(T);if(!U){D.fail("DD.Drag: Invalid Node Given: "+T);}else{U=U.item(0);}return U;}},dragNode:{set:function(T){var U=D.Node.get(T);if(!U){D.fail("DD.Drag: Invalid dragNode Given: "+T);}return U;}},offsetNode:{value:true},clickPixelThresh:{value:E.get("clickPixelThresh")},clickTimeThresh:{value:E.get("clickTimeThresh")},lock:{value:false,set:function(T){if(T){this.get(S).addClass(E.CSS_PREFIX+"-locked");}else{this.get(S).removeClass(E.CSS_PREFIX+"-locked");}}},data:{value:false},move:{value:true},useShim:{value:true},activeHandle:{value:false},primaryButtonOnly:{value:true},dragging:{value:false},parent:{value:false},target:{value:false,set:function(T){this._handleTarget(T);}},dragMode:{value:null,set:function(T){return E._setDragMode(T);}},groups:{value:["default"],get:function(){if(!this._groups){this._groups={};}var T=[];D.each(this._groups,function(V,U){T[T.length]=U;});return T;},set:function(T){this._groups={};D.each(T,function(V,U){this._groups[V]=true;},this);}},handles:{value:null,set:function(T){if(T){this._handles={};D.each(T,function(V,U){this._handles[V]=true;},this);}else{this._handles=null;}return T;}},bubbles:{writeOnce:true,value:D.DD.DDM}};D.extend(A,D.Base,{addToGroup:function(T){this._groups[T]=true;E._activateTargets();return this;},removeFromGroup:function(T){delete this._groups[T];E._activateTargets();return this;},target:null,_handleTarget:function(T){if(D.DD.Drop){if(T===false){if(this.target){E._unregTarget(this.target);this.target=null;}return false;}else{if(!D.Lang.isObject(T)){T={};}T.bubbles=this.get("bubbles");T.node=this.get(S);this.target=new D.DD.Drop(T);}}else{return false;}},_groups:null,_createEvents:function(){this.publish(G,{defaultFn:this._handleMouseDown,queuable:true,emitFacade:true,bubbles:true});var T=[B,F,K,P,R,I,H,N,"drag:drophit","drag:dropmiss","drag:over","drag:enter","drag:exit"];D.each(T,function(V,U){this.publish(V,{type:V,emitFacade:true,bubbles:true,preventable:false,queuable:true});},this);if(this.get("bubbles")){this.addTarget(this.get("bubbles"));}},_ev_md:null,_startTime:null,_endTime:null,_handles:null,_invalids:null,_invalidsDefault:{"textarea":true,"input":true,"a":true,"button":true},_dragThreshMet:null,_fromTimeout:null,_clickTimeout:null,deltaXY:null,startXY:null,nodeXY:null,lastXY:null,realXY:null,mouseXY:null,region:null,_handleMouseUp:function(T){this._fixIEMouseUp();if(E.activeDrag){E._end();}},_fixDragStart:function(T){T.preventDefault();},_ieSelectFix:function(){return false;},_ieSelectBack:null,_fixIEMouseDown:function(){if(D.UA.ie){this._ieSelectBack=D.config.doc.body.onselectstart;D.config.doc.body.onselectstart=this._ieSelectFix;}},_fixIEMouseUp:function(){if(D.UA.ie){D.config.doc.body.onselectstart=this._ieSelectBack;}},_handleMouseDownEvent:function(T){this.fire(G,{ev:T});},_handleMouseDown:function(V){var U=V.ev;this._dragThreshMet=false;this._ev_md=U;if(this.get("primaryButtonOnly")&&U.button>1){return false;}if(this.validClick(U)){this._fixIEMouseDown();U.halt();this._setStartPosition([U.pageX,U.pageY]);E.activeDrag=this;var T=this;this._clickTimeout=setTimeout(function(){T._timeoutCheck.call(T);},this.get("clickTimeThresh"));}this.fire(B,{ev:U});},validClick:function(X){var W=false,T=X.target,V=null;if(this._handles){D.each(this._handles,function(Z,a){if(D.Lang.isString(a)){if(T.test(a+", "+a+" *")&&!V){V=a;W=true;}}});}else{if(this.get(S).contains(T)||this.get(S).compareTo(T)){W=true;}}if(W){if(this._invalids){D.each(this._invalids,function(Z,a){if(D.Lang.isString(a)){if(T.test(a+", "+a+" *")){W=false;}}});}}if(W){if(V){var U=X.currentTarget.queryAll(V),Y=false;U.each(function(a,Z){if((a.contains(T)||a.compareTo(T))&&!Y){Y=true;this.set("activeHandle",U.item(Z));}},this);}else{this.set("activeHandle",this.get(S));}}return W;},_setStartPosition:function(T){this.startXY=T;this.nodeXY=this.get(S).getXY();this.lastXY=this.nodeXY;this.realXY=this.nodeXY;if(this.get("offsetNode")){this.deltaXY=[(this.startXY[0]-this.nodeXY[0]),(this.startXY[1]-this.nodeXY[1])];}else{this.deltaXY=[0,0];}},_timeoutCheck:function(){if(!this.get("lock")){this._fromTimeout=true;this._dragThreshMet=true;this.start();this._moveNode([this._ev_md.pageX,this._ev_md.pageY],true);}},removeHandle:function(T){if(this._handles[T]){delete this._handles[T];this.fire(F,{handle:T});}return this;},addHandle:function(T){if(!this._handles){this._handles={};}if(D.Lang.isString(T)){this._handles[T]=true;this.fire(K,{handle:T});}return this;},removeInvalid:function(T){if(this._invalids[T]){this._invalids[T]=null;delete this._invalids[T];this.fire(P,{handle:T});}return this;},addInvalid:function(T){if(D.Lang.isString(T)){this._invalids[T]=true;this.fire(R,{handle:T});}else{}return this;},initializer:function(){if(!this.get(S).get("id")){var T=D.stamp(this.get(S));this.get(S).set("id",T);}this._invalids=D.clone(this._invalidsDefault,true);this._createEvents();if(!this.get(M)){this.set(M,this.get(S));}this._prep();this._dragThreshMet=false;},_prep:function(){var T=this.get(S);T.addClass(E.CSS_PREFIX+"-draggable");
+T.on(O,this._handleMouseDownEvent,this,true);T.on(Q,this._handleMouseUp,this,true);T.on(L,this._fixDragStart,this,true);},_unprep:function(){var T=this.get(S);T.removeClass(E.CSS_PREFIX+"-draggable");T.detach(O,this._handleMouseDownEvent,this,true);T.detach(Q,this._handleMouseUp,this,true);T.detach(L,this._fixDragStart,this,true);},start:function(){if(!this.get("lock")&&!this.get("dragging")){this.set("dragging",true);E._start(this.deltaXY,[this.get(S).get(C),this.get(S).get(J)]);this.get(S).addClass(E.CSS_PREFIX+"-dragging");this.fire(I,{pageX:this.nodeXY[0],pageY:this.nodeXY[1]});this.get(M).on(Q,this._handleMouseUp,this,true);var T=this.nodeXY;this._startTime=(new Date()).getTime();this.region={"0":T[0],"1":T[1],area:0,top:T[1],right:T[0]+this.get(S).get(J),bottom:T[1]+this.get(S).get(C),left:T[0]};}return this;},end:function(){this._endTime=(new Date()).getTime();clearTimeout(this._clickTimeout);this._dragThreshMet=false;this._fromTimeout=false;if(!this.get("lock")&&this.get("dragging")){this.fire(H,{pageX:this.lastXY[0],pageY:this.lastXY[1]});}this.get(S).removeClass(E.CSS_PREFIX+"-dragging");this.set("dragging",false);this.deltaXY=[0,0];this.get(M).detach(Q,this._handleMouseUp,this,true);return this;},_align:function(T){return[T[0]-this.deltaXY[0],T[1]-this.deltaXY[1]];},_moveNode:function(T,Y){var X=this._align(T),U=[],V=[];U[0]=(X[0]-this.lastXY[0]);U[1]=(X[1]-this.lastXY[1]);V[0]=(X[0]-this.nodeXY[0]);V[1]=(X[1]-this.nodeXY[1]);if(this.get("move")){if(D.UA.opera){this.get(M).setXY(X);}else{E.setXY(this.get(M),U);}this.realXY=X;}this.region={"0":X[0],"1":X[1],area:0,top:X[1],right:X[0]+this.get(M).get(J),bottom:X[1]+this.get(M).get(C),left:X[0]};var W=this.nodeXY;if(!Y){this.fire(N,{pageX:X[0],pageY:X[1],info:{start:W,xy:X,delta:U,offset:V}});}this.lastXY=X;},_move:function(V){if(this.get("lock")){return false;}else{this.mouseXY=[V.pageX,V.pageY];if(!this._dragThreshMet){var U=Math.abs(this.startXY[0]-V.pageX);var T=Math.abs(this.startXY[1]-V.pageY);if(U>this.get("clickPixelThresh")||T>this.get("clickPixelThresh")){this._dragThreshMet=true;this.start();this._moveNode([V.pageX,V.pageY]);}}else{clearTimeout(this._clickTimeout);this._moveNode([V.pageX,V.pageY]);}}},stopDrag:function(){if(this.get("dragging")){E._end();}return this;},destructor:function(){E._unregDrag(this);this._unprep();if(this.target){this.target.destroy();}}});D.namespace("DD");D.DD.Drag=A;},"3.0.0pr2",{requires:["dd-ddm-base"],skinnable:false});YUI.add("dd-proxy",function(F){var E=F.DD.DDM,A="node",B="dragNode",C="proxy";var G=function(){G.superclass.constructor.apply(this,arguments);};G.NAME="dragProxy";G.ATTRS={moveOnEnd:{value:true},resizeFrame:{value:true},proxy:{value:false},positionProxy:{value:true},borderStyle:{value:"1px solid #808080"}};var D={_createFrame:function(){if(!E._proxy){E._proxy=true;var I=F.Node.create("<div></div>");I.setStyles({position:"absolute",display:"none",zIndex:"999",top:"-999px",left:"-999px",border:this.get("borderStyle")});var H=F.Node.get("body");H.insertBefore(I,H.get("firstChild"));I.set("id",F.stamp(I));I.addClass(E.CSS_PREFIX+"-proxy");E._proxy=I;}},_setFrame:function(){var H=this.get(A);if(this.get("resizeFrame")){E._proxy.setStyles({height:H.get("offsetHeight")+"px",width:H.get("offsetWidth")+"px"});}this.get(B).setStyles({visibility:"hidden",display:"block",border:this.get("borderStyle")});if(this.get("positionProxy")){this.get(B).setXY(this.nodeXY);}this.get(B).setStyle("visibility","visible");},initializer:function(){if(this.get(C)){this._createFrame();}},start:function(){if(!this.get("lock")){if(this.get(C)){if(this.get(B).compareTo(this.get(A))){this.set(B,E._proxy);}}else{this.set(B,this.get(A));}}G.superclass.start.apply(this);if(this.get(C)){this._setFrame();}},end:function(){if(this.get(C)&&this.get("dragging")){if(this.get("moveOnEnd")){this.get(A).setXY(this.lastXY);}this.get(B).setStyle("display","none");}G.superclass.end.apply(this);}};F.extend(G,F.DD.Drag,D);F.DD.Drag=G;},"3.0.0pr2",{requires:["dd-ddm","dd-drag"],skinnable:false});YUI.add("dd-constrain",function(E){var A="dragNode",G="offsetHeight",F="offsetWidth";var D=function(){D.superclass.constructor.apply(this,arguments);};D.NAME="dragConstrained";D.ATTRS={stickX:{value:false},stickY:{value:false},tickX:{value:false},tickY:{value:false},tickXArray:{value:false},tickYArray:{value:false},constrain2region:{value:false,get:function(C){if(E.Lang.isObject(C)){var H={};E.mix(H,C);return H;}else{return false;}},set:function(C){if(E.Lang.isObject(C)){if(C.top&&C.right&&C.left&&C.bottom){var H={};E.mix(H,C);return H;}else{return false;}}else{if(C!==false){return false;}}}},gutter:{value:"0",set:function(C){return E.DD.DDM.cssSizestoObject(C);}},constrain2node:{value:false,set:function(H){if(!this.get("constrain2region")){var C=E.Node.get(H);if(C){return C;}}else{if(this.get("constrain2region")!==false){}}return false;}},constrain2view:{value:false}};var B={start:function(){D.superclass.start.apply(this,arguments);this._regionCache=null;},_regionCache:null,_cacheRegion:function(){this._regionCache=this.get("constrain2node").get("region");},getRegion:function(K){var I={};if(this.get("constrain2node")){if(!this._regionCache){E.on("resize",this._cacheRegion,this,true,window);this._cacheRegion();}I=E.clone(this._regionCache);}else{if(this.get("constrain2region")){I=this.get("constrain2region");}else{if(this.get("constrain2view")){I=this.get("node").get("viewportRegion");}else{return false;}}}var H=this.get("gutter");E.each(H,function(L,M){if((M=="right")||(M=="bottom")){I[M]-=L;}else{I[M]+=L;}});if(K){var J=this.get(A).get(G),C=this.get(A).get(F);I.right=I.right-C;I.bottom=I.bottom-J;}return I;},_checkRegion:function(C){var I=C,J=this.getRegion(),K=this.get(A).get(G),H=this.get(A).get(F);if(I[1]>(J.bottom-K)){C[1]=(J.bottom-K);}if(J.top>I[1]){C[1]=J.top;}if(I[0]>(J.right-H)){C[0]=(J.right-H);}if(J.left>I[0]){C[0]=J.left;}return C;},inRegion:function(I){I=I||this.get(A).getXY();var H=this._checkRegion([I[0],I[1]]),C=false;
+if((I[0]===H[0])&&(I[1]===H[1])){C=true;}return C;},_align:function(I){var C=D.superclass._align.apply(this,arguments),H=this.getRegion(true);if(this.get("stickX")){C[1]=(this.startXY[1]-this.deltaXY[1]);}if(this.get("stickY")){C[0]=(this.startXY[0]-this.deltaXY[0]);}if(H){C=this._checkRegion(C);}C=this._checkTicks(C,H);return C;},_calcTicks:function(N,M,J,L,K){var H=((N-M)/J),I=Math.floor(H),C=Math.ceil(H);if((I!==0)||(C!==0)){if((H>=I)&&(H<=C)){N=(M+(J*I));if(L&&K){if(N<L){N=(M+(J*(I+1)));}if(N>K){N=(M+(J*(I-1)));}}}}return N;},_calcTickArray:function(O,P,N,K){var H=0,L=P.length,J=0;if(!P||(P.length===0)){return O;}else{if(P[0]>=O){return P[0];}else{for(H=0;H<L;H++){J=(H+1);if(P[J]&&P[J]>=O){var I=O-P[H],C=P[J]-O;var M=(C>I)?P[H]:P[J];if(N&&K){if(M>K){if(P[H]){M=P[H];}else{M=P[L-1];}}}return M;}}return P[P.length-1];}}},_checkTicks:function(L,J){var K=(this.startXY[0]-this.deltaXY[0]),I=(this.startXY[1]-this.deltaXY[1]),C=this.get("tickX"),H=this.get("tickY");if(C&&!this.get("tickXArray")){L[0]=this._calcTicks(L[0],K,C,J.left,J.right);}if(H&&!this.get("tickYArray")){L[1]=this._calcTicks(L[1],I,H,J.top,J.bottom);}if(this.get("tickXArray")){L[0]=this._calcTickArray(L[0],this.get("tickXArray"),J.left,J.right);}if(this.get("tickYArray")){L[1]=this._calcTickArray(L[1],this.get("tickYArray"),J.top,J.bottom);}return L;}};E.extend(D,E.DD.Drag,B);E.DD.Drag=D;},"3.0.0pr2",{requires:["dd-drag","dd-proxy"],skinnable:false});YUI.add("dd-plugin",function(B){var A=function(C){C.node=C.owner;A.superclass.constructor.apply(this,arguments);};A.NAME="dd-plugin";A.NS="dd";B.extend(A,B.DD.Drag);B.namespace("plugin");B.plugin.Drag=A;},"3.0.0pr2",{requires:["dd-drag"],skinnable:false,optional:["dd-constrain","dd-proxy"]});YUI.add("dd-drop",function(A){var B="node",G=A.DD.DDM,F="offsetHeight",C="offsetWidth",I="drop:over",H="drop:enter",D="drop:exit";var E=function(){E.superclass.constructor.apply(this,arguments);this._createShim();G._regTarget(this);};E.NAME="drop";E.ATTRS={node:{set:function(J){var K=A.Node.get(J);if(!K){A.fail("DD.Drop: Invalid Node Given: "+J);}return K;}},groups:{value:["default"],set:function(J){this._groups={};A.each(J,function(L,K){this._groups[L]=true;},this);}},padding:{value:"0",set:function(J){return G.cssSizestoObject(J);}},lock:{value:false,set:function(J){if(J){this.get(B).addClass(G.CSS_PREFIX+"-drop-locked");}else{this.get(B).removeClass(G.CSS_PREFIX+"-drop-locked");}}},bubbles:{writeOnce:true,value:A.DD.DDM}};A.extend(E,A.Base,{_createEvents:function(){var J=[I,H,D,"drop:hit"];A.each(J,function(L,K){this.publish(L,{type:L,emitFacade:true,preventable:false,bubbles:true,queuable:true});},this);if(this.get("bubbles")){this.addTarget(this.get("bubbles"));}},_valid:null,_groups:null,shim:null,region:null,overTarget:null,inGroup:function(J){this._valid=false;var K=false;A.each(J,function(M,L){if(this._groups[M]){K=true;this._valid=true;}},this);return K;},initializer:function(){this._createEvents();var J=this.get(B);if(!J.get("id")){var K=A.stamp(J);J.set("id",K);}J.addClass(G.CSS_PREFIX+"-drop");},destructor:function(){G._unregTarget(this);if(this.shim){this.shim.get("parentNode").removeChild(this.shim);this.shim=null;}this.get(B).removeClass(G.CSS_PREFIX+"-drop");},_deactivateShim:function(){this.get(B).removeClass(G.CSS_PREFIX+"-drop-active-valid");this.get(B).removeClass(G.CSS_PREFIX+"-drop-active-invalid");this.get(B).removeClass(G.CSS_PREFIX+"-drop-over");this.shim.setStyles({top:"-999px",left:"-999px"});this.overTarget=false;},_activateShim:function(){if(!G.activeDrag){return false;}if(this.get(B)===G.activeDrag.get(B)){return false;}if(this.get("lock")){return false;}var J=this.get(B);if(this.inGroup(G.activeDrag.get("groups"))){J.removeClass(G.CSS_PREFIX+"-drop-active-invalid");J.addClass(G.CSS_PREFIX+"-drop-active-valid");G._addValid(this);this.overTarget=false;this.sizeShim();}else{G._removeValid(this);J.removeClass(G.CSS_PREFIX+"-drop-active-valid");J.addClass(G.CSS_PREFIX+"-drop-active-invalid");}},sizeShim:function(){if(!G.activeDrag){return false;}if(this.get(B)===G.activeDrag.get(B)){return false;}if(this.get("lock")){return false;}var O=this.get(B),M=O.get(F),K=O.get(C),Q=O.getXY(),P=this.get("padding");K=K+P.left+P.right;M=M+P.top+P.bottom;Q[0]=Q[0]-P.left;Q[1]=Q[1]-P.top;if(G.activeDrag.get("dragMode")===G.INTERSECT){var J=G.activeDrag,N=J.get(B).get(F),L=J.get(B).get(C);M=(M+N);K=(K+L);Q[0]=Q[0]-(L-J.deltaXY[0]);Q[1]=Q[1]-(N-J.deltaXY[1]);}this.shim.setStyles({height:M+"px",width:K+"px",top:Q[1]+"px",left:Q[0]+"px"});this.region={"0":Q[0],"1":Q[1],area:0,top:Q[1],right:Q[0]+K,bottom:Q[1]+M,left:Q[0]};},_createShim:function(){var J=A.Node.create('<div id="'+this.get(B).get("id")+'_shim"></div>');J.setStyles({height:this.get(B).get(F)+"px",width:this.get(B).get(C)+"px",backgroundColor:"yellow",opacity:".5",zIndex:999,overflow:"hidden",top:"-900px",left:"-900px",position:"absolute"});G._pg.appendChild(J);this.shim=J;J.on("mouseover",this._handleOverEvent,this,true);J.on("mouseout",this._handleOutEvent,this,true);},_handleTargetOver:function(){if(G.isOverTarget(this)){this.get(B).addClass(G.CSS_PREFIX+"-drop-over");G.activeDrop=this;G.otherDrops[this]=this;if(this.overTarget){G.activeDrag.fire("drag:over",{drop:this,drag:G.activeDrag});this.fire(I,{drop:this,drag:G.activeDrag});}else{this.overTarget=true;this.fire(H,{drop:this,drag:G.activeDrag});G.activeDrag.fire("drag:enter",{drop:this,drag:G.activeDrag});G.activeDrag.get(B).addClass(G.CSS_PREFIX+"-drag-over");G._handleTargetOver();}}else{this._handleOut();}},_handleOverEvent:function(){G._addActiveShim(this);},_handleOutEvent:function(){G._removeActiveShim(this);},_handleOut:function(){if(!G.isOverTarget(this)){if(this.overTarget){this.overTarget=false;G._removeActiveShim(this);if(G.activeDrag){this.get(B).removeClass(G.CSS_PREFIX+"-drop-over");G.activeDrag.get(B).removeClass(G.CSS_PREFIX+"-drag-over");this.fire(D);G.activeDrag.fire("drag:exit",{drop:this});delete G.otherDrops[this];}}}}});A.DD.Drop=E;},"3.0.0pr2",{requires:["dd-ddm-drop","dd-drag"],skinnable:false});
+YUI.add("dd-drop-plugin",function(A){var B=function(C){C.node=C.owner;B.superclass.constructor.apply(this,arguments);};B.NAME="dd-drop-plugin";B.NS="drop";A.extend(B,A.DD.Drop);A.namespace("plugin");A.plugin.Drop=B;},"3.0.0pr2",{requires:["dd-drop"],skinnable:false});YUI.add("dd",function(A){},"3.0.0pr2",{use:["dd-ddm-base","dd-ddm","dd-ddm-drop","dd-drag","dd-proxy","dd-constrain","dd-plugin","dd-drop","dd-drop-plugin"],skinnable:false});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-plugin-debug.js'
--- loggerhead/static/javascript/yui/build/dd/dd-plugin-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-plugin-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,48 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-plugin', function(Y) {
+
+       /**
+        * This is a simple Drag plugin that can be attached to a Node via the plug method.
+        * @module dd-plugin
+        * @submodule dd-plugin
+        */
+       /**
+        * This is a simple Drag plugin that can be attached to a Node via the plug method.
+        * @class DragPlugin
+        * @extends Drag
+        * @constructor
+        * @namespace plugin
+        */
+
+
+        var Drag = function(config) {
+            config.node = config.owner;
+            Drag.superclass.constructor.apply(this, arguments);
+        };
+        
+        /**
+        * @property NAME
+        * @description dd-plugin
+        * @type {String}
+        */
+        Drag.NAME = "dd-plugin";
+        /**
+        * @property NS
+        * @description The Drag instance will be placed on the Node instance under the dd namespace. It can be accessed via Node.dd;
+        * @type {String}
+        */
+        Drag.NS = "dd";
+
+
+        Y.extend(Drag, Y.DD.Drag);
+        Y.namespace('plugin');
+        Y.plugin.Drag = Drag;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drag'], skinnable:false, optional:['dd-constrain', 'dd-proxy']});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-plugin-min.js'
--- loggerhead/static/javascript/yui/build/dd/dd-plugin-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-plugin-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dd-plugin",function(B){var A=function(C){C.node=C.owner;A.superclass.constructor.apply(this,arguments);};A.NAME="dd-plugin";A.NS="dd";B.extend(A,B.DD.Drag);B.namespace("plugin");B.plugin.Drag=A;},"3.0.0pr2",{requires:["dd-drag"],skinnable:false,optional:["dd-constrain","dd-proxy"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-plugin.js'
--- loggerhead/static/javascript/yui/build/dd/dd-plugin.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-plugin.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,48 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-plugin', function(Y) {
+
+       /**
+        * This is a simple Drag plugin that can be attached to a Node via the plug method.
+        * @module dd-plugin
+        * @submodule dd-plugin
+        */
+       /**
+        * This is a simple Drag plugin that can be attached to a Node via the plug method.
+        * @class DragPlugin
+        * @extends Drag
+        * @constructor
+        * @namespace plugin
+        */
+
+
+        var Drag = function(config) {
+            config.node = config.owner;
+            Drag.superclass.constructor.apply(this, arguments);
+        };
+        
+        /**
+        * @property NAME
+        * @description dd-plugin
+        * @type {String}
+        */
+        Drag.NAME = "dd-plugin";
+        /**
+        * @property NS
+        * @description The Drag instance will be placed on the Node instance under the dd namespace. It can be accessed via Node.dd;
+        * @type {String}
+        */
+        Drag.NS = "dd";
+
+
+        Y.extend(Drag, Y.DD.Drag);
+        Y.namespace('plugin');
+        Y.plugin.Drag = Drag;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drag'], skinnable:false, optional:['dd-constrain', 'dd-proxy']});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-proxy-debug.js'
--- loggerhead/static/javascript/yui/build/dd/dd-proxy-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-proxy-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,178 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-proxy', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-proxy
+     */
+    /**
+     * This class extends dd-drag to allow for creating a proxy drag node, instead of dragging the original node.
+     * @class Proxy
+     * @extends Drag
+     * @constructor
+     */
+    var DDM = Y.DD.DDM,
+        NODE = 'node',
+        DRAG_NODE = 'dragNode',
+        PROXY = 'proxy';
+     
+
+    var Proxy = function() {
+        Proxy.superclass.constructor.apply(this, arguments);
+
+    };
+
+    Proxy.NAME = 'dragProxy';
+
+    Proxy.ATTRS = {
+        /**
+        * @attribute moveOnEnd
+        * @description Move the original node at the end of the drag. Default: true
+        * @type Boolean
+        */
+        moveOnEnd: {
+            value: true
+        },
+        /**
+        * @attribute resizeFrame
+        * @description Make the Proxy node assume the size of the original node. Default: true
+        * @type Boolean
+        */
+        resizeFrame: {
+            value: true
+        },
+        /**
+        * @attribute proxy
+        * @description Make this Draggable instance a Proxy instance. Default: false
+        * @type Boolean
+        */
+        proxy: {
+            value: false
+        },        
+        /**
+        * @attribute positionProxy
+        * @description Make the Proxy node appear in the same place as the original node. Default: true
+        * @type Boolean
+        */
+        positionProxy: {
+            value: true
+        },
+        /**
+        * @attribute borderStyle
+        * @description The default border style for the border of the proxy. Default: 1px solid #808080
+        * @type Boolean
+        */
+        borderStyle: {
+            value: '1px solid #808080'
+        }
+    };
+
+    var proto = {
+        /**
+        * @private
+        * @method _createFrame
+        * @description Create the proxy element if it doesn't already exist and set the DD.DDM._proxy value
+        */
+        _createFrame: function() {
+            if (!DDM._proxy) {
+                DDM._proxy = true;
+                var p = Y.Node.create('<div></div>');
+
+                p.setStyles({
+                    position: 'absolute',
+                    display: 'none',
+                    zIndex: '999',
+                    top: '-999px',
+                    left: '-999px',
+                    border: this.get('borderStyle')
+                });
+
+                var b = Y.Node.get('body');
+                b.insertBefore(p, b.get('firstChild'));
+                p.set('id', Y.stamp(p));
+                p.addClass(DDM.CSS_PREFIX + '-proxy');
+                DDM._proxy = p;
+            }
+        },
+        /**
+        * @private
+        * @method _setFrame
+        * @description If resizeProxy is set to true (default) it will resize the proxy element to match the size of the Drag Element.
+        * If positionProxy is set to true (default) it will position the proxy element in the same location as the Drag Element.
+        */
+        _setFrame: function() {
+            var n = this.get(NODE);
+            if (this.get('resizeFrame')) {
+                DDM._proxy.setStyles({
+                    height: n.get('offsetHeight') + 'px',
+                    width: n.get('offsetWidth') + 'px'
+                });
+            }
+            this.get(DRAG_NODE).setStyles({
+                visibility: 'hidden',
+                display: 'block',
+                border: this.get('borderStyle')
+            });
+
+            if (this.get('positionProxy')) {
+                this.get(DRAG_NODE).setXY(this.nodeXY);
+            }
+            this.get(DRAG_NODE).setStyle('visibility', 'visible');
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Lifecycle method
+        */
+        initializer: function() {
+            if (this.get(PROXY)) {
+                this._createFrame();
+            }
+        },
+        /**
+        * @method start
+        * @description Starts the drag operation and sets the dragNode config option.
+        */       
+        start: function() {
+            if (!this.get('lock')) {
+                if (this.get(PROXY)) {
+                    if (this.get(DRAG_NODE).compareTo(this.get(NODE))) {
+                        this.set(DRAG_NODE, DDM._proxy);
+                    }
+                } else {
+                    this.set(DRAG_NODE, this.get(NODE));
+                }
+            }
+            Proxy.superclass.start.apply(this);
+            if (this.get(PROXY)) {
+                this._setFrame();
+            }
+        },
+        /**
+        * @method end
+        * @description Ends the drag operation, if moveOnEnd is set it will position the Drag Element to the new location of the proxy.
+        */        
+        end: function() {
+            if (this.get(PROXY) && this.get('dragging')) {
+                if (this.get('moveOnEnd')) {
+                    this.get(NODE).setXY(this.lastXY);
+                }
+                this.get(DRAG_NODE).setStyle('display', 'none');
+            }
+            Proxy.superclass.end.apply(this);
+        }
+    };
+    //Extend DD.Drag
+    Y.extend(Proxy, Y.DD.Drag, proto);
+    //Set this new class as DD.Drag for other extensions
+    Y.DD.Drag = Proxy;    
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm', 'dd-drag'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-proxy-min.js'
--- loggerhead/static/javascript/yui/build/dd/dd-proxy-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-proxy-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dd-proxy",function(F){var E=F.DD.DDM,A="node",B="dragNode",C="proxy";var G=function(){G.superclass.constructor.apply(this,arguments);};G.NAME="dragProxy";G.ATTRS={moveOnEnd:{value:true},resizeFrame:{value:true},proxy:{value:false},positionProxy:{value:true},borderStyle:{value:"1px solid #808080"}};var D={_createFrame:function(){if(!E._proxy){E._proxy=true;var I=F.Node.create("<div></div>");I.setStyles({position:"absolute",display:"none",zIndex:"999",top:"-999px",left:"-999px",border:this.get("borderStyle")});var H=F.Node.get("body");H.insertBefore(I,H.get("firstChild"));I.set("id",F.stamp(I));I.addClass(E.CSS_PREFIX+"-proxy");E._proxy=I;}},_setFrame:function(){var H=this.get(A);if(this.get("resizeFrame")){E._proxy.setStyles({height:H.get("offsetHeight")+"px",width:H.get("offsetWidth")+"px"});}this.get(B).setStyles({visibility:"hidden",display:"block",border:this.get("borderStyle")});if(this.get("positionProxy")){this.get(B).setXY(this.nodeXY);}this.get(B).setStyle("visibility","visible");},initializer:function(){if(this.get(C)){this._createFrame();}},start:function(){if(!this.get("lock")){if(this.get(C)){if(this.get(B).compareTo(this.get(A))){this.set(B,E._proxy);}}else{this.set(B,this.get(A));}}G.superclass.start.apply(this);if(this.get(C)){this._setFrame();}},end:function(){if(this.get(C)&&this.get("dragging")){if(this.get("moveOnEnd")){this.get(A).setXY(this.lastXY);}this.get(B).setStyle("display","none");}G.superclass.end.apply(this);}};F.extend(G,F.DD.Drag,D);F.DD.Drag=G;},"3.0.0pr2",{requires:["dd-ddm","dd-drag"],skinnable:false});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dd/dd-proxy.js'
--- loggerhead/static/javascript/yui/build/dd/dd-proxy.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd-proxy.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,178 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-proxy', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-proxy
+     */
+    /**
+     * This class extends dd-drag to allow for creating a proxy drag node, instead of dragging the original node.
+     * @class Proxy
+     * @extends Drag
+     * @constructor
+     */
+    var DDM = Y.DD.DDM,
+        NODE = 'node',
+        DRAG_NODE = 'dragNode',
+        PROXY = 'proxy';
+     
+
+    var Proxy = function() {
+        Proxy.superclass.constructor.apply(this, arguments);
+
+    };
+
+    Proxy.NAME = 'dragProxy';
+
+    Proxy.ATTRS = {
+        /**
+        * @attribute moveOnEnd
+        * @description Move the original node at the end of the drag. Default: true
+        * @type Boolean
+        */
+        moveOnEnd: {
+            value: true
+        },
+        /**
+        * @attribute resizeFrame
+        * @description Make the Proxy node assume the size of the original node. Default: true
+        * @type Boolean
+        */
+        resizeFrame: {
+            value: true
+        },
+        /**
+        * @attribute proxy
+        * @description Make this Draggable instance a Proxy instance. Default: false
+        * @type Boolean
+        */
+        proxy: {
+            value: false
+        },        
+        /**
+        * @attribute positionProxy
+        * @description Make the Proxy node appear in the same place as the original node. Default: true
+        * @type Boolean
+        */
+        positionProxy: {
+            value: true
+        },
+        /**
+        * @attribute borderStyle
+        * @description The default border style for the border of the proxy. Default: 1px solid #808080
+        * @type Boolean
+        */
+        borderStyle: {
+            value: '1px solid #808080'
+        }
+    };
+
+    var proto = {
+        /**
+        * @private
+        * @method _createFrame
+        * @description Create the proxy element if it doesn't already exist and set the DD.DDM._proxy value
+        */
+        _createFrame: function() {
+            if (!DDM._proxy) {
+                DDM._proxy = true;
+                var p = Y.Node.create('<div></div>');
+
+                p.setStyles({
+                    position: 'absolute',
+                    display: 'none',
+                    zIndex: '999',
+                    top: '-999px',
+                    left: '-999px',
+                    border: this.get('borderStyle')
+                });
+
+                var b = Y.Node.get('body');
+                b.insertBefore(p, b.get('firstChild'));
+                p.set('id', Y.stamp(p));
+                p.addClass(DDM.CSS_PREFIX + '-proxy');
+                DDM._proxy = p;
+            }
+        },
+        /**
+        * @private
+        * @method _setFrame
+        * @description If resizeProxy is set to true (default) it will resize the proxy element to match the size of the Drag Element.
+        * If positionProxy is set to true (default) it will position the proxy element in the same location as the Drag Element.
+        */
+        _setFrame: function() {
+            var n = this.get(NODE);
+            if (this.get('resizeFrame')) {
+                DDM._proxy.setStyles({
+                    height: n.get('offsetHeight') + 'px',
+                    width: n.get('offsetWidth') + 'px'
+                });
+            }
+            this.get(DRAG_NODE).setStyles({
+                visibility: 'hidden',
+                display: 'block',
+                border: this.get('borderStyle')
+            });
+
+            if (this.get('positionProxy')) {
+                this.get(DRAG_NODE).setXY(this.nodeXY);
+            }
+            this.get(DRAG_NODE).setStyle('visibility', 'visible');
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Lifecycle method
+        */
+        initializer: function() {
+            if (this.get(PROXY)) {
+                this._createFrame();
+            }
+        },
+        /**
+        * @method start
+        * @description Starts the drag operation and sets the dragNode config option.
+        */       
+        start: function() {
+            if (!this.get('lock')) {
+                if (this.get(PROXY)) {
+                    if (this.get(DRAG_NODE).compareTo(this.get(NODE))) {
+                        this.set(DRAG_NODE, DDM._proxy);
+                    }
+                } else {
+                    this.set(DRAG_NODE, this.get(NODE));
+                }
+            }
+            Proxy.superclass.start.apply(this);
+            if (this.get(PROXY)) {
+                this._setFrame();
+            }
+        },
+        /**
+        * @method end
+        * @description Ends the drag operation, if moveOnEnd is set it will position the Drag Element to the new location of the proxy.
+        */        
+        end: function() {
+            if (this.get(PROXY) && this.get('dragging')) {
+                if (this.get('moveOnEnd')) {
+                    this.get(NODE).setXY(this.lastXY);
+                }
+                this.get(DRAG_NODE).setStyle('display', 'none');
+            }
+            Proxy.superclass.end.apply(this);
+        }
+    };
+    //Extend DD.Drag
+    Y.extend(Proxy, Y.DD.Drag, proto);
+    //Set this new class as DD.Drag for other extensions
+    Y.DD.Drag = Proxy;    
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm', 'dd-drag'], skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dd/dd.js'
--- loggerhead/static/javascript/yui/build/dd/dd.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dd/dd.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,2860 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dd-ddm-base', function(Y) {
+
+    /**
+     * Provides the base Drag Drop Manger required for making a Node draggable.
+     * @module dd
+     * @submodule dd-ddm-base
+     */     
+     /**
+     * Provides the base Drag Drop Manger required for making a Node draggable.
+     * @class DDM
+     * @extends Base
+     * @constructor
+     */
+    
+    var DDMBase = function() {
+        //debugger;
+        DDMBase.superclass.constructor.apply(this, arguments);
+    };
+
+    DDMBase.NAME = 'dragDropMgr';
+
+    DDMBase.ATTRS = {
+        /**
+        * @attribute clickPixelThresh
+        * @description The number of pixels to move to start a drag operation, default is 3.
+        * @type Number
+        */
+        clickPixelThresh: {
+            value: 3
+        },
+        /**
+        * @attribute clickTimeThresh
+        * @description The number of milliseconds a mousedown has to pass to start a drag operation, default is 1000.
+        * @type Number
+        */        
+        clickTimeThresh: {
+            value: 1000
+        },
+        /**
+        * @attribute dragMode
+        * @description This attribute only works if the dd-drop module is active. It will set the dragMode (point, intersect, strict) of all future Drag instances. 
+        * @type String
+        */        
+        dragMode: {
+            value: 'point',
+            set: function(mode) {
+                this._setDragMode(mode);
+            }           
+        }
+
+    };
+
+    Y.extend(DDMBase, Y.Base, {
+        /**
+        * @private
+        * @method _setDragMode
+        * @description Handler for dragMode attribute setter.
+        * @param String/Number The Number value or the String for the DragMode to default all future drag instances to.
+        * @return Number The Mode to be set
+        */
+        _setDragMode: function(mode) {
+            if (mode === null) {
+                mode = Y.DD.DDM.get('dragMode');
+            }
+            switch (mode) {
+                case 1:
+                case 'intersect':
+                    return 1;
+                case 2:
+                case 'strict':
+                    return 2;
+                case 0:
+                case 'point':
+                    return 0;
+            }
+            return 0;       
+        },
+        /**
+        * @property CSS_PREFIX
+        * @description The PREFIX to attach to all DD CSS class names
+        * @type {String}
+        */
+        CSS_PREFIX: 'yui-dd',
+        _activateTargets: function() {},        
+        /**
+        * @private
+        * @property _drags
+        * @description Holder for all registered drag elements.
+        * @type {Array}
+        */
+        _drags: [],
+        /**
+        * @property activeDrag
+        * @description A reference to the currently active draggable object.
+        * @type {Drag}
+        */
+        activeDrag: false,
+        /**
+        * @private
+        * @method _regDrag
+        * @description Adds a reference to the drag object to the DDM._drags array, called in the constructor of Drag.
+        * @param {Drag} d The Drag object
+        */
+        _regDrag: function(d) {
+            this._drags[this._drags.length] = d;
+        },
+        /**
+        * @private
+        * @method _unregDrag
+        * @description Remove this drag object from the DDM._drags array.
+        * @param {Drag} d The drag object.
+        */
+        _unregDrag: function(d) {
+            var tmp = [];
+            Y.each(this._drags, function(n, i) {
+                if (n !== d) {
+                    tmp[tmp.length] = n;
+                }
+            });
+            this._drags = tmp;
+        },
+        /**
+        * @private
+        * @method _init
+        * @description DDM's init method
+        */
+        initializer: function() {
+            Y.Node.get('document').on('mousemove', this._move, this, true);
+            Y.Node.get('document').on('mouseup', this._end, this, true);
+        },
+        /**
+        * @private
+        * @method _start
+        * @description Internal method used by Drag to signal the start of a drag operation
+        * @param {Number} x The x position of the drag element
+        * @param {Number} y The y position of the drag element
+        * @param {Number} w The width of the drag element
+        * @param {Number} h The height of the drag element
+        */
+        _start: function(x, y, w, h) {
+            this._startDrag.apply(this, arguments);
+        },
+        /**
+        * @private
+        * @method _startDrag
+        * @description Factory method to be overwritten by other DDM's
+        * @param {Number} x The x position of the drag element
+        * @param {Number} y The y position of the drag element
+        * @param {Number} w The width of the drag element
+        * @param {Number} h The height of the drag element
+        */
+        _startDrag: function() {},
+        /**
+        * @private
+        * @method _endDrag
+        * @description Factory method to be overwritten by other DDM's
+        */
+        _endDrag: function() {},
+        _dropMove: function() {},
+        /**
+        * @private
+        * @method _end
+        * @description Internal method used by Drag to signal the end of a drag operation
+        */
+        _end: function() {
+            //@TODO - Here we can get a (click - drag - click - release) interaction instead of a (mousedown - drag - mouseup - release) interaction
+            //Add as a config option??
+            if (this.activeDrag) {
+                this._endDrag();
+                this.activeDrag.end.call(this.activeDrag);
+                this.activeDrag = null;
+            }
+        },
+        /**
+        * @method stopDrag
+        * @description Method will forcefully stop a drag operation. For example calling this from inside an ESC keypress handler will stop this drag.
+        * @return {Self}
+        * @chainable
+        */       
+        stopDrag: function() {
+            if (this.activeDrag) {
+                this._end();
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method _move
+        * @description Internal listener for the mousemove DOM event to pass to the Drag's move method.
+        * @param {Event} ev The Dom mousemove Event
+        */
+        _move: function(ev) {
+            if (this.activeDrag) {
+                this.activeDrag._move.apply(this.activeDrag, arguments);
+                this._dropMove();
+            }
+        },
+        /**
+        * @method setXY
+        * @description A simple method to set the top and left position from offsets instead of page coordinates
+        * @param {Object} node The node to set the position of 
+        * @param {Array} xy The Array of left/top position to be set.
+        */
+        setXY: function(node, xy) {
+            var t = parseInt(node.getStyle('top'), 10),
+            l = parseInt(node.getStyle('left'), 10),
+            pos = node.getStyle('position');
+
+            if (pos === 'static') {
+                node.setStyle('position', 'relative');
+            }
+
+            // in case of 'auto'
+            if (isNaN(t)) { t = 0; }
+            if (isNaN(l)) { l = 0; }
+            
+            node.setStyle('top', (xy[1] + t) + 'px');
+            node.setStyle('left', (xy[0] + l) + 'px');
+            
+        },
+        /**
+        * //TODO Private, rename??...
+        * @private
+        * @method cssSizestoObject
+        * @description Helper method to use to set the gutter from the attribute setter.
+        * @param {String} gutter CSS style string for gutter: '5 0' (sets top and bottom to 5px, left and right to 0px), '1 2 3 4' (top 1px, right 2px, bottom 3px, left 4px)
+        * @return {Object} The gutter Object Literal.
+        */
+        cssSizestoObject: function(gutter) {
+            var x = gutter.split(' ');
+                
+            switch (x.length) {
+                case 1: x[1] = x[2] = x[3] = x[0]; break;
+                case 2: x[2] = x[0]; x[3] = x[1]; break;
+                case 3: x[3] = x[1]; break;
+            }
+
+            return {
+                top   : parseInt(x[0],10),
+                right : parseInt(x[1],10),
+                bottom: parseInt(x[2],10),
+                left  : parseInt(x[3],10)
+            };
+        },
+        /**
+        * @method getDrag
+        * @description Get a valid Drag instance back from a Node or a selector string, false otherwise
+        * @param {String/Object} node The Node instance or Selector string to check for a valid Drag Object
+        * @return {Object}
+        */
+        getDrag: function(node) {
+            var drag = false,
+                n = Y.Node.get(node);
+            if (n instanceof Y.Node) {
+                Y.each(this._drags, function(v, k) {
+                    if (n.compareTo(v.get('node'))) {
+                        drag = v;
+                    }
+                });
+            }
+            return drag;
+        }
+    });
+
+    Y.namespace('DD');
+    Y.DD.DDM = new DDMBase();
+
+
+
+}, '3.0.0pr2' ,{requires:['node', 'base'], skinnable:false});
+YUI.add('dd-ddm', function(Y) {
+
+    /**
+     * Extends the dd-ddm-base Class to add support for the viewport shim to allow a draggable node to drag to be dragged over an iframe or any other node that traps mousemove events.
+     * It is also required to have Drop Targets enabled, as the viewport shim will contain the shims for the Drop Targets.
+     * @module dd
+     * @submodule dd-ddm
+     * @for DDM
+     */
+    Y.mix(Y.DD.DDM, {
+        /**
+        * @private
+        * @property _pg
+        * @description The shim placed over the screen to track the mousemove event.
+        * @type {Node}
+        */
+        _pg: null,
+        /**
+        * @private
+        * @property _debugShim
+        * @description Set this to true to set the shims opacity to .5 for debugging it, default: false.
+        * @type {Boolean}
+        */
+        _debugShim: false,
+        _activateTargets: function() {},
+        _deactivateTargets: function() {},
+        _startDrag: function() {
+            if (this.activeDrag.get('useShim')) {
+                this._pg_activate();
+                this._activateTargets();
+            }
+        },
+        _endDrag: function() {
+            this._pg_deactivate();
+            this._deactivateTargets();
+        },
+        /**
+        * @private
+        * @method _pg_deactivate
+        * @description Deactivates the shim
+        */
+        _pg_deactivate: function() {
+            this._pg.setStyle('display', 'none');
+        },
+        /**
+        * @private
+        * @method _pg_activate
+        * @description Activates the shim
+        */
+        _pg_activate: function() {
+            this._pg_size();
+            this._pg.setStyles({
+                top: 0,
+                left: 0,
+                display: 'block',
+                opacity: ((this._debugShim) ? '.5' : '0')
+            });
+        },
+        /**
+        * @private
+        * @method _pg_size
+        * @description Sizes the shim on: activatation, window:scroll, window:resize
+        */
+        _pg_size: function() {
+            if (this.activeDrag) {
+                var b = Y.Node.get('body'),
+                h = b.get('docHeight'),
+                w = b.get('docWidth');
+                this._pg.setStyles({
+                    height: h + 'px',
+                    width: w + 'px'
+                });
+            }
+        },
+        /**
+        * @private
+        * @method _createPG
+        * @description Creates the shim and adds it's listeners to it.
+        */
+        _createPG: function() {
+            //var pg = Y.Node.create(['div']),
+            var pg = Y.Node.create('<div></div>'),
+            bd = Y.Node.get('body');
+            pg.setStyles({
+                top: '0',
+                left: '0',
+                position: 'absolute',
+                zIndex: '9999',
+                overflow: 'hidden',
+                //opacity: '0',
+                backgroundColor: 'red',
+                display: 'none',
+                height: '5px',
+                width: '5px'
+            });
+            if (bd.get('firstChild')) {
+                bd.insertBefore(pg, bd.get('firstChild'));
+            } else {
+                bd.appendChild(pg);
+            }
+            this._pg = pg;
+            this._pg.on('mouseup', this._end, this, true);
+            this._pg.on('mousemove', this._move, this, true);
+            
+            
+            Y.on('resize', this._pg_size, window, this, true);
+            Y.on('scroll', this._pg_size, window, this, true);
+        }   
+    }, true);
+
+    Y.DD.DDM._createPG();    
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-base'], skinnable:false});
+YUI.add('dd-ddm-drop', function(Y) {
+
+    /**
+     * Extends the dd-ddm Class to add support for the placement of Drop Target shims inside the viewport shim. It also handles all Drop Target related events and interactions.
+     * @module dd
+     * @submodule dd-ddm-drop
+     * @for DDM
+     */
+
+    //TODO CSS class name for the bestMatch..
+    Y.mix(Y.DD.DDM, {
+        /**
+        * @private
+        * @property _noShim
+        * @description This flag turns off the use of the mouseover/mouseout shim. It should not be used unless you know what you are doing.
+        * @type {Boolean}
+        */
+        _noShim: false,
+        /**
+        * @private
+        * @property _activeShims
+        * @description Placeholder for all active shims on the page
+        * @type {Array}
+        */
+        _activeShims: [],
+        /**
+        * @private
+        * @method _hasActiveShim
+        * @description This method checks the _activeShims Object to see if there is a shim active.
+        * @return {Boolean}
+        */
+        _hasActiveShim: function() {
+            if (this._noShim) {
+                return true;
+            }
+            return this._activeShims.length;
+        },
+        /**
+        * @private
+        * @method _addActiveShim 
+        * @description Adds a Drop Target to the list of active shims
+        * @param {Object} d The Drop instance to add to the list.
+        */
+        _addActiveShim: function(d) {
+            this._activeShims[this._activeShims.length] = d;
+        },
+        /**
+        * @private
+        * @method _removeActiveShim 
+        * @description Removes a Drop Target to the list of active shims
+        * @param {Object} d The Drop instance to remove from the list.
+        */
+        _removeActiveShim: function(d) {
+            var s = [];
+            Y.each(this._activeShims, function(v, k) {
+                if (v._yuid !== d._yuid) {
+                    s[s.length] = v;
+                }
+                
+            });
+            this._activeShims = s;
+        },
+        /**
+        * @method syncActiveShims
+        * @description This method will sync the position of the shims on the Drop Targets that are currently active.
+        * @param {Boolean} force Resize/sync all Targets.
+        * @return {Array} drops The list of Drop Targets that was just synced.
+        */
+        syncActiveShims: function(force) {
+            var drops = ((force) ? this.targets : this._lookup());
+            Y.each(drops, function(v, k) {
+                v.sizeShim.call(v);
+            }, this);
+
+            return drops;
+        },
+        /**
+        * @private
+        * @property mode
+        * @description The mode that the drag operations will run in 0 for Point, 1 for Intersect, 2 for Strict
+        * @type Number
+        */
+        mode: 0,
+        /**
+        * @private
+        * @property POINT
+        * @description In point mode, a Drop is targeted by the cursor being over the Target
+        * @type Number
+        */
+        POINT: 0,
+        /**
+        * @private
+        * @property INTERSECT
+        * @description In intersect mode, a Drop is targeted by "part" of the drag node being over the Target
+        * @type Number
+        */
+        INTERSECT: 1,
+        /**
+        * @private
+        * @property STRICT
+        * @description In strict mode, a Drop is targeted by the "entire" drag node being over the Target
+        * @type Number
+        */
+        STRICT: 2,
+        /**
+        * @property useHash
+        * @description Should we only check targets that are in the viewport on drags (for performance), default: true
+        * @type {Boolean}
+        */
+        useHash: true,
+        /**
+        * @property activeDrop
+        * @description A reference to the active Drop Target
+        * @type {Object}
+        */
+        activeDrop: null,
+        /**
+        * @property validDrops
+        * @description An array of the valid Drop Targets for this interaction.
+        * @type {Array}
+        */
+        //TODO Change array/object literals to be in sync..
+        validDrops: [],
+        /**
+        * @property otherDrops
+        * @description An object literal of Other Drop Targets that we encountered during this interaction (in the case of overlapping Drop Targets)
+        * @type {Object}
+        */
+        otherDrops: {},
+        /**
+        * @property targets
+        * @description All of the Targets
+        * @type {Array}
+        */
+        targets: [],
+        /**
+        * @private 
+        * @method _addValid
+        * @description Add a Drop Target to the list of Valid Targets. This list get's regenerated on each new drag operation.
+        * @param {Object} drop
+        * @return {Self}
+        * @chainable
+        */
+        _addValid: function(drop) {
+            this.validDrops[this.validDrops.length] = drop;
+            return this;
+        },
+        /**
+        * @private 
+        * @method _removeValid
+        * @description Removes a Drop Target from the list of Valid Targets. This list get's regenerated on each new drag operation.
+        * @param {Object} drop
+        * @return {Self}
+        * @chainable
+        */
+        _removeValid: function(drop) {
+            var drops = [];
+            Y.each(this.validDrops, function(v, k) {
+                if (v !== drop) {
+                    drops[drops.length] = v
+                }
+            });
+
+            this.validDrops = drops;
+            return this;
+        },
+        /**
+        * @method isOverTarget
+        * @description Check to see if the Drag element is over the target, method varies on current mode
+        * @param {Object} drop The drop to check against
+        * @return {Boolean}
+        */
+        isOverTarget: function(drop) {
+            //if (Y.Lang.isObject(this.activeDrag) && drop) { //TODO, check this check..
+            if (this.activeDrag && drop) {
+                var xy = this.activeDrag.mouseXY;
+                if (xy) {
+                    if (this.activeDrag.get('dragMode') == this.STRICT) {
+                        return this.activeDrag.get('dragNode').inRegion(drop.region, true, this.activeDrag.region);
+                    } else {
+                        if (drop && drop.shim) {
+                            return drop.shim.intersect({
+                                top: xy[1],
+                                bottom: xy[1],
+                                left: xy[0], 
+                                right: xy[0]
+                            }, drop.region).inRegion;
+                        } else {
+                            return false;
+                        }
+                    }
+                } else {
+                    return false;
+                }
+            } else {
+                return false;
+            }
+        },
+        /**
+        * @method clearCache
+        * @description Clears the cache data used for this interaction.
+        */
+        clearCache: function() {
+            this.validDrops = [];
+            this.otherDrops = {};
+            this._activeShims = [];
+        },
+        /**
+        * @private
+        * @method _activateTargets
+        * @description Clear the cache and activate the shims of all the targets
+        */
+        _activateTargets: function() {
+            this.clearCache();
+            Y.each(this.targets, function(v, k) {
+                v._activateShim.apply(v, []);
+            }, this);
+            this._handleTargetOver();
+            
+        },
+        /**
+        * @method getBestMatch
+        * @description This method will gather the area for all potential targets and see which has the hightest covered area and return it.
+        * @param {Array} drops An Array of drops to scan for the best match.
+        * @param {Boolean} all If present, it returns an Array. First item is best match, second is an Array of the other items in the original Array.
+        * @return {Object or Array} 
+        */
+        getBestMatch: function(drops, all) {
+            var biggest = null, area = 0;
+
+            Y.each(drops, function(v, k) {
+                var inter = this.activeDrag.get('dragNode').intersect(v.get('node'));
+                v.region.area = inter.area;
+
+                if (inter.inRegion) {
+                    if (inter.area > area) {
+                        area = inter.area;
+                        biggest = v;
+                    }
+                }
+            }, this);
+            if (all) {
+                var out = [];
+                //TODO Sort the others in numeric order by area covered..
+                Y.each(drops, function(v, k) {
+                    if (v !== biggest) {
+                        out[out.length] = v;
+                    }
+                }, this);
+                return [biggest, out];
+            } else {
+                return biggest;
+            }
+        },
+        /**
+        * @private
+        * @method _deactivateTargets
+        * @description This method fires the drop:hit, drag:drophit, drag:dropmiss methods and deactivates the shims..
+        */
+        _deactivateTargets: function() {
+            var other = [],
+                activeDrag = this.activeDrag,
+                activeDrop = this.activeDrop;
+            
+            //TODO why is this check so hard??
+            if (activeDrag && activeDrop && this.otherDrops[activeDrop]) {
+                if (!activeDrag.get('dragMode')) {
+                    //TODO otherDrops -- private..
+                    other = this.otherDrops;
+                    delete other[activeDrop];
+                } else {
+                    var tmp = this.getBestMatch(this.otherDrops, true);
+                    activeDrop = tmp[0];
+                    other = tmp[1];
+                }
+                activeDrag.get('node').removeClass(this.CSS_PREFIX + '-drag-over')
+                if (activeDrop) {
+                    activeDrop.fire('drop:hit', { drag: activeDrag, drop: activeDrop, others: other });
+                    activeDrag.fire('drag:drophit', { drag: activeDrag,  drop: activeDrop, others: other });
+                }
+            } else if (activeDrag) {
+                activeDrag.get('node').removeClass(this.CSS_PREFIX + '-drag-over')
+                activeDrag.fire('drag:dropmiss', { pageX: activeDrag.lastXY[0], pageY: activeDrag.lastXY[1] });
+            } else {
+            }
+            
+            this.activeDrop = null;
+
+            Y.each(this.targets, function(v, k) {
+                v._deactivateShim.apply(v, []);
+            }, this);
+        },
+        /**
+        * @private
+        * @method _dropMove
+        * @description This method is called when the move method is called on the Drag Object.
+        */
+        _dropMove: function() {
+            if (this._hasActiveShim()) {
+                this._handleTargetOver();
+            } else {
+                Y.each(this.otherDrops, function(v, k) {
+                    v._handleOut.apply(v, []);
+                });
+            }
+        },
+        /**
+        * @private
+        * @method _lookup
+        * @description Filters the list of Drops down to those in the viewport.
+        * @return {Array} The valid Drop Targets that are in the viewport.
+        */
+        _lookup: function() {
+            if (!this.useHash) {
+                return this.validDrops;
+            }
+            var drops = [];
+            //Only scan drop shims that are in the Viewport
+            Y.each(this.validDrops, function(v, k) {
+                if (v.shim && v.shim.inViewportRegion(false, v.region)) {
+                    drops[drops.length] = v;
+                }
+            });
+            return drops;
+                
+        },
+        /**
+        * @private
+        * @method _handleTargetOver
+        * @description This method execs _handleTargetOver on all valid Drop Targets
+        * @param {Boolean} force Force it to run the first time.
+        */
+        _handleTargetOver: function() {
+            var drops = this._lookup();
+            Y.each(drops, function(v, k) {
+                v._handleTargetOver.call(v);
+            }, this);
+        },
+        /**
+        * @private
+        * @method _regTarget
+        * @description Add the passed in Target to the targets collection
+        * @param {Object} t The Target to add to the targets collection
+        */
+        _regTarget: function(t) {
+            this.targets[this.targets.length] = t;
+        },
+        /**
+        * @private
+        * @method _unregTarget
+        * @description Remove the passed in Target from the targets collection
+        * @param {Object} drop The Target to remove from the targets collection
+        */
+        _unregTarget: function(drop) {
+            var targets = [];
+            Y.each(this.targets, function(v, k) {
+                if (v != drop) {
+                    targets[targets.length] = v;
+                }
+            }, this);
+            this.targets = targets;
+
+            var vdrops = [];
+            Y.each(this.validDrops, function(v, k) {
+                if (v !== drop) {
+                    vdrops[vdrops.length] = v
+                }
+            });
+
+            this.validDrops = vdrops;
+        },
+        /**
+        * @method getDrop
+        * @description Get a valid Drop instance back from a Node or a selector string, false otherwise
+        * @param {String/Object} node The Node instance or Selector string to check for a valid Drop Object
+        * @return {Object}
+        */
+        getDrop: function(node) {
+            var drop = false,
+                n = Y.Node.get(node);
+            if (n instanceof Y.Node) {
+                Y.each(this.targets, function(v, k) {
+                    if (n.compareTo(v.get('node'))) {
+                        drop = v;
+                    }
+                });
+            }
+            return drop;
+        }
+    }, true);
+    
+
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm'], skinnable:false});
+YUI.add('dd-drag', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-drag
+     */     
+    /**
+     * This class provides the ability to drag a Node.
+     * @class Drag
+     * @extends Base
+     * @constructor
+     */
+
+    var DDM = Y.DD.DDM,
+        NODE = 'node',
+        DRAG_NODE = 'dragNode',
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth',        
+        MOUSE_UP = 'mouseup',
+        MOUSE_DOWN = 'mousedown',
+        DRAG_START = 'dragstart',
+        /**
+        * @event drag:mouseDown
+        * @description Handles the mousedown DOM event, checks to see if you have a valid handle then starts the drag timers.
+        * @preventable _handleMouseDown
+        * @param {Event} ev The mousedown event.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_MOUSE_DOWN = 'drag:mouseDown',
+        /**
+        * @event drag:afterMouseDown
+        * @description Fires after the mousedown event has been cleared.
+        * @param {Event} ev The mousedown event.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_AFTER_MOUSE_DOWN = 'drag:afterMouseDown',
+        /**
+        * @event drag:removeHandle
+        * @description Fires after a handle is removed.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_REMOVE_HANDLE = 'drag:removeHandle',
+        /**
+        * @event drag:addHandle
+        * @description Fires after a handle is added.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_ADD_HANDLE = 'drag:addHandle',
+        /**
+        * @event drag:removeInvalid
+        * @description Fires after an invalid selector is removed.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_REMOVE_INVALID = 'drag:removeInvalid',
+        /**
+        * @event drag:addInvalid
+        * @description Fires after an invalid selector is added.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_ADD_INVALID = 'drag:addInvalid',
+        /**
+        * @event drag:start
+        * @description Fires at the start of a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_START = 'drag:start',
+        /**
+        * @event drag:end
+        * @description Fires at the end of a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_END = 'drag:end',
+        /**
+        * @event drag:drag
+        * @description Fires every mousemove during a drag operation.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DRAG = 'drag:drag';
+
+
+        /**
+        * @event drag:over
+        * @description Fires when this node is over a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:enter
+        * @description Fires when this node enters a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:exit
+        * @description Fires when this node exits a Drop Target. (Fired from dd-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:drophit
+        * @description Fires when this node is dropped on a valid Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        /**
+        * @event drag:dropmiss
+        * @description Fires when this node is dropped on an invalid Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+    
+    var Drag = function() {
+        Drag.superclass.constructor.apply(this, arguments);
+
+        DDM._regDrag(this);
+    };
+
+    Drag.NAME = 'drag';
+
+    Drag.ATTRS = {
+        /**
+        * @attribute node
+        * @description Y.Node instanace to use as the element to initiate a drag operation
+        * @type Node
+        */
+        node: {
+            set: function(node) {
+                var n = Y.get(node);
+                if (!n) {
+                    Y.fail('DD.Drag: Invalid Node Given: ' + node);
+                } else {
+                    n = n.item(0);
+                }
+                return n;
+            }
+        },
+        /**
+        * @attribute dragNode
+        * @description Y.Node instanace to use as the draggable element, defaults to node
+        * @type Node
+        */
+        dragNode: {
+            set: function(node) {
+                var n = Y.Node.get(node);
+                if (!n) {
+                    Y.fail('DD.Drag: Invalid dragNode Given: ' + node);
+                }
+                return n;
+            }
+        },
+        /**
+        * @attribute offsetNode
+        * @description Offset the drag element by the difference in cursor position: default true
+        * @type Boolean
+        */
+        offsetNode: {
+            value: true
+        },
+        /**
+        * @attribute clickPixelThresh
+        * @description The number of pixels to move to start a drag operation, default is 3.
+        * @type Number
+        */
+        clickPixelThresh: {
+            value: DDM.get('clickPixelThresh')
+        },
+        /**
+        * @attribute clickTimeThresh
+        * @description The number of milliseconds a mousedown has to pass to start a drag operation, default is 1000.
+        * @type Number
+        */
+        clickTimeThresh: {
+            value: DDM.get('clickTimeThresh')
+        },
+        /**
+        * @attribute lock
+        * @description Set to lock this drag element so that it can't be dragged: default false.
+        * @type Boolean
+        */
+        lock: {
+            value: false,
+            set: function(lock) {
+                if (lock) {
+                    this.get(NODE).addClass(DDM.CSS_PREFIX + '-locked');
+                } else {
+                    this.get(NODE).removeClass(DDM.CSS_PREFIX + '-locked');
+                }
+            }
+        },
+        /**
+        * @attribute data
+        * @description A payload holder to store arbitrary data about this drag object, can be used to store any value.
+        * @type Mixed
+        */
+        data: {
+            value: false
+        },
+        /**
+        * @attribute move
+        * @description If this is false, the drag element will not move with the cursor: default true. Can be used to "resize" the element.
+        * @type Boolean
+        */
+        move: {
+            value: true
+        },
+        /**
+        * @attribute useShim
+        * @description Use the protective shim on all drag operations: default true. Only works with dd-ddm, not dd-ddm-base.
+        * @type Boolean
+        */
+        useShim: {
+            value: true
+        },
+        /**
+        * @attribute activeHandle
+        * @description This config option is set by Drag to inform you of which handle fired the drag event (in the case that there are several handles): default false.
+        * @type Node
+        */
+        activeHandle: {
+            value: false
+        },
+        /**
+        * @attribute primaryButtonOnly
+        * @description By default a drag operation will only begin if the mousedown occurred with the primary mouse button. Setting this to false will allow for all mousedown events to trigger a drag.
+        * @type Boolean
+        */
+        primaryButtonOnly: {
+            value: true
+        },
+        /**
+        * @attribute dragging
+        * @description This attribute is not meant to be used by the implementor, it is meant to be used as an Event tracker so you can listen for it to change.
+        * @type Boolean
+        */
+        dragging: {
+            value: false
+        },
+        parent: {
+            value: false
+        },
+        /**
+        * @attribute target
+        * @description This attribute only works if the dd-drop module has been loaded. It will make this node a drop target as well as draggable.
+        * @type Boolean
+        */
+        target: {
+            value: false,
+            set: function(config) {
+                this._handleTarget(config);
+            }
+        },
+        /**
+        * @attribute dragMode
+        * @description This attribute only works if the dd-drop module is active. It will set the dragMode (point, intersect, strict) of this Drag instance.
+        * @type String
+        */
+        dragMode: {
+            value: null,
+            set: function(mode) {
+                return DDM._setDragMode(mode);
+            }
+        },
+        /**
+        * @attribute groups
+        * @description Array of groups to add this drag into.
+        * @type Array
+        */
+        groups: {
+            value: ['default'],
+            get: function() {
+                if (!this._groups) {
+                    this._groups = {};
+                }
+                var ret = [];
+                Y.each(this._groups, function(v, k) {
+                    ret[ret.length] = k;
+                });
+                return ret;
+            },
+            set: function(g) {
+                this._groups = {};
+                Y.each(g, function(v, k) {
+                    this._groups[v] = true;
+                }, this);
+            }
+        },
+        /**
+        * @attribute handles
+        * @description Array of valid handles to add. Adding something here will set all handles, even if previously added with addHandle
+        * @type Array
+        */
+        handles: {
+            value: null,
+            set: function(g) {
+                if (g) {
+                    this._handles = {};
+                    Y.each(g, function(v, k) {
+                        this._handles[v] = true;
+                    }, this);
+                } else {
+                    this._handles = null;
+                }
+                return g;
+            }
+        },
+        /**
+        * @attribute bubbles
+        * @description Controls the default bubble parent for this Drag instance. Default: Y.DD.DDM. Set to false to disable bubbling.
+        * @type Object
+        */
+        bubbles: {
+            writeOnce: true,
+            value: Y.DD.DDM
+        }
+    };
+
+    Y.extend(Drag, Y.Base, {
+        /**
+        * @method addToGroup
+        * @description Add this Drag instance to a group, this should be used for on-the-fly group additions.
+        * @param {String} g The group to add this Drag Instance to.
+        * @return {Self}
+        * @chainable
+        */
+        addToGroup: function(g) {
+            this._groups[g] = true;
+            DDM._activateTargets();
+            return this;
+        },
+        /**
+        * @method removeFromGroup
+        * @description Remove this Drag instance from a group, this should be used for on-the-fly group removals.
+        * @param {String} g The group to remove this Drag Instance from.
+        * @return {Self}
+        * @chainable
+        */
+        removeFromGroup: function(g) {
+            delete this._groups[g];
+            DDM._activateTargets();
+            return this;
+        },
+        /**
+        * @property target
+        * @description This will be a reference to the Drop instance associated with this drag if the target: true config attribute is set..
+        * @type {Object}
+        */
+        target: null,
+        /**
+        * @private
+        * @method _handleTarget
+        * @description Attribute handler for the target config attribute.
+        * @param {Boolean/Object}
+        * @return {Boolean/Object}
+        */
+        _handleTarget: function(config) {
+            if (Y.DD.Drop) {
+                if (config === false) {
+                    if (this.target) {
+                        DDM._unregTarget(this.target);
+                        this.target = null;
+                    }
+                    return false;
+                } else {
+                    if (!Y.Lang.isObject(config)) {
+                        config = {};
+                    }
+                    config.bubbles = this.get('bubbles');
+                    config.node = this.get(NODE);
+                    this.target = new Y.DD.Drop(config);
+                }
+            } else {
+                return false;
+            }
+        },
+        /**
+        * @private
+        * @property _groups
+        * @description Storage Array for the groups this drag belongs to.
+        * @type {Array}
+        */
+        _groups: null,
+        /**
+        * @private
+        * @method _createEvents
+        * @description This method creates all the events for this Event Target and publishes them so we get Event Bubbling.
+        */
+        _createEvents: function() {
+            
+            this.publish(EV_MOUSE_DOWN, {
+                defaultFn: this._handleMouseDown,
+                queuable: true,
+                emitFacade: true,
+                bubbles: true
+            });
+            
+            var ev = [
+                EV_AFTER_MOUSE_DOWN,
+                EV_REMOVE_HANDLE,
+                EV_ADD_HANDLE,
+                EV_REMOVE_INVALID,
+                EV_ADD_INVALID,
+                EV_START,
+                EV_END,
+                EV_DRAG,
+                'drag:drophit',
+                'drag:dropmiss',
+                'drag:over',
+                'drag:enter',
+                'drag:exit'
+            ];
+            
+            Y.each(ev, function(v, k) {
+                this.publish(v, {
+                    type: v,
+                    emitFacade: true,
+                    bubbles: true,
+                    preventable: false,
+                    queuable: true
+                });
+            }, this);
+
+            if (this.get('bubbles')) {
+                this.addTarget(this.get('bubbles'));
+            }
+            
+           
+        },
+        /**
+        * @private
+        * @property _ev_md
+        * @description A private reference to the mousedown DOM event
+        * @type {Event}
+        */
+        _ev_md: null,
+        /**
+        * @private
+        * @property _startTime
+        * @description The getTime of the mousedown event. Not used, just here in case someone wants/needs to use it.
+        * @type Date
+        */
+        _startTime: null,
+        /**
+        * @private
+        * @property _endTime
+        * @description The getTime of the mouseup event. Not used, just here in case someone wants/needs to use it.
+        * @type Date
+        */
+        _endTime: null,
+        /**
+        * @private
+        * @property _handles
+        * @description A private hash of the valid drag handles
+        * @type {Object}
+        */
+        _handles: null,
+        /**
+        * @private
+        * @property _invalids
+        * @description A private hash of the invalid selector strings
+        * @type {Object}
+        */
+        _invalids: null,
+        /**
+        * @private
+        * @property _invalidsDefault
+        * @description A private hash of the default invalid selector strings: {'textarea': true, 'input': true, 'a': true, 'button': true}
+        * @type {Object}
+        */
+        _invalidsDefault: {'textarea': true, 'input': true, 'a': true, 'button': true},
+        /**
+        * @private
+        * @property _dragThreshMet
+        * @description Private flag to see if the drag threshhold was met
+        * @type {Boolean}
+        */
+        _dragThreshMet: null,
+        /**
+        * @private
+        * @property _fromTimeout
+        * @description Flag to determine if the drag operation came from a timeout
+        * @type {Boolean}
+        */
+        _fromTimeout: null,
+        /**
+        * @private
+        * @property _clickTimeout
+        * @description Holder for the setTimeout call
+        * @type {Boolean}
+        */
+        _clickTimeout: null,
+        /**
+        * @property deltaXY
+        * @description The offset of the mouse position to the element's position
+        * @type {Array}
+        */
+        deltaXY: null,
+        /**
+        * @property startXY
+        * @description The initial mouse position
+        * @type {Array}
+        */
+        startXY: null,
+        /**
+        * @property nodeXY
+        * @description The initial element position
+        * @type {Array}
+        */
+        nodeXY: null,
+        /**
+        * @property lastXY
+        * @description The position of the element as it's moving (for offset calculations)
+        * @type {Array}
+        */
+        lastXY: null,
+        realXY: null,
+        /**
+        * @property mouseXY
+        * @description The XY coords of the mousemove
+        * @type {Array}
+        */
+        mouseXY: null,
+        /**
+        * @property region
+        * @description A region object associated with this drag, used for checking regions while dragging.
+        * @type Object
+        */
+        region: null,       
+        /**
+        * @private
+        * @method _handleMouseUp
+        * @description Handler for the mouseup DOM event
+        * @param {Event}
+        */
+        _handleMouseUp: function(ev) {
+            this._fixIEMouseUp();
+            if (DDM.activeDrag) {
+                DDM._end();
+            }
+        },
+        /** 
+        * @private
+        * @method _fixDragStart
+        * @description The function we use as the ondragstart handler when we start a drag in Internet Explorer. This keeps IE from blowing up on images as drag handles.
+        */
+        _fixDragStart: function(e) {
+            e.preventDefault();
+        },
+        /** 
+        * @private
+        * @method _ieSelectFix
+        * @description The function we use as the onselectstart handler when we start a drag in Internet Explorer
+        */
+        _ieSelectFix: function() {
+            return false;
+        },
+        /** 
+        * @private
+        * @property _ieSelectBack
+        * @description We will hold a copy of the current "onselectstart" method on this property, and reset it after we are done using it.
+        */
+        _ieSelectBack: null,
+        /**
+        * @private
+        * @method _fixIEMouseDown
+        * @description This method copies the onselectstart listner on the document to the _ieSelectFix property
+        */
+        _fixIEMouseDown: function() {
+            if (Y.UA.ie) {
+                this._ieSelectBack = Y.config.doc.body.onselectstart;
+                Y.config.doc.body.onselectstart = this._ieSelectFix;
+            }           
+        },
+        /**
+        * @private
+        * @method _fixIEMouseUp
+        * @description This method copies the _ieSelectFix property back to the onselectstart listner on the document.
+        */
+        _fixIEMouseUp: function() {
+            if (Y.UA.ie) {
+                Y.config.doc.body.onselectstart = this._ieSelectBack;
+            }           
+        },
+        /**
+        * @private
+        * @method _handleMouseDownEvent
+        * @description Handler for the mousedown DOM event
+        * @param {Event}
+        */
+        _handleMouseDownEvent: function(ev) {
+            this.fire(EV_MOUSE_DOWN, { ev: ev });
+        },
+        /**
+        * @private
+        * @method _handleMouseDown
+        * @description Handler for the mousedown DOM event
+        * @param {Event}
+        */
+        _handleMouseDown: function(e) {
+            var ev = e.ev;
+            this._dragThreshMet = false;
+            this._ev_md = ev;
+            
+            if (this.get('primaryButtonOnly') && ev.button > 1) {
+                return false;
+            }
+            if (this.validClick(ev)) {
+                this._fixIEMouseDown();
+                ev.halt();
+                this._setStartPosition([ev.pageX, ev.pageY]);
+
+                DDM.activeDrag = this;
+
+                var self = this;
+                this._clickTimeout = setTimeout(function() {
+                    self._timeoutCheck.call(self);
+                }, this.get('clickTimeThresh'));
+            }
+            this.fire(EV_AFTER_MOUSE_DOWN, { ev: ev });
+        },
+        /**
+        * @method validClick
+        * @description Method first checks to see if we have handles, if so it validates the click against the handle. Then if it finds a valid handle, it checks it against the invalid handles list. Returns true if a good handle was used, false otherwise.
+        * @param {Event}
+        * @return {Boolean}
+        */
+        validClick: function(ev) {
+            var r = false,
+            tar = ev.target,
+            hTest = null;
+            if (this._handles) {
+                Y.each(this._handles, function(i, n) {
+                    if (Y.Lang.isString(n)) {
+                        //Am I this or am I inside this
+                        if (tar.test(n + ', ' + n + ' *') && !hTest) {
+                            hTest = n;
+                            r = true;
+                        }
+                    }
+                });
+            } else {
+                if (this.get(NODE).contains(tar) || this.get(NODE).compareTo(tar)) {
+                    r = true;
+                }
+            }
+            if (r) {
+                if (this._invalids) {
+                    Y.each(this._invalids, function(i, n) {
+                        if (Y.Lang.isString(n)) {
+                            //Am I this or am I inside this
+                            if (tar.test(n + ', ' + n + ' *')) {
+                                r = false;
+                            }
+                        }
+                    });
+                }
+            }
+            if (r) {
+                if (hTest) {
+                    var els = ev.currentTarget.queryAll(hTest),
+                        set = false;
+                    els.each(function(n, i) {
+                        if ((n.contains(tar) || n.compareTo(tar)) && !set) {
+                            set = true;
+                            this.set('activeHandle', els.item(i));
+                        }
+                    }, this);
+                } else {
+                    this.set('activeHandle', this.get(NODE));
+                }
+            }
+            return r;
+        },
+        /**
+        * @private
+        * @method _setStartPosition
+        * @description Sets the current position of the Element and calculates the offset
+        * @param {Array} xy The XY coords to set the position to.
+        */
+        _setStartPosition: function(xy) {
+            this.startXY = xy;
+            
+            this.nodeXY = this.get(NODE).getXY();
+            this.lastXY = this.nodeXY;
+            this.realXY = this.nodeXY;
+
+            if (this.get('offsetNode')) {
+                this.deltaXY = [(this.startXY[0] - this.nodeXY[0]), (this.startXY[1] - this.nodeXY[1])];
+            } else {
+                this.deltaXY = [0, 0];
+            }
+        },
+        /**
+        * @private
+        * @method _timeoutCheck
+        * @description The method passed to setTimeout to determine if the clickTimeThreshold was met.
+        */
+        _timeoutCheck: function() {
+            if (!this.get('lock')) {
+                this._fromTimeout = true;
+                this._dragThreshMet = true;
+                this.start();
+                this._moveNode([this._ev_md.pageX, this._ev_md.pageY], true);
+            }
+        },
+        /**
+        * @method removeHandle
+        * @description Remove a Selector added by addHandle
+        * @param {String} str The selector for the handle to be removed. 
+        * @return {Self}
+        * @chainable
+        */
+        removeHandle: function(str) {
+            if (this._handles[str]) {
+                delete this._handles[str];
+                this.fire(EV_REMOVE_HANDLE, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method addHandle
+        * @description Add a handle to a drag element. Drag only initiates when a mousedown happens on this element.
+        * @param {String} str The selector to test for a valid handle. Must be a child of the element.
+        * @return {Self}
+        * @chainable
+        */
+        addHandle: function(str) {
+            if (!this._handles) {
+                this._handles = {};
+            }
+            if (Y.Lang.isString(str)) {
+                this._handles[str] = true;
+                this.fire(EV_ADD_HANDLE, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method removeInvalid
+        * @description Remove an invalid handle added by addInvalid
+        * @param {String} str The invalid handle to remove from the internal list.
+        * @return {Self}
+        * @chainable
+        */
+        removeInvalid: function(str) {
+            if (this._invalids[str]) {
+                this._invalids[str] = null;
+                delete this._invalids[str];
+                this.fire(EV_REMOVE_INVALID, { handle: str });
+            }
+            return this;
+        },
+        /**
+        * @method addInvalid
+        * @description Add a selector string to test the handle against. If the test passes the drag operation will not continue.
+        * @param {String} str The selector to test against to determine if this is an invalid drag handle.
+        * @return {Self}
+        * @chainable
+        */
+        addInvalid: function(str) {
+            if (Y.Lang.isString(str)) {
+                this._invalids[str] = true;
+                this.fire(EV_ADD_INVALID, { handle: str });
+            } else {
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Internal init handler
+        */
+        initializer: function() {
+            //TODO give the node instance a copy of this object
+            //Not supported in PR1 due to Y.Node.get calling a new under the hood.
+            //this.get(NODE).dd = this;
+
+            if (!this.get(NODE).get('id')) {
+                var id = Y.stamp(this.get(NODE));
+                this.get(NODE).set('id', id);
+            }
+            
+
+            this._invalids = Y.clone(this._invalidsDefault, true);
+
+            this._createEvents();
+            
+            if (!this.get(DRAG_NODE)) {
+                this.set(DRAG_NODE, this.get(NODE));
+            }
+            this._prep();
+            this._dragThreshMet = false;
+        },
+        /**
+        * @private
+        * @method _prep
+        * @description Attach event listners and add classname
+        */
+        _prep: function() {
+            var node = this.get(NODE);
+            node.addClass(DDM.CSS_PREFIX + '-draggable');
+            node.on(MOUSE_DOWN, this._handleMouseDownEvent, this, true);
+            node.on(MOUSE_UP, this._handleMouseUp, this, true);
+            node.on(DRAG_START, this._fixDragStart, this, true);
+        },
+        /**
+        * @private
+        * @method _unprep
+        * @description Detach event listners and remove classname
+        */
+        _unprep: function() {
+            var node = this.get(NODE);
+            node.removeClass(DDM.CSS_PREFIX + '-draggable');
+            node.detach(MOUSE_DOWN, this._handleMouseDownEvent, this, true);
+            node.detach(MOUSE_UP, this._handleMouseUp, this, true);
+            node.detach(DRAG_START, this._fixDragStart, this, true);
+        },
+        /**
+        * @method start
+        * @description Starts the drag operation
+        * @return {Self}
+        * @chainable
+        */
+        start: function() {
+            if (!this.get('lock') && !this.get('dragging')) {
+                this.set('dragging', true);
+                DDM._start(this.deltaXY, [this.get(NODE).get(OFFSET_HEIGHT), this.get(NODE).get(OFFSET_WIDTH)]);
+                this.get(NODE).addClass(DDM.CSS_PREFIX + '-dragging');
+                this.fire(EV_START, { pageX: this.nodeXY[0], pageY: this.nodeXY[1] });
+                this.get(DRAG_NODE).on(MOUSE_UP, this._handleMouseUp, this, true);
+                var xy = this.nodeXY;
+
+                this._startTime = (new Date()).getTime();
+                
+                this.region = {
+                    '0': xy[0], 
+                    '1': xy[1],
+                    area: 0,
+                    top: xy[1],
+                    right: xy[0] + this.get(NODE).get(OFFSET_WIDTH),
+                    bottom: xy[1] + this.get(NODE).get(OFFSET_HEIGHT),
+                    left: xy[0]
+                };
+                
+            }
+            return this;
+        },
+        /**
+        * @method end
+        * @description Ends the drag operation
+        * @return {Self}
+        * @chainable
+        */
+        end: function() {
+            this._endTime = (new Date()).getTime();
+            clearTimeout(this._clickTimeout);
+            this._dragThreshMet = false;
+            this._fromTimeout = false;
+            if (!this.get('lock') && this.get('dragging')) {
+                this.fire(EV_END, { pageX: this.lastXY[0], pageY: this.lastXY[1] });
+            }
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-dragging');
+            this.set('dragging', false);
+            this.deltaXY = [0, 0];
+            this.get(DRAG_NODE).detach(MOUSE_UP, this._handleMouseUp, this, true);
+
+            return this;
+        },
+        /**
+        * @private
+        * @method _align
+        * @description Calculates the offsets and set's the XY that the element will move to.
+        * @param {Array} xy The xy coords to align with.
+        * @return Array
+        * @type {Array}
+        */
+        _align: function(xy) {
+            return [xy[0] - this.deltaXY[0], xy[1] - this.deltaXY[1]];
+        },
+        /**
+        * @private
+        * @method _moveNode
+        * @description This method performs the actual element move.
+        * @param {Array} eXY The XY to move the element to, usually comes from the mousemove DOM event.
+        * @param {Boolean} noFire If true, the drag:drag event will not fire.
+        */
+        _moveNode: function(eXY, noFire) {
+            var xy = this._align(eXY), diffXY = [], diffXY2 = [];
+
+            //This will probably kill your machine ;)
+            diffXY[0] = (xy[0] - this.lastXY[0]);
+            diffXY[1] = (xy[1] - this.lastXY[1]);
+
+            diffXY2[0] = (xy[0] - this.nodeXY[0]);
+            diffXY2[1] = (xy[1] - this.nodeXY[1]);
+
+
+            if (this.get('move')) {
+                if (Y.UA.opera) {
+                    this.get(DRAG_NODE).setXY(xy);
+                } else {
+                    DDM.setXY(this.get(DRAG_NODE), diffXY);
+                }
+                this.realXY = xy;
+            }
+
+            this.region = {
+                '0': xy[0], 
+                '1': xy[1],
+                area: 0,
+                top: xy[1],
+                right: xy[0] + this.get(DRAG_NODE).get(OFFSET_WIDTH),
+                bottom: xy[1] + this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                left: xy[0]
+            };
+
+            var startXY = this.nodeXY;
+            if (!noFire) {
+                this.fire(EV_DRAG, {
+                    pageX: xy[0],
+                    pageY: xy[1],
+                    info: {
+                        start: startXY,
+                        xy: xy,
+                        delta: diffXY,
+                        offset: diffXY2
+                    } 
+                });
+            }
+            
+            this.lastXY = xy;
+        },
+        /**
+        * @private
+        * @method _move
+        * @description Fired from DragDropMgr (DDM) on mousemove.
+        * @param {Event} ev The mousemove DOM event
+        */
+        _move: function(ev) {
+            if (this.get('lock')) {
+                return false;
+            } else {
+                this.mouseXY = [ev.pageX, ev.pageY];
+                if (!this._dragThreshMet) {
+                    var diffX = Math.abs(this.startXY[0] - ev.pageX);
+                    var diffY = Math.abs(this.startXY[1] - ev.pageY);
+                    if (diffX > this.get('clickPixelThresh') || diffY > this.get('clickPixelThresh')) {
+                        this._dragThreshMet = true;
+                        this.start();
+                        this._moveNode([ev.pageX, ev.pageY]);
+                    }
+                
+                } else {
+                    clearTimeout(this._clickTimeout);
+                    this._moveNode([ev.pageX, ev.pageY]);
+                }
+            }
+        },
+        /**
+        * @method stopDrag
+        * @description Method will forcefully stop a drag operation. For example calling this from inside an ESC keypress handler will stop this drag.
+        * @return {Self}
+        * @chainable
+        */
+        stopDrag: function() {
+            if (this.get('dragging')) {
+                DDM._end();
+            }
+            return this;
+        },
+        /**
+        * @private
+        * @method destructor
+        * @description Lifecycle destructor, unreg the drag from the DDM and remove listeners
+        */
+        destructor: function() {
+            DDM._unregDrag(this);
+
+            this._unprep();
+            if (this.target) {
+                this.target.destroy();
+            }
+        }
+    });
+    Y.namespace('DD');    
+    Y.DD.Drag = Drag;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-base'], skinnable:false});
+YUI.add('dd-proxy', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-proxy
+     */
+    /**
+     * This class extends dd-drag to allow for creating a proxy drag node, instead of dragging the original node.
+     * @class Proxy
+     * @extends Drag
+     * @constructor
+     */
+    var DDM = Y.DD.DDM,
+        NODE = 'node',
+        DRAG_NODE = 'dragNode',
+        PROXY = 'proxy';
+     
+
+    var Proxy = function() {
+        Proxy.superclass.constructor.apply(this, arguments);
+
+    };
+
+    Proxy.NAME = 'dragProxy';
+
+    Proxy.ATTRS = {
+        /**
+        * @attribute moveOnEnd
+        * @description Move the original node at the end of the drag. Default: true
+        * @type Boolean
+        */
+        moveOnEnd: {
+            value: true
+        },
+        /**
+        * @attribute resizeFrame
+        * @description Make the Proxy node assume the size of the original node. Default: true
+        * @type Boolean
+        */
+        resizeFrame: {
+            value: true
+        },
+        /**
+        * @attribute proxy
+        * @description Make this Draggable instance a Proxy instance. Default: false
+        * @type Boolean
+        */
+        proxy: {
+            value: false
+        },        
+        /**
+        * @attribute positionProxy
+        * @description Make the Proxy node appear in the same place as the original node. Default: true
+        * @type Boolean
+        */
+        positionProxy: {
+            value: true
+        },
+        /**
+        * @attribute borderStyle
+        * @description The default border style for the border of the proxy. Default: 1px solid #808080
+        * @type Boolean
+        */
+        borderStyle: {
+            value: '1px solid #808080'
+        }
+    };
+
+    var proto = {
+        /**
+        * @private
+        * @method _createFrame
+        * @description Create the proxy element if it doesn't already exist and set the DD.DDM._proxy value
+        */
+        _createFrame: function() {
+            if (!DDM._proxy) {
+                DDM._proxy = true;
+                var p = Y.Node.create('<div></div>');
+
+                p.setStyles({
+                    position: 'absolute',
+                    display: 'none',
+                    zIndex: '999',
+                    top: '-999px',
+                    left: '-999px',
+                    border: this.get('borderStyle')
+                });
+
+                var b = Y.Node.get('body');
+                b.insertBefore(p, b.get('firstChild'));
+                p.set('id', Y.stamp(p));
+                p.addClass(DDM.CSS_PREFIX + '-proxy');
+                DDM._proxy = p;
+            }
+        },
+        /**
+        * @private
+        * @method _setFrame
+        * @description If resizeProxy is set to true (default) it will resize the proxy element to match the size of the Drag Element.
+        * If positionProxy is set to true (default) it will position the proxy element in the same location as the Drag Element.
+        */
+        _setFrame: function() {
+            var n = this.get(NODE);
+            if (this.get('resizeFrame')) {
+                DDM._proxy.setStyles({
+                    height: n.get('offsetHeight') + 'px',
+                    width: n.get('offsetWidth') + 'px'
+                });
+            }
+            this.get(DRAG_NODE).setStyles({
+                visibility: 'hidden',
+                display: 'block',
+                border: this.get('borderStyle')
+            });
+
+            if (this.get('positionProxy')) {
+                this.get(DRAG_NODE).setXY(this.nodeXY);
+            }
+            this.get(DRAG_NODE).setStyle('visibility', 'visible');
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Lifecycle method
+        */
+        initializer: function() {
+            if (this.get(PROXY)) {
+                this._createFrame();
+            }
+        },
+        /**
+        * @method start
+        * @description Starts the drag operation and sets the dragNode config option.
+        */       
+        start: function() {
+            if (!this.get('lock')) {
+                if (this.get(PROXY)) {
+                    if (this.get(DRAG_NODE).compareTo(this.get(NODE))) {
+                        this.set(DRAG_NODE, DDM._proxy);
+                    }
+                } else {
+                    this.set(DRAG_NODE, this.get(NODE));
+                }
+            }
+            Proxy.superclass.start.apply(this);
+            if (this.get(PROXY)) {
+                this._setFrame();
+            }
+        },
+        /**
+        * @method end
+        * @description Ends the drag operation, if moveOnEnd is set it will position the Drag Element to the new location of the proxy.
+        */        
+        end: function() {
+            if (this.get(PROXY) && this.get('dragging')) {
+                if (this.get('moveOnEnd')) {
+                    this.get(NODE).setXY(this.lastXY);
+                }
+                this.get(DRAG_NODE).setStyle('display', 'none');
+            }
+            Proxy.superclass.end.apply(this);
+        }
+    };
+    //Extend DD.Drag
+    Y.extend(Proxy, Y.DD.Drag, proto);
+    //Set this new class as DD.Drag for other extensions
+    Y.DD.Drag = Proxy;    
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm', 'dd-drag'], skinnable:false});
+YUI.add('dd-constrain', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-constrain
+     */
+    /**
+     * This class extends the dd-drag module to add the constraining methods to it. It supports constraining to a region, node or viewport. It also
+     * supports tick based moves and XY axis constraints.
+     * @class DragConstrained
+     * @extends Drag
+     * @constructor
+     */
+
+    var DRAG_NODE = 'dragNode',
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth';
+
+
+    var C = function() {
+        C.superclass.constructor.apply(this, arguments);
+
+    };
+    
+    C.NAME = 'dragConstrained';
+
+    C.ATTRS = {
+        /**
+        * @attribute stickX
+        * @description Stick the drag movement to the X-Axis. Default: false
+        * @type Boolean
+        */        
+        stickX: {
+            value: false
+        },
+        /**
+        * @attribute stickY
+        * @description Stick the drag movement to the Y-Axis
+        * @type Boolean
+        */        
+        stickY: {
+            value: false
+        },
+        /**
+        * @attribute tickX
+        * @description The X tick offset the drag node should snap to on each drag move. False for no ticks. Default: false
+        * @type Number/false
+        */        
+        tickX: {
+            value: false
+        },
+        /**
+        * @attribute tickY
+        * @description The Y tick offset the drag node should snap to on each drag move. False for no ticks. Default: false
+        * @type Number/false
+        */        
+        tickY: {
+            value: false
+        },
+        /**
+        * @attribute tickXArray
+        * @description An array of page coordinates to use as X ticks for drag movement.
+        * @type Array
+        */
+        tickXArray: {
+            value: false
+        },
+        /**
+        * @attribute tickYArray
+        * @description An array of page coordinates to use as Y ticks for drag movement.
+        * @type Array
+        */
+        tickYArray: {
+            value: false
+        },
+        /**
+        * @attribute constrain2region
+        * @description An Object Literal containing a valid region (top, right, bottom, left) of page positions to constrain the drag node to.
+        * @type Object
+        */
+        constrain2region: {
+            value: false,
+            get: function(r) {
+                if (Y.Lang.isObject(r)) {
+                    var o = {};
+                    Y.mix(o, r);
+                    return o;
+                } else {
+                    return false;
+                }
+            },
+            set: function (r) {
+                if (Y.Lang.isObject(r)) {
+                    if (r.top && r.right && r.left && r.bottom) {
+                        var o = {};
+                        Y.mix(o, r);
+                        return o;
+                    } else {
+                        return false;
+                    }
+                } else if (r !== false) {
+                    return false;
+                }
+            }
+        },
+        /**
+        * @attribute gutter
+        * @description CSS style string for the gutter of a region (supports negative values): '5 0' (sets top and bottom to 5px, left and right to 0px), '1 2 3 4' (top 1px, right 2px, bottom 3px, left 4px)        
+        * @type String
+        */
+        gutter: {
+            value: '0',
+            set: function(gutter) {
+                return Y.DD.DDM.cssSizestoObject(gutter);
+            }
+        },
+        /**
+        * @attribute constrain2node
+        * @description Will attempt to constrain the drag node to the bounderies of this node.
+        * @type Object
+        */
+        constrain2node: {
+            value: false,
+            set: function(n) {
+                if (!this.get('constrain2region')) {
+                    var node = Y.Node.get(n);
+                    if (node) {
+                        return node;
+                    }
+                } else if (this.get('constrain2region') !== false) {
+                }
+                return false;
+            }
+        },
+        /**
+        * @attribute constrain2view
+        * @description Will attempt to constrain the drag node to the bounderies of the viewport region.
+        * @type Object
+        */
+        constrain2view: {
+            value: false
+        }
+    };
+
+    var proto = {
+        start: function() {
+            C.superclass.start.apply(this, arguments);
+            this._regionCache = null;
+        },
+        /**
+        * @private
+        * @property _regionCache
+        * @description Store a cache of the region that we are constraining to
+        * @type Object
+        */
+        _regionCache: null,
+        /**
+        * @private
+        * @method _cacheRegion
+        * @description Get's the region and caches it, called from window.resize and when the cache is null
+        */
+        _cacheRegion: function() {
+            this._regionCache = this.get('constrain2node').get('region');
+        },
+        /**
+        * @method getRegion
+        * @description Get the active region: viewport, node, custom region
+        * @param {Boolean} inc Include the node's height and width
+        * @return {Object}
+        */
+        getRegion: function(inc) {
+            var r = {};
+            if (this.get('constrain2node')) {
+                if (!this._regionCache) {
+                    Y.on('resize', this._cacheRegion, this, true, window);
+                    this._cacheRegion();
+                }
+                r = Y.clone(this._regionCache);
+            } else if (this.get('constrain2region')) {
+                r = this.get('constrain2region');
+            } else if (this.get('constrain2view')) {
+                r = this.get('node').get('viewportRegion');
+            } else {
+                return false;
+            }
+            var g = this.get('gutter');
+            Y.each(g, function(i, n) {
+                if ((n == 'right') || (n == 'bottom')) {
+                    r[n] -= i;
+                } else {
+                    r[n] += i;
+                }
+            });
+            if (inc) {
+                var oh = this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                    ow = this.get(DRAG_NODE).get(OFFSET_WIDTH);
+                r.right = r.right - ow;
+                r.bottom = r.bottom - oh;
+            }
+            return r;
+        },
+        /**
+        * @private
+        * @method _checkRegion
+        * @description
+        * @param {Array} _xy The XY to check if it's in the current region, if it isn't inside the region, it will reset the xy array to be inside the region.
+        * @return {Array} The new XY that is inside the region
+        */
+        _checkRegion: function(_xy) {
+            var oxy = _xy,
+                r = this.getRegion(),
+                oh = this.get(DRAG_NODE).get(OFFSET_HEIGHT),
+                ow = this.get(DRAG_NODE).get(OFFSET_WIDTH);
+            
+                if (oxy[1] > (r.bottom - oh)) {
+                    _xy[1] = (r.bottom - oh);
+                }
+                if (r.top > oxy[1]) {
+                    _xy[1] = r.top;
+
+                }
+                if (oxy[0] > (r.right - ow)) {
+                    _xy[0] = (r.right - ow);
+                }
+                if (r.left > oxy[0]) {
+                    _xy[0] = r.left;
+                }
+
+            return _xy;
+        },
+        /**
+        * @method inRegion
+        * @description Checks if the XY passed or the dragNode is inside the active region.
+        * @param {Array} xy Optional XY to check, if not supplied this.get('dragNode').getXY() is used.
+        * @return {Boolean} True if the XY is inside the region, false otherwise.
+        */
+        inRegion: function(xy) {
+            xy = xy || this.get(DRAG_NODE).getXY();
+
+            var _xy = this._checkRegion([xy[0], xy[1]]),
+                inside = false;
+                if ((xy[0] === _xy[0]) && (xy[1] === _xy[1])) {
+                    inside = true;
+                }
+            return inside;
+        },
+        /**
+        * @private
+        * @method _align
+        * @description Override of Drag _align to account for region checking and tick checking
+        * @param {Array} xy The XY to check for ticks and region
+        * @return {Array} The modified XY coords.
+        */
+        _align: function(xy) {
+            var _xy = C.superclass._align.apply(this, arguments),
+                r = this.getRegion(true);
+
+            if (this.get('stickX')) {
+                _xy[1] = (this.startXY[1] - this.deltaXY[1]);
+            }
+            if (this.get('stickY')) {
+                _xy[0] = (this.startXY[0] - this.deltaXY[0]);
+            }
+
+
+            if (r) {
+                _xy = this._checkRegion(_xy);
+            }
+                
+            _xy = this._checkTicks(_xy, r);
+            return _xy;
+        },
+        /**
+        * @private
+        * @method _calcTicks
+        * @description Helper method to calculate the tick offsets for a given position
+        * @param {Number} pos The current X or Y position
+        * @param {Number} start The start X or Y position
+        * @param {Number} tick The X or Y tick increment
+        * @param {Number} off1 The min offset that we can't pass (region)
+        * @param {Number} off2 The max offset that we can't pass (region)
+        * @return {Number} The new position based on the tick calculation
+        */
+        _calcTicks: function(pos, start, tick, off1, off2) {
+            var ix = ((pos - start) / tick),
+                min = Math.floor(ix),
+                max = Math.ceil(ix);
+                if ((min !== 0) || (max !== 0)) {
+                    if ((ix >= min) && (ix <= max)) {
+                        pos = (start + (tick * min));
+                        if (off1 && off2) {
+                            if (pos < off1) {
+                                pos = (start + (tick * (min + 1)));
+                            }
+                            if (pos > off2) {
+                                pos = (start + (tick * (min - 1)));
+                            }
+                        }
+                    }
+                }
+                return pos;
+        },
+        /**
+        * @private
+        * @method _calcTickArray
+        * @description This method is used with the tickXArray and tickYArray config options
+        * @param {Number} pos The current X or Y position
+        * @param {Number} ticks The array containing our custom tick positions.
+        * @param {Number} off1 The min offset that we can't pass (region)
+        * @param {Number} off2 The max offset that we can't pass (region)
+        * @return The tick position
+        */
+        _calcTickArray: function(pos, ticks, off1, off2) {
+            var i = 0, len = ticks.length, next = 0;
+
+            if (!ticks || (ticks.length === 0)) {
+                return pos;
+            } else if (ticks[0] >= pos) {
+                return ticks[0];
+            } else {
+                for (i = 0; i < len; i++) {
+                    next = (i + 1);
+                    if (ticks[next] && ticks[next] >= pos) {
+                        var diff1 = pos - ticks[i],
+                            diff2 = ticks[next] - pos;
+                        var ret = (diff2 > diff1) ? ticks[i] : ticks[next];
+                        if (off1 && off2) {
+                            if (ret > off2) {
+                                if (ticks[i]) {
+                                    ret = ticks[i];
+                                } else {
+                                    ret = ticks[len - 1];
+                                }
+                            }
+                        }
+                        return ret;
+                    }
+                    
+                }
+                return ticks[ticks.length - 1];
+            }
+        },
+        /**
+        * @private
+        * @method _checkTicks
+        * @description This method delegates the proper helper method for tick calculations
+        * @param {Array} xy The XY coords for the Drag
+        * @param {Object} r The optional region that we are bound to.
+        * @return {Array} The calced XY coords
+        */
+        _checkTicks: function(xy, r) {
+            var lx = (this.startXY[0] - this.deltaXY[0]),
+                ly = (this.startXY[1] - this.deltaXY[1]),
+                xt = this.get('tickX'),
+                yt = this.get('tickY');
+                if (xt && !this.get('tickXArray')) {
+                    xy[0] = this._calcTicks(xy[0], lx, xt, r.left, r.right);
+                }
+                if (yt && !this.get('tickYArray')) {
+                    xy[1] = this._calcTicks(xy[1], ly, yt, r.top, r.bottom);
+                }
+                if (this.get('tickXArray')) {
+                    xy[0] = this._calcTickArray(xy[0], this.get('tickXArray'), r.left, r.right);
+                }
+                if (this.get('tickYArray')) {
+                    xy[1] = this._calcTickArray(xy[1], this.get('tickYArray'), r.top, r.bottom);
+                }
+
+            return xy;
+        }
+    };
+    //Extend DD.Drag
+    Y.extend(C, Y.DD.Drag, proto);
+    //Set this to DD.Drag for other extensions
+    Y.DD.Drag = C;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drag', 'dd-proxy'], skinnable:false});
+YUI.add('dd-plugin', function(Y) {
+
+       /**
+        * This is a simple Drag plugin that can be attached to a Node via the plug method.
+        * @module dd-plugin
+        * @submodule dd-plugin
+        */
+       /**
+        * This is a simple Drag plugin that can be attached to a Node via the plug method.
+        * @class DragPlugin
+        * @extends Drag
+        * @constructor
+        * @namespace plugin
+        */
+
+
+        var Drag = function(config) {
+            config.node = config.owner;
+            Drag.superclass.constructor.apply(this, arguments);
+        };
+        
+        /**
+        * @property NAME
+        * @description dd-plugin
+        * @type {String}
+        */
+        Drag.NAME = "dd-plugin";
+        /**
+        * @property NS
+        * @description The Drag instance will be placed on the Node instance under the dd namespace. It can be accessed via Node.dd;
+        * @type {String}
+        */
+        Drag.NS = "dd";
+
+
+        Y.extend(Drag, Y.DD.Drag);
+        Y.namespace('plugin');
+        Y.plugin.Drag = Drag;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drag'], skinnable:false, optional:['dd-constrain', 'dd-proxy']});
+YUI.add('dd-drop', function(Y) {
+
+    /**
+     * The Drag & Drop Utility allows you to create a draggable interface efficiently, buffering you from browser-level abnormalities and enabling you to focus on the interesting logic surrounding your particular implementation. This component enables you to create a variety of standard draggable objects with just a few lines of code and then, using its extensive API, add your own specific implementation logic.
+     * @module dd
+     * @submodule dd-drop
+     */     
+    /**
+     * This class provides the ability to create a Drop Target.
+     * @class Drop
+     * @extends Base
+     * @constructor
+     */
+
+    var NODE = 'node',
+        DDM = Y.DD.DDM,
+        OFFSET_HEIGHT = 'offsetHeight',
+        OFFSET_WIDTH = 'offsetWidth',
+        /**
+        * @event drop:over
+        * @description Fires when a drag element is over this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_OVER = 'drop:over',
+        /**
+        * @event drop:enter
+        * @description Fires when a drag element enters this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_ENTER = 'drop:enter',
+        /**
+        * @event drop:exit
+        * @description Fires when a drag element exits this target.
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        EV_DROP_EXIT = 'drop:exit';
+
+        /**
+        * @event drop:hit
+        * @description Fires when a draggable node is dropped on this Drop Target. (Fired from dd-ddm-drop)
+        * @bubbles DDM
+        * @type Event.Custom
+        */
+        
+
+    var Drop = function() {
+        Drop.superclass.constructor.apply(this, arguments);
+
+        this._createShim();
+        DDM._regTarget(this);
+        /* TODO
+        if (Dom.getStyle(this.el, 'position') == 'fixed') {
+            Event.on(window, 'scroll', function() {
+                this.activateShim();
+            }, this, true);
+        }
+        */
+    };
+
+    Drop.NAME = 'drop';
+
+    Drop.ATTRS = {
+        /**
+        * @attribute node
+        * @description Y.Node instanace to use as the element to make a Drop Target
+        * @type Node
+        */        
+        node: {
+            set: function(node) {
+                var n = Y.Node.get(node);
+                if (!n) {
+                    Y.fail('DD.Drop: Invalid Node Given: ' + node);
+                }
+                return n;               
+            }
+        },
+        /**
+        * @attribute groups
+        * @description Array of groups to add this drop into.
+        * @type Array
+        */        
+        groups: {
+            value: ['default'],
+            set: function(g) {
+                this._groups = {};
+                Y.each(g, function(v, k) {
+                    this._groups[v] = true;
+                }, this);
+            }
+        },   
+        /**
+        * @attribute padding
+        * @description CSS style padding to make the Drop Target bigger than the node.
+        * @type String
+        */
+        padding: {
+            value: '0',
+            set: function(p) {
+                return DDM.cssSizestoObject(p);
+            }
+        },
+        /**
+        * @attribute lock
+        * @description Set to lock this drop element.
+        * @type Boolean
+        */        
+        lock: {
+            value: false,
+            set: function(lock) {
+                if (lock) {
+                    this.get(NODE).addClass(DDM.CSS_PREFIX + '-drop-locked');
+                } else {
+                    this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-locked');
+                }
+            }
+        },
+        /**
+        * @attribute bubbles
+        * @description Controls the default bubble parent for this Drop instance. Default: Y.DD.DDM. Set to false to disable bubbling.
+        * @type Object
+        */
+        bubbles: {
+            writeOnce: true,
+            value: Y.DD.DDM
+        }
+
+    };
+
+    Y.extend(Drop, Y.Base, {
+        /**
+        * @private
+        * @method _createEvents
+        * @description This method creates all the events for this Event Target and publishes them so we get Event Bubbling.
+        */
+        _createEvents: function() {
+            
+            var ev = [
+                EV_DROP_OVER,
+                EV_DROP_ENTER,
+                EV_DROP_EXIT,
+                'drop:hit'
+            ];
+
+            Y.each(ev, function(v, k) {
+                this.publish(v, {
+                    type: v,
+                    emitFacade: true,
+                    preventable: false,
+                    bubbles: true,
+                    queuable: true
+                });
+            }, this);
+
+            if (this.get('bubbles')) {
+                this.addTarget(this.get('bubbles'));
+            }
+            
+        },
+        /**
+        * @private
+        * @property _valid
+        * @description Flag for determining if the target is valid in this operation.
+        * @type Boolean
+        */
+        _valid: null,
+        /**
+        * @private
+        * @property _groups
+        * @description The groups this target belongs to.
+        * @type Array
+        */
+        _groups: null,
+        /**
+        * @property shim
+        * @description Node reference to the targets shim
+        * @type {Object}
+        */
+        shim: null,
+        /**
+        * @property region
+        * @description A region object associated with this target, used for checking regions while dragging.
+        * @type Object
+        */
+        region: null,
+        /**
+        * @property overTarget
+        * @description This flag is tripped when a drag element is over this target.
+        * @type Boolean
+        */
+        overTarget: null,
+        /**
+        * @method inGroup
+        * @description Check if this target is in one of the supplied groups.
+        * @param {Array} groups The groups to check against
+        * @return Boolean
+        */
+        inGroup: function(groups) {
+            this._valid = false;
+            var ret = false;
+            Y.each(groups, function(v, k) {
+                if (this._groups[v]) {
+                    ret = true;
+                    this._valid = true;
+                }
+            }, this);
+            return ret;
+        },
+        /**
+        * @private
+        * @method initializer
+        * @description Private lifecycle method
+        */
+        initializer: function() {
+            this._createEvents();
+            var node = this.get(NODE);
+            if (!node.get('id')) {
+                var id = Y.stamp(node);
+                node.set('id', id);
+            }
+            node.addClass(DDM.CSS_PREFIX + '-drop');
+        },
+        /**
+        * @private
+        * @method destructor
+        * @description Lifecycle destructor, unreg the drag from the DDM and remove listeners
+        */
+        destructor: function() {
+            DDM._unregTarget(this);
+            if (this.shim) {
+                this.shim.get('parentNode').removeChild(this.shim);
+                this.shim = null;
+            }
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop');
+        },        
+        /**
+        * @private
+        * @method _deactivateShim
+        * @description Removes classes from the target, resets some flags and sets the shims deactive position [-999, -999]
+        */
+        _deactivateShim: function() {
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-active-valid');
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+            this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-over');
+            this.shim.setStyles({
+                top: '-999px',
+                left: '-999px'
+            });
+            this.overTarget = false;
+        },
+        /**
+        * @private
+        * @method _activateShim
+        * @description Activates the shim and adds some interaction CSS classes
+        */
+        _activateShim: function() {
+            if (!DDM.activeDrag) {
+                return false; //Nothing is dragging, no reason to activate.
+            }
+            if (this.get(NODE) === DDM.activeDrag.get(NODE)) {
+                return false;
+            }
+            if (this.get('lock')) {
+                return false;
+            }
+            var node = this.get(NODE);
+            //TODO Visibility Check..
+            //if (this.inGroup(DDM.activeDrag.get('groups')) && this.get(NODE).isVisible()) {
+            if (this.inGroup(DDM.activeDrag.get('groups'))) {
+                node.removeClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+                node.addClass(DDM.CSS_PREFIX + '-drop-active-valid');
+                DDM._addValid(this);
+                this.overTarget = false;
+                this.sizeShim();
+            } else {
+                DDM._removeValid(this);
+                node.removeClass(DDM.CSS_PREFIX + '-drop-active-valid');
+                node.addClass(DDM.CSS_PREFIX + '-drop-active-invalid');
+            }
+        },
+        /**
+        * @method sizeShim
+        * @description Positions and sizes the shim with the raw data from the node, this can be used to programatically adjust the Targets shim for Animation..
+        */
+        sizeShim: function() {
+            if (!DDM.activeDrag) {
+                return false; //Nothing is dragging, no reason to activate.
+            }
+            if (this.get(NODE) === DDM.activeDrag.get(NODE)) {
+                return false;
+            }
+            if (this.get('lock')) {
+                return false;
+            }
+            var node = this.get(NODE),
+                nh = node.get(OFFSET_HEIGHT),
+                nw = node.get(OFFSET_WIDTH),
+                xy = node.getXY(),
+                p = this.get('padding');
+
+
+            //Apply padding
+            nw = nw + p.left + p.right;
+            nh = nh + p.top + p.bottom;
+            xy[0] = xy[0] - p.left;
+            xy[1] = xy[1] - p.top;
+            
+
+            if (DDM.activeDrag.get('dragMode') === DDM.INTERSECT) {
+                //Intersect Mode, make the shim bigger
+                var dd = DDM.activeDrag,
+                    dH = dd.get(NODE).get(OFFSET_HEIGHT),
+                    dW = dd.get(NODE).get(OFFSET_WIDTH);
+                
+                nh = (nh + dH);
+                nw = (nw + dW);
+                xy[0] = xy[0] - (dW - dd.deltaXY[0]);
+                xy[1] = xy[1] - (dH - dd.deltaXY[1]);
+
+            }
+            
+            //Set the style on the shim
+            this.shim.setStyles({
+                height: nh + 'px',
+                width: nw + 'px',
+                top: xy[1] + 'px',
+                left: xy[0] + 'px'
+            });
+            
+            //Create the region to be used by intersect when a drag node is over us.
+            this.region = {
+                '0': xy[0], 
+                '1': xy[1],
+                area: 0,
+                top: xy[1],
+                right: xy[0] + nw,
+                bottom: xy[1] + nh,
+                left: xy[0]
+            };
+        },
+        /**
+        * @private
+        * @method _createShim
+        * @description Creates the Target shim and adds it to the DDM's playground..
+        */
+        _createShim: function() {
+            //var s = Y.Node.create(['div', { id: this.get(NODE).get('id') + '_shim' }]);
+            var s = Y.Node.create('<div id="' + this.get(NODE).get('id') + '_shim"></div>');
+            s.setStyles({
+                height: this.get(NODE).get(OFFSET_HEIGHT) + 'px',
+                width: this.get(NODE).get(OFFSET_WIDTH) + 'px',
+                backgroundColor: 'yellow',
+                opacity: '.5',
+                zIndex: 999,
+                overflow: 'hidden',
+                top: '-900px',
+                left: '-900px',
+                position:  'absolute'
+            });
+            DDM._pg.appendChild(s);
+            this.shim = s;
+
+            s.on('mouseover', this._handleOverEvent, this, true);
+            s.on('mouseout', this._handleOutEvent, this, true);
+        },
+        /**
+        * @private
+        * @method _handleOverTarget
+        * @description This handles the over target call made from this object or from the DDM
+        */
+        _handleTargetOver: function() {
+            if (DDM.isOverTarget(this)) {
+                this.get(NODE).addClass(DDM.CSS_PREFIX + '-drop-over');
+                DDM.activeDrop = this;
+                DDM.otherDrops[this] = this;
+                if (this.overTarget) {
+                    DDM.activeDrag.fire('drag:over', { drop: this, drag: DDM.activeDrag });
+                    this.fire(EV_DROP_OVER, { drop: this, drag: DDM.activeDrag });
+                } else {
+                    this.overTarget = true;
+                    this.fire(EV_DROP_ENTER, { drop: this, drag: DDM.activeDrag });
+                    DDM.activeDrag.fire('drag:enter', { drop: this, drag: DDM.activeDrag });
+                    DDM.activeDrag.get(NODE).addClass(DDM.CSS_PREFIX + '-drag-over');
+                    DDM._handleTargetOver();
+                }
+            } else {
+                this._handleOut();
+            }
+            
+        },
+        /**
+        * @private
+        * @method _handleOverEvent
+        * @description Handles the mouseover DOM event on the Target Shim
+        */
+        _handleOverEvent: function() {
+            DDM._addActiveShim(this);
+        },
+        /**
+        * @private
+        * @method _handleOut
+        * @description Handles the mouseout DOM event on the Target Shim
+        */
+        _handleOutEvent: function() {
+            DDM._removeActiveShim(this);
+        },
+        /**
+        * @private
+        * @method _handleOut
+        * @description Handles out of target calls/checks
+        */
+        _handleOut: function() {
+            if (!DDM.isOverTarget(this)) {
+                if (this.overTarget) {
+                    this.overTarget = false;
+                    DDM._removeActiveShim(this);
+                    if (DDM.activeDrag) {
+                        this.get(NODE).removeClass(DDM.CSS_PREFIX + '-drop-over');
+                        DDM.activeDrag.get(NODE).removeClass(DDM.CSS_PREFIX + '-drag-over');
+                        this.fire(EV_DROP_EXIT);
+                        DDM.activeDrag.fire('drag:exit', { drop: this });
+                        delete DDM.otherDrops[this];
+                    }
+                }
+            }
+        }
+    });
+
+    Y.DD.Drop = Drop;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-ddm-drop', 'dd-drag'], skinnable:false});
+YUI.add('dd-drop-plugin', function(Y) {
+
+       /**
+        * This is a simple Drop plugin that can be attached to a Node via the plug method.
+        * @module dd-plugin
+        * @submodule dd-drop-plugin
+        */
+       /**
+        * This is a simple Drop plugin that can be attached to a Node via the plug method.
+        * @class DropPlugin
+        * @extends Drop
+        * @constructor
+        * @namespace plugin
+        */
+
+
+        var Drop = function(config) {
+            config.node = config.owner;
+            Drop.superclass.constructor.apply(this, arguments);
+        };
+        
+        /**
+        * @property NAME
+        * @description dd-drop-plugin
+        * @type {String}
+        */
+        Drop.NAME = "dd-drop-plugin";
+        /**
+        * @property NS
+        * @description The Drop instance will be placed on the Node instance under the drop namespace. It can be accessed via Node.drop;
+        * @type {String}
+        */
+        Drop.NS = "drop";
+
+
+        Y.extend(Drop, Y.DD.Drop);
+        Y.namespace('plugin');
+        Y.plugin.Drop = Drop;
+
+
+
+}, '3.0.0pr2' ,{requires:['dd-drop'], skinnable:false});
+
+
+YUI.add('dd', function(Y){}, '3.0.0pr2' ,{use:['dd-ddm-base', 'dd-ddm', 'dd-ddm-drop', 'dd-drag', 'dd-proxy', 'dd-constrain', 'dd-plugin', 'dd-drop', 'dd-drop-plugin'], skinnable:false});
+

=== added directory 'loggerhead/static/javascript/yui/build/dom'
=== added file 'loggerhead/static/javascript/yui/build/dom/README'
--- loggerhead/static/javascript/yui/build/dom/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+**** version 3.0.0 PR2 ***
+
+* Documentation updates
+
+
+**** version 3.0.0 PR1 ***
+
+* initial 3.0 revision

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-base-debug.js'
--- loggerhead/static/javascript/yui/build/dom/dom-base-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-base-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,618 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dom-base', function(Y) {
+
+/** 
+ * The DOM utility provides a cross-browser abtraction layer
+ * normalizing DOM tasks, and adds extra helper functionality
+ * for other common tasks. 
+ * @module dom
+ * @submodule dom-base
+ *
+ */
+
+/** 
+ * Provides DOM helper methods.
+ * @class DOM
+ *
+ */
+var NODE_TYPE = 'nodeType',
+    OWNER_DOCUMENT = 'ownerDocument',
+    DOCUMENT_ELEMENT = 'documentElement',
+    DEFAULT_VIEW = 'defaultView',
+    PARENT_WINDOW = 'parentWindow',
+    TAG_NAME = 'tagName',
+    PARENT_NODE = 'parentNode',
+    FIRST_CHILD = 'firstChild',
+    LAST_CHILD = 'lastChild',
+    PREVIOUS_SIBLING = 'previousSibling',
+    NEXT_SIBLING = 'nextSibling',
+    CONTAINS = 'contains',
+    COMPARE_DOCUMENT_POSITION = 'compareDocumentPosition',
+    INNER_TEXT = 'innerText',
+    TEXT_CONTENT = 'textContent',
+    LENGTH = 'length',
+
+    UNDEFINED = undefined;
+
+var re_tag = /<([a-z]+)/i;
+
+var templateCache = {};
+
+Y.DOM = {
+    /**
+     * Returns the HTMLElement with the given ID (Wrapper for document.getElementById).
+     * @method byId         
+     * @param {String} id the id attribute 
+     * @param {Object} doc optional The document to search. Defaults to current document 
+     * @return {HTMLElement | null} The HTMLElement with the id, or null if none found. 
+     */
+    byId: function(id, doc) {
+        return Y.DOM._getDoc(doc).getElementById(id);
+    },
+
+    /**
+     * Returns the text content of the HTMLElement. 
+     * @method getText         
+     * @param {HTMLElement} element The html element. 
+     * @return {String} The text content of the element (includes text of any descending elements).
+     */
+    getText: function(element) {
+        var text = element ? element[TEXT_CONTENT] : '';
+        if (text === UNDEFINED && INNER_TEXT in element) {
+            text = element[INNER_TEXT];
+        } 
+        return text || '';
+    },
+
+    /**
+     * Finds the firstChild of the given HTMLElement. 
+     * @method firstChild
+     * @param {HTMLElement} element The html element. 
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first found is returned.
+     * @return {HTMLElement | null} The first matching child html element.
+     */
+    firstChild: function(element, fn) {
+        return Y.DOM._childBy(element, null, fn);
+    },
+
+    firstChildByTag: function(element, tag, fn) {
+        return Y.DOM._childBy(element, tag, fn);
+    },
+
+    /**
+     * Finds the lastChild of the given HTMLElement.
+     * @method lastChild
+     * @param {HTMLElement} element The html element.
+     * @param {String} tag The tag to search for.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first found is returned.
+     * @return {HTMLElement | null} The first matching child html element.
+     */
+    lastChild: function(element, fn) {
+        return Y.DOM._childBy(element, null, fn, true);
+    },
+
+    lastChildByTag: function(element, tag, fn) {
+        return Y.DOM._childBy(element, tag, fn, true);
+    },
+
+    /**
+     * Finds all HTMLElement childNodes matching the given tag.
+     * @method childrenByTag
+     * @param {HTMLElement} element The html element.
+     * @param {String} tag The tag to search for.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all children with the given tag are collected.
+     * @return {Array} The collection of child elements.
+     */
+    childrenByTag: function() {
+        if (document[DOCUMENT_ELEMENT].children) {
+            return function(element, tag, fn, toArray) { // TODO: keep toArray option?
+                tag = (tag && tag !== '*') ? tag : null;
+                var elements = [];
+                if (element) {
+                    elements = (tag) ? element.children.tags(tag) : element.children; 
+
+                    if (fn || toArray) {
+                        elements = Y.DOM.filterElementsBy(elements, fn);
+                    }
+                }
+
+                return elements;
+            };
+        } else {
+            return function(element, tag, fn) {
+                tag = (tag && tag !== '*') ? tag.toUpperCase() : null;
+                var elements = [],
+                    wrapFn = fn;
+
+                if (element) {
+                    elements = element.childNodes; 
+                    if (tag) { // wrap fn and add tag test TODO: allow tag in filterElementsBy?
+                        wrapFn = function(el) {
+                            return el[TAG_NAME].toUpperCase() === tag && (!fn || fn(el));
+                        };
+                    }
+
+                    elements = Y.DOM.filterElementsBy(elements, wrapFn);
+                }
+                return elements;
+            };
+        }
+    }(),
+
+    /**
+     * Finds all HTMLElement childNodes.
+     * @method children
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all children are collected.
+     * @return {Array} The collection of child elements.
+     */
+    children: function(element, fn) {
+        return Y.DOM.childrenByTag(element, null, fn);
+    },
+
+    /**
+     * Finds the previous sibling of the element.
+     * @method previous
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the first sibling is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    previous: function(element, fn) {
+        return Y.DOM.elementByAxis(element, PREVIOUS_SIBLING, fn);
+    },
+
+    /**
+     * Finds the next sibling of the element.
+     * @method next
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the first sibling is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    next: function(element, fn) {
+        return Y.DOM.elementByAxis(element, NEXT_SIBLING, fn);
+    },
+
+    /**
+     * Finds the ancestor of the element.
+     * @method ancestor
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the parentNode is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    ancestor: function(element, fn) {
+        return Y.DOM.elementByAxis(element, PARENT_NODE, fn);
+    },
+
+    /**
+     * Searches the element by the given axis for the first matching element.
+     * @method elementByAxis
+     * @param {HTMLElement} element The html element.
+     * @param {String} axis The axis to search (parentNode, nextSibling, previousSibling).
+     * @param {Function} fn optional An optional boolean test to apply.
+     * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first element is returned.
+     * @return {HTMLElement | null} The matching element or null if none found.
+     */
+    elementByAxis: function(element, axis, fn, all) {
+        while (element && (element = element[axis])) { // NOTE: assignment
+                if ( (all || element[TAG_NAME]) && (!fn || fn(element)) ) {
+                    return element;
+                }
+        }
+        return null;
+    },
+
+    /**
+     * Finds all elements with the given tag.
+     * @method byTag
+     * @param {String} tag The tag being search for. 
+     * @param {HTMLElement} root optional An optional root element to start from.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all elements with the given tag are returned.
+     * @return {Array} The collection of matching elements.
+     */
+    byTag: function(tag, root, fn) {
+        root = root || Y.config.doc;
+
+        var elements = root.getElementsByTagName(tag),
+            retNodes = [];
+
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if ( !fn || fn(elements[i]) ) {
+                retNodes[retNodes[LENGTH]] = elements[i];
+            }
+        }
+        return retNodes;
+    },
+
+    /**
+     * Finds the first element with the given tag.
+     * @method firstByTag
+     * @param {String} tag The tag being search for. 
+     * @param {HTMLElement} root optional An optional root element to start from.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first match is returned. 
+     * @return {HTMLElement} The matching element.
+     */
+    firstByTag: function(tag, root, fn) {
+        root = root || Y.config.doc;
+
+        var elements = root.getElementsByTagName(tag),
+            ret = null;
+
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if ( !fn || fn(elements[i]) ) {
+                ret = elements[i];
+                break;
+            }
+        }
+        return ret;
+    },
+
+    /**
+     * Filters a collection of HTMLElements by the given attributes.
+     * @method filterElementsBy
+     * @param {Array} elements The collection of HTMLElements to filter.
+     * @param {Function} fn A boolean test to apply.
+     * The function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all HTMLElements are kept.
+     * @return {Array} The filtered collection of HTMLElements.
+     */
+    filterElementsBy: function(elements, fn, firstOnly) {
+        var ret = (firstOnly) ? null : [];
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if (elements[i][TAG_NAME] && (!fn || fn(elements[i]))) {
+                if (firstOnly) {
+                    ret = elements[i];
+                    break;
+                } else {
+                    ret[ret[LENGTH]] = elements[i];
+                }
+            }
+        }
+
+        return ret;
+    },
+
+    /**
+     * Determines whether or not one HTMLElement is or contains another HTMLElement.
+     * @method contains
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} needle The html element that may be contained.
+     * @return {Boolean} Whether or not the element is or contains the needle.
+     */
+    contains: function(element, needle) {
+        var ret = false;
+
+        if ( !needle || !element || !needle[NODE_TYPE] || !element[NODE_TYPE]) {
+            ret = false;
+        } else if (element[CONTAINS])  {
+            if (Y.UA.opera || needle[NODE_TYPE] === 1) { // IE & SAF contains fail if needle not an ELEMENT_NODE
+                ret = element[CONTAINS](needle);
+            } else {
+                ret = Y.DOM._bruteContains(element, needle); 
+            }
+        } else if (element[COMPARE_DOCUMENT_POSITION]) { // gecko
+            if (element === needle || !!(element[COMPARE_DOCUMENT_POSITION](needle) & 16)) { 
+                ret = true;
+            }
+        }
+
+        return ret;
+    },
+
+    /**
+     * Determines whether or not the HTMLElement is part of the document.
+     * @method inDoc
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} doc optional The document to check.
+     * @return {Boolean} Whether or not the element is attached to the document. 
+     */
+    inDoc: function(element, doc) {
+        doc = doc || Y.config.doc;
+        return Y.DOM.contains(doc.documentElement, element);
+    },
+
+    create: function(html, doc) {
+        doc = doc || Y.config.doc;
+        var m = re_tag.exec(html);
+        var create = Y.DOM._create,
+            custom = Y.DOM.creators,
+            tag, ret;
+
+        if (m && custom[m[1]]) {
+            if (typeof custom[m[1]] === 'function') {
+                create = custom[m[1]];
+            } else {
+                tag = custom[m[1]];
+            }
+        }
+        ret = create(html, doc, tag);
+        return (ret.childNodes.length > 1) ? ret.childNodes : ret.childNodes[0]; // collection or item
+        //return ret.firstChild;
+    },
+
+    _create: function(html, doc, tag) {
+        tag = tag || 'div';
+        var frag = templateCache[tag] || doc.createElement(tag);
+        frag.innerHTML = Y.Lang.trim(html);
+        return frag;
+    },
+
+    /**
+     * Brute force version of contains.
+     * Used for browsers without contains support for non-HTMLElement Nodes (textNodes, etc).
+     * @method _bruteContains
+     * @private
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} needle The html element that may be contained.
+     * @return {Boolean} Whether or not the element is or contains the needle.
+     */
+    _bruteContains: function(element, needle) {
+        while (needle) {
+            if (element === needle) {
+                return true;
+            }
+            needle = needle.parentNode;
+        }
+        return false;
+    },
+
+    /**
+     * Memoizes dynamic regular expressions to boost runtime performance. 
+     * @method _getRegExp
+     * @private
+     * @param {String} str The string to convert to a regular expression.
+     * @param {String} flags optional An optinal string of flags.
+     * @return {RegExp} An instance of RegExp
+     */
+    _getRegExp: function(str, flags) {
+        flags = flags || '';
+        Y.DOM._regexCache = Y.DOM._regexCache || {};
+        if (!Y.DOM._regexCache[str + flags]) {
+            Y.DOM._regexCache[str + flags] = new RegExp(str, flags);
+        }
+        return Y.DOM._regexCache[str + flags];
+    },
+
+    /**
+     * returns the appropriate document.
+     * @method _getDoc
+     * @private
+     * @param {HTMLElement} element optional Target element.
+     * @return {Object} The document for the given element or the default document. 
+     */
+    _getDoc: function(element) {
+        element = element || {};
+        return (element[NODE_TYPE] === 9) ? element : element[OWNER_DOCUMENT] ||
+                                                Y.config.doc;
+    },
+
+    /**
+     * returns the appropriate window.
+     * @method _getWin
+     * @private
+     * @param {HTMLElement} element optional Target element.
+     * @return {Object} The window for the given element or the default window. 
+     */
+    _getWin: function(element) {
+        var doc = Y.DOM._getDoc(element);
+        return (element.document) ? element : doc[DEFAULT_VIEW] ||
+                                        doc[PARENT_WINDOW] || Y.config.win;
+    },
+
+    _childBy: function(element, tag, fn, rev) {
+        var ret = null,
+            root, axis;
+
+        if (element) {
+            if (rev) {
+                root = element[LAST_CHILD];
+                axis = PREVIOUS_SIBLING;
+            } else {
+                root = element[FIRST_CHILD];
+                axis = NEXT_SIBLING;
+            }
+
+            if (Y.DOM._testElement(root, tag, fn)) { // is the matching element
+                ret = root;
+            } else { // need to scan nextSibling axis of firstChild to find matching element
+                ret = Y.DOM.elementByAxis(root, axis, fn);
+            }
+        }
+        return ret;
+
+    },
+
+    _testElement: function(element, tag, fn) {
+        tag = (tag && tag !== '*') ? tag.toUpperCase() : null;
+        return (element && element[TAG_NAME] &&
+                (!tag || element[TAG_NAME].toUpperCase() === tag) &&
+                (!fn || fn(element)));
+    },
+
+    creators: {},
+
+    _IESimpleCreate: function(html, doc) {
+        doc = doc || Y.config.doc;
+        return doc.createElement(html);
+    }
+};
+
+
+(function() {
+    var creators = Y.DOM.creators,
+        create = Y.DOM.create,
+        re_tbody = /(?:\/(?:thead|tfoot|tbody|caption|col|colgroup)>)+\s*<tbody/;
+
+    var TABLE_OPEN = '<table>',
+        TABLE_CLOSE = '</table>';
+
+    if (Y.UA.gecko || Y.UA.ie) { // require custom creation code for certain element types
+        Y.mix(creators, {
+            option: function(html, doc) {
+                var frag = create('<select>' + html + '</select>');
+                return frag;
+            },
+
+            tr: function(html, doc) {
+                var frag = creators.tbody('<tbody>' + html + '</tbody>', doc);
+                return frag.firstChild;
+            },
+
+            td: function(html, doc) {
+                var frag = creators.tr('<tr>' + html + '</tr>', doc);
+                return frag.firstChild;
+            }, 
+
+            tbody: function(html, doc) {
+                var frag = create(TABLE_OPEN + html + TABLE_CLOSE, doc);
+                return frag;
+            },
+
+            legend: 'fieldset'
+        });
+
+        creators.col = creators.tbody; // IE wraps in colgroup
+    }
+
+    if (Y.UA.ie) {
+        // TODO: allow multiples ("<link><link>")
+        creators.col = creators.script = creators.link = Y.DOM._IESimpleCreate; 
+
+        // TODO: thead/tfoot with nested tbody
+        creators.tbody = function(html, doc) {
+            var frag = create(TABLE_OPEN + html + TABLE_CLOSE, doc);
+            var tb = frag.children.tags('tbody')[0];
+            if (frag.children.length > 1 && tb && !re_tbody.test(html)) {
+                tb.parentNode.removeChild(tb);
+            }
+            return frag;
+        };
+
+    }
+
+    if (Y.UA.gecko || Y.UA.ie) { // require custom creation code for certain element types
+        Y.mix(creators, {
+                th: creators.td,
+                thead: creators.tbody,
+                tfoot: creators.tbody,
+                caption: creators.tbody,
+                colgroup: creators.tbody,
+                col: creators.tbody,
+                optgroup: creators.option
+        });
+    }
+})();
+
+/** 
+ * The DOM utility provides a cross-browser abtraction layer
+ * normalizing DOM tasks, and adds extra helper functionality
+ * for other common tasks. 
+ * @module dom
+ * @submodule dom-base
+ * @for DOM
+ */
+
+var CLASS_NAME = 'className';
+
+Y.mix(Y.DOM, {
+    /**
+     * Determines whether a DOM element has the given className.
+     * @method hasClass
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to search for
+     * @return {Boolean} Whether or not the element has the given class. 
+     */
+    hasClass: function(node, className) {
+        var re = Y.DOM._getRegExp('(?:^|\\s+)' + className + '(?:\\s+|$)');
+        return re.test(node[CLASS_NAME]);
+    },
+
+    /**
+     * Adds a class name to a given DOM element.
+     * @method addClass         
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to add to the class attribute
+     */
+    addClass: function(node, className) {
+        if (!Y.DOM.hasClass(node, className)) { // skip if already present 
+            node[CLASS_NAME] = Y.Lang.trim([node[CLASS_NAME], className].join(' '));
+        }
+    },
+
+    /**
+     * Removes a class name from a given element.
+     * @method removeClass         
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to remove from the class attribute
+     */
+    removeClass: function(node, className) {
+        if (className && Y.DOM.hasClass(node, className)) {
+            node[CLASS_NAME] = Y.Lang.trim(node[CLASS_NAME].replace(Y.DOM._getRegExp('(?:^|\\s+)' +
+                            className + '(?:\\s+|$)'), ' '));
+
+            if ( Y.DOM.hasClass(node, className) ) { // in case of multiple adjacent
+                Y.DOM.removeClass(node, className);
+            }
+        }                 
+    },
+
+    /**
+     * Replace a class with another class for a given element.
+     * If no oldClassName is present, the newClassName is simply added.
+     * @method replaceClass  
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} oldClassName the class name to be replaced
+     * @param {String} newClassName the class name that will be replacing the old class name
+     */
+    replaceClass: function(node, oldC, newC) {
+        //Y.log('replaceClass replacing ' + oldC + ' with ' + newC, 'info', 'Node');
+        Y.DOM.addClass(node, newC);
+        Y.DOM.removeClass(node, oldC);
+    },
+
+    /**
+     * If the className exists on the node it is removed, if it doesn't exist it is added.
+     * @method toggleClass  
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to be toggled
+     */
+    toggleClass: function(node, className) {
+        if (Y.DOM.hasClass(node, className)) {
+            Y.DOM.removeClass(node, className);
+        } else {
+            Y.DOM.addClass(node, className);
+        }
+    }
+});
+
+
+
+
+}, '3.0.0pr2' ,{skinnable:false, requires:['event']});

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-base-min.js'
--- loggerhead/static/javascript/yui/build/dom/dom-base-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-base-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dom-base",function(D){var J="nodeType",O="ownerDocument",S="documentElement",C="defaultView",I="parentWindow",M="tagName",F="parentNode",B="firstChild",R="lastChild",N="previousSibling",T="nextSibling",G="contains",K="compareDocumentPosition",P="innerText",Q="textContent",L="length",U=undefined;var H=/<([a-z]+)/i;var E={};D.DOM={byId:function(W,V){return D.DOM._getDoc(V).getElementById(W);},getText:function(V){var W=V?V[Q]:"";if(W===U&&P in V){W=V[P];}return W||"";},firstChild:function(V,W){return D.DOM._childBy(V,null,W);},firstChildByTag:function(W,V,X){return D.DOM._childBy(W,V,X);},lastChild:function(V,W){return D.DOM._childBy(V,null,W,true);},lastChildByTag:function(W,V,X){return D.DOM._childBy(W,V,X,true);},childrenByTag:function(){if(document[S].children){return function(X,V,Y,W){V=(V&&V!=="*")?V:null;var Z=[];if(X){Z=(V)?X.children.tags(V):X.children;if(Y||W){Z=D.DOM.filterElementsBy(Z,Y);}}return Z;};}else{return function(X,W,Y){W=(W&&W!=="*")?W.toUpperCase():null;var Z=[],V=Y;if(X){Z=X.childNodes;if(W){V=function(a){return a[M].toUpperCase()===W&&(!Y||Y(a));};}Z=D.DOM.filterElementsBy(Z,V);}return Z;};}}(),children:function(V,W){return D.DOM.childrenByTag(V,null,W);},previous:function(V,W){return D.DOM.elementByAxis(V,N,W);},next:function(V,W){return D.DOM.elementByAxis(V,T,W);},ancestor:function(V,W){return D.DOM.elementByAxis(V,F,W);},elementByAxis:function(V,Y,X,W){while(V&&(V=V[Y])){if((W||V[M])&&(!X||X(V))){return V;}}return null;},byTag:function(W,X,a){X=X||D.config.doc;var b=X.getElementsByTagName(W),Z=[];for(var Y=0,V=b[L];Y<V;++Y){if(!a||a(b[Y])){Z[Z[L]]=b[Y];}}return Z;},firstByTag:function(W,X,a){X=X||D.config.doc;var b=X.getElementsByTagName(W),Y=null;for(var Z=0,V=b[L];Z<V;++Z){if(!a||a(b[Z])){Y=b[Z];break;}}return Y;},filterElementsBy:function(a,Z,Y){var W=(Y)?null:[];for(var X=0,V=a[L];X<V;++X){if(a[X][M]&&(!Z||Z(a[X]))){if(Y){W=a[X];break;}else{W[W[L]]=a[X];}}}return W;},contains:function(W,X){var V=false;if(!X||!W||!X[J]||!W[J]){V=false;}else{if(W[G]){if(D.UA.opera||X[J]===1){V=W[G](X);}else{V=D.DOM._bruteContains(W,X);}}else{if(W[K]){if(W===X||!!(W[K](X)&16)){V=true;}}}}return V;},inDoc:function(V,W){W=W||D.config.doc;return D.DOM.contains(W.documentElement,V);},create:function(Z,b){b=b||D.config.doc;var W=H.exec(Z);var Y=D.DOM._create,a=D.DOM.creators,V,X;if(W&&a[W[1]]){if(typeof a[W[1]]==="function"){Y=a[W[1]];}else{V=a[W[1]];}}X=Y(Z,b,V);return(X.childNodes.length>1)?X.childNodes:X.childNodes[0];},_create:function(W,X,V){V=V||"div";var Y=E[V]||X.createElement(V);Y.innerHTML=D.Lang.trim(W);return Y;},_bruteContains:function(V,W){while(W){if(V===W){return true;}W=W.parentNode;}return false;},_getRegExp:function(W,V){V=V||"";D.DOM._regexCache=D.DOM._regexCache||{};if(!D.DOM._regexCache[W+V]){D.DOM._regexCache[W+V]=new RegExp(W,V);}return D.DOM._regexCache[W+V];},_getDoc:function(V){V=V||{};return(V[J]===9)?V:V[O]||D.config.doc;},_getWin:function(V){var W=D.DOM._getDoc(V);return(V.document)?V:W[C]||W[I]||D.config.win;},_childBy:function(Z,V,b,X){var Y=null,W,a;if(Z){if(X){W=Z[R];a=N;}else{W=Z[B];a=T;}if(D.DOM._testElement(W,V,b)){Y=W;}else{Y=D.DOM.elementByAxis(W,a,b);}}return Y;},_testElement:function(W,V,X){V=(V&&V!=="*")?V.toUpperCase():null;return(W&&W[M]&&(!V||W[M].toUpperCase()===V)&&(!X||X(W)));},creators:{},_IESimpleCreate:function(V,W){W=W||D.config.doc;return W.createElement(V);}};(function(){var Z=D.DOM.creators,V=D.DOM.create,Y=/(?:\/(?:thead|tfoot|tbody|caption|col|colgroup)>)+\s*<tbody/;var X="<table>",W="</table>";if(D.UA.gecko||D.UA.ie){D.mix(Z,{option:function(a,b){var c=V("<select>"+a+"</select>");return c;},tr:function(a,b){var c=Z.tbody("<tbody>"+a+"</tbody>",b);return c.firstChild;},td:function(a,b){var c=Z.tr("<tr>"+a+"</tr>",b);return c.firstChild;},tbody:function(a,b){var c=V(X+a+W,b);return c;},legend:"fieldset"});Z.col=Z.tbody;}if(D.UA.ie){Z.col=Z.script=Z.link=D.DOM._IESimpleCreate;Z.tbody=function(b,c){var d=V(X+b+W,c);var a=d.children.tags("tbody")[0];if(d.children.length>1&&a&&!Y.test(b)){a.parentNode.removeChild(a);}return d;};}if(D.UA.gecko||D.UA.ie){D.mix(Z,{th:Z.td,thead:Z.tbody,tfoot:Z.tbody,caption:Z.tbody,colgroup:Z.tbody,col:Z.tbody,optgroup:Z.option});}})();var A="className";D.mix(D.DOM,{hasClass:function(X,W){var V=D.DOM._getRegExp("(?:^|\\s+)"+W+"(?:\\s+|$)");return V.test(X[A]);},addClass:function(W,V){if(!D.DOM.hasClass(W,V)){W[A]=D.Lang.trim([W[A],V].join(" "));}},removeClass:function(W,V){if(V&&D.DOM.hasClass(W,V)){W[A]=D.Lang.trim(W[A].replace(D.DOM._getRegExp("(?:^|\\s+)"+V+"(?:\\s+|$)")," "));if(D.DOM.hasClass(W,V)){D.DOM.removeClass(W,V);}}},replaceClass:function(W,V,X){D.DOM.addClass(W,X);D.DOM.removeClass(W,V);},toggleClass:function(W,V){if(D.DOM.hasClass(W,V)){D.DOM.removeClass(W,V);}else{D.DOM.addClass(W,V);}}});},"3.0.0pr2",{skinnable:false,requires:["event"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-base.js'
--- loggerhead/static/javascript/yui/build/dom/dom-base.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-base.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,617 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dom-base', function(Y) {
+
+/** 
+ * The DOM utility provides a cross-browser abtraction layer
+ * normalizing DOM tasks, and adds extra helper functionality
+ * for other common tasks. 
+ * @module dom
+ * @submodule dom-base
+ *
+ */
+
+/** 
+ * Provides DOM helper methods.
+ * @class DOM
+ *
+ */
+var NODE_TYPE = 'nodeType',
+    OWNER_DOCUMENT = 'ownerDocument',
+    DOCUMENT_ELEMENT = 'documentElement',
+    DEFAULT_VIEW = 'defaultView',
+    PARENT_WINDOW = 'parentWindow',
+    TAG_NAME = 'tagName',
+    PARENT_NODE = 'parentNode',
+    FIRST_CHILD = 'firstChild',
+    LAST_CHILD = 'lastChild',
+    PREVIOUS_SIBLING = 'previousSibling',
+    NEXT_SIBLING = 'nextSibling',
+    CONTAINS = 'contains',
+    COMPARE_DOCUMENT_POSITION = 'compareDocumentPosition',
+    INNER_TEXT = 'innerText',
+    TEXT_CONTENT = 'textContent',
+    LENGTH = 'length',
+
+    UNDEFINED = undefined;
+
+var re_tag = /<([a-z]+)/i;
+
+var templateCache = {};
+
+Y.DOM = {
+    /**
+     * Returns the HTMLElement with the given ID (Wrapper for document.getElementById).
+     * @method byId         
+     * @param {String} id the id attribute 
+     * @param {Object} doc optional The document to search. Defaults to current document 
+     * @return {HTMLElement | null} The HTMLElement with the id, or null if none found. 
+     */
+    byId: function(id, doc) {
+        return Y.DOM._getDoc(doc).getElementById(id);
+    },
+
+    /**
+     * Returns the text content of the HTMLElement. 
+     * @method getText         
+     * @param {HTMLElement} element The html element. 
+     * @return {String} The text content of the element (includes text of any descending elements).
+     */
+    getText: function(element) {
+        var text = element ? element[TEXT_CONTENT] : '';
+        if (text === UNDEFINED && INNER_TEXT in element) {
+            text = element[INNER_TEXT];
+        } 
+        return text || '';
+    },
+
+    /**
+     * Finds the firstChild of the given HTMLElement. 
+     * @method firstChild
+     * @param {HTMLElement} element The html element. 
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first found is returned.
+     * @return {HTMLElement | null} The first matching child html element.
+     */
+    firstChild: function(element, fn) {
+        return Y.DOM._childBy(element, null, fn);
+    },
+
+    firstChildByTag: function(element, tag, fn) {
+        return Y.DOM._childBy(element, tag, fn);
+    },
+
+    /**
+     * Finds the lastChild of the given HTMLElement.
+     * @method lastChild
+     * @param {HTMLElement} element The html element.
+     * @param {String} tag The tag to search for.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first found is returned.
+     * @return {HTMLElement | null} The first matching child html element.
+     */
+    lastChild: function(element, fn) {
+        return Y.DOM._childBy(element, null, fn, true);
+    },
+
+    lastChildByTag: function(element, tag, fn) {
+        return Y.DOM._childBy(element, tag, fn, true);
+    },
+
+    /**
+     * Finds all HTMLElement childNodes matching the given tag.
+     * @method childrenByTag
+     * @param {HTMLElement} element The html element.
+     * @param {String} tag The tag to search for.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all children with the given tag are collected.
+     * @return {Array} The collection of child elements.
+     */
+    childrenByTag: function() {
+        if (document[DOCUMENT_ELEMENT].children) {
+            return function(element, tag, fn, toArray) { // TODO: keep toArray option?
+                tag = (tag && tag !== '*') ? tag : null;
+                var elements = [];
+                if (element) {
+                    elements = (tag) ? element.children.tags(tag) : element.children; 
+
+                    if (fn || toArray) {
+                        elements = Y.DOM.filterElementsBy(elements, fn);
+                    }
+                }
+
+                return elements;
+            };
+        } else {
+            return function(element, tag, fn) {
+                tag = (tag && tag !== '*') ? tag.toUpperCase() : null;
+                var elements = [],
+                    wrapFn = fn;
+
+                if (element) {
+                    elements = element.childNodes; 
+                    if (tag) { // wrap fn and add tag test TODO: allow tag in filterElementsBy?
+                        wrapFn = function(el) {
+                            return el[TAG_NAME].toUpperCase() === tag && (!fn || fn(el));
+                        };
+                    }
+
+                    elements = Y.DOM.filterElementsBy(elements, wrapFn);
+                }
+                return elements;
+            };
+        }
+    }(),
+
+    /**
+     * Finds all HTMLElement childNodes.
+     * @method children
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all children are collected.
+     * @return {Array} The collection of child elements.
+     */
+    children: function(element, fn) {
+        return Y.DOM.childrenByTag(element, null, fn);
+    },
+
+    /**
+     * Finds the previous sibling of the element.
+     * @method previous
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the first sibling is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    previous: function(element, fn) {
+        return Y.DOM.elementByAxis(element, PREVIOUS_SIBLING, fn);
+    },
+
+    /**
+     * Finds the next sibling of the element.
+     * @method next
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the first sibling is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    next: function(element, fn) {
+        return Y.DOM.elementByAxis(element, NEXT_SIBLING, fn);
+    },
+
+    /**
+     * Finds the ancestor of the element.
+     * @method ancestor
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the parentNode is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    ancestor: function(element, fn) {
+        return Y.DOM.elementByAxis(element, PARENT_NODE, fn);
+    },
+
+    /**
+     * Searches the element by the given axis for the first matching element.
+     * @method elementByAxis
+     * @param {HTMLElement} element The html element.
+     * @param {String} axis The axis to search (parentNode, nextSibling, previousSibling).
+     * @param {Function} fn optional An optional boolean test to apply.
+     * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first element is returned.
+     * @return {HTMLElement | null} The matching element or null if none found.
+     */
+    elementByAxis: function(element, axis, fn, all) {
+        while (element && (element = element[axis])) { // NOTE: assignment
+                if ( (all || element[TAG_NAME]) && (!fn || fn(element)) ) {
+                    return element;
+                }
+        }
+        return null;
+    },
+
+    /**
+     * Finds all elements with the given tag.
+     * @method byTag
+     * @param {String} tag The tag being search for. 
+     * @param {HTMLElement} root optional An optional root element to start from.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all elements with the given tag are returned.
+     * @return {Array} The collection of matching elements.
+     */
+    byTag: function(tag, root, fn) {
+        root = root || Y.config.doc;
+
+        var elements = root.getElementsByTagName(tag),
+            retNodes = [];
+
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if ( !fn || fn(elements[i]) ) {
+                retNodes[retNodes[LENGTH]] = elements[i];
+            }
+        }
+        return retNodes;
+    },
+
+    /**
+     * Finds the first element with the given tag.
+     * @method firstByTag
+     * @param {String} tag The tag being search for. 
+     * @param {HTMLElement} root optional An optional root element to start from.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first match is returned. 
+     * @return {HTMLElement} The matching element.
+     */
+    firstByTag: function(tag, root, fn) {
+        root = root || Y.config.doc;
+
+        var elements = root.getElementsByTagName(tag),
+            ret = null;
+
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if ( !fn || fn(elements[i]) ) {
+                ret = elements[i];
+                break;
+            }
+        }
+        return ret;
+    },
+
+    /**
+     * Filters a collection of HTMLElements by the given attributes.
+     * @method filterElementsBy
+     * @param {Array} elements The collection of HTMLElements to filter.
+     * @param {Function} fn A boolean test to apply.
+     * The function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all HTMLElements are kept.
+     * @return {Array} The filtered collection of HTMLElements.
+     */
+    filterElementsBy: function(elements, fn, firstOnly) {
+        var ret = (firstOnly) ? null : [];
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if (elements[i][TAG_NAME] && (!fn || fn(elements[i]))) {
+                if (firstOnly) {
+                    ret = elements[i];
+                    break;
+                } else {
+                    ret[ret[LENGTH]] = elements[i];
+                }
+            }
+        }
+
+        return ret;
+    },
+
+    /**
+     * Determines whether or not one HTMLElement is or contains another HTMLElement.
+     * @method contains
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} needle The html element that may be contained.
+     * @return {Boolean} Whether or not the element is or contains the needle.
+     */
+    contains: function(element, needle) {
+        var ret = false;
+
+        if ( !needle || !element || !needle[NODE_TYPE] || !element[NODE_TYPE]) {
+            ret = false;
+        } else if (element[CONTAINS])  {
+            if (Y.UA.opera || needle[NODE_TYPE] === 1) { // IE & SAF contains fail if needle not an ELEMENT_NODE
+                ret = element[CONTAINS](needle);
+            } else {
+                ret = Y.DOM._bruteContains(element, needle); 
+            }
+        } else if (element[COMPARE_DOCUMENT_POSITION]) { // gecko
+            if (element === needle || !!(element[COMPARE_DOCUMENT_POSITION](needle) & 16)) { 
+                ret = true;
+            }
+        }
+
+        return ret;
+    },
+
+    /**
+     * Determines whether or not the HTMLElement is part of the document.
+     * @method inDoc
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} doc optional The document to check.
+     * @return {Boolean} Whether or not the element is attached to the document. 
+     */
+    inDoc: function(element, doc) {
+        doc = doc || Y.config.doc;
+        return Y.DOM.contains(doc.documentElement, element);
+    },
+
+    create: function(html, doc) {
+        doc = doc || Y.config.doc;
+        var m = re_tag.exec(html);
+        var create = Y.DOM._create,
+            custom = Y.DOM.creators,
+            tag, ret;
+
+        if (m && custom[m[1]]) {
+            if (typeof custom[m[1]] === 'function') {
+                create = custom[m[1]];
+            } else {
+                tag = custom[m[1]];
+            }
+        }
+        ret = create(html, doc, tag);
+        return (ret.childNodes.length > 1) ? ret.childNodes : ret.childNodes[0]; // collection or item
+        //return ret.firstChild;
+    },
+
+    _create: function(html, doc, tag) {
+        tag = tag || 'div';
+        var frag = templateCache[tag] || doc.createElement(tag);
+        frag.innerHTML = Y.Lang.trim(html);
+        return frag;
+    },
+
+    /**
+     * Brute force version of contains.
+     * Used for browsers without contains support for non-HTMLElement Nodes (textNodes, etc).
+     * @method _bruteContains
+     * @private
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} needle The html element that may be contained.
+     * @return {Boolean} Whether or not the element is or contains the needle.
+     */
+    _bruteContains: function(element, needle) {
+        while (needle) {
+            if (element === needle) {
+                return true;
+            }
+            needle = needle.parentNode;
+        }
+        return false;
+    },
+
+    /**
+     * Memoizes dynamic regular expressions to boost runtime performance. 
+     * @method _getRegExp
+     * @private
+     * @param {String} str The string to convert to a regular expression.
+     * @param {String} flags optional An optinal string of flags.
+     * @return {RegExp} An instance of RegExp
+     */
+    _getRegExp: function(str, flags) {
+        flags = flags || '';
+        Y.DOM._regexCache = Y.DOM._regexCache || {};
+        if (!Y.DOM._regexCache[str + flags]) {
+            Y.DOM._regexCache[str + flags] = new RegExp(str, flags);
+        }
+        return Y.DOM._regexCache[str + flags];
+    },
+
+    /**
+     * returns the appropriate document.
+     * @method _getDoc
+     * @private
+     * @param {HTMLElement} element optional Target element.
+     * @return {Object} The document for the given element or the default document. 
+     */
+    _getDoc: function(element) {
+        element = element || {};
+        return (element[NODE_TYPE] === 9) ? element : element[OWNER_DOCUMENT] ||
+                                                Y.config.doc;
+    },
+
+    /**
+     * returns the appropriate window.
+     * @method _getWin
+     * @private
+     * @param {HTMLElement} element optional Target element.
+     * @return {Object} The window for the given element or the default window. 
+     */
+    _getWin: function(element) {
+        var doc = Y.DOM._getDoc(element);
+        return (element.document) ? element : doc[DEFAULT_VIEW] ||
+                                        doc[PARENT_WINDOW] || Y.config.win;
+    },
+
+    _childBy: function(element, tag, fn, rev) {
+        var ret = null,
+            root, axis;
+
+        if (element) {
+            if (rev) {
+                root = element[LAST_CHILD];
+                axis = PREVIOUS_SIBLING;
+            } else {
+                root = element[FIRST_CHILD];
+                axis = NEXT_SIBLING;
+            }
+
+            if (Y.DOM._testElement(root, tag, fn)) { // is the matching element
+                ret = root;
+            } else { // need to scan nextSibling axis of firstChild to find matching element
+                ret = Y.DOM.elementByAxis(root, axis, fn);
+            }
+        }
+        return ret;
+
+    },
+
+    _testElement: function(element, tag, fn) {
+        tag = (tag && tag !== '*') ? tag.toUpperCase() : null;
+        return (element && element[TAG_NAME] &&
+                (!tag || element[TAG_NAME].toUpperCase() === tag) &&
+                (!fn || fn(element)));
+    },
+
+    creators: {},
+
+    _IESimpleCreate: function(html, doc) {
+        doc = doc || Y.config.doc;
+        return doc.createElement(html);
+    }
+};
+
+
+(function() {
+    var creators = Y.DOM.creators,
+        create = Y.DOM.create,
+        re_tbody = /(?:\/(?:thead|tfoot|tbody|caption|col|colgroup)>)+\s*<tbody/;
+
+    var TABLE_OPEN = '<table>',
+        TABLE_CLOSE = '</table>';
+
+    if (Y.UA.gecko || Y.UA.ie) { // require custom creation code for certain element types
+        Y.mix(creators, {
+            option: function(html, doc) {
+                var frag = create('<select>' + html + '</select>');
+                return frag;
+            },
+
+            tr: function(html, doc) {
+                var frag = creators.tbody('<tbody>' + html + '</tbody>', doc);
+                return frag.firstChild;
+            },
+
+            td: function(html, doc) {
+                var frag = creators.tr('<tr>' + html + '</tr>', doc);
+                return frag.firstChild;
+            }, 
+
+            tbody: function(html, doc) {
+                var frag = create(TABLE_OPEN + html + TABLE_CLOSE, doc);
+                return frag;
+            },
+
+            legend: 'fieldset'
+        });
+
+        creators.col = creators.tbody; // IE wraps in colgroup
+    }
+
+    if (Y.UA.ie) {
+        // TODO: allow multiples ("<link><link>")
+        creators.col = creators.script = creators.link = Y.DOM._IESimpleCreate; 
+
+        // TODO: thead/tfoot with nested tbody
+        creators.tbody = function(html, doc) {
+            var frag = create(TABLE_OPEN + html + TABLE_CLOSE, doc);
+            var tb = frag.children.tags('tbody')[0];
+            if (frag.children.length > 1 && tb && !re_tbody.test(html)) {
+                tb.parentNode.removeChild(tb);
+            }
+            return frag;
+        };
+
+    }
+
+    if (Y.UA.gecko || Y.UA.ie) { // require custom creation code for certain element types
+        Y.mix(creators, {
+                th: creators.td,
+                thead: creators.tbody,
+                tfoot: creators.tbody,
+                caption: creators.tbody,
+                colgroup: creators.tbody,
+                col: creators.tbody,
+                optgroup: creators.option
+        });
+    }
+})();
+
+/** 
+ * The DOM utility provides a cross-browser abtraction layer
+ * normalizing DOM tasks, and adds extra helper functionality
+ * for other common tasks. 
+ * @module dom
+ * @submodule dom-base
+ * @for DOM
+ */
+
+var CLASS_NAME = 'className';
+
+Y.mix(Y.DOM, {
+    /**
+     * Determines whether a DOM element has the given className.
+     * @method hasClass
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to search for
+     * @return {Boolean} Whether or not the element has the given class. 
+     */
+    hasClass: function(node, className) {
+        var re = Y.DOM._getRegExp('(?:^|\\s+)' + className + '(?:\\s+|$)');
+        return re.test(node[CLASS_NAME]);
+    },
+
+    /**
+     * Adds a class name to a given DOM element.
+     * @method addClass         
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to add to the class attribute
+     */
+    addClass: function(node, className) {
+        if (!Y.DOM.hasClass(node, className)) { // skip if already present 
+            node[CLASS_NAME] = Y.Lang.trim([node[CLASS_NAME], className].join(' '));
+        }
+    },
+
+    /**
+     * Removes a class name from a given element.
+     * @method removeClass         
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to remove from the class attribute
+     */
+    removeClass: function(node, className) {
+        if (className && Y.DOM.hasClass(node, className)) {
+            node[CLASS_NAME] = Y.Lang.trim(node[CLASS_NAME].replace(Y.DOM._getRegExp('(?:^|\\s+)' +
+                            className + '(?:\\s+|$)'), ' '));
+
+            if ( Y.DOM.hasClass(node, className) ) { // in case of multiple adjacent
+                Y.DOM.removeClass(node, className);
+            }
+        }                 
+    },
+
+    /**
+     * Replace a class with another class for a given element.
+     * If no oldClassName is present, the newClassName is simply added.
+     * @method replaceClass  
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} oldClassName the class name to be replaced
+     * @param {String} newClassName the class name that will be replacing the old class name
+     */
+    replaceClass: function(node, oldC, newC) {
+        Y.DOM.addClass(node, newC);
+        Y.DOM.removeClass(node, oldC);
+    },
+
+    /**
+     * If the className exists on the node it is removed, if it doesn't exist it is added.
+     * @method toggleClass  
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to be toggled
+     */
+    toggleClass: function(node, className) {
+        if (Y.DOM.hasClass(node, className)) {
+            Y.DOM.removeClass(node, className);
+        } else {
+            Y.DOM.addClass(node, className);
+        }
+    }
+});
+
+
+
+
+}, '3.0.0pr2' ,{skinnable:false, requires:['event']});

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-debug.js'
--- loggerhead/static/javascript/yui/build/dom/dom-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,2166 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dom', function(Y) {
+
+/** 
+ * The DOM utility provides a cross-browser abtraction layer
+ * normalizing DOM tasks, and adds extra helper functionality
+ * for other common tasks. 
+ * @module dom
+ * @submodule dom-base
+ *
+ */
+
+/** 
+ * Provides DOM helper methods.
+ * @class DOM
+ *
+ */
+var NODE_TYPE = 'nodeType',
+    OWNER_DOCUMENT = 'ownerDocument',
+    DOCUMENT_ELEMENT = 'documentElement',
+    DEFAULT_VIEW = 'defaultView',
+    PARENT_WINDOW = 'parentWindow',
+    TAG_NAME = 'tagName',
+    PARENT_NODE = 'parentNode',
+    FIRST_CHILD = 'firstChild',
+    LAST_CHILD = 'lastChild',
+    PREVIOUS_SIBLING = 'previousSibling',
+    NEXT_SIBLING = 'nextSibling',
+    CONTAINS = 'contains',
+    COMPARE_DOCUMENT_POSITION = 'compareDocumentPosition',
+    INNER_TEXT = 'innerText',
+    TEXT_CONTENT = 'textContent',
+    LENGTH = 'length',
+
+    UNDEFINED = undefined;
+
+var re_tag = /<([a-z]+)/i;
+
+var templateCache = {};
+
+Y.DOM = {
+    /**
+     * Returns the HTMLElement with the given ID (Wrapper for document.getElementById).
+     * @method byId         
+     * @param {String} id the id attribute 
+     * @param {Object} doc optional The document to search. Defaults to current document 
+     * @return {HTMLElement | null} The HTMLElement with the id, or null if none found. 
+     */
+    byId: function(id, doc) {
+        return Y.DOM._getDoc(doc).getElementById(id);
+    },
+
+    /**
+     * Returns the text content of the HTMLElement. 
+     * @method getText         
+     * @param {HTMLElement} element The html element. 
+     * @return {String} The text content of the element (includes text of any descending elements).
+     */
+    getText: function(element) {
+        var text = element ? element[TEXT_CONTENT] : '';
+        if (text === UNDEFINED && INNER_TEXT in element) {
+            text = element[INNER_TEXT];
+        } 
+        return text || '';
+    },
+
+    /**
+     * Finds the firstChild of the given HTMLElement. 
+     * @method firstChild
+     * @param {HTMLElement} element The html element. 
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first found is returned.
+     * @return {HTMLElement | null} The first matching child html element.
+     */
+    firstChild: function(element, fn) {
+        return Y.DOM._childBy(element, null, fn);
+    },
+
+    firstChildByTag: function(element, tag, fn) {
+        return Y.DOM._childBy(element, tag, fn);
+    },
+
+    /**
+     * Finds the lastChild of the given HTMLElement.
+     * @method lastChild
+     * @param {HTMLElement} element The html element.
+     * @param {String} tag The tag to search for.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first found is returned.
+     * @return {HTMLElement | null} The first matching child html element.
+     */
+    lastChild: function(element, fn) {
+        return Y.DOM._childBy(element, null, fn, true);
+    },
+
+    lastChildByTag: function(element, tag, fn) {
+        return Y.DOM._childBy(element, tag, fn, true);
+    },
+
+    /**
+     * Finds all HTMLElement childNodes matching the given tag.
+     * @method childrenByTag
+     * @param {HTMLElement} element The html element.
+     * @param {String} tag The tag to search for.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all children with the given tag are collected.
+     * @return {Array} The collection of child elements.
+     */
+    childrenByTag: function() {
+        if (document[DOCUMENT_ELEMENT].children) {
+            return function(element, tag, fn, toArray) { // TODO: keep toArray option?
+                tag = (tag && tag !== '*') ? tag : null;
+                var elements = [];
+                if (element) {
+                    elements = (tag) ? element.children.tags(tag) : element.children; 
+
+                    if (fn || toArray) {
+                        elements = Y.DOM.filterElementsBy(elements, fn);
+                    }
+                }
+
+                return elements;
+            };
+        } else {
+            return function(element, tag, fn) {
+                tag = (tag && tag !== '*') ? tag.toUpperCase() : null;
+                var elements = [],
+                    wrapFn = fn;
+
+                if (element) {
+                    elements = element.childNodes; 
+                    if (tag) { // wrap fn and add tag test TODO: allow tag in filterElementsBy?
+                        wrapFn = function(el) {
+                            return el[TAG_NAME].toUpperCase() === tag && (!fn || fn(el));
+                        };
+                    }
+
+                    elements = Y.DOM.filterElementsBy(elements, wrapFn);
+                }
+                return elements;
+            };
+        }
+    }(),
+
+    /**
+     * Finds all HTMLElement childNodes.
+     * @method children
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all children are collected.
+     * @return {Array} The collection of child elements.
+     */
+    children: function(element, fn) {
+        return Y.DOM.childrenByTag(element, null, fn);
+    },
+
+    /**
+     * Finds the previous sibling of the element.
+     * @method previous
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the first sibling is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    previous: function(element, fn) {
+        return Y.DOM.elementByAxis(element, PREVIOUS_SIBLING, fn);
+    },
+
+    /**
+     * Finds the next sibling of the element.
+     * @method next
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the first sibling is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    next: function(element, fn) {
+        return Y.DOM.elementByAxis(element, NEXT_SIBLING, fn);
+    },
+
+    /**
+     * Finds the ancestor of the element.
+     * @method ancestor
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the parentNode is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    ancestor: function(element, fn) {
+        return Y.DOM.elementByAxis(element, PARENT_NODE, fn);
+    },
+
+    /**
+     * Searches the element by the given axis for the first matching element.
+     * @method elementByAxis
+     * @param {HTMLElement} element The html element.
+     * @param {String} axis The axis to search (parentNode, nextSibling, previousSibling).
+     * @param {Function} fn optional An optional boolean test to apply.
+     * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first element is returned.
+     * @return {HTMLElement | null} The matching element or null if none found.
+     */
+    elementByAxis: function(element, axis, fn, all) {
+        while (element && (element = element[axis])) { // NOTE: assignment
+                if ( (all || element[TAG_NAME]) && (!fn || fn(element)) ) {
+                    return element;
+                }
+        }
+        return null;
+    },
+
+    /**
+     * Finds all elements with the given tag.
+     * @method byTag
+     * @param {String} tag The tag being search for. 
+     * @param {HTMLElement} root optional An optional root element to start from.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all elements with the given tag are returned.
+     * @return {Array} The collection of matching elements.
+     */
+    byTag: function(tag, root, fn) {
+        root = root || Y.config.doc;
+
+        var elements = root.getElementsByTagName(tag),
+            retNodes = [];
+
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if ( !fn || fn(elements[i]) ) {
+                retNodes[retNodes[LENGTH]] = elements[i];
+            }
+        }
+        return retNodes;
+    },
+
+    /**
+     * Finds the first element with the given tag.
+     * @method firstByTag
+     * @param {String} tag The tag being search for. 
+     * @param {HTMLElement} root optional An optional root element to start from.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first match is returned. 
+     * @return {HTMLElement} The matching element.
+     */
+    firstByTag: function(tag, root, fn) {
+        root = root || Y.config.doc;
+
+        var elements = root.getElementsByTagName(tag),
+            ret = null;
+
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if ( !fn || fn(elements[i]) ) {
+                ret = elements[i];
+                break;
+            }
+        }
+        return ret;
+    },
+
+    /**
+     * Filters a collection of HTMLElements by the given attributes.
+     * @method filterElementsBy
+     * @param {Array} elements The collection of HTMLElements to filter.
+     * @param {Function} fn A boolean test to apply.
+     * The function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all HTMLElements are kept.
+     * @return {Array} The filtered collection of HTMLElements.
+     */
+    filterElementsBy: function(elements, fn, firstOnly) {
+        var ret = (firstOnly) ? null : [];
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if (elements[i][TAG_NAME] && (!fn || fn(elements[i]))) {
+                if (firstOnly) {
+                    ret = elements[i];
+                    break;
+                } else {
+                    ret[ret[LENGTH]] = elements[i];
+                }
+            }
+        }
+
+        return ret;
+    },
+
+    /**
+     * Determines whether or not one HTMLElement is or contains another HTMLElement.
+     * @method contains
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} needle The html element that may be contained.
+     * @return {Boolean} Whether or not the element is or contains the needle.
+     */
+    contains: function(element, needle) {
+        var ret = false;
+
+        if ( !needle || !element || !needle[NODE_TYPE] || !element[NODE_TYPE]) {
+            ret = false;
+        } else if (element[CONTAINS])  {
+            if (Y.UA.opera || needle[NODE_TYPE] === 1) { // IE & SAF contains fail if needle not an ELEMENT_NODE
+                ret = element[CONTAINS](needle);
+            } else {
+                ret = Y.DOM._bruteContains(element, needle); 
+            }
+        } else if (element[COMPARE_DOCUMENT_POSITION]) { // gecko
+            if (element === needle || !!(element[COMPARE_DOCUMENT_POSITION](needle) & 16)) { 
+                ret = true;
+            }
+        }
+
+        return ret;
+    },
+
+    /**
+     * Determines whether or not the HTMLElement is part of the document.
+     * @method inDoc
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} doc optional The document to check.
+     * @return {Boolean} Whether or not the element is attached to the document. 
+     */
+    inDoc: function(element, doc) {
+        doc = doc || Y.config.doc;
+        return Y.DOM.contains(doc.documentElement, element);
+    },
+
+    create: function(html, doc) {
+        doc = doc || Y.config.doc;
+        var m = re_tag.exec(html);
+        var create = Y.DOM._create,
+            custom = Y.DOM.creators,
+            tag, ret;
+
+        if (m && custom[m[1]]) {
+            if (typeof custom[m[1]] === 'function') {
+                create = custom[m[1]];
+            } else {
+                tag = custom[m[1]];
+            }
+        }
+        ret = create(html, doc, tag);
+        return (ret.childNodes.length > 1) ? ret.childNodes : ret.childNodes[0]; // collection or item
+        //return ret.firstChild;
+    },
+
+    _create: function(html, doc, tag) {
+        tag = tag || 'div';
+        var frag = templateCache[tag] || doc.createElement(tag);
+        frag.innerHTML = Y.Lang.trim(html);
+        return frag;
+    },
+
+    /**
+     * Brute force version of contains.
+     * Used for browsers without contains support for non-HTMLElement Nodes (textNodes, etc).
+     * @method _bruteContains
+     * @private
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} needle The html element that may be contained.
+     * @return {Boolean} Whether or not the element is or contains the needle.
+     */
+    _bruteContains: function(element, needle) {
+        while (needle) {
+            if (element === needle) {
+                return true;
+            }
+            needle = needle.parentNode;
+        }
+        return false;
+    },
+
+    /**
+     * Memoizes dynamic regular expressions to boost runtime performance. 
+     * @method _getRegExp
+     * @private
+     * @param {String} str The string to convert to a regular expression.
+     * @param {String} flags optional An optinal string of flags.
+     * @return {RegExp} An instance of RegExp
+     */
+    _getRegExp: function(str, flags) {
+        flags = flags || '';
+        Y.DOM._regexCache = Y.DOM._regexCache || {};
+        if (!Y.DOM._regexCache[str + flags]) {
+            Y.DOM._regexCache[str + flags] = new RegExp(str, flags);
+        }
+        return Y.DOM._regexCache[str + flags];
+    },
+
+    /**
+     * returns the appropriate document.
+     * @method _getDoc
+     * @private
+     * @param {HTMLElement} element optional Target element.
+     * @return {Object} The document for the given element or the default document. 
+     */
+    _getDoc: function(element) {
+        element = element || {};
+        return (element[NODE_TYPE] === 9) ? element : element[OWNER_DOCUMENT] ||
+                                                Y.config.doc;
+    },
+
+    /**
+     * returns the appropriate window.
+     * @method _getWin
+     * @private
+     * @param {HTMLElement} element optional Target element.
+     * @return {Object} The window for the given element or the default window. 
+     */
+    _getWin: function(element) {
+        var doc = Y.DOM._getDoc(element);
+        return (element.document) ? element : doc[DEFAULT_VIEW] ||
+                                        doc[PARENT_WINDOW] || Y.config.win;
+    },
+
+    _childBy: function(element, tag, fn, rev) {
+        var ret = null,
+            root, axis;
+
+        if (element) {
+            if (rev) {
+                root = element[LAST_CHILD];
+                axis = PREVIOUS_SIBLING;
+            } else {
+                root = element[FIRST_CHILD];
+                axis = NEXT_SIBLING;
+            }
+
+            if (Y.DOM._testElement(root, tag, fn)) { // is the matching element
+                ret = root;
+            } else { // need to scan nextSibling axis of firstChild to find matching element
+                ret = Y.DOM.elementByAxis(root, axis, fn);
+            }
+        }
+        return ret;
+
+    },
+
+    _testElement: function(element, tag, fn) {
+        tag = (tag && tag !== '*') ? tag.toUpperCase() : null;
+        return (element && element[TAG_NAME] &&
+                (!tag || element[TAG_NAME].toUpperCase() === tag) &&
+                (!fn || fn(element)));
+    },
+
+    creators: {},
+
+    _IESimpleCreate: function(html, doc) {
+        doc = doc || Y.config.doc;
+        return doc.createElement(html);
+    }
+};
+
+
+(function() {
+    var creators = Y.DOM.creators,
+        create = Y.DOM.create,
+        re_tbody = /(?:\/(?:thead|tfoot|tbody|caption|col|colgroup)>)+\s*<tbody/;
+
+    var TABLE_OPEN = '<table>',
+        TABLE_CLOSE = '</table>';
+
+    if (Y.UA.gecko || Y.UA.ie) { // require custom creation code for certain element types
+        Y.mix(creators, {
+            option: function(html, doc) {
+                var frag = create('<select>' + html + '</select>');
+                return frag;
+            },
+
+            tr: function(html, doc) {
+                var frag = creators.tbody('<tbody>' + html + '</tbody>', doc);
+                return frag.firstChild;
+            },
+
+            td: function(html, doc) {
+                var frag = creators.tr('<tr>' + html + '</tr>', doc);
+                return frag.firstChild;
+            }, 
+
+            tbody: function(html, doc) {
+                var frag = create(TABLE_OPEN + html + TABLE_CLOSE, doc);
+                return frag;
+            },
+
+            legend: 'fieldset'
+        });
+
+        creators.col = creators.tbody; // IE wraps in colgroup
+    }
+
+    if (Y.UA.ie) {
+        // TODO: allow multiples ("<link><link>")
+        creators.col = creators.script = creators.link = Y.DOM._IESimpleCreate; 
+
+        // TODO: thead/tfoot with nested tbody
+        creators.tbody = function(html, doc) {
+            var frag = create(TABLE_OPEN + html + TABLE_CLOSE, doc);
+            var tb = frag.children.tags('tbody')[0];
+            if (frag.children.length > 1 && tb && !re_tbody.test(html)) {
+                tb.parentNode.removeChild(tb);
+            }
+            return frag;
+        };
+
+    }
+
+    if (Y.UA.gecko || Y.UA.ie) { // require custom creation code for certain element types
+        Y.mix(creators, {
+                th: creators.td,
+                thead: creators.tbody,
+                tfoot: creators.tbody,
+                caption: creators.tbody,
+                colgroup: creators.tbody,
+                col: creators.tbody,
+                optgroup: creators.option
+        });
+    }
+})();
+
+/** 
+ * The DOM utility provides a cross-browser abtraction layer
+ * normalizing DOM tasks, and adds extra helper functionality
+ * for other common tasks. 
+ * @module dom
+ * @submodule dom-base
+ * @for DOM
+ */
+
+var CLASS_NAME = 'className';
+
+Y.mix(Y.DOM, {
+    /**
+     * Determines whether a DOM element has the given className.
+     * @method hasClass
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to search for
+     * @return {Boolean} Whether or not the element has the given class. 
+     */
+    hasClass: function(node, className) {
+        var re = Y.DOM._getRegExp('(?:^|\\s+)' + className + '(?:\\s+|$)');
+        return re.test(node[CLASS_NAME]);
+    },
+
+    /**
+     * Adds a class name to a given DOM element.
+     * @method addClass         
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to add to the class attribute
+     */
+    addClass: function(node, className) {
+        if (!Y.DOM.hasClass(node, className)) { // skip if already present 
+            node[CLASS_NAME] = Y.Lang.trim([node[CLASS_NAME], className].join(' '));
+        }
+    },
+
+    /**
+     * Removes a class name from a given element.
+     * @method removeClass         
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to remove from the class attribute
+     */
+    removeClass: function(node, className) {
+        if (className && Y.DOM.hasClass(node, className)) {
+            node[CLASS_NAME] = Y.Lang.trim(node[CLASS_NAME].replace(Y.DOM._getRegExp('(?:^|\\s+)' +
+                            className + '(?:\\s+|$)'), ' '));
+
+            if ( Y.DOM.hasClass(node, className) ) { // in case of multiple adjacent
+                Y.DOM.removeClass(node, className);
+            }
+        }                 
+    },
+
+    /**
+     * Replace a class with another class for a given element.
+     * If no oldClassName is present, the newClassName is simply added.
+     * @method replaceClass  
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} oldClassName the class name to be replaced
+     * @param {String} newClassName the class name that will be replacing the old class name
+     */
+    replaceClass: function(node, oldC, newC) {
+        //Y.log('replaceClass replacing ' + oldC + ' with ' + newC, 'info', 'Node');
+        Y.DOM.addClass(node, newC);
+        Y.DOM.removeClass(node, oldC);
+    },
+
+    /**
+     * If the className exists on the node it is removed, if it doesn't exist it is added.
+     * @method toggleClass  
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to be toggled
+     */
+    toggleClass: function(node, className) {
+        if (Y.DOM.hasClass(node, className)) {
+            Y.DOM.removeClass(node, className);
+        } else {
+            Y.DOM.addClass(node, className);
+        }
+    }
+});
+
+
+/** 
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var DOCUMENT_ELEMENT = 'documentElement',
+    DEFAULT_VIEW = 'defaultView',
+    OWNER_DOCUMENT = 'ownerDocument',
+    STYLE = 'style',
+    FLOAT = 'float',
+    CSS_FLOAT = 'cssFloat',
+    STYLE_FLOAT = 'styleFloat',
+    TRANSPARENT = 'transparent',
+    VISIBLE = 'visible',
+    WIDTH = 'width',
+    HEIGHT = 'height',
+    BORDER_TOP_WIDTH = 'borderTopWidth',
+    BORDER_RIGHT_WIDTH = 'borderRightWidth',
+    BORDER_BOTTOM_WIDTH = 'borderBottomWidth',
+    BORDER_LEFT_WIDTH = 'borderLeftWidth',
+    GET_COMPUTED_STYLE = 'getComputedStyle',
+
+    DOCUMENT = Y.config.doc,
+    UNDEFINED = undefined,
+
+    re_color = /color$/i;
+
+
+Y.mix(Y.DOM, {
+    CUSTOM_STYLES: {},
+
+
+    /**
+     * Sets a style property for a given element.
+     * @method setStyle
+     * @param {HTMLElement} An HTMLElement to apply the style to.
+     * @param {String} att The style property to set. 
+     * @param {String|Number} val The value. 
+     */
+    setStyle: function(node, att, val, style) {
+        style = node[STYLE],
+            CUSTOM_STYLES = Y.DOM.CUSTOM_STYLES;
+
+        if (style) {
+            if (att in CUSTOM_STYLES) {
+                if (CUSTOM_STYLES[att].set) {
+                    CUSTOM_STYLES[att].set(node, val, style);
+                    return; // NOTE: return
+                } else if (typeof CUSTOM_STYLES[att] === 'string') {
+                    att = CUSTOM_STYLES[att];
+                }
+            }
+            style[att] = val; 
+        }
+    },
+
+    /**
+     * Returns the current style value for the given property.
+     * @method getStyle
+     * @param {HTMLElement} An HTMLElement to get the style from.
+     * @param {String} att The style property to get. 
+     */
+    getStyle: function(node, att) {
+        var style = node[STYLE],
+            CUSTOM_STYLES = Y.DOM.CUSTOM_STYLES,
+            val = '';
+
+        if (style) {
+            if (att in CUSTOM_STYLES) {
+                if (CUSTOM_STYLES[att].get) {
+                    return CUSTOM_STYLES[att].get(node, att, style); // NOTE: return
+                } else if (typeof CUSTOM_STYLES[att] === 'string') {
+                    att = CUSTOM_STYLES[att];
+                }
+            }
+            val = style[att];
+            if (val === '') { // TODO: is empty string sufficient?
+                val = Y.DOM[GET_COMPUTED_STYLE](node, att);
+            }
+        }
+
+        return val;
+    },
+
+    /**
+     * Sets multiple style properties.
+     * @method setStyles
+     * @param {HTMLElement} node An HTMLElement to apply the styles to. 
+     * @param {Object} hash An object literal of property:value pairs. 
+     */
+    'setStyles': function(node, hash) {
+        Y.each(hash, function(v, n) {
+            Y.DOM.setStyle(node, n, v);
+        }, Y.DOM);
+    },
+
+    /**
+     * Returns the computed style for the given node.
+     * @method getComputedStyle
+     * @param {HTMLElement} An HTMLElement to get the style from.
+     * @param {String} att The style property to get. 
+     * @return {String} The computed value of the style property. 
+     */
+    getComputedStyle: function(node, att) {
+        var val = '',
+            doc = node[OWNER_DOCUMENT];
+
+        if (node[STYLE]) {
+            val = doc[DEFAULT_VIEW][GET_COMPUTED_STYLE](node, '')[att];
+        }
+        return val;
+    }
+});
+
+if (DOCUMENT[DOCUMENT_ELEMENT][STYLE][CSS_FLOAT] !== UNDEFINED) {
+    Y.DOM.CUSTOM_STYLES[FLOAT] = CSS_FLOAT;
+} else if (DOCUMENT[DOCUMENT_ELEMENT][STYLE][STYLE_FLOAT] !== UNDEFINED) {
+    Y.DOM.CUSTOM_STYLES[FLOAT] = STYLE_FLOAT;
+}
+
+if (Y.UA.opera) { // opera defaults to hex instead of RGB
+    Y.DOM[GET_COMPUTED_STYLE] = function(node, att) {
+        var view = node[OWNER_DOCUMENT][DEFAULT_VIEW],
+            val = view[GET_COMPUTED_STYLE](node, '')[att];
+
+        if (re_color.test(att)) {
+            val = Y.Color.toRGB(val);
+        }
+
+        return val;
+    };
+
+}
+
+if (Y.UA.webkit) { // safari converts transparent to rgba()
+    Y.DOM[GET_COMPUTED_STYLE] = function(node, att) {
+        var view = node[OWNER_DOCUMENT][DEFAULT_VIEW],
+            val = view[GET_COMPUTED_STYLE](node, '')[att];
+
+        if (val === 'rgba(0, 0, 0, 0)') {
+            val = TRANSPARENT; 
+        }
+
+        return val;
+    };
+
+}
+
+
+
+/**
+ * Adds position and region management functionality to DOM.
+ * @module dom
+ * @submodule dom-screen
+ * @for DOM
+ */
+
+var OFFSET_TOP = 'offsetTop',
+
+    DOCUMENT_ELEMENT = 'documentElement',
+    COMPAT_MODE = 'compatMode',
+    OFFSET_LEFT = 'offsetLeft',
+    OFFSET_PARENT = 'offsetParent',
+    POSITION = 'position',
+    FIXED = 'fixed',
+    RELATIVE = 'relative',
+    LEFT = 'left',
+    TOP = 'top',
+    SCROLL_LEFT = 'scrollLeft',
+    SCROLL_TOP = 'scrollTop',
+    _BACK_COMPAT = 'BackCompat',
+    MEDIUM = 'medium',
+    HEIGHT = 'height',
+    WIDTH = 'width',
+    BORDER_LEFT_WIDTH = 'borderLeftWidth',
+    BORDER_TOP_WIDTH = 'borderTopWidth',
+    GET_BOUNDING_CLIENT_RECT = 'getBoundingClientRect',
+    GET_COMPUTED_STYLE = 'getComputedStyle',
+    RE_TABLE = /^t(?:able|d|h)$/i;
+
+Y.mix(Y.DOM, {
+
+
+    /**
+     * Returns the inner height of the viewport (exludes scrollbar). 
+     * @method winHeight
+
+     */
+    winHeight: function(node) {
+        var h = Y.DOM._getWinSize(node)[HEIGHT];
+        Y.log('winHeight returning ' + h, 'info', 'DOM');
+        return h;
+    },
+
+    /**
+     * Returns the inner width of the viewport (exludes scrollbar). 
+     * @method winWidth
+
+     */
+    winWidth: function(node) {
+        var w = Y.DOM._getWinSize(node)[WIDTH];
+        Y.log('winWidth returning ' + w, 'info', 'DOM');
+        return w;
+    },
+
+    /**
+     * Document height 
+     * @method docHeight
+
+     */
+    docHeight:  function(node) {
+        var h = Y.DOM._getDocSize(node)[HEIGHT];
+        Y.log('docHeight returning ' + h, 'info', 'DOM');
+        return Math.max(h, Y.DOM._getWinSize(node)[HEIGHT]);
+    },
+
+    /**
+     * Document width 
+     * @method docWidth
+
+     */
+    docWidth:  function(node) {
+        var w = Y.DOM._getDocSize(node)[WIDTH];
+        Y.log('docWidth returning ' + w, 'info', 'DOM');
+        return Math.max(w, Y.DOM._getWinSize(node)[WIDTH]);
+    },
+
+    /**
+     * Amount page has been scroll vertically 
+     * @method docScrollX
+
+     */
+    docScrollX: function(node) {
+        var doc = Y.DOM._getDoc();
+        return Math.max(doc[DOCUMENT_ELEMENT][SCROLL_LEFT], doc.body[SCROLL_LEFT]);
+    },
+
+    /**
+     * Amount page has been scroll horizontally 
+     * @method docScrollY
+
+     */
+    docScrollY:  function(node) {
+        var doc = Y.DOM._getDoc();
+        return Math.max(doc[DOCUMENT_ELEMENT][SCROLL_TOP], doc.body[SCROLL_TOP]);
+    },
+
+    /**
+     * Gets the current position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getXY
+     * @param element The target element
+     * @return {Array} The XY position of the element
+
+     TODO: test inDocument/display
+     */
+    getXY: function() {
+
+
+
+
+        if (document[DOCUMENT_ELEMENT][GET_BOUNDING_CLIENT_RECT]) {
+            return function(node) {
+                if (!node) {
+                    return false;
+                }
+                var scrollLeft = Y.DOM.docScrollX(node),
+                    scrollTop = Y.DOM.docScrollY(node),
+                    box = node[GET_BOUNDING_CLIENT_RECT](),
+                    doc = Y.DOM._getDoc(node),
+                    //Round the numbers so we get sane data back
+                    xy = [Math.floor(box[LEFT]), Math.floor(box[TOP])];
+
+                    if (Y.UA.ie) {
+                        var off1 = 2, off2 = 2,
+                        mode = doc[COMPAT_MODE],
+                        bLeft = Y.DOM[GET_COMPUTED_STYLE](doc[DOCUMENT_ELEMENT], BORDER_LEFT_WIDTH),
+                        bTop = Y.DOM[GET_COMPUTED_STYLE](doc[DOCUMENT_ELEMENT], BORDER_TOP_WIDTH);
+
+                        if (Y.UA.ie === 6) {
+                            if (mode !== _BACK_COMPAT) {
+                                off1 = 0;
+                                off2 = 0;
+                            }
+                        }
+                        
+                        if ((mode == _BACK_COMPAT)) {
+                            if (bLeft !== MEDIUM) {
+                                off1 = parseInt(bLeft, 10);
+                            }
+                            if (bTop !== MEDIUM) {
+                                off2 = parseInt(bTop, 10);
+                            }
+
+
+
+                        }
+                        
+                        xy[0] -= off1;
+                        xy[1] -= off2;
+
+                    }
+
+                if ((scrollTop || scrollLeft)) {
+                    xy[0] += scrollLeft;
+                    xy[1] += scrollTop;
+                }
+
+                // gecko may return sub-pixel (non-int) values
+                xy[0] = Math.floor(xy[0]);
+                xy[1] = Math.floor(xy[1]);
+
+                return xy;                   
+            };
+        } else {
+            return function(node) { // manually calculate by crawling up offsetParents
+                //Calculate the Top and Left border sizes (assumes pixels)
+                var xy = [node[OFFSET_LEFT], node[OFFSET_TOP]],
+                    parentNode = node,
+                    bCheck = ((Y.UA.gecko || (Y.UA.webkit > 519)) ? true : false);
+
+                while ((parentNode = parentNode[OFFSET_PARENT])) {
+                    xy[0] += parentNode[OFFSET_LEFT];
+                    xy[1] += parentNode[OFFSET_TOP];
+                    if (bCheck) {
+                        xy = Y.DOM._calcBorders(parentNode, xy);
+                    }
+                }
+
+                // account for any scrolled ancestors
+                if (Y.DOM.getStyle(node, POSITION) != FIXED) {
+                    parentNode = node;
+                    var scrollTop, scrollLeft;
+
+                    while ((parentNode = parentNode.parentNode)) {
+                        scrollTop = parentNode[SCROLL_TOP];
+                        scrollLeft = parentNode[SCROLL_LEFT];
+
+                        //Firefox does something funky with borders when overflow is not visible.
+                        if (Y.UA.gecko && (Y.DOM.getStyle(parentNode, 'overflow') !== 'visible')) {
+                                xy = Y.DOM._calcBorders(parentNode, xy);
+                        }
+                        
+
+                        if (scrollTop || scrollLeft) {
+                            xy[0] -= scrollLeft;
+                            xy[1] -= scrollTop;
+                        }
+                    }
+                    xy[0] += Y.DOM.docScrollX(node);
+                    xy[1] += Y.DOM.docScrollY(node);
+
+                } else {
+                    //Fix FIXED position -- add scrollbars
+                    if (Y.UA.opera) {
+                        xy[0] -= Y.DOM.docScrollX(node);
+                        xy[1] -= Y.DOM.docScrollY(node);
+                    } else if (Y.UA.webkit || Y.UA.gecko) {
+                        xy[0] += Y.DOM.docScrollX(node);
+                        xy[1] += Y.DOM.docScrollY(node);
+                    }
+                }
+                //Round the numbers so we get sane data back
+                xy[0] = Math.floor(xy[0]);
+                xy[1] = Math.floor(xy[1]);
+
+                return xy;                
+            };
+        }
+    }(),// NOTE: Executing for loadtime branching
+
+    /**
+     * Gets the current X position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getX
+     * @param element The target element
+     * @return {Int} The X position of the element
+     */
+
+    getX: function(node) {
+        return Y.DOM.getXY(node)[0];
+    },
+
+    /**
+     * Gets the current Y position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getY
+     * @param element The target element
+     * @return {Int} The Y position of the element
+     */
+
+    getY: function(node) {
+        return Y.DOM.getXY(node)[1];
+    },
+
+    /**
+     * Set the position of an html element in page coordinates.
+     * The element must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setXY
+     * @param element The target element
+     * @param {Array} xy Contains X & Y values for new position (coordinates are page-based)
+     * @param {Boolean} noRetry By default we try and set the position a second time if the first fails
+     */
+    setXY: function(node, xy, noRetry) {
+        var pos = Y.DOM.getStyle(node, POSITION),
+            setStyle = Y.DOM.setStyle,
+
+            delta = [ // assuming pixels; if not we will have to retry
+                parseInt( Y.DOM[GET_COMPUTED_STYLE](node, LEFT), 10 ),
+                parseInt( Y.DOM[GET_COMPUTED_STYLE](node, TOP), 10 )
+            ];
+    
+        if (pos == 'static') { // default to relative
+            pos = RELATIVE;
+            setStyle(node, POSITION, pos);
+        }
+
+        var currentXY = Y.DOM.getXY(node);
+
+
+
+
+        if (currentXY === false) { // has to be part of doc to have xy
+
+
+
+
+
+            Y.log('xy failed: node not available', 'error', 'Node');
+            return false; 
+        }
+        
+        if ( isNaN(delta[0]) ) {// in case of 'auto'
+            delta[0] = (pos == RELATIVE) ? 0 : node[OFFSET_LEFT];
+        } 
+        if ( isNaN(delta[1]) ) { // in case of 'auto'
+            delta[1] = (pos == RELATIVE) ? 0 : node[OFFSET_TOP];
+        } 
+
+        if (xy[0] !== null) {
+            setStyle(node, LEFT, xy[0] - currentXY[0] + delta[0] + 'px');
+        }
+
+        if (xy[1] !== null) {
+            setStyle(node, TOP, xy[1] - currentXY[1] + delta[1] + 'px');
+        }
+      
+        if (!noRetry) {
+            var newXY = Y.DOM.getXY(node);
+
+            // if retry is true, try one more time if we miss 
+           if ( (xy[0] !== null && newXY[0] != xy[0]) || 
+                (xy[1] !== null && newXY[1] != xy[1]) ) {
+               Y.DOM.setXY(node, xy, true);
+           }
+        }        
+
+        Y.log('setXY setting position to ' + xy, 'info', 'Node');
+    },
+
+    /**
+     * Set the X position of an html element in page coordinates, regardless of how the element is positioned.
+     * The element(s) must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setX
+     * @param element The target element
+     * @param {Int} x The X values for new position (coordinates are page-based)
+     */
+    setX: function(node, x) {
+        return Y.DOM.setXY(node, [x, null]);
+    },
+
+    /**
+     * Set the Y position of an html element in page coordinates, regardless of how the element is positioned.
+     * The element(s) must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setY
+     * @param element The target element
+     * @param {Int} y The Y values for new position (coordinates are page-based)
+     */
+    setY: function(node, y) {
+        return Y.DOM.setXY(node, [null, y]);
+    },
+
+    _calcBorders: function(node, xy2) {
+        var t = parseInt(Y.DOM[GET_COMPUTED_STYLE](node, BORDER_TOP_WIDTH), 10) || 0,
+            l = parseInt(Y.DOM[GET_COMPUTED_STYLE](node, BORDER_LEFT_WIDTH), 10) || 0;
+        if (Y.UA.gecko) {
+            if (RE_TABLE.test(node.tagName)) {
+                t = 0;
+                l = 0;
+            }
+        }
+        xy2[0] += l;
+        xy2[1] += t;
+        return xy2;
+    },
+
+    _getWinSize: function(node) {
+        var doc = Y.DOM._getDoc(),
+            win = doc.defaultView || doc.parentWindow,
+            mode = doc[COMPAT_MODE],
+            h = win.innerHeight,
+            w = win.innerWidth,
+            root = doc[DOCUMENT_ELEMENT];
+
+        if ( mode && !Y.UA.opera ) { // IE, Gecko
+            if (mode != 'CSS1Compat') { // Quirks
+                root = doc.body; 
+            }
+            h = root.clientHeight;
+            w = root.clientWidth;
+        }
+        return { height: h, width: w }; 
+    },
+
+    _getDocSize: function(node) {
+        var doc = Y.DOM._getDoc(),
+            root = doc[DOCUMENT_ELEMENT];
+
+        if (doc[COMPAT_MODE] != 'CSS1Compat') {
+            root = doc.body;
+        }
+
+        return { height: root.scrollHeight, width: root.scrollWidth };
+    }
+});
+
+
+
+/**
+ * Adds position and region management functionality to DOM.
+ * @module dom
+ * @submodule dom-screen
+ * @for DOM
+ */
+
+var OFFSET_WIDTH = 'offsetWidth',
+    OFFSET_HEIGHT = 'offsetHeight',
+    TOP = 'top',
+    RIGHT = 'right',
+    BOTTOM = 'bottom',
+    LEFT = 'left',
+    TAG_NAME = 'tagName';
+
+var getOffsets = function(r1, r2) {
+    var t = Math.max(r1[TOP], r2[TOP]),
+        r = Math.min(r1[RIGHT], r2[RIGHT]),
+        b = Math.min(r1[BOTTOM], r2[BOTTOM]),
+        l = Math.max(r1[LEFT], r2[LEFT]),
+        ret = {};
+    
+    ret[TOP] = t;
+    ret[RIGHT] = r;
+    ret[BOTTOM] = b;
+    ret[LEFT] = l;
+    return ret;
+};
+
+var DOM = DOM || Y.DOM;
+Y.mix(DOM, {
+    /**
+     * Returns an Object literal containing the following about this element: (top, right, bottom, left)
+     * @method region
+     * @param {HTMLElement} element The DOM element. 
+     @return {Object} Object literal containing the following about this element: (top, right, bottom, left)
+     */
+    region: function(node) {
+        var x = DOM.getXY(node),
+            ret = false;
+        
+        if (x) {
+            ret = {
+                '0': x[0],
+                '1': x[1],
+                top: x[1],
+                right: x[0] + node[OFFSET_WIDTH],
+                bottom: x[1] + node[OFFSET_HEIGHT],
+                left: x[0],
+                height: node[OFFSET_HEIGHT],
+                width: node[OFFSET_WIDTH]
+            };
+        }
+
+        return ret;
+    },
+
+    /**
+     * Find the intersect information for the passes nodes.
+     * @method intersect
+     * @param {HTMLElement} element The first element 
+     * @param {HTMLElement | Object} element2 The element or region to check the interect with
+     * @param {Object} altRegion An object literal containing the region for the first element if we already have the data (for performance i.e. DragDrop)
+     @return {Object} Object literal containing the following intersection data: (top, right, bottom, left, area, yoff, xoff, inRegion)
+     */
+    intersect: function(node, node2, altRegion) {
+        var r = altRegion || DOM.region(node), region = {};
+
+        var n = node2;
+        if (n[TAG_NAME]) {
+            region = DOM.region(n);
+        } else if (Y.Lang.isObject(node2)) {
+            region = node2;
+        } else {
+            return false;
+        }
+        
+        var off = getOffsets(region, r);
+        return {
+            top: off[TOP],
+            right: off[RIGHT],
+            bottom: off[BOTTOM],
+            left: off[LEFT],
+            area: ((off[BOTTOM] - off[TOP]) * (off[RIGHT] - off[LEFT])),
+            yoff: ((off[BOTTOM] - off[TOP])),
+            xoff: (off[RIGHT] - off[LEFT]),
+            inRegion: DOM.inRegion(node, node2, false, altRegion)
+        };
+        
+    },
+    /**
+     * Check if any part of this node is in the passed region
+     * @method inRegion
+     * @param {Object} node2 The node to get the region from or an Object literal of the region
+     * $param {Boolean} all Should all of the node be inside the region
+     * @param {Object} altRegion An object literal containing the region for this node if we already have the data (for performance i.e. DragDrop)
+     * @return {Boolean} True if in region, false if not.
+     */
+    inRegion: function(node, node2, all, altRegion) {
+        var region = {},
+            r = altRegion || DOM.region(node);
+
+        var n = node2;
+        if (n[TAG_NAME]) {
+            region = DOM.region(n);
+        } else if (Y.Lang.isObject(node2)) {
+            region = node2;
+        } else {
+            return false;
+        }
+            
+        if (all) {
+            return (
+                r[LEFT]   >= region[LEFT]   &&
+                r[RIGHT]  <= region[RIGHT]  && 
+                r[TOP]    >= region[TOP]    && 
+                r[BOTTOM] <= region[BOTTOM]  );
+        } else {
+            var off = getOffsets(region, r);
+            if (off[BOTTOM] >= off[TOP] && off[RIGHT] >= off[LEFT]) {
+                return true;
+            } else {
+                return false;
+            }
+            
+        }
+    },
+
+    /**
+     * Check if any part of this element is in the viewport
+     * @method inViewportRegion
+     * @param {HTMLElement} element The DOM element. 
+     * @param {Boolean} all Should all of the node be inside the region
+     * @param {Object} altRegion An object literal containing the region for this node if we already have the data (for performance i.e. DragDrop)
+     * @return {Boolean} True if in region, false if not.
+     */
+    inViewportRegion: function(node, all, altRegion) {
+        return DOM.inRegion(node, DOM.viewportRegion(node), all, altRegion);
+            
+    },
+
+    /**
+     * Returns an Object literal containing the following about the visible region of viewport: (top, right, bottom, left)
+     * @method viewportRegion
+     @return {Object} Object literal containing the following about the visible region of the viewport: (top, right, bottom, left)
+     */
+    viewportRegion: function(node) {
+        node = node || Y.config.doc.documentElement;
+        var r = {};
+        r[TOP] = DOM.docScrollY(node);
+        r[RIGHT] = DOM.winWidth(node) + DOM.docScrollX(node);
+        r[BOTTOM] = (DOM.docScrollY(node) + DOM.winHeight(node));
+        r[LEFT] = DOM.docScrollX(node);
+
+        return r;
+    }
+});
+
+/**
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var CLIENT_TOP = 'clientTop',
+    CLIENT_LEFT = 'clientLeft',
+    PARENT_NODE = 'parentNode',
+    RIGHT = 'right',
+    HAS_LAYOUT = 'hasLayout',
+    PX = 'px',
+    FILTER = 'filter',
+    FILTERS = 'filters',
+    OPACITY = 'opacity',
+    AUTO = 'auto',
+    CURRENT_STYLE = 'currentStyle';
+
+// use alpha filter for IE opacity
+if (document[DOCUMENT_ELEMENT][STYLE][OPACITY] === UNDEFINED &&
+        document[DOCUMENT_ELEMENT][FILTERS]) {
+    Y.DOM.CUSTOM_STYLES[OPACITY] = {
+        get: function(node) {
+            var val = 100;
+            try { // will error if no DXImageTransform
+                val = node[FILTERS]['DXImageTransform.Microsoft.Alpha'][OPACITY];
+
+            } catch(e) {
+                try { // make sure its in the document
+                    val = node[FILTERS]('alpha')[OPACITY];
+                } catch(err) {
+                    Y.log('getStyle: IE opacity filter not found; returning 1', 'warn', 'DOM');
+                }
+            }
+            return val / 100;
+        },
+
+        set: function(node, val, style) {
+            if (typeof style[FILTER] == 'string') { // in case not appended
+                style[FILTER] = 'alpha(' + OPACITY + '=' + val * 100 + ')';
+                
+                if (!node[CURRENT_STYLE] || !node[CURRENT_STYLE][HAS_LAYOUT]) {
+                    style.zoom = 1; // needs layout 
+                }
+            }
+        }
+    };
+}
+
+// IE getComputedStyle
+// TODO: unit-less lineHeight (e.g. 1.22)
+var re_size = /^width|height$/,
+    re_unit = /^(\d[.\d]*)+(em|ex|px|gd|rem|vw|vh|vm|ch|mm|cm|in|pt|pc|deg|rad|ms|s|hz|khz|%){1}?/i;
+
+var ComputedStyle = {
+    CUSTOM_STYLES: {},
+
+    get: function(el, property) {
+        var value = '',
+            current = el[CURRENT_STYLE][property];
+
+        if (property === OPACITY) {
+            value = Y.DOM.CUSTOM_STYLES[OPACITY].get(el);        
+        } else if (!current || (current.indexOf && current.indexOf(PX) > -1)) { // no need to convert
+            value = current;
+        } else if (Y.DOM.IE.COMPUTED[property]) { // use compute function
+            value = Y.DOM.IE.COMPUTED[property](el, property);
+        } else if (re_unit.test(current)) { // convert to pixel
+            value = Y.DOM.IE.ComputedStyle.getPixel(el, property);
+        } else {
+            value = current;
+        }
+
+        return value;
+    },
+
+    getOffset: function(el, prop) {
+        var current = el[CURRENT_STYLE][prop],                        // value of "width", "top", etc.
+            capped = prop.charAt(0).toUpperCase() + prop.substr(1), // "Width", "Top", etc.
+            offset = 'offset' + capped,                             // "offsetWidth", "offsetTop", etc.
+            pixel = 'pixel' + capped,                               // "pixelWidth", "pixelTop", etc.
+            value = '';
+
+        if (current == AUTO) {
+            var actual = el[offset]; // offsetHeight/Top etc.
+            if (actual === UNDEFINED) { // likely "right" or "bottom"
+                value = 0;
+            }
+
+            value = actual;
+            if (re_size.test(prop)) { // account for box model diff 
+                el[STYLE][prop] = actual; 
+                if (el[offset] > actual) {
+                    // the difference is padding + border (works in Standards & Quirks modes)
+                    value = actual - (el[offset] - actual);
+                }
+                el[STYLE][prop] = AUTO; // revert to auto
+            }
+        } else { // convert units to px
+            if (!el[STYLE][pixel] && !el[STYLE][prop]) { // need to map style.width to currentStyle (no currentStyle.pixelWidth)
+                el[STYLE][prop] = current;              // no style.pixelWidth if no style.width
+            }
+            value = el[STYLE][pixel];
+        }
+        return value + PX;
+    },
+
+    getBorderWidth: function(el, property) {
+        // clientHeight/Width = paddingBox (e.g. offsetWidth - borderWidth)
+        // clientTop/Left = borderWidth
+        var value = null;
+        if (!el[CURRENT_STYLE][HAS_LAYOUT]) { // TODO: unset layout?
+            el[STYLE].zoom = 1; // need layout to measure client
+        }
+
+        switch(property) {
+            case BORDER_TOP_WIDTH:
+                value = el[CLIENT_TOP];
+                break;
+            case BORDER_BOTTOM_WIDTH:
+                value = el.offsetHeight - el.clientHeight - el[CLIENT_TOP];
+                break;
+            case BORDER_LEFT_WIDTH:
+                value = el[CLIENT_LEFT];
+                break;
+            case BORDER_RIGHT_WIDTH:
+                value = el.offsetWidth - el.clientWidth - el[CLIENT_LEFT];
+                break;
+        }
+        return value + PX;
+    },
+
+    getPixel: function(node, att) {
+        // use pixelRight to convert to px
+        var val = null,
+            styleRight = node[CURRENT_STYLE][RIGHT],
+            current = node[CURRENT_STYLE][att];
+
+        node[STYLE][RIGHT] = current;
+        val = node[STYLE].pixelRight;
+        node[STYLE][RIGHT] = styleRight; // revert
+
+        return val + PX;
+    },
+
+    getMargin: function(node, att) {
+        var val;
+        if (node[CURRENT_STYLE][att] == AUTO) {
+            val = 0 + PX;
+        } else {
+            val = Y.DOM.IE.ComputedStyle.getPixel(node, att);
+        }
+        return val;
+    },
+
+    getVisibility: function(node, att) {
+        var current;
+        while ( (current = node[CURRENT_STYLE]) && current[att] == 'inherit') { // NOTE: assignment in test
+            node = node[PARENT_NODE];
+        }
+        return (current) ? current[att] : VISIBLE;
+    },
+
+    getColor: function(node, att) {
+        var current = node[CURRENT_STYLE][att];
+
+        if (!current || current === TRANSPARENT) {
+            Y.DOM.elementByAxis(node, PARENT_NODE, null, function(parent) {
+                current = parent[CURRENT_STYLE][att];
+                if (current && current !== TRANSPARENT) {
+                    node = parent;
+                    return true;
+                }
+            });
+        }
+
+        return Y.Color.toRGB(current);
+    },
+
+    getBorderColor: function(node, att) {
+        var current = node[CURRENT_STYLE];
+        var val = current[att] || current.color;
+        return Y.Color.toRGB(Y.Color.toHex(val));
+    }
+
+};
+
+//fontSize: getPixelFont,
+var IEComputed = {};
+
+IEComputed[WIDTH] = IEComputed[HEIGHT] = ComputedStyle.getOffset;
+
+IEComputed.color = IEComputed.backgroundColor = ComputedStyle.getColor;
+
+IEComputed[BORDER_TOP_WIDTH] = IEComputed[BORDER_RIGHT_WIDTH] =
+        IEComputed[BORDER_BOTTOM_WIDTH] = IEComputed[BORDER_LEFT_WIDTH] =
+        ComputedStyle.getBorderWidth;
+
+IEComputed.marginTop = IEComputed.marginRight = IEComputed.marginBottom =
+        IEComputed.marginLeft = ComputedStyle.getMargin;
+
+IEComputed.visibility = ComputedStyle.getVisibility;
+IEComputed.borderColor = IEComputed.borderTopColor =
+        IEComputed.borderRightColor = IEComputed.borderBottomColor =
+        IEComputed.borderLeftColor = ComputedStyle.getBorderColor;
+
+if (!Y.config.win[GET_COMPUTED_STYLE]) {
+    Y.DOM[GET_COMPUTED_STYLE] = ComputedStyle.get; 
+}
+
+Y.namespace('DOM.IE');
+Y.DOM.IE.COMPUTED = IEComputed;
+Y.DOM.IE.ComputedStyle = ComputedStyle;
+
+
+/**
+ * Provides helper methods for collecting and filtering DOM elements.
+ * @module dom
+ * @submodule selector
+ */
+
+/**
+ * Provides helper methods for collecting and filtering DOM elements.
+ * @class Selector
+ * @static
+ */
+
+var TAG = 'tag',
+    PARENT_NODE = 'parentNode',
+    PREVIOUS_SIBLING = 'previousSibling',
+    LENGTH = 'length',
+    NODE_TYPE = 'nodeType',
+    TAG_NAME = 'tagName',
+    ATTRIBUTES = 'attributes',
+    PSEUDOS = 'pseudos',
+    COMBINATOR = 'combinator';
+
+var reNth = /^(?:([\-]?\d*)(n){1}|(odd|even)$)*([\-+]?\d*)$/;
+
+var patterns = {
+    tag: /^((?:-?[_a-z]+[\w\-]*)|\*)/i,
+    attributes: /^\[([a-z]+\w*)+([~\|\^\$\*!=]=?)?['"]?([^\]]*?)['"]?\]/i,
+    pseudos: /^:([\-\w]+)(?:\(['"]?(.+)['"]?\))*/i,
+    combinator: /^\s*([>+~]|\s)\s*/
+};
+
+var Selector = {
+    /**
+     * Default document for use queries 
+     * @property document
+     * @type object
+     * @default window.document
+     */
+    document: Y.config.doc,
+    /**
+     * Mapping of attributes to aliases, normally to work around HTMLAttributes
+     * that conflict with JS reserved words.
+     * @property attrAliases
+     * @type object
+     */
+    attrAliases: {},
+
+    /**
+     * Mapping of shorthand tokens to corresponding attribute selector 
+     * @property shorthand
+     * @type object
+     */
+    shorthand: {
+        '\\#(-?[_a-z]+[-\\w]*)': '[id=$1]',
+        '\\.(-?[_a-z]+[-\\w]*)': '[class~=$1]'
+    },
+
+    /**
+     * List of operators and corresponding boolean functions. 
+     * These functions are passed the attribute and the current node's value of the attribute.
+     * @property operators
+     * @type object
+     */
+    operators: {
+        '=': function(attr, val) { return attr === val; }, // Equality
+        '!=': function(attr, val) { return attr !== val; }, // Inequality
+        '~=': function(attr, val) { // Match one of space seperated words 
+            var s = ' ';
+            return (s + attr + s).indexOf((s + val + s)) > -1;
+        },
+        '|=': function(attr, val) { return Y.DOM._getRegExp('^' + val + '[-]?').test(attr); }, // Match start with value followed by optional hyphen
+        '^=': function(attr, val) { return attr.indexOf(val) === 0; }, // Match starts with value
+        '$=': function(attr, val) { return attr.lastIndexOf(val) === attr[LENGTH] - val[LENGTH]; }, // Match ends with value
+        '*=': function(attr, val) { return attr.indexOf(val) > -1; }, // Match contains value as substring 
+        '': function(attr, val) { return attr; } // Just test for existence of attribute
+    },
+
+    /**
+     * List of pseudo-classes and corresponding boolean functions. 
+     * These functions are called with the current node, and any value that was parsed with the pseudo regex.
+     * @property pseudos
+     * @type object
+     */
+    pseudos: {
+        'root': function(node) {
+            return node === node.ownerDocument.documentElement;
+        },
+
+        'nth-child': function(node, val) {
+            return Selector.getNth(node, val);
+        },
+
+        'nth-last-child': function(node, val) {
+            return Selector.getNth(node, val, null, true);
+        },
+
+        'nth-of-type': function(node, val) {
+            return Selector.getNth(node, val, node[TAG_NAME]);
+        },
+         
+        'nth-last-of-type': function(node, val) {
+            return Selector.getNth(node, val, node[TAG_NAME], true);
+        },
+         
+        'first-child': function(node) {
+            return Y.DOM.firstChild(node[PARENT_NODE]) === node;
+        },
+
+        'last-child': function(node) {
+            return Y.DOM.lastChild(node[PARENT_NODE]) === node;
+        },
+
+        'first-of-type': function(node, val) {
+            return Y.DOM.firstChildByTag(node[PARENT_NODE], node[TAG_NAME]) === node;
+        },
+         
+        'last-of-type': function(node, val) {
+            return Y.DOM.lastChildByTag(node[PARENT_NODE], node[TAG_NAME]) === node;
+        },
+         
+        'only-child': function(node) {
+            var children = Y.DOM.children(node[PARENT_NODE]);
+            return children[LENGTH] === 1 && children[0] === node;
+        },
+
+        'only-of-type': function(node) {
+            return Y.DOM.childrenByTag(node[PARENT_NODE], node[TAG_NAME])[LENGTH] === 1;
+        },
+
+        'empty': function(node) {
+            return node.childNodes[LENGTH] === 0;
+        },
+
+        'not': function(node, simple) {
+            return !Selector.test(node, simple);
+        },
+
+        'contains': function(node, str) {
+            var text = node.innerText || node.textContent || '';
+            return text.indexOf(str) > -1;
+        },
+        'checked': function(node) {
+            return node.checked === true;
+        }
+    },
+
+    /**
+     * Test if the supplied node matches the supplied selector.
+     * @method test
+     *
+     * @param {HTMLElement | String} node An id or node reference to the HTMLElement being tested.
+     * @param {string} selector The CSS Selector to test the node against.
+     * @return{boolean} Whether or not the node matches the selector.
+     * @static
+    
+     */
+    test: function(node, selector) {
+        if (!node) {
+            return false;
+        }
+
+        var groups = selector ? selector.split(',') : [];
+        if (groups[LENGTH]) {
+            for (var i = 0, len = groups[LENGTH]; i < len; ++i) {
+                if ( Selector._testNode(node, groups[i]) ) { // passes if ANY group matches
+                    return true;
+                }
+            }
+            return false;
+        }
+        return Selector._testNode(node, selector);
+    },
+
+    /**
+     * Filters a set of nodes based on a given CSS selector. 
+     * @method filter
+     *
+     * @param {array} nodes A set of nodes/ids to filter. 
+     * @param {string} selector The selector used to test each node.
+     * @return{array} An array of nodes from the supplied array that match the given selector.
+     * @static
+     */
+    filter: function(nodes, selector) {
+        nodes = nodes || [];
+
+        var result = Selector._filter(nodes, Selector._tokenize(selector)[0]);
+        Y.log('filter: returning:' + result[LENGTH], 'info', 'Selector');
+        return result;
+    },
+
+    /**
+     * Retrieves a set of nodes based on a given CSS selector. 
+     * @method query
+     *
+     * @param {string} selector The CSS Selector to test the node against.
+     * @param {HTMLElement | String} root optional An id or HTMLElement to start the query from. Defaults to Selector.document.
+     * @param {Boolean} firstOnly optional Whether or not to return only the first match.
+     * @return {Array} An array of nodes that match the given selector.
+     * @static
+     */
+    query: function(selector, root, firstOnly) {
+        var result = Selector._query(selector, root, firstOnly);
+        //Y.log('query: ' + selector + ' returning ' + result, 'info', 'Selector');
+        return result;
+    },
+
+    _query: function(selector, root, firstOnly, deDupe) {
+        var result =  (firstOnly) ? null : [];
+        if (!selector) {
+            return result;
+        }
+
+        root = root || Selector.document;
+        var groups = selector.split(','); // TODO: handle comma in attribute/pseudo
+
+        if (groups[LENGTH] > 1) {
+            var found;
+            for (var i = 0, len = groups[LENGTH]; i < len; ++i) {
+                found = arguments.callee(groups[i], root, firstOnly, true);
+                result = firstOnly ? found : result.concat(found); 
+            }
+            Selector._clearFoundCache();
+            return result;
+        }
+
+        var tokens = Selector._tokenize(selector);
+        var idToken = tokens[Selector._getIdTokenIndex(tokens)],
+            nodes = [],
+            node,
+            id,
+            token = tokens.pop() || {};
+            
+        if (idToken) {
+            id = Selector._getId(idToken[ATTRIBUTES]);
+        }
+
+        // use id shortcut when possible
+        if (id) {
+            node = Selector.document.getElementById(id);
+
+            if (node && (root[NODE_TYPE] === 9 || Y.DOM.contains(root, node))) {
+                if ( Selector._testNode(node, null, idToken) ) {
+                    if (idToken === token) {
+                        nodes = [node]; // simple selector
+                    } else {
+                        root = node; // start from here
+                    }
+                }
+            } else {
+                return result;
+            }
+        }
+
+        if (root && !nodes[LENGTH]) {
+            nodes = root.getElementsByTagName(token[TAG]);
+        }
+
+        if (nodes[LENGTH]) {
+            result = Selector._filter(nodes, token, firstOnly, deDupe); 
+        }
+        return result;
+    },
+
+    _filter: function(nodes, token, firstOnly, deDupe) {
+        var result = firstOnly ? null : [];
+
+        result = Y.DOM.filterElementsBy(nodes, function(node) {
+            if (! Selector._testNode(node, '', token, deDupe)) {
+                return false;
+            }
+
+            if (deDupe) {
+                if (node._found) {
+                    return false;
+                }
+                node._found = true;
+                Selector._foundCache[Selector._foundCache[LENGTH]] = node;
+            }
+            return true;
+        }, firstOnly);
+
+        return result;
+    },
+
+    _testNode: function(node, selector, token, deDupe) {
+        token = token || Selector._tokenize(selector).pop() || {};
+        var ops = Selector.operators,
+            pseudos = Selector.pseudos,
+            prev = token.previous,
+            i, len;
+
+        if (!node[TAG_NAME] ||
+            (token[TAG] !== '*' && node[TAG_NAME].toUpperCase() !== token[TAG]) ||
+            (deDupe && node._found) ) {
+            return false;
+        }
+
+        if (token[ATTRIBUTES][LENGTH]) {
+            var attribute;
+            for (i = 0, len = token[ATTRIBUTES][LENGTH]; i < len; ++i) {
+                attribute = node.getAttribute(token[ATTRIBUTES][i][0], 2);
+                if (attribute === undefined) {
+                    return false;
+                }
+                if ( ops[token[ATTRIBUTES][i][1]] &&
+                        !ops[token[ATTRIBUTES][i][1]](attribute, token[ATTRIBUTES][i][2])) {
+                    return false;
+                }
+            }
+        }
+
+        if (token[PSEUDOS][LENGTH]) {
+            for (i = 0, len = token[PSEUDOS][LENGTH]; i < len; ++i) {
+                if (pseudos[token[PSEUDOS][i][0]] &&
+                        !pseudos[token[PSEUDOS][i][0]](node, token[PSEUDOS][i][1])) {
+                    return false;
+                }
+            }
+        }
+        return (prev && prev[COMBINATOR] !== ',') ?
+                Selector.combinators[prev[COMBINATOR]](node, token) :
+                true;
+    },
+
+
+    _foundCache: [],
+    _regexCache: {},
+
+    _clearFoundCache: function() {
+        Y.log('getBySelector: clearing found cache of ' + Selector._foundCache[LENGTH] + ' elements');
+        for (var i = 0, len = Selector._foundCache[LENGTH]; i < len; ++i) {
+            try { // IE no like delete
+                delete Selector._foundCache[i]._found;
+            } catch(e) {
+                Selector._foundCache[i].removeAttribute('_found');
+            }
+        }
+        Selector._foundCache = [];
+        Y.log('getBySelector: done clearing Selector._foundCache');
+    },
+
+    combinators: {
+        ' ': function(node, token) {
+            while ((node = node[PARENT_NODE])) {
+                if (Selector._testNode(node, '', token.previous)) {
+                    return true;
+                }
+            }  
+            return false;
+        },
+
+        '>': function(node, token) {
+            return Selector._testNode(node[PARENT_NODE], null, token.previous);
+        },
+        '+': function(node, token) {
+            var sib = node[PREVIOUS_SIBLING];
+            while (sib && sib[NODE_TYPE] !== 1) {
+                sib = sib[PREVIOUS_SIBLING];
+            }
+
+            if (sib && Selector._testNode(sib, null, token.previous)) {
+                return true; 
+            }
+            return false;
+        },
+
+        '~': function(node, token) {
+            var sib = node[PREVIOUS_SIBLING];
+            while (sib) {
+                if (sib[NODE_TYPE] === 1 && Selector._testNode(sib, null, token.previous)) {
+                    return true;
+                }
+                sib = sib[PREVIOUS_SIBLING];
+            }
+
+            return false;
+        }
+    },
+
+
+    /*
+        an+b = get every _a_th node starting at the _b_th
+        0n+b = no repeat ("0" and "n" may both be omitted (together) , e.g. "0n+1" or "1", not "0+1"), return only the _b_th element
+        1n+b =  get every element starting from b ("1" may may be omitted, e.g. "1n+0" or "n+0" or "n")
+        an+0 = get every _a_th element, "0" may be omitted 
+    */
+    getNth: function(node, expr, tag, reverse) {
+        reNth.test(expr);
+
+        var a = parseInt(RegExp.$1, 10), // include every _a_ elements (zero means no repeat, just first _a_)
+            n = RegExp.$2, // "n"
+            oddeven = RegExp.$3, // "odd" or "even"
+            b = parseInt(RegExp.$4, 10) || 0, // start scan from element _b_
+            op, i, len, siblings;
+
+        if (tag) {
+            siblings = Y.DOM.childrenByTag(node[PARENT_NODE], tag);
+        } else {
+            siblings = Y.DOM.children(node[PARENT_NODE]);
+        }
+
+        if (oddeven) {
+            a = 2; // always every other
+            op = '+';
+            n = 'n';
+            b = (oddeven === 'odd') ? 1 : 0;
+        } else if ( isNaN(a) ) {
+            a = (n) ? 1 : 0; // start from the first or no repeat
+        }
+
+        if (a === 0) { // just the first
+            if (reverse) {
+                b = siblings[LENGTH] - b + 1; 
+            }
+
+            if (siblings[b - 1] === node) {
+                return true;
+            } else {
+                return false;
+            }
+
+        } else if (a < 0) {
+            reverse = !!reverse;
+            a = Math.abs(a);
+        }
+
+        if (!reverse) {
+            for (i = b - 1, len = siblings[LENGTH]; i < len; i += a) {
+                if ( i >= 0 && siblings[i] === node ) {
+                    return true;
+                }
+            }
+        } else {
+            for (i = siblings[LENGTH] - b, len = siblings[LENGTH]; i >= 0; i -= a) {
+                if ( i < len && siblings[i] === node ) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    },
+
+    _getId: function(attr) {
+        for (var i = 0, len = attr[LENGTH]; i < len; ++i) {
+            if (attr[i][0] == 'id' && attr[i][1] === '=') {
+                return attr[i][2];
+            }
+        }
+    },
+
+    _getIdTokenIndex: function(tokens) {
+        for (var i = 0, len = tokens[LENGTH]; i < len; ++i) {
+            if (Selector._getId(tokens[i][ATTRIBUTES])) {
+                return i;
+            }
+        }
+        return -1;
+    },
+
+    /**
+        Break selector into token units per simple selector.
+        Combinator is attached to left-hand selector.
+     */
+    _tokenize: function(selector) {
+        var token = {},     // one token per simple selector (left selector holds combinator)
+            tokens = [],    // array of tokens
+            found = false,  // whether or not any matches were found this pass
+            match;          // the regex match
+
+        selector = Selector._replaceShorthand(selector); // convert ID and CLASS shortcuts to attributes
+
+        /*
+            Search for selector patterns, store, and strip them from the selector string
+            until no patterns match (invalid selector) or we run out of chars.
+
+            Multiple attributes and pseudos are allowed, in any order.
+            for example:
+                'form:first-child[type=button]:not(button)[lang|=en]'
+        */
+        do {
+            found = false; // reset after full pass
+            for (var re in patterns) {
+                if (patterns.hasOwnProperty(re)) {
+                    if (re != TAG && re != COMBINATOR) { // only one allowed
+                        token[re] = token[re] || [];
+                    }
+                    if ((match = patterns[re].exec(selector))) { // note assignment
+                        found = true;
+                        if (re != TAG && re != COMBINATOR) { // only one allowed
+                            //token[re] = token[re] || [];
+
+                            // capture ID for fast path to element
+                            if (re === ATTRIBUTES && match[1] === 'id') {
+                                token.id = match[3];
+                            }
+
+                            token[re].push(match.slice(1));
+                        } else { // single selector (tag, combinator)
+                            token[re] = match[1];
+                        }
+                        selector = selector.replace(match[0], ''); // strip current match from selector
+                        if (re === COMBINATOR || !selector[LENGTH]) { // next token or done
+                            token[ATTRIBUTES] = Selector._fixAttributes(token[ATTRIBUTES]);
+                            token[PSEUDOS] = token[PSEUDOS] || [];
+                            token[TAG] = token[TAG] ? token[TAG].toUpperCase() : '*';
+                            tokens.push(token);
+
+                            token = { // prep next token
+                                previous: token
+                            };
+                        }
+                    }
+                }
+            }
+        } while (found);
+
+        return tokens;
+    },
+
+    _fixAttributes: function(attr) {
+        var aliases = Selector.attrAliases;
+        attr = attr || [];
+        for (var i = 0, len = attr[LENGTH]; i < len; ++i) {
+            if (aliases[attr[i][0]]) { // convert reserved words, etc
+                attr[i][0] = aliases[attr[i][0]];
+            }
+            if (!attr[i][1]) { // use exists operator
+                attr[i][1] = '';
+            }
+        }
+        return attr;
+    },
+
+    _replaceShorthand: function(selector) {
+        var shorthand = Selector.shorthand;
+        var attrs = selector.match(patterns[ATTRIBUTES]); // pull attributes to avoid false pos on "." and "#"
+        if (attrs) {
+            selector = selector.replace(patterns[ATTRIBUTES], 'REPLACED_ATTRIBUTE');
+        }
+        for (var re in shorthand) {
+            if (shorthand.hasOwnProperty(re)) {
+                selector = selector.replace(Y.DOM._getRegExp(re, 'gi'), shorthand[re]);
+            }
+        }
+
+        if (attrs) {
+            for (var i = 0, len = attrs[LENGTH]; i < len; ++i) {
+                selector = selector.replace('REPLACED_ATTRIBUTE', attrs[i]);
+            }
+        }
+        return selector;
+    }
+
+};
+
+if (Y.UA.ie && Y.UA.ie < 8) { // rewrite class for IE (others use getAttribute('class')
+    Selector.attrAliases['class'] = 'className';
+    Selector.attrAliases['for'] = 'htmlFor';
+}
+
+Y.Selector = Selector;
+Y.Selector.patterns = patterns;
+
+
+/**
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var TO_STRING = 'toString',
+    PARSE_INT = parseInt,
+    RE = RegExp;
+
+Y.Color = {
+    KEYWORDS: {
+        black: '000',
+        silver: 'c0c0c0',
+        gray: '808080',
+        white: 'fff',
+        maroon: '800000',
+        red: 'f00',
+        purple: '800080',
+        fuchsia: 'f0f',
+        green: '008000',
+        lime: '0f0',
+        olive: '808000',
+        yellow: 'ff0',
+        navy: '000080',
+        blue: '00f',
+        teal: '008080',
+        aqua: '0ff'
+    },
+
+    re_RGB: /^rgb\(([0-9]+)\s*,\s*([0-9]+)\s*,\s*([0-9]+)\)$/i,
+    re_hex: /^#?([0-9A-F]{2})([0-9A-F]{2})([0-9A-F]{2})$/i,
+    re_hex3: /([0-9A-F])/gi,
+
+    toRGB: function(val) {
+        if (!Y.Color.re_RGB.test(val)) {
+            val = Y.Color.toHex(val);
+        }
+
+        if(Y.Color.re_hex.exec(val)) {
+            val = 'rgb(' + [
+                PARSE_INT(RE.$1, 16),
+                PARSE_INT(RE.$2, 16),
+                PARSE_INT(RE.$3, 16)
+            ].join(', ') + ')';
+        }
+        return val;
+    },
+
+    toHex: function(val) {
+        val = Y.Color.KEYWORDS[val] || val;
+        if (Y.Color.re_RGB.exec(val)) {
+            var r = (RE.$1.length === 1) ? '0' + RE.$1 : Number(RE.$1),
+                g = (RE.$2.length === 1) ? '0' + RE.$2 : Number(RE.$2),
+                b = (RE.$3.length === 1) ? '0' + RE.$3 : Number(RE.$3);
+
+            val = [
+                r[TO_STRING](16),
+                g[TO_STRING](16),
+                b[TO_STRING](16)
+            ].join('');
+        }
+
+        if (val.length < 6) {
+            val = val.replace(Y.Color.re_hex3, '$1$1');
+        }
+
+        if (val !== 'transparent' && val.indexOf('#') < 0) {
+            val = '#' + val;
+        }
+
+        return val.toLowerCase();
+    }
+};
+
+
+
+
+}, '3.0.0pr2' ,{skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-min.js'
--- loggerhead/static/javascript/yui/build/dom/dom-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,10 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dom",function(q){var N="nodeType",AB="ownerDocument",R="documentElement",z="defaultView",AH="parentWindow",AU="tagName",C="parentNode",m="firstChild",o="lastChild",v="previousSibling",AZ="nextSibling",AK="contains",AJ="compareDocumentPosition",l="innerText",K="textContent",w="length",x=undefined;var W=/<([a-z]+)/i;var AL={};q.DOM={byId:function(Ad,Y){return q.DOM._getDoc(Y).getElementById(Ad);},getText:function(Y){var Ad=Y?Y[K]:"";if(Ad===x&&l in Y){Ad=Y[l];}return Ad||"";},firstChild:function(Y,Ad){return q.DOM._childBy(Y,null,Ad);},firstChildByTag:function(Ad,Y,Ae){return q.DOM._childBy(Ad,Y,Ae);},lastChild:function(Y,Ad){return q.DOM._childBy(Y,null,Ad,true);},lastChildByTag:function(Ad,Y,Ae){return q.DOM._childBy(Ad,Y,Ae,true);},childrenByTag:function(){if(document[R].children){return function(Ae,Y,Af,Ad){Y=(Y&&Y!=="*")?Y:null;var Ag=[];if(Ae){Ag=(Y)?Ae.children.tags(Y):Ae.children;if(Af||Ad){Ag=q.DOM.filterElementsBy(Ag,Af);}}return Ag;};}else{return function(Ae,Ad,Af){Ad=(Ad&&Ad!=="*")?Ad.toUpperCase():null;var Ag=[],Y=Af;if(Ae){Ag=Ae.childNodes;if(Ad){Y=function(Ah){return Ah[AU].toUpperCase()===Ad&&(!Af||Af(Ah));};}Ag=q.DOM.filterElementsBy(Ag,Y);}return Ag;};}}(),children:function(Y,Ad){return q.DOM.childrenByTag(Y,null,Ad);},previous:function(Y,Ad){return q.DOM.elementByAxis(Y,v,Ad);},next:function(Y,Ad){return q.DOM.elementByAxis(Y,AZ,Ad);},ancestor:function(Y,Ad){return q.DOM.elementByAxis(Y,C,Ad);},elementByAxis:function(Y,Af,Ae,Ad){while(Y&&(Y=Y[Af])){if((Ad||Y[AU])&&(!Ae||Ae(Y))){return Y;}}return null;},byTag:function(Ad,Ae,Ah){Ae=Ae||q.config.doc;var Ai=Ae.getElementsByTagName(Ad),Ag=[];for(var Af=0,Y=Ai[w];Af<Y;++Af){if(!Ah||Ah(Ai[Af])){Ag[Ag[w]]=Ai[Af];}}return Ag;},firstByTag:function(Ad,Ae,Ah){Ae=Ae||q.config.doc;var Ai=Ae.getElementsByTagName(Ad),Af=null;for(var Ag=0,Y=Ai[w];Ag<Y;++Ag){if(!Ah||Ah(Ai[Ag])){Af=Ai[Ag];break;}}return Af;},filterElementsBy:function(Ah,Ag,Af){var Ad=(Af)?null:[];for(var Ae=0,Y=Ah[w];Ae<Y;++Ae){if(Ah[Ae][AU]&&(!Ag||Ag(Ah[Ae]))){if(Af){Ad=Ah[Ae];break;}else{Ad[Ad[w]]=Ah[Ae];}}}return Ad;},contains:function(Ad,Ae){var Y=false;if(!Ae||!Ad||!Ae[N]||!Ad[N]){Y=false;}else{if(Ad[AK]){if(q.UA.opera||Ae[N]===1){Y=Ad[AK](Ae);}else{Y=q.DOM._bruteContains(Ad,Ae);}}else{if(Ad[AJ]){if(Ad===Ae||!!(Ad[AJ](Ae)&16)){Y=true;}}}}return Y;},inDoc:function(Y,Ad){Ad=Ad||q.config.doc;return q.DOM.contains(Ad.documentElement,Y);},create:function(Ag,Ai){Ai=Ai||q.config.doc;var Ad=W.exec(Ag);var Af=q.DOM._create,Ah=q.DOM.creators,Y,Ae;if(Ad&&Ah[Ad[1]]){if(typeof Ah[Ad[1]]==="function"){Af=Ah[Ad[1]];}else{Y=Ah[Ad[1]];}}Ae=Af(Ag,Ai,Y);return(Ae.childNodes.length>1)?Ae.childNodes:Ae.childNodes[0];},_create:function(Ad,Ae,Y){Y=Y||"div";var Af=AL[Y]||Ae.createElement(Y);Af.innerHTML=q.Lang.trim(Ad);return Af;},_bruteContains:function(Y,Ad){while(Ad){if(Y===Ad){return true;}Ad=Ad.parentNode;}return false;},_getRegExp:function(Ad,Y){Y=Y||"";q.DOM._regexCache=q.DOM._regexCache||{};if(!q.DOM._regexCache[Ad+Y]){q.DOM._regexCache[Ad+Y]=new RegExp(Ad,Y);}return q.DOM._regexCache[Ad+Y];},_getDoc:function(Y){Y=Y||{};return(Y[N]===9)?Y:Y[AB]||q.config.doc;},_getWin:function(Y){var Ad=q.DOM._getDoc(Y);return(Y.document)?Y:Ad[z]||Ad[AH]||q.config.win;},_childBy:function(Ag,Y,Ai,Ae){var Af=null,Ad,Ah;if(Ag){if(Ae){Ad=Ag[o];Ah=v;}else{Ad=Ag[m];Ah=AZ;}if(q.DOM._testElement(Ad,Y,Ai)){Af=Ad;}else{Af=q.DOM.elementByAxis(Ad,Ah,Ai);}}return Af;},_testElement:function(Ad,Y,Ae){Y=(Y&&Y!=="*")?Y.toUpperCase():null;return(Ad&&Ad[AU]&&(!Y||Ad[AU].toUpperCase()===Y)&&(!Ae||Ae(Ad)));},creators:{},_IESimpleCreate:function(Y,Ad){Ad=Ad||q.config.doc;return Ad.createElement(Y);}};(function(){var Ag=q.DOM.creators,Y=q.DOM.create,Af=/(?:\/(?:thead|tfoot|tbody|caption|col|colgroup)>)+\s*<tbody/;var Ae="<table>",Ad="</table>";if(q.UA.gecko||q.UA.ie){q.mix(Ag,{option:function(Ah,Ai){var Aj=Y("<select>"+Ah+"</select>");return Aj;},tr:function(Ah,Ai){var Aj=Ag.tbody("<tbody>"+Ah+"</tbody>",Ai);return Aj.firstChild;},td:function(Ah,Ai){var Aj=Ag.tr("<tr>"+Ah+"</tr>",Ai);return Aj.firstChild;},tbody:function(Ah,Ai){var Aj=Y(Ae+Ah+Ad,Ai);return Aj;},legend:"fieldset"});Ag.col=Ag.tbody;}if(q.UA.ie){Ag.col=Ag.script=Ag.link=q.DOM._IESimpleCreate;Ag.tbody=function(Ai,Aj){var Ak=Y(Ae+Ai+Ad,Aj);var Ah=Ak.children.tags("tbody")[0];if(Ak.children.length>1&&Ah&&!Af.test(Ai)){Ah.parentNode.removeChild(Ah);}return Ak;};}if(q.UA.gecko||q.UA.ie){q.mix(Ag,{th:Ag.td,thead:Ag.tbody,tfoot:Ag.tbody,caption:Ag.tbody,colgroup:Ag.tbody,col:Ag.tbody,optgroup:Ag.option});}})();var AI="className";q.mix(q.DOM,{hasClass:function(Ae,Ad){var Y=q.DOM._getRegExp("(?:^|\\s+)"+Ad+"(?:\\s+|$)");return Y.test(Ae[AI]);},addClass:function(Ad,Y){if(!q.DOM.hasClass(Ad,Y)){Ad[AI]=q.Lang.trim([Ad[AI],Y].join(" "));}},removeClass:function(Ad,Y){if(Y&&q.DOM.hasClass(Ad,Y)){Ad[AI]=q.Lang.trim(Ad[AI].replace(q.DOM._getRegExp("(?:^|\\s+)"+Y+"(?:\\s+|$)")," "));if(q.DOM.hasClass(Ad,Y)){q.DOM.removeClass(Ad,Y);}}},replaceClass:function(Ad,Y,Ae){q.DOM.addClass(Ad,Ae);q.DOM.removeClass(Ad,Y);},toggleClass:function(Ad,Y){if(q.DOM.hasClass(Ad,Y)){q.DOM.removeClass(Ad,Y);}else{q.DOM.addClass(Ad,Y);}}});var R="documentElement",z="defaultView",AB="ownerDocument",E="style",X="float",n="cssFloat",L="styleFloat",AD="transparent",t="visible",c="width",AP="height",U="borderTopWidth",S="borderRightWidth",B="borderBottomWidth",f="borderLeftWidth",AG="getComputedStyle",AT=q.config.doc,x=undefined,P=/color$/i;q.mix(q.DOM,{CUSTOM_STYLES:{},setStyle:function(Ae,Y,Af,Ad){Ad=Ae[E],CUSTOM_STYLES=q.DOM.CUSTOM_STYLES;if(Ad){if(Y in CUSTOM_STYLES){if(CUSTOM_STYLES[Y].set){CUSTOM_STYLES[Y].set(Ae,Af,Ad);return ;}else{if(typeof CUSTOM_STYLES[Y]==="string"){Y=CUSTOM_STYLES[Y];}}}Ad[Y]=Af;}},getStyle:function(Af,Y){var Ae=Af[E],Ad=q.DOM.CUSTOM_STYLES,Ag="";if(Ae){if(Y in Ad){if(Ad[Y].get){return Ad[Y].get(Af,Y,Ae);}else{if(typeof Ad[Y]==="string"){Y=Ad[Y];}}}Ag=Ae[Y];if(Ag===""){Ag=q.DOM[AG](Af,Y);}}return Ag;},"setStyles":function(Y,Ad){q.each(Ad,function(Ae,Af){q.DOM.setStyle(Y,Af,Ae);
+},q.DOM);},getComputedStyle:function(Ad,Y){var Af="",Ae=Ad[AB];if(Ad[E]){Af=Ae[z][AG](Ad,"")[Y];}return Af;}});if(AT[R][E][n]!==x){q.DOM.CUSTOM_STYLES[X]=n;}else{if(AT[R][E][L]!==x){q.DOM.CUSTOM_STYLES[X]=L;}}if(q.UA.opera){q.DOM[AG]=function(Ae,Ad){var Y=Ae[AB][z],Af=Y[AG](Ae,"")[Ad];if(P.test(Ad)){Af=q.Color.toRGB(Af);}return Af;};}if(q.UA.webkit){q.DOM[AG]=function(Ae,Ad){var Y=Ae[AB][z],Af=Y[AG](Ae,"")[Ad];if(Af==="rgba(0, 0, 0, 0)"){Af=AD;}return Af;};}var D="offsetTop",R="documentElement",i="compatMode",AF="offsetLeft",AE="offsetParent",J="position",e="fixed",I="relative",A="left",H="top",Ac="scrollLeft",u="scrollTop",AC="BackCompat",Q="medium",AP="height",c="width",f="borderLeftWidth",U="borderTopWidth",V="getBoundingClientRect",AG="getComputedStyle",AS=/^t(?:able|d|h)$/i;q.mix(q.DOM,{winHeight:function(Ad){var Y=q.DOM._getWinSize(Ad)[AP];return Y;},winWidth:function(Ad){var Y=q.DOM._getWinSize(Ad)[c];return Y;},docHeight:function(Ad){var Y=q.DOM._getDocSize(Ad)[AP];return Math.max(Y,q.DOM._getWinSize(Ad)[AP]);},docWidth:function(Ad){var Y=q.DOM._getDocSize(Ad)[c];return Math.max(Y,q.DOM._getWinSize(Ad)[c]);},docScrollX:function(Y){var Ad=q.DOM._getDoc();return Math.max(Ad[R][Ac],Ad.body[Ac]);},docScrollY:function(Y){var Ad=q.DOM._getDoc();return Math.max(Ad[R][u],Ad.body[u]);},getXY:function(){if(document[R][V]){return function(Af){if(!Af){return false;}var Ag=q.DOM.docScrollX(Af),Ad=q.DOM.docScrollY(Af),Ah=Af[V](),Al=q.DOM._getDoc(Af),Am=[Math.floor(Ah[A]),Math.floor(Ah[H])];if(q.UA.ie){var Ak=2,Aj=2,Ai=Al[i],Y=q.DOM[AG](Al[R],f),Ae=q.DOM[AG](Al[R],U);if(q.UA.ie===6){if(Ai!==AC){Ak=0;Aj=0;}}if((Ai==AC)){if(Y!==Q){Ak=parseInt(Y,10);}if(Ae!==Q){Aj=parseInt(Ae,10);}}Am[0]-=Ak;Am[1]-=Aj;}if((Ad||Ag)){Am[0]+=Ag;Am[1]+=Ad;}Am[0]=Math.floor(Am[0]);Am[1]=Math.floor(Am[1]);return Am;};}else{return function(Ad){var Af=[Ad[AF],Ad[D]],Y=Ad,Ah=((q.UA.gecko||(q.UA.webkit>519))?true:false);while((Y=Y[AE])){Af[0]+=Y[AF];Af[1]+=Y[D];if(Ah){Af=q.DOM._calcBorders(Y,Af);}}if(q.DOM.getStyle(Ad,J)!=e){Y=Ad;var Ae,Ag;while((Y=Y.parentNode)){Ae=Y[u];Ag=Y[Ac];if(q.UA.gecko&&(q.DOM.getStyle(Y,"overflow")!=="visible")){Af=q.DOM._calcBorders(Y,Af);}if(Ae||Ag){Af[0]-=Ag;Af[1]-=Ae;}}Af[0]+=q.DOM.docScrollX(Ad);Af[1]+=q.DOM.docScrollY(Ad);}else{if(q.UA.opera){Af[0]-=q.DOM.docScrollX(Ad);Af[1]-=q.DOM.docScrollY(Ad);}else{if(q.UA.webkit||q.UA.gecko){Af[0]+=q.DOM.docScrollX(Ad);Af[1]+=q.DOM.docScrollY(Ad);}}}Af[0]=Math.floor(Af[0]);Af[1]=Math.floor(Af[1]);return Af;};}}(),getX:function(Y){return q.DOM.getXY(Y)[0];},getY:function(Y){return q.DOM.getXY(Y)[1];},setXY:function(Ad,Ag,Aj){var Ai=q.DOM.getStyle(Ad,J),Ae=q.DOM.setStyle,Ah=[parseInt(q.DOM[AG](Ad,A),10),parseInt(q.DOM[AG](Ad,H),10)];if(Ai=="static"){Ai=I;Ae(Ad,J,Ai);}var Af=q.DOM.getXY(Ad);if(Af===false){return false;}if(isNaN(Ah[0])){Ah[0]=(Ai==I)?0:Ad[AF];}if(isNaN(Ah[1])){Ah[1]=(Ai==I)?0:Ad[D];}if(Ag[0]!==null){Ae(Ad,A,Ag[0]-Af[0]+Ah[0]+"px");}if(Ag[1]!==null){Ae(Ad,H,Ag[1]-Af[1]+Ah[1]+"px");}if(!Aj){var Y=q.DOM.getXY(Ad);if((Ag[0]!==null&&Y[0]!=Ag[0])||(Ag[1]!==null&&Y[1]!=Ag[1])){q.DOM.setXY(Ad,Ag,true);}}},setX:function(Ad,Y){return q.DOM.setXY(Ad,[Y,null]);},setY:function(Y,Ad){return q.DOM.setXY(Y,[null,Ad]);},_calcBorders:function(Ae,Af){var Ad=parseInt(q.DOM[AG](Ae,U),10)||0,Y=parseInt(q.DOM[AG](Ae,f),10)||0;if(q.UA.gecko){if(AS.test(Ae.tagName)){Ad=0;Y=0;}}Af[0]+=Y;Af[1]+=Ad;return Af;},_getWinSize:function(Af){var Ah=q.DOM._getDoc(),Ag=Ah.defaultView||Ah.parentWindow,Ai=Ah[i],Ae=Ag.innerHeight,Ad=Ag.innerWidth,Y=Ah[R];if(Ai&&!q.UA.opera){if(Ai!="CSS1Compat"){Y=Ah.body;}Ae=Y.clientHeight;Ad=Y.clientWidth;}return{height:Ae,width:Ad};},_getDocSize:function(Ad){var Ae=q.DOM._getDoc(),Y=Ae[R];if(Ae[i]!="CSS1Compat"){Y=Ae.body;}return{height:Y.scrollHeight,width:Y.scrollWidth};}});var AW="offsetWidth",b="offsetHeight",H="top",G="right",AO="bottom",A="left",AU="tagName";var Aa=function(Af,Ae){var Ah=Math.max(Af[H],Ae[H]),Ai=Math.min(Af[G],Ae[G]),Y=Math.min(Af[AO],Ae[AO]),Ad=Math.max(Af[A],Ae[A]),Ag={};Ag[H]=Ah;Ag[G]=Ai;Ag[AO]=Y;Ag[A]=Ad;return Ag;};var y=y||q.DOM;q.mix(y,{region:function(Ae){var Y=y.getXY(Ae),Ad=false;if(Y){Ad={"0":Y[0],"1":Y[1],top:Y[1],right:Y[0]+Ae[AW],bottom:Y[1]+Ae[b],left:Y[0],height:Ae[b],width:Ae[AW]};}return Ad;},intersect:function(Ae,Y,Ag){var Ad=Ag||y.region(Ae),Af={};var Ai=Y;if(Ai[AU]){Af=y.region(Ai);}else{if(q.Lang.isObject(Y)){Af=Y;}else{return false;}}var Ah=Aa(Af,Ad);return{top:Ah[H],right:Ah[G],bottom:Ah[AO],left:Ah[A],area:((Ah[AO]-Ah[H])*(Ah[G]-Ah[A])),yoff:((Ah[AO]-Ah[H])),xoff:(Ah[G]-Ah[A]),inRegion:y.inRegion(Ae,Y,false,Ag)};},inRegion:function(Af,Y,Ad,Ah){var Ag={},Ae=Ah||y.region(Af);var Aj=Y;if(Aj[AU]){Ag=y.region(Aj);}else{if(q.Lang.isObject(Y)){Ag=Y;}else{return false;}}if(Ad){return(Ae[A]>=Ag[A]&&Ae[G]<=Ag[G]&&Ae[H]>=Ag[H]&&Ae[AO]<=Ag[AO]);}else{var Ai=Aa(Ag,Ae);if(Ai[AO]>=Ai[H]&&Ai[G]>=Ai[A]){return true;}else{return false;}}},inViewportRegion:function(Ad,Y,Ae){return y.inRegion(Ad,y.viewportRegion(Ad),Y,Ae);},viewportRegion:function(Ad){Ad=Ad||q.config.doc.documentElement;var Y={};Y[H]=y.docScrollY(Ad);Y[G]=y.winWidth(Ad)+y.docScrollX(Ad);Y[AO]=(y.docScrollY(Ad)+y.winHeight(Ad));Y[A]=y.docScrollX(Ad);return Y;}});var AM="clientTop",g="clientLeft",C="parentNode",G="right",r="hasLayout",s="px",AY="filter",AX="filters",p="opacity",Ab="auto",d="currentStyle";if(document[R][E][p]===x&&document[R][AX]){q.DOM.CUSTOM_STYLES[p]={get:function(Ad){var Af=100;try{Af=Ad[AX]["DXImageTransform.Microsoft.Alpha"][p];}catch(Ae){try{Af=Ad[AX]("alpha")[p];}catch(Y){}}return Af/100;},set:function(Ad,Ae,Y){if(typeof Y[AY]=="string"){Y[AY]="alpha("+p+"="+Ae*100+")";if(!Ad[d]||!Ad[d][r]){Y.zoom=1;}}}};}var AV=/^width|height$/,j=/^(\d[.\d]*)+(em|ex|px|gd|rem|vw|vh|vm|ch|mm|cm|in|pt|pc|deg|rad|ms|s|hz|khz|%){1}?/i;var AA={CUSTOM_STYLES:{},get:function(Y,Ae){var Ad="",Af=Y[d][Ae];if(Ae===p){Ad=q.DOM.CUSTOM_STYLES[p].get(Y);}else{if(!Af||(Af.indexOf&&Af.indexOf(s)>-1)){Ad=Af;}else{if(q.DOM.IE.COMPUTED[Ae]){Ad=q.DOM.IE.COMPUTED[Ae](Y,Ae);
+}else{if(j.test(Af)){Ad=q.DOM.IE.ComputedStyle.getPixel(Y,Ae);}else{Ad=Af;}}}}return Ad;},getOffset:function(Ae,Aj){var Ag=Ae[d][Aj],Y=Aj.charAt(0).toUpperCase()+Aj.substr(1),Ah="offset"+Y,Ad="pixel"+Y,Af="";if(Ag==Ab){var Ai=Ae[Ah];if(Ai===x){Af=0;}Af=Ai;if(AV.test(Aj)){Ae[E][Aj]=Ai;if(Ae[Ah]>Ai){Af=Ai-(Ae[Ah]-Ai);}Ae[E][Aj]=Ab;}}else{if(!Ae[E][Ad]&&!Ae[E][Aj]){Ae[E][Aj]=Ag;}Af=Ae[E][Ad];}return Af+s;},getBorderWidth:function(Y,Ae){var Ad=null;if(!Y[d][r]){Y[E].zoom=1;}switch(Ae){case U:Ad=Y[AM];break;case B:Ad=Y.offsetHeight-Y.clientHeight-Y[AM];break;case f:Ad=Y[g];break;case S:Ad=Y.offsetWidth-Y.clientWidth-Y[g];break;}return Ad+s;},getPixel:function(Ad,Y){var Af=null,Ag=Ad[d][G],Ae=Ad[d][Y];Ad[E][G]=Ae;Af=Ad[E].pixelRight;Ad[E][G]=Ag;return Af+s;},getMargin:function(Ad,Y){var Ae;if(Ad[d][Y]==Ab){Ae=0+s;}else{Ae=q.DOM.IE.ComputedStyle.getPixel(Ad,Y);}return Ae;},getVisibility:function(Ad,Y){var Ae;while((Ae=Ad[d])&&Ae[Y]=="inherit"){Ad=Ad[C];}return(Ae)?Ae[Y]:t;},getColor:function(Ad,Y){var Ae=Ad[d][Y];if(!Ae||Ae===AD){q.DOM.elementByAxis(Ad,C,null,function(Af){Ae=Af[d][Y];if(Ae&&Ae!==AD){Ad=Af;return true;}});}return q.Color.toRGB(Ae);},getBorderColor:function(Ad,Y){var Ae=Ad[d];var Af=Ae[Y]||Ae.color;return q.Color.toRGB(q.Color.toHex(Af));}};var AQ={};AQ[c]=AQ[AP]=AA.getOffset;AQ.color=AQ.backgroundColor=AA.getColor;AQ[U]=AQ[S]=AQ[B]=AQ[f]=AA.getBorderWidth;AQ.marginTop=AQ.marginRight=AQ.marginBottom=AQ.marginLeft=AA.getMargin;AQ.visibility=AA.getVisibility;AQ.borderColor=AQ.borderTopColor=AQ.borderRightColor=AQ.borderBottomColor=AQ.borderLeftColor=AA.getBorderColor;if(!q.config.win[AG]){q.DOM[AG]=AA.get;}q.namespace("DOM.IE");q.DOM.IE.COMPUTED=AQ;q.DOM.IE.ComputedStyle=AA;var h="tag",C="parentNode",v="previousSibling",w="length",N="nodeType",AU="tagName",M="attributes",k="pseudos",F="combinator";var a=/^(?:([\-]?\d*)(n){1}|(odd|even)$)*([\-+]?\d*)$/;var AN={tag:/^((?:-?[_a-z]+[\w\-]*)|\*)/i,attributes:/^\[([a-z]+\w*)+([~\|\^\$\*!=]=?)?['"]?([^\]]*?)['"]?\]/i,pseudos:/^:([\-\w]+)(?:\(['"]?(.+)['"]?\))*/i,combinator:/^\s*([>+~]|\s)\s*/};var AR={document:q.config.doc,attrAliases:{},shorthand:{"\\#(-?[_a-z]+[-\\w]*)":"[id=$1]","\\.(-?[_a-z]+[-\\w]*)":"[class~=$1]"},operators:{"=":function(Y,Ad){return Y===Ad;},"!=":function(Y,Ad){return Y!==Ad;},"~=":function(Y,Ae){var Ad=" ";return(Ad+Y+Ad).indexOf((Ad+Ae+Ad))>-1;},"|=":function(Y,Ad){return q.DOM._getRegExp("^"+Ad+"[-]?").test(Y);},"^=":function(Y,Ad){return Y.indexOf(Ad)===0;},"$=":function(Y,Ad){return Y.lastIndexOf(Ad)===Y[w]-Ad[w];},"*=":function(Y,Ad){return Y.indexOf(Ad)>-1;},"":function(Y,Ad){return Y;}},pseudos:{"root":function(Y){return Y===Y.ownerDocument.documentElement;},"nth-child":function(Y,Ad){return AR.getNth(Y,Ad);},"nth-last-child":function(Y,Ad){return AR.getNth(Y,Ad,null,true);},"nth-of-type":function(Y,Ad){return AR.getNth(Y,Ad,Y[AU]);},"nth-last-of-type":function(Y,Ad){return AR.getNth(Y,Ad,Y[AU],true);},"first-child":function(Y){return q.DOM.firstChild(Y[C])===Y;},"last-child":function(Y){return q.DOM.lastChild(Y[C])===Y;},"first-of-type":function(Y,Ad){return q.DOM.firstChildByTag(Y[C],Y[AU])===Y;},"last-of-type":function(Y,Ad){return q.DOM.lastChildByTag(Y[C],Y[AU])===Y;},"only-child":function(Ad){var Y=q.DOM.children(Ad[C]);return Y[w]===1&&Y[0]===Ad;},"only-of-type":function(Y){return q.DOM.childrenByTag(Y[C],Y[AU])[w]===1;},"empty":function(Y){return Y.childNodes[w]===0;},"not":function(Y,Ad){return !AR.test(Y,Ad);},"contains":function(Y,Ae){var Ad=Y.innerText||Y.textContent||"";return Ad.indexOf(Ae)>-1;},"checked":function(Y){return Y.checked===true;}},test:function(Ag,Ae){if(!Ag){return false;}var Ad=Ae?Ae.split(","):[];if(Ad[w]){for(var Af=0,Y=Ad[w];Af<Y;++Af){if(AR._testNode(Ag,Ad[Af])){return true;}}return false;}return AR._testNode(Ag,Ae);},filter:function(Ae,Ad){Ae=Ae||[];var Y=AR._filter(Ae,AR._tokenize(Ad)[0]);return Y;},query:function(Ad,Ae,Af){var Y=AR._query(Ad,Ae,Af);return Y;},_query:function(Ai,An,Ao,Ag){var Aq=(Ao)?null:[];if(!Ai){return Aq;}An=An||AR.document;var Ae=Ai.split(",");if(Ae[w]>1){var Ap;for(var Aj=0,Ak=Ae[w];Aj<Ak;++Aj){Ap=arguments.callee(Ae[Aj],An,Ao,true);Aq=Ao?Ap:Aq.concat(Ap);}AR._clearFoundCache();return Aq;}var Am=AR._tokenize(Ai);var Al=Am[AR._getIdTokenIndex(Am)],Y=[],Af,Ad,Ah=Am.pop()||{};if(Al){Ad=AR._getId(Al[M]);}if(Ad){Af=AR.document.getElementById(Ad);if(Af&&(An[N]===9||q.DOM.contains(An,Af))){if(AR._testNode(Af,null,Al)){if(Al===Ah){Y=[Af];}else{An=Af;}}}else{return Aq;}}if(An&&!Y[w]){Y=An.getElementsByTagName(Ah[h]);}if(Y[w]){Aq=AR._filter(Y,Ah,Ao,Ag);}return Aq;},_filter:function(Ae,Af,Ag,Ad){var Y=Ag?null:[];Y=q.DOM.filterElementsBy(Ae,function(Ah){if(!AR._testNode(Ah,"",Af,Ad)){return false;}if(Ad){if(Ah._found){return false;}Ah._found=true;AR._foundCache[AR._foundCache[w]]=Ah;}return true;},Ag);return Y;},_testNode:function(Ae,Ai,Ah,Af){Ah=Ah||AR._tokenize(Ai).pop()||{};var Ad=AR.operators,Al=AR.pseudos,Ag=Ah.previous,Aj,Ak;if(!Ae[AU]||(Ah[h]!=="*"&&Ae[AU].toUpperCase()!==Ah[h])||(Af&&Ae._found)){return false;}if(Ah[M][w]){var Y;for(Aj=0,Ak=Ah[M][w];Aj<Ak;++Aj){Y=Ae.getAttribute(Ah[M][Aj][0],2);if(Y===undefined){return false;}if(Ad[Ah[M][Aj][1]]&&!Ad[Ah[M][Aj][1]](Y,Ah[M][Aj][2])){return false;}}}if(Ah[k][w]){for(Aj=0,Ak=Ah[k][w];Aj<Ak;++Aj){if(Al[Ah[k][Aj][0]]&&!Al[Ah[k][Aj][0]](Ae,Ah[k][Aj][1])){return false;}}}return(Ag&&Ag[F]!==",")?AR.combinators[Ag[F]](Ae,Ah):true;},_foundCache:[],_regexCache:{},_clearFoundCache:function(){for(var Ad=0,Y=AR._foundCache[w];Ad<Y;++Ad){try{delete AR._foundCache[Ad]._found;}catch(Ae){AR._foundCache[Ad].removeAttribute("_found");}}AR._foundCache=[];},combinators:{" ":function(Ad,Y){while((Ad=Ad[C])){if(AR._testNode(Ad,"",Y.previous)){return true;}}return false;},">":function(Ad,Y){return AR._testNode(Ad[C],null,Y.previous);},"+":function(Ae,Ad){var Y=Ae[v];while(Y&&Y[N]!==1){Y=Y[v];}if(Y&&AR._testNode(Y,null,Ad.previous)){return true;}return false;},"~":function(Ae,Ad){var Y=Ae[v];while(Y){if(Y[N]===1&&AR._testNode(Y,null,Ad.previous)){return true;
+}Y=Y[v];}return false;}},getNth:function(Ad,Am,An,Ah){a.test(Am);var Al=parseInt(RegExp.$1,10),Y=RegExp.$2,Ai=RegExp.$3,Aj=parseInt(RegExp.$4,10)||0,Af,Ae,Ag,Ak;if(An){Ak=q.DOM.childrenByTag(Ad[C],An);}else{Ak=q.DOM.children(Ad[C]);}if(Ai){Al=2;Af="+";Y="n";Aj=(Ai==="odd")?1:0;}else{if(isNaN(Al)){Al=(Y)?1:0;}}if(Al===0){if(Ah){Aj=Ak[w]-Aj+1;}if(Ak[Aj-1]===Ad){return true;}else{return false;}}else{if(Al<0){Ah=!!Ah;Al=Math.abs(Al);}}if(!Ah){for(Ae=Aj-1,Ag=Ak[w];Ae<Ag;Ae+=Al){if(Ae>=0&&Ak[Ae]===Ad){return true;}}}else{for(Ae=Ak[w]-Aj,Ag=Ak[w];Ae>=0;Ae-=Al){if(Ae<Ag&&Ak[Ae]===Ad){return true;}}}return false;},_getId:function(Ad){for(var Ae=0,Y=Ad[w];Ae<Y;++Ae){if(Ad[Ae][0]=="id"&&Ad[Ae][1]==="="){return Ad[Ae][2];}}},_getIdTokenIndex:function(Ae){for(var Ad=0,Y=Ae[w];Ad<Y;++Ad){if(AR._getId(Ae[Ad][M])){return Ad;}}return -1;},_tokenize:function(Y){var Ae={},Ah=[],Ag=false,Ad;Y=AR._replaceShorthand(Y);do{Ag=false;for(var Af in AN){if(AN.hasOwnProperty(Af)){if(Af!=h&&Af!=F){Ae[Af]=Ae[Af]||[];}if((Ad=AN[Af].exec(Y))){Ag=true;if(Af!=h&&Af!=F){if(Af===M&&Ad[1]==="id"){Ae.id=Ad[3];}Ae[Af].push(Ad.slice(1));}else{Ae[Af]=Ad[1];}Y=Y.replace(Ad[0],"");if(Af===F||!Y[w]){Ae[M]=AR._fixAttributes(Ae[M]);Ae[k]=Ae[k]||[];Ae[h]=Ae[h]?Ae[h].toUpperCase():"*";Ah.push(Ae);Ae={previous:Ae};}}}}}while(Ag);return Ah;},_fixAttributes:function(Ad){var Ae=AR.attrAliases;Ad=Ad||[];for(var Af=0,Y=Ad[w];Af<Y;++Af){if(Ae[Ad[Af][0]]){Ad[Af][0]=Ae[Ad[Af][0]];}if(!Ad[Af][1]){Ad[Af][1]="";}}return Ad;},_replaceShorthand:function(Ad){var Ae=AR.shorthand;var Af=Ad.match(AN[M]);if(Af){Ad=Ad.replace(AN[M],"REPLACED_ATTRIBUTE");}for(var Ah in Ae){if(Ae.hasOwnProperty(Ah)){Ad=Ad.replace(q.DOM._getRegExp(Ah,"gi"),Ae[Ah]);}}if(Af){for(var Ag=0,Y=Af[w];Ag<Y;++Ag){Ad=Ad.replace("REPLACED_ATTRIBUTE",Af[Ag]);}}return Ad;}};if(q.UA.ie&&q.UA.ie<8){AR.attrAliases["class"]="className";AR.attrAliases["for"]="htmlFor";}q.Selector=AR;q.Selector.patterns=AN;var T="toString",O=parseInt,Z=RegExp;q.Color={KEYWORDS:{black:"000",silver:"c0c0c0",gray:"808080",white:"fff",maroon:"800000",red:"f00",purple:"800080",fuchsia:"f0f",green:"008000",lime:"0f0",olive:"808000",yellow:"ff0",navy:"000080",blue:"00f",teal:"008080",aqua:"0ff"},re_RGB:/^rgb\(([0-9]+)\s*,\s*([0-9]+)\s*,\s*([0-9]+)\)$/i,re_hex:/^#?([0-9A-F]{2})([0-9A-F]{2})([0-9A-F]{2})$/i,re_hex3:/([0-9A-F])/gi,toRGB:function(Y){if(!q.Color.re_RGB.test(Y)){Y=q.Color.toHex(Y);}if(q.Color.re_hex.exec(Y)){Y="rgb("+[O(Z.$1,16),O(Z.$2,16),O(Z.$3,16)].join(", ")+")";}return Y;},toHex:function(Af){Af=q.Color.KEYWORDS[Af]||Af;if(q.Color.re_RGB.exec(Af)){var Ae=(Z.$1.length===1)?"0"+Z.$1:Number(Z.$1),Ad=(Z.$2.length===1)?"0"+Z.$2:Number(Z.$2),Y=(Z.$3.length===1)?"0"+Z.$3:Number(Z.$3);Af=[Ae[T](16),Ad[T](16),Y[T](16)].join("");}if(Af.length<6){Af=Af.replace(q.Color.re_hex3,"$1$1");}if(Af!=="transparent"&&Af.indexOf("#")<0){Af="#"+Af;}return Af.toLowerCase();}};},"3.0.0pr2",{skinnable:false});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-screen-debug.js'
--- loggerhead/static/javascript/yui/build/dom/dom-screen-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-screen-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,551 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dom-screen', function(Y) {
+
+
+/**
+ * Adds position and region management functionality to DOM.
+ * @module dom
+ * @submodule dom-screen
+ * @for DOM
+ */
+
+var OFFSET_TOP = 'offsetTop',
+
+    DOCUMENT_ELEMENT = 'documentElement',
+    COMPAT_MODE = 'compatMode',
+    OFFSET_LEFT = 'offsetLeft',
+    OFFSET_PARENT = 'offsetParent',
+    POSITION = 'position',
+    FIXED = 'fixed',
+    RELATIVE = 'relative',
+    LEFT = 'left',
+    TOP = 'top',
+    SCROLL_LEFT = 'scrollLeft',
+    SCROLL_TOP = 'scrollTop',
+    _BACK_COMPAT = 'BackCompat',
+    MEDIUM = 'medium',
+    HEIGHT = 'height',
+    WIDTH = 'width',
+    BORDER_LEFT_WIDTH = 'borderLeftWidth',
+    BORDER_TOP_WIDTH = 'borderTopWidth',
+    GET_BOUNDING_CLIENT_RECT = 'getBoundingClientRect',
+    GET_COMPUTED_STYLE = 'getComputedStyle',
+    RE_TABLE = /^t(?:able|d|h)$/i;
+
+Y.mix(Y.DOM, {
+
+
+    /**
+     * Returns the inner height of the viewport (exludes scrollbar). 
+     * @method winHeight
+
+     */
+    winHeight: function(node) {
+        var h = Y.DOM._getWinSize(node)[HEIGHT];
+        Y.log('winHeight returning ' + h, 'info', 'DOM');
+        return h;
+    },
+
+    /**
+     * Returns the inner width of the viewport (exludes scrollbar). 
+     * @method winWidth
+
+     */
+    winWidth: function(node) {
+        var w = Y.DOM._getWinSize(node)[WIDTH];
+        Y.log('winWidth returning ' + w, 'info', 'DOM');
+        return w;
+    },
+
+    /**
+     * Document height 
+     * @method docHeight
+
+     */
+    docHeight:  function(node) {
+        var h = Y.DOM._getDocSize(node)[HEIGHT];
+        Y.log('docHeight returning ' + h, 'info', 'DOM');
+        return Math.max(h, Y.DOM._getWinSize(node)[HEIGHT]);
+    },
+
+    /**
+     * Document width 
+     * @method docWidth
+
+     */
+    docWidth:  function(node) {
+        var w = Y.DOM._getDocSize(node)[WIDTH];
+        Y.log('docWidth returning ' + w, 'info', 'DOM');
+        return Math.max(w, Y.DOM._getWinSize(node)[WIDTH]);
+    },
+
+    /**
+     * Amount page has been scroll vertically 
+     * @method docScrollX
+
+     */
+    docScrollX: function(node) {
+        var doc = Y.DOM._getDoc();
+        return Math.max(doc[DOCUMENT_ELEMENT][SCROLL_LEFT], doc.body[SCROLL_LEFT]);
+    },
+
+    /**
+     * Amount page has been scroll horizontally 
+     * @method docScrollY
+
+     */
+    docScrollY:  function(node) {
+        var doc = Y.DOM._getDoc();
+        return Math.max(doc[DOCUMENT_ELEMENT][SCROLL_TOP], doc.body[SCROLL_TOP]);
+    },
+
+    /**
+     * Gets the current position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getXY
+     * @param element The target element
+     * @return {Array} The XY position of the element
+
+     TODO: test inDocument/display
+     */
+    getXY: function() {
+
+
+
+
+        if (document[DOCUMENT_ELEMENT][GET_BOUNDING_CLIENT_RECT]) {
+            return function(node) {
+                if (!node) {
+                    return false;
+                }
+                var scrollLeft = Y.DOM.docScrollX(node),
+                    scrollTop = Y.DOM.docScrollY(node),
+                    box = node[GET_BOUNDING_CLIENT_RECT](),
+                    doc = Y.DOM._getDoc(node),
+                    //Round the numbers so we get sane data back
+                    xy = [Math.floor(box[LEFT]), Math.floor(box[TOP])];
+
+                    if (Y.UA.ie) {
+                        var off1 = 2, off2 = 2,
+                        mode = doc[COMPAT_MODE],
+                        bLeft = Y.DOM[GET_COMPUTED_STYLE](doc[DOCUMENT_ELEMENT], BORDER_LEFT_WIDTH),
+                        bTop = Y.DOM[GET_COMPUTED_STYLE](doc[DOCUMENT_ELEMENT], BORDER_TOP_WIDTH);
+
+                        if (Y.UA.ie === 6) {
+                            if (mode !== _BACK_COMPAT) {
+                                off1 = 0;
+                                off2 = 0;
+                            }
+                        }
+                        
+                        if ((mode == _BACK_COMPAT)) {
+                            if (bLeft !== MEDIUM) {
+                                off1 = parseInt(bLeft, 10);
+                            }
+                            if (bTop !== MEDIUM) {
+                                off2 = parseInt(bTop, 10);
+                            }
+
+
+
+                        }
+                        
+                        xy[0] -= off1;
+                        xy[1] -= off2;
+
+                    }
+
+                if ((scrollTop || scrollLeft)) {
+                    xy[0] += scrollLeft;
+                    xy[1] += scrollTop;
+                }
+
+                // gecko may return sub-pixel (non-int) values
+                xy[0] = Math.floor(xy[0]);
+                xy[1] = Math.floor(xy[1]);
+
+                return xy;                   
+            };
+        } else {
+            return function(node) { // manually calculate by crawling up offsetParents
+                //Calculate the Top and Left border sizes (assumes pixels)
+                var xy = [node[OFFSET_LEFT], node[OFFSET_TOP]],
+                    parentNode = node,
+                    bCheck = ((Y.UA.gecko || (Y.UA.webkit > 519)) ? true : false);
+
+                while ((parentNode = parentNode[OFFSET_PARENT])) {
+                    xy[0] += parentNode[OFFSET_LEFT];
+                    xy[1] += parentNode[OFFSET_TOP];
+                    if (bCheck) {
+                        xy = Y.DOM._calcBorders(parentNode, xy);
+                    }
+                }
+
+                // account for any scrolled ancestors
+                if (Y.DOM.getStyle(node, POSITION) != FIXED) {
+                    parentNode = node;
+                    var scrollTop, scrollLeft;
+
+                    while ((parentNode = parentNode.parentNode)) {
+                        scrollTop = parentNode[SCROLL_TOP];
+                        scrollLeft = parentNode[SCROLL_LEFT];
+
+                        //Firefox does something funky with borders when overflow is not visible.
+                        if (Y.UA.gecko && (Y.DOM.getStyle(parentNode, 'overflow') !== 'visible')) {
+                                xy = Y.DOM._calcBorders(parentNode, xy);
+                        }
+                        
+
+                        if (scrollTop || scrollLeft) {
+                            xy[0] -= scrollLeft;
+                            xy[1] -= scrollTop;
+                        }
+                    }
+                    xy[0] += Y.DOM.docScrollX(node);
+                    xy[1] += Y.DOM.docScrollY(node);
+
+                } else {
+                    //Fix FIXED position -- add scrollbars
+                    if (Y.UA.opera) {
+                        xy[0] -= Y.DOM.docScrollX(node);
+                        xy[1] -= Y.DOM.docScrollY(node);
+                    } else if (Y.UA.webkit || Y.UA.gecko) {
+                        xy[0] += Y.DOM.docScrollX(node);
+                        xy[1] += Y.DOM.docScrollY(node);
+                    }
+                }
+                //Round the numbers so we get sane data back
+                xy[0] = Math.floor(xy[0]);
+                xy[1] = Math.floor(xy[1]);
+
+                return xy;                
+            };
+        }
+    }(),// NOTE: Executing for loadtime branching
+
+    /**
+     * Gets the current X position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getX
+     * @param element The target element
+     * @return {Int} The X position of the element
+     */
+
+    getX: function(node) {
+        return Y.DOM.getXY(node)[0];
+    },
+
+    /**
+     * Gets the current Y position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getY
+     * @param element The target element
+     * @return {Int} The Y position of the element
+     */
+
+    getY: function(node) {
+        return Y.DOM.getXY(node)[1];
+    },
+
+    /**
+     * Set the position of an html element in page coordinates.
+     * The element must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setXY
+     * @param element The target element
+     * @param {Array} xy Contains X & Y values for new position (coordinates are page-based)
+     * @param {Boolean} noRetry By default we try and set the position a second time if the first fails
+     */
+    setXY: function(node, xy, noRetry) {
+        var pos = Y.DOM.getStyle(node, POSITION),
+            setStyle = Y.DOM.setStyle,
+
+            delta = [ // assuming pixels; if not we will have to retry
+                parseInt( Y.DOM[GET_COMPUTED_STYLE](node, LEFT), 10 ),
+                parseInt( Y.DOM[GET_COMPUTED_STYLE](node, TOP), 10 )
+            ];
+    
+        if (pos == 'static') { // default to relative
+            pos = RELATIVE;
+            setStyle(node, POSITION, pos);
+        }
+
+        var currentXY = Y.DOM.getXY(node);
+
+
+
+
+        if (currentXY === false) { // has to be part of doc to have xy
+
+
+
+
+
+            Y.log('xy failed: node not available', 'error', 'Node');
+            return false; 
+        }
+        
+        if ( isNaN(delta[0]) ) {// in case of 'auto'
+            delta[0] = (pos == RELATIVE) ? 0 : node[OFFSET_LEFT];
+        } 
+        if ( isNaN(delta[1]) ) { // in case of 'auto'
+            delta[1] = (pos == RELATIVE) ? 0 : node[OFFSET_TOP];
+        } 
+
+        if (xy[0] !== null) {
+            setStyle(node, LEFT, xy[0] - currentXY[0] + delta[0] + 'px');
+        }
+
+        if (xy[1] !== null) {
+            setStyle(node, TOP, xy[1] - currentXY[1] + delta[1] + 'px');
+        }
+      
+        if (!noRetry) {
+            var newXY = Y.DOM.getXY(node);
+
+            // if retry is true, try one more time if we miss 
+           if ( (xy[0] !== null && newXY[0] != xy[0]) || 
+                (xy[1] !== null && newXY[1] != xy[1]) ) {
+               Y.DOM.setXY(node, xy, true);
+           }
+        }        
+
+        Y.log('setXY setting position to ' + xy, 'info', 'Node');
+    },
+
+    /**
+     * Set the X position of an html element in page coordinates, regardless of how the element is positioned.
+     * The element(s) must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setX
+     * @param element The target element
+     * @param {Int} x The X values for new position (coordinates are page-based)
+     */
+    setX: function(node, x) {
+        return Y.DOM.setXY(node, [x, null]);
+    },
+
+    /**
+     * Set the Y position of an html element in page coordinates, regardless of how the element is positioned.
+     * The element(s) must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setY
+     * @param element The target element
+     * @param {Int} y The Y values for new position (coordinates are page-based)
+     */
+    setY: function(node, y) {
+        return Y.DOM.setXY(node, [null, y]);
+    },
+
+    _calcBorders: function(node, xy2) {
+        var t = parseInt(Y.DOM[GET_COMPUTED_STYLE](node, BORDER_TOP_WIDTH), 10) || 0,
+            l = parseInt(Y.DOM[GET_COMPUTED_STYLE](node, BORDER_LEFT_WIDTH), 10) || 0;
+        if (Y.UA.gecko) {
+            if (RE_TABLE.test(node.tagName)) {
+                t = 0;
+                l = 0;
+            }
+        }
+        xy2[0] += l;
+        xy2[1] += t;
+        return xy2;
+    },
+
+    _getWinSize: function(node) {
+        var doc = Y.DOM._getDoc(),
+            win = doc.defaultView || doc.parentWindow,
+            mode = doc[COMPAT_MODE],
+            h = win.innerHeight,
+            w = win.innerWidth,
+            root = doc[DOCUMENT_ELEMENT];
+
+        if ( mode && !Y.UA.opera ) { // IE, Gecko
+            if (mode != 'CSS1Compat') { // Quirks
+                root = doc.body; 
+            }
+            h = root.clientHeight;
+            w = root.clientWidth;
+        }
+        return { height: h, width: w }; 
+    },
+
+    _getDocSize: function(node) {
+        var doc = Y.DOM._getDoc(),
+            root = doc[DOCUMENT_ELEMENT];
+
+        if (doc[COMPAT_MODE] != 'CSS1Compat') {
+            root = doc.body;
+        }
+
+        return { height: root.scrollHeight, width: root.scrollWidth };
+    }
+});
+
+
+
+/**
+ * Adds position and region management functionality to DOM.
+ * @module dom
+ * @submodule dom-screen
+ * @for DOM
+ */
+
+var OFFSET_WIDTH = 'offsetWidth',
+    OFFSET_HEIGHT = 'offsetHeight',
+    TOP = 'top',
+    RIGHT = 'right',
+    BOTTOM = 'bottom',
+    LEFT = 'left',
+    TAG_NAME = 'tagName';
+
+var getOffsets = function(r1, r2) {
+    var t = Math.max(r1[TOP], r2[TOP]),
+        r = Math.min(r1[RIGHT], r2[RIGHT]),
+        b = Math.min(r1[BOTTOM], r2[BOTTOM]),
+        l = Math.max(r1[LEFT], r2[LEFT]),
+        ret = {};
+    
+    ret[TOP] = t;
+    ret[RIGHT] = r;
+    ret[BOTTOM] = b;
+    ret[LEFT] = l;
+    return ret;
+};
+
+var DOM = DOM || Y.DOM;
+Y.mix(DOM, {
+    /**
+     * Returns an Object literal containing the following about this element: (top, right, bottom, left)
+     * @method region
+     * @param {HTMLElement} element The DOM element. 
+     @return {Object} Object literal containing the following about this element: (top, right, bottom, left)
+     */
+    region: function(node) {
+        var x = DOM.getXY(node),
+            ret = false;
+        
+        if (x) {
+            ret = {
+                '0': x[0],
+                '1': x[1],
+                top: x[1],
+                right: x[0] + node[OFFSET_WIDTH],
+                bottom: x[1] + node[OFFSET_HEIGHT],
+                left: x[0],
+                height: node[OFFSET_HEIGHT],
+                width: node[OFFSET_WIDTH]
+            };
+        }
+
+        return ret;
+    },
+
+    /**
+     * Find the intersect information for the passes nodes.
+     * @method intersect
+     * @param {HTMLElement} element The first element 
+     * @param {HTMLElement | Object} element2 The element or region to check the interect with
+     * @param {Object} altRegion An object literal containing the region for the first element if we already have the data (for performance i.e. DragDrop)
+     @return {Object} Object literal containing the following intersection data: (top, right, bottom, left, area, yoff, xoff, inRegion)
+     */
+    intersect: function(node, node2, altRegion) {
+        var r = altRegion || DOM.region(node), region = {};
+
+        var n = node2;
+        if (n[TAG_NAME]) {
+            region = DOM.region(n);
+        } else if (Y.Lang.isObject(node2)) {
+            region = node2;
+        } else {
+            return false;
+        }
+        
+        var off = getOffsets(region, r);
+        return {
+            top: off[TOP],
+            right: off[RIGHT],
+            bottom: off[BOTTOM],
+            left: off[LEFT],
+            area: ((off[BOTTOM] - off[TOP]) * (off[RIGHT] - off[LEFT])),
+            yoff: ((off[BOTTOM] - off[TOP])),
+            xoff: (off[RIGHT] - off[LEFT]),
+            inRegion: DOM.inRegion(node, node2, false, altRegion)
+        };
+        
+    },
+    /**
+     * Check if any part of this node is in the passed region
+     * @method inRegion
+     * @param {Object} node2 The node to get the region from or an Object literal of the region
+     * $param {Boolean} all Should all of the node be inside the region
+     * @param {Object} altRegion An object literal containing the region for this node if we already have the data (for performance i.e. DragDrop)
+     * @return {Boolean} True if in region, false if not.
+     */
+    inRegion: function(node, node2, all, altRegion) {
+        var region = {},
+            r = altRegion || DOM.region(node);
+
+        var n = node2;
+        if (n[TAG_NAME]) {
+            region = DOM.region(n);
+        } else if (Y.Lang.isObject(node2)) {
+            region = node2;
+        } else {
+            return false;
+        }
+            
+        if (all) {
+            return (
+                r[LEFT]   >= region[LEFT]   &&
+                r[RIGHT]  <= region[RIGHT]  && 
+                r[TOP]    >= region[TOP]    && 
+                r[BOTTOM] <= region[BOTTOM]  );
+        } else {
+            var off = getOffsets(region, r);
+            if (off[BOTTOM] >= off[TOP] && off[RIGHT] >= off[LEFT]) {
+                return true;
+            } else {
+                return false;
+            }
+            
+        }
+    },
+
+    /**
+     * Check if any part of this element is in the viewport
+     * @method inViewportRegion
+     * @param {HTMLElement} element The DOM element. 
+     * @param {Boolean} all Should all of the node be inside the region
+     * @param {Object} altRegion An object literal containing the region for this node if we already have the data (for performance i.e. DragDrop)
+     * @return {Boolean} True if in region, false if not.
+     */
+    inViewportRegion: function(node, all, altRegion) {
+        return DOM.inRegion(node, DOM.viewportRegion(node), all, altRegion);
+            
+    },
+
+    /**
+     * Returns an Object literal containing the following about the visible region of viewport: (top, right, bottom, left)
+     * @method viewportRegion
+     @return {Object} Object literal containing the following about the visible region of the viewport: (top, right, bottom, left)
+     */
+    viewportRegion: function(node) {
+        node = node || Y.config.doc.documentElement;
+        var r = {};
+        r[TOP] = DOM.docScrollY(node);
+        r[RIGHT] = DOM.winWidth(node) + DOM.docScrollX(node);
+        r[BOTTOM] = (DOM.docScrollY(node) + DOM.winHeight(node));
+        r[LEFT] = DOM.docScrollX(node);
+
+        return r;
+    }
+});
+
+
+
+}, '3.0.0pr2' ,{skinnable:false, requires:['dom-base', 'dom-style']});

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-screen-min.js'
--- loggerhead/static/javascript/yui/build/dom/dom-screen-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-screen-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dom-screen",function(E){var N="offsetTop",W="documentElement",M="compatMode",D="offsetLeft",a="offsetParent",P="position",U="fixed",c="relative",O="left",S="top",b="scrollLeft",X="scrollTop",Z="BackCompat",R="medium",Q="height",H="width",F="borderLeftWidth",G="borderTopWidth",C="getBoundingClientRect",B="getComputedStyle",d=/^t(?:able|d|h)$/i;E.mix(E.DOM,{winHeight:function(e){var Y=E.DOM._getWinSize(e)[Q];return Y;},winWidth:function(e){var Y=E.DOM._getWinSize(e)[H];return Y;},docHeight:function(e){var Y=E.DOM._getDocSize(e)[Q];return Math.max(Y,E.DOM._getWinSize(e)[Q]);},docWidth:function(e){var Y=E.DOM._getDocSize(e)[H];return Math.max(Y,E.DOM._getWinSize(e)[H]);},docScrollX:function(Y){var e=E.DOM._getDoc();return Math.max(e[W][b],e.body[b]);},docScrollY:function(Y){var e=E.DOM._getDoc();return Math.max(e[W][X],e.body[X]);},getXY:function(){if(document[W][C]){return function(g){if(!g){return false;}var h=E.DOM.docScrollX(g),e=E.DOM.docScrollY(g),i=g[C](),m=E.DOM._getDoc(g),n=[Math.floor(i[O]),Math.floor(i[S])];if(E.UA.ie){var l=2,k=2,j=m[M],Y=E.DOM[B](m[W],F),f=E.DOM[B](m[W],G);if(E.UA.ie===6){if(j!==Z){l=0;k=0;}}if((j==Z)){if(Y!==R){l=parseInt(Y,10);}if(f!==R){k=parseInt(f,10);}}n[0]-=l;n[1]-=k;}if((e||h)){n[0]+=h;n[1]+=e;}n[0]=Math.floor(n[0]);n[1]=Math.floor(n[1]);return n;};}else{return function(e){var g=[e[D],e[N]],Y=e,i=((E.UA.gecko||(E.UA.webkit>519))?true:false);while((Y=Y[a])){g[0]+=Y[D];g[1]+=Y[N];if(i){g=E.DOM._calcBorders(Y,g);}}if(E.DOM.getStyle(e,P)!=U){Y=e;var f,h;while((Y=Y.parentNode)){f=Y[X];h=Y[b];if(E.UA.gecko&&(E.DOM.getStyle(Y,"overflow")!=="visible")){g=E.DOM._calcBorders(Y,g);}if(f||h){g[0]-=h;g[1]-=f;}}g[0]+=E.DOM.docScrollX(e);g[1]+=E.DOM.docScrollY(e);}else{if(E.UA.opera){g[0]-=E.DOM.docScrollX(e);g[1]-=E.DOM.docScrollY(e);}else{if(E.UA.webkit||E.UA.gecko){g[0]+=E.DOM.docScrollX(e);g[1]+=E.DOM.docScrollY(e);}}}g[0]=Math.floor(g[0]);g[1]=Math.floor(g[1]);return g;};}}(),getX:function(Y){return E.DOM.getXY(Y)[0];},getY:function(Y){return E.DOM.getXY(Y)[1];},setXY:function(e,h,k){var j=E.DOM.getStyle(e,P),f=E.DOM.setStyle,i=[parseInt(E.DOM[B](e,O),10),parseInt(E.DOM[B](e,S),10)];if(j=="static"){j=c;f(e,P,j);}var g=E.DOM.getXY(e);if(g===false){return false;}if(isNaN(i[0])){i[0]=(j==c)?0:e[D];}if(isNaN(i[1])){i[1]=(j==c)?0:e[N];}if(h[0]!==null){f(e,O,h[0]-g[0]+i[0]+"px");}if(h[1]!==null){f(e,S,h[1]-g[1]+i[1]+"px");}if(!k){var Y=E.DOM.getXY(e);if((h[0]!==null&&Y[0]!=h[0])||(h[1]!==null&&Y[1]!=h[1])){E.DOM.setXY(e,h,true);}}},setX:function(e,Y){return E.DOM.setXY(e,[Y,null]);},setY:function(Y,e){return E.DOM.setXY(Y,[null,e]);},_calcBorders:function(f,g){var e=parseInt(E.DOM[B](f,G),10)||0,Y=parseInt(E.DOM[B](f,F),10)||0;if(E.UA.gecko){if(d.test(f.tagName)){e=0;Y=0;}}g[0]+=Y;g[1]+=e;return g;},_getWinSize:function(g){var j=E.DOM._getDoc(),i=j.defaultView||j.parentWindow,k=j[M],f=i.innerHeight,e=i.innerWidth,Y=j[W];if(k&&!E.UA.opera){if(k!="CSS1Compat"){Y=j.body;}f=Y.clientHeight;e=Y.clientWidth;}return{height:f,width:e};},_getDocSize:function(e){var f=E.DOM._getDoc(),Y=f[W];if(f[M]!="CSS1Compat"){Y=f.body;}return{height:Y.scrollHeight,width:Y.scrollWidth};}});var J="offsetWidth",A="offsetHeight",S="top",K="right",I="bottom",O="left",T="tagName";var L=function(g,f){var i=Math.max(g[S],f[S]),j=Math.min(g[K],f[K]),Y=Math.min(g[I],f[I]),e=Math.max(g[O],f[O]),h={};h[S]=i;h[K]=j;h[I]=Y;h[O]=e;return h;};var V=V||E.DOM;E.mix(V,{region:function(f){var Y=V.getXY(f),e=false;if(Y){e={"0":Y[0],"1":Y[1],top:Y[1],right:Y[0]+f[J],bottom:Y[1]+f[A],left:Y[0],height:f[A],width:f[J]};}return e;},intersect:function(f,Y,h){var e=h||V.region(f),g={};var j=Y;if(j[T]){g=V.region(j);}else{if(E.Lang.isObject(Y)){g=Y;}else{return false;}}var i=L(g,e);return{top:i[S],right:i[K],bottom:i[I],left:i[O],area:((i[I]-i[S])*(i[K]-i[O])),yoff:((i[I]-i[S])),xoff:(i[K]-i[O]),inRegion:V.inRegion(f,Y,false,h)};},inRegion:function(g,Y,e,i){var h={},f=i||V.region(g);var k=Y;if(k[T]){h=V.region(k);}else{if(E.Lang.isObject(Y)){h=Y;}else{return false;}}if(e){return(f[O]>=h[O]&&f[K]<=h[K]&&f[S]>=h[S]&&f[I]<=h[I]);}else{var j=L(h,f);if(j[I]>=j[S]&&j[K]>=j[O]){return true;}else{return false;}}},inViewportRegion:function(e,Y,f){return V.inRegion(e,V.viewportRegion(e),Y,f);},viewportRegion:function(e){e=e||E.config.doc.documentElement;var Y={};Y[S]=V.docScrollY(e);Y[K]=V.winWidth(e)+V.docScrollX(e);Y[I]=(V.docScrollY(e)+V.winHeight(e));Y[O]=V.docScrollX(e);return Y;}});},"3.0.0pr2",{skinnable:false,requires:["dom-base","dom-style"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-screen.js'
--- loggerhead/static/javascript/yui/build/dom/dom-screen.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-screen.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,545 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dom-screen', function(Y) {
+
+
+/**
+ * Adds position and region management functionality to DOM.
+ * @module dom
+ * @submodule dom-screen
+ * @for DOM
+ */
+
+var OFFSET_TOP = 'offsetTop',
+
+    DOCUMENT_ELEMENT = 'documentElement',
+    COMPAT_MODE = 'compatMode',
+    OFFSET_LEFT = 'offsetLeft',
+    OFFSET_PARENT = 'offsetParent',
+    POSITION = 'position',
+    FIXED = 'fixed',
+    RELATIVE = 'relative',
+    LEFT = 'left',
+    TOP = 'top',
+    SCROLL_LEFT = 'scrollLeft',
+    SCROLL_TOP = 'scrollTop',
+    _BACK_COMPAT = 'BackCompat',
+    MEDIUM = 'medium',
+    HEIGHT = 'height',
+    WIDTH = 'width',
+    BORDER_LEFT_WIDTH = 'borderLeftWidth',
+    BORDER_TOP_WIDTH = 'borderTopWidth',
+    GET_BOUNDING_CLIENT_RECT = 'getBoundingClientRect',
+    GET_COMPUTED_STYLE = 'getComputedStyle',
+    RE_TABLE = /^t(?:able|d|h)$/i;
+
+Y.mix(Y.DOM, {
+
+
+    /**
+     * Returns the inner height of the viewport (exludes scrollbar). 
+     * @method winHeight
+
+     */
+    winHeight: function(node) {
+        var h = Y.DOM._getWinSize(node)[HEIGHT];
+        return h;
+    },
+
+    /**
+     * Returns the inner width of the viewport (exludes scrollbar). 
+     * @method winWidth
+
+     */
+    winWidth: function(node) {
+        var w = Y.DOM._getWinSize(node)[WIDTH];
+        return w;
+    },
+
+    /**
+     * Document height 
+     * @method docHeight
+
+     */
+    docHeight:  function(node) {
+        var h = Y.DOM._getDocSize(node)[HEIGHT];
+        return Math.max(h, Y.DOM._getWinSize(node)[HEIGHT]);
+    },
+
+    /**
+     * Document width 
+     * @method docWidth
+
+     */
+    docWidth:  function(node) {
+        var w = Y.DOM._getDocSize(node)[WIDTH];
+        return Math.max(w, Y.DOM._getWinSize(node)[WIDTH]);
+    },
+
+    /**
+     * Amount page has been scroll vertically 
+     * @method docScrollX
+
+     */
+    docScrollX: function(node) {
+        var doc = Y.DOM._getDoc();
+        return Math.max(doc[DOCUMENT_ELEMENT][SCROLL_LEFT], doc.body[SCROLL_LEFT]);
+    },
+
+    /**
+     * Amount page has been scroll horizontally 
+     * @method docScrollY
+
+     */
+    docScrollY:  function(node) {
+        var doc = Y.DOM._getDoc();
+        return Math.max(doc[DOCUMENT_ELEMENT][SCROLL_TOP], doc.body[SCROLL_TOP]);
+    },
+
+    /**
+     * Gets the current position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getXY
+     * @param element The target element
+     * @return {Array} The XY position of the element
+
+     TODO: test inDocument/display
+     */
+    getXY: function() {
+
+
+
+
+        if (document[DOCUMENT_ELEMENT][GET_BOUNDING_CLIENT_RECT]) {
+            return function(node) {
+                if (!node) {
+                    return false;
+                }
+                var scrollLeft = Y.DOM.docScrollX(node),
+                    scrollTop = Y.DOM.docScrollY(node),
+                    box = node[GET_BOUNDING_CLIENT_RECT](),
+                    doc = Y.DOM._getDoc(node),
+                    //Round the numbers so we get sane data back
+                    xy = [Math.floor(box[LEFT]), Math.floor(box[TOP])];
+
+                    if (Y.UA.ie) {
+                        var off1 = 2, off2 = 2,
+                        mode = doc[COMPAT_MODE],
+                        bLeft = Y.DOM[GET_COMPUTED_STYLE](doc[DOCUMENT_ELEMENT], BORDER_LEFT_WIDTH),
+                        bTop = Y.DOM[GET_COMPUTED_STYLE](doc[DOCUMENT_ELEMENT], BORDER_TOP_WIDTH);
+
+                        if (Y.UA.ie === 6) {
+                            if (mode !== _BACK_COMPAT) {
+                                off1 = 0;
+                                off2 = 0;
+                            }
+                        }
+                        
+                        if ((mode == _BACK_COMPAT)) {
+                            if (bLeft !== MEDIUM) {
+                                off1 = parseInt(bLeft, 10);
+                            }
+                            if (bTop !== MEDIUM) {
+                                off2 = parseInt(bTop, 10);
+                            }
+
+
+
+                        }
+                        
+                        xy[0] -= off1;
+                        xy[1] -= off2;
+
+                    }
+
+                if ((scrollTop || scrollLeft)) {
+                    xy[0] += scrollLeft;
+                    xy[1] += scrollTop;
+                }
+
+                // gecko may return sub-pixel (non-int) values
+                xy[0] = Math.floor(xy[0]);
+                xy[1] = Math.floor(xy[1]);
+
+                return xy;                   
+            };
+        } else {
+            return function(node) { // manually calculate by crawling up offsetParents
+                //Calculate the Top and Left border sizes (assumes pixels)
+                var xy = [node[OFFSET_LEFT], node[OFFSET_TOP]],
+                    parentNode = node,
+                    bCheck = ((Y.UA.gecko || (Y.UA.webkit > 519)) ? true : false);
+
+                while ((parentNode = parentNode[OFFSET_PARENT])) {
+                    xy[0] += parentNode[OFFSET_LEFT];
+                    xy[1] += parentNode[OFFSET_TOP];
+                    if (bCheck) {
+                        xy = Y.DOM._calcBorders(parentNode, xy);
+                    }
+                }
+
+                // account for any scrolled ancestors
+                if (Y.DOM.getStyle(node, POSITION) != FIXED) {
+                    parentNode = node;
+                    var scrollTop, scrollLeft;
+
+                    while ((parentNode = parentNode.parentNode)) {
+                        scrollTop = parentNode[SCROLL_TOP];
+                        scrollLeft = parentNode[SCROLL_LEFT];
+
+                        //Firefox does something funky with borders when overflow is not visible.
+                        if (Y.UA.gecko && (Y.DOM.getStyle(parentNode, 'overflow') !== 'visible')) {
+                                xy = Y.DOM._calcBorders(parentNode, xy);
+                        }
+                        
+
+                        if (scrollTop || scrollLeft) {
+                            xy[0] -= scrollLeft;
+                            xy[1] -= scrollTop;
+                        }
+                    }
+                    xy[0] += Y.DOM.docScrollX(node);
+                    xy[1] += Y.DOM.docScrollY(node);
+
+                } else {
+                    //Fix FIXED position -- add scrollbars
+                    if (Y.UA.opera) {
+                        xy[0] -= Y.DOM.docScrollX(node);
+                        xy[1] -= Y.DOM.docScrollY(node);
+                    } else if (Y.UA.webkit || Y.UA.gecko) {
+                        xy[0] += Y.DOM.docScrollX(node);
+                        xy[1] += Y.DOM.docScrollY(node);
+                    }
+                }
+                //Round the numbers so we get sane data back
+                xy[0] = Math.floor(xy[0]);
+                xy[1] = Math.floor(xy[1]);
+
+                return xy;                
+            };
+        }
+    }(),// NOTE: Executing for loadtime branching
+
+    /**
+     * Gets the current X position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getX
+     * @param element The target element
+     * @return {Int} The X position of the element
+     */
+
+    getX: function(node) {
+        return Y.DOM.getXY(node)[0];
+    },
+
+    /**
+     * Gets the current Y position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getY
+     * @param element The target element
+     * @return {Int} The Y position of the element
+     */
+
+    getY: function(node) {
+        return Y.DOM.getXY(node)[1];
+    },
+
+    /**
+     * Set the position of an html element in page coordinates.
+     * The element must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setXY
+     * @param element The target element
+     * @param {Array} xy Contains X & Y values for new position (coordinates are page-based)
+     * @param {Boolean} noRetry By default we try and set the position a second time if the first fails
+     */
+    setXY: function(node, xy, noRetry) {
+        var pos = Y.DOM.getStyle(node, POSITION),
+            setStyle = Y.DOM.setStyle,
+
+            delta = [ // assuming pixels; if not we will have to retry
+                parseInt( Y.DOM[GET_COMPUTED_STYLE](node, LEFT), 10 ),
+                parseInt( Y.DOM[GET_COMPUTED_STYLE](node, TOP), 10 )
+            ];
+    
+        if (pos == 'static') { // default to relative
+            pos = RELATIVE;
+            setStyle(node, POSITION, pos);
+        }
+
+        var currentXY = Y.DOM.getXY(node);
+
+
+
+
+        if (currentXY === false) { // has to be part of doc to have xy
+
+
+
+
+
+            return false; 
+        }
+        
+        if ( isNaN(delta[0]) ) {// in case of 'auto'
+            delta[0] = (pos == RELATIVE) ? 0 : node[OFFSET_LEFT];
+        } 
+        if ( isNaN(delta[1]) ) { // in case of 'auto'
+            delta[1] = (pos == RELATIVE) ? 0 : node[OFFSET_TOP];
+        } 
+
+        if (xy[0] !== null) {
+            setStyle(node, LEFT, xy[0] - currentXY[0] + delta[0] + 'px');
+        }
+
+        if (xy[1] !== null) {
+            setStyle(node, TOP, xy[1] - currentXY[1] + delta[1] + 'px');
+        }
+      
+        if (!noRetry) {
+            var newXY = Y.DOM.getXY(node);
+
+            // if retry is true, try one more time if we miss 
+           if ( (xy[0] !== null && newXY[0] != xy[0]) || 
+                (xy[1] !== null && newXY[1] != xy[1]) ) {
+               Y.DOM.setXY(node, xy, true);
+           }
+        }        
+
+    },
+
+    /**
+     * Set the X position of an html element in page coordinates, regardless of how the element is positioned.
+     * The element(s) must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setX
+     * @param element The target element
+     * @param {Int} x The X values for new position (coordinates are page-based)
+     */
+    setX: function(node, x) {
+        return Y.DOM.setXY(node, [x, null]);
+    },
+
+    /**
+     * Set the Y position of an html element in page coordinates, regardless of how the element is positioned.
+     * The element(s) must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setY
+     * @param element The target element
+     * @param {Int} y The Y values for new position (coordinates are page-based)
+     */
+    setY: function(node, y) {
+        return Y.DOM.setXY(node, [null, y]);
+    },
+
+    _calcBorders: function(node, xy2) {
+        var t = parseInt(Y.DOM[GET_COMPUTED_STYLE](node, BORDER_TOP_WIDTH), 10) || 0,
+            l = parseInt(Y.DOM[GET_COMPUTED_STYLE](node, BORDER_LEFT_WIDTH), 10) || 0;
+        if (Y.UA.gecko) {
+            if (RE_TABLE.test(node.tagName)) {
+                t = 0;
+                l = 0;
+            }
+        }
+        xy2[0] += l;
+        xy2[1] += t;
+        return xy2;
+    },
+
+    _getWinSize: function(node) {
+        var doc = Y.DOM._getDoc(),
+            win = doc.defaultView || doc.parentWindow,
+            mode = doc[COMPAT_MODE],
+            h = win.innerHeight,
+            w = win.innerWidth,
+            root = doc[DOCUMENT_ELEMENT];
+
+        if ( mode && !Y.UA.opera ) { // IE, Gecko
+            if (mode != 'CSS1Compat') { // Quirks
+                root = doc.body; 
+            }
+            h = root.clientHeight;
+            w = root.clientWidth;
+        }
+        return { height: h, width: w }; 
+    },
+
+    _getDocSize: function(node) {
+        var doc = Y.DOM._getDoc(),
+            root = doc[DOCUMENT_ELEMENT];
+
+        if (doc[COMPAT_MODE] != 'CSS1Compat') {
+            root = doc.body;
+        }
+
+        return { height: root.scrollHeight, width: root.scrollWidth };
+    }
+});
+
+
+
+/**
+ * Adds position and region management functionality to DOM.
+ * @module dom
+ * @submodule dom-screen
+ * @for DOM
+ */
+
+var OFFSET_WIDTH = 'offsetWidth',
+    OFFSET_HEIGHT = 'offsetHeight',
+    TOP = 'top',
+    RIGHT = 'right',
+    BOTTOM = 'bottom',
+    LEFT = 'left',
+    TAG_NAME = 'tagName';
+
+var getOffsets = function(r1, r2) {
+    var t = Math.max(r1[TOP], r2[TOP]),
+        r = Math.min(r1[RIGHT], r2[RIGHT]),
+        b = Math.min(r1[BOTTOM], r2[BOTTOM]),
+        l = Math.max(r1[LEFT], r2[LEFT]),
+        ret = {};
+    
+    ret[TOP] = t;
+    ret[RIGHT] = r;
+    ret[BOTTOM] = b;
+    ret[LEFT] = l;
+    return ret;
+};
+
+var DOM = DOM || Y.DOM;
+Y.mix(DOM, {
+    /**
+     * Returns an Object literal containing the following about this element: (top, right, bottom, left)
+     * @method region
+     * @param {HTMLElement} element The DOM element. 
+     @return {Object} Object literal containing the following about this element: (top, right, bottom, left)
+     */
+    region: function(node) {
+        var x = DOM.getXY(node),
+            ret = false;
+        
+        if (x) {
+            ret = {
+                '0': x[0],
+                '1': x[1],
+                top: x[1],
+                right: x[0] + node[OFFSET_WIDTH],
+                bottom: x[1] + node[OFFSET_HEIGHT],
+                left: x[0],
+                height: node[OFFSET_HEIGHT],
+                width: node[OFFSET_WIDTH]
+            };
+        }
+
+        return ret;
+    },
+
+    /**
+     * Find the intersect information for the passes nodes.
+     * @method intersect
+     * @param {HTMLElement} element The first element 
+     * @param {HTMLElement | Object} element2 The element or region to check the interect with
+     * @param {Object} altRegion An object literal containing the region for the first element if we already have the data (for performance i.e. DragDrop)
+     @return {Object} Object literal containing the following intersection data: (top, right, bottom, left, area, yoff, xoff, inRegion)
+     */
+    intersect: function(node, node2, altRegion) {
+        var r = altRegion || DOM.region(node), region = {};
+
+        var n = node2;
+        if (n[TAG_NAME]) {
+            region = DOM.region(n);
+        } else if (Y.Lang.isObject(node2)) {
+            region = node2;
+        } else {
+            return false;
+        }
+        
+        var off = getOffsets(region, r);
+        return {
+            top: off[TOP],
+            right: off[RIGHT],
+            bottom: off[BOTTOM],
+            left: off[LEFT],
+            area: ((off[BOTTOM] - off[TOP]) * (off[RIGHT] - off[LEFT])),
+            yoff: ((off[BOTTOM] - off[TOP])),
+            xoff: (off[RIGHT] - off[LEFT]),
+            inRegion: DOM.inRegion(node, node2, false, altRegion)
+        };
+        
+    },
+    /**
+     * Check if any part of this node is in the passed region
+     * @method inRegion
+     * @param {Object} node2 The node to get the region from or an Object literal of the region
+     * $param {Boolean} all Should all of the node be inside the region
+     * @param {Object} altRegion An object literal containing the region for this node if we already have the data (for performance i.e. DragDrop)
+     * @return {Boolean} True if in region, false if not.
+     */
+    inRegion: function(node, node2, all, altRegion) {
+        var region = {},
+            r = altRegion || DOM.region(node);
+
+        var n = node2;
+        if (n[TAG_NAME]) {
+            region = DOM.region(n);
+        } else if (Y.Lang.isObject(node2)) {
+            region = node2;
+        } else {
+            return false;
+        }
+            
+        if (all) {
+            return (
+                r[LEFT]   >= region[LEFT]   &&
+                r[RIGHT]  <= region[RIGHT]  && 
+                r[TOP]    >= region[TOP]    && 
+                r[BOTTOM] <= region[BOTTOM]  );
+        } else {
+            var off = getOffsets(region, r);
+            if (off[BOTTOM] >= off[TOP] && off[RIGHT] >= off[LEFT]) {
+                return true;
+            } else {
+                return false;
+            }
+            
+        }
+    },
+
+    /**
+     * Check if any part of this element is in the viewport
+     * @method inViewportRegion
+     * @param {HTMLElement} element The DOM element. 
+     * @param {Boolean} all Should all of the node be inside the region
+     * @param {Object} altRegion An object literal containing the region for this node if we already have the data (for performance i.e. DragDrop)
+     * @return {Boolean} True if in region, false if not.
+     */
+    inViewportRegion: function(node, all, altRegion) {
+        return DOM.inRegion(node, DOM.viewportRegion(node), all, altRegion);
+            
+    },
+
+    /**
+     * Returns an Object literal containing the following about the visible region of viewport: (top, right, bottom, left)
+     * @method viewportRegion
+     @return {Object} Object literal containing the following about the visible region of the viewport: (top, right, bottom, left)
+     */
+    viewportRegion: function(node) {
+        node = node || Y.config.doc.documentElement;
+        var r = {};
+        r[TOP] = DOM.docScrollY(node);
+        r[RIGHT] = DOM.winWidth(node) + DOM.docScrollX(node);
+        r[BOTTOM] = (DOM.docScrollY(node) + DOM.winHeight(node));
+        r[LEFT] = DOM.docScrollX(node);
+
+        return r;
+    }
+});
+
+
+
+}, '3.0.0pr2' ,{skinnable:false, requires:['dom-base', 'dom-style']});

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-style-debug.js'
--- loggerhead/static/javascript/yui/build/dom/dom-style-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-style-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,455 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dom-style', function(Y) {
+
+/** 
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var DOCUMENT_ELEMENT = 'documentElement',
+    DEFAULT_VIEW = 'defaultView',
+    OWNER_DOCUMENT = 'ownerDocument',
+    STYLE = 'style',
+    FLOAT = 'float',
+    CSS_FLOAT = 'cssFloat',
+    STYLE_FLOAT = 'styleFloat',
+    TRANSPARENT = 'transparent',
+    VISIBLE = 'visible',
+    WIDTH = 'width',
+    HEIGHT = 'height',
+    BORDER_TOP_WIDTH = 'borderTopWidth',
+    BORDER_RIGHT_WIDTH = 'borderRightWidth',
+    BORDER_BOTTOM_WIDTH = 'borderBottomWidth',
+    BORDER_LEFT_WIDTH = 'borderLeftWidth',
+    GET_COMPUTED_STYLE = 'getComputedStyle',
+
+    DOCUMENT = Y.config.doc,
+    UNDEFINED = undefined,
+
+    re_color = /color$/i;
+
+
+Y.mix(Y.DOM, {
+    CUSTOM_STYLES: {},
+
+
+    /**
+     * Sets a style property for a given element.
+     * @method setStyle
+     * @param {HTMLElement} An HTMLElement to apply the style to.
+     * @param {String} att The style property to set. 
+     * @param {String|Number} val The value. 
+     */
+    setStyle: function(node, att, val, style) {
+        style = node[STYLE],
+            CUSTOM_STYLES = Y.DOM.CUSTOM_STYLES;
+
+        if (style) {
+            if (att in CUSTOM_STYLES) {
+                if (CUSTOM_STYLES[att].set) {
+                    CUSTOM_STYLES[att].set(node, val, style);
+                    return; // NOTE: return
+                } else if (typeof CUSTOM_STYLES[att] === 'string') {
+                    att = CUSTOM_STYLES[att];
+                }
+            }
+            style[att] = val; 
+        }
+    },
+
+    /**
+     * Returns the current style value for the given property.
+     * @method getStyle
+     * @param {HTMLElement} An HTMLElement to get the style from.
+     * @param {String} att The style property to get. 
+     */
+    getStyle: function(node, att) {
+        var style = node[STYLE],
+            CUSTOM_STYLES = Y.DOM.CUSTOM_STYLES,
+            val = '';
+
+        if (style) {
+            if (att in CUSTOM_STYLES) {
+                if (CUSTOM_STYLES[att].get) {
+                    return CUSTOM_STYLES[att].get(node, att, style); // NOTE: return
+                } else if (typeof CUSTOM_STYLES[att] === 'string') {
+                    att = CUSTOM_STYLES[att];
+                }
+            }
+            val = style[att];
+            if (val === '') { // TODO: is empty string sufficient?
+                val = Y.DOM[GET_COMPUTED_STYLE](node, att);
+            }
+        }
+
+        return val;
+    },
+
+    /**
+     * Sets multiple style properties.
+     * @method setStyles
+     * @param {HTMLElement} node An HTMLElement to apply the styles to. 
+     * @param {Object} hash An object literal of property:value pairs. 
+     */
+    'setStyles': function(node, hash) {
+        Y.each(hash, function(v, n) {
+            Y.DOM.setStyle(node, n, v);
+        }, Y.DOM);
+    },
+
+    /**
+     * Returns the computed style for the given node.
+     * @method getComputedStyle
+     * @param {HTMLElement} An HTMLElement to get the style from.
+     * @param {String} att The style property to get. 
+     * @return {String} The computed value of the style property. 
+     */
+    getComputedStyle: function(node, att) {
+        var val = '',
+            doc = node[OWNER_DOCUMENT];
+
+        if (node[STYLE]) {
+            val = doc[DEFAULT_VIEW][GET_COMPUTED_STYLE](node, '')[att];
+        }
+        return val;
+    }
+});
+
+if (DOCUMENT[DOCUMENT_ELEMENT][STYLE][CSS_FLOAT] !== UNDEFINED) {
+    Y.DOM.CUSTOM_STYLES[FLOAT] = CSS_FLOAT;
+} else if (DOCUMENT[DOCUMENT_ELEMENT][STYLE][STYLE_FLOAT] !== UNDEFINED) {
+    Y.DOM.CUSTOM_STYLES[FLOAT] = STYLE_FLOAT;
+}
+
+if (Y.UA.opera) { // opera defaults to hex instead of RGB
+    Y.DOM[GET_COMPUTED_STYLE] = function(node, att) {
+        var view = node[OWNER_DOCUMENT][DEFAULT_VIEW],
+            val = view[GET_COMPUTED_STYLE](node, '')[att];
+
+        if (re_color.test(att)) {
+            val = Y.Color.toRGB(val);
+        }
+
+        return val;
+    };
+
+}
+
+if (Y.UA.webkit) { // safari converts transparent to rgba()
+    Y.DOM[GET_COMPUTED_STYLE] = function(node, att) {
+        var view = node[OWNER_DOCUMENT][DEFAULT_VIEW],
+            val = view[GET_COMPUTED_STYLE](node, '')[att];
+
+        if (val === 'rgba(0, 0, 0, 0)') {
+            val = TRANSPARENT; 
+        }
+
+        return val;
+    };
+
+}
+
+
+/**
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var TO_STRING = 'toString',
+    PARSE_INT = parseInt,
+    RE = RegExp;
+
+Y.Color = {
+    KEYWORDS: {
+        black: '000',
+        silver: 'c0c0c0',
+        gray: '808080',
+        white: 'fff',
+        maroon: '800000',
+        red: 'f00',
+        purple: '800080',
+        fuchsia: 'f0f',
+        green: '008000',
+        lime: '0f0',
+        olive: '808000',
+        yellow: 'ff0',
+        navy: '000080',
+        blue: '00f',
+        teal: '008080',
+        aqua: '0ff'
+    },
+
+    re_RGB: /^rgb\(([0-9]+)\s*,\s*([0-9]+)\s*,\s*([0-9]+)\)$/i,
+    re_hex: /^#?([0-9A-F]{2})([0-9A-F]{2})([0-9A-F]{2})$/i,
+    re_hex3: /([0-9A-F])/gi,
+
+    toRGB: function(val) {
+        if (!Y.Color.re_RGB.test(val)) {
+            val = Y.Color.toHex(val);
+        }
+
+        if(Y.Color.re_hex.exec(val)) {
+            val = 'rgb(' + [
+                PARSE_INT(RE.$1, 16),
+                PARSE_INT(RE.$2, 16),
+                PARSE_INT(RE.$3, 16)
+            ].join(', ') + ')';
+        }
+        return val;
+    },
+
+    toHex: function(val) {
+        val = Y.Color.KEYWORDS[val] || val;
+        if (Y.Color.re_RGB.exec(val)) {
+            var r = (RE.$1.length === 1) ? '0' + RE.$1 : Number(RE.$1),
+                g = (RE.$2.length === 1) ? '0' + RE.$2 : Number(RE.$2),
+                b = (RE.$3.length === 1) ? '0' + RE.$3 : Number(RE.$3);
+
+            val = [
+                r[TO_STRING](16),
+                g[TO_STRING](16),
+                b[TO_STRING](16)
+            ].join('');
+        }
+
+        if (val.length < 6) {
+            val = val.replace(Y.Color.re_hex3, '$1$1');
+        }
+
+        if (val !== 'transparent' && val.indexOf('#') < 0) {
+            val = '#' + val;
+        }
+
+        return val.toLowerCase();
+    }
+};
+
+
+/**
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var CLIENT_TOP = 'clientTop',
+    CLIENT_LEFT = 'clientLeft',
+    PARENT_NODE = 'parentNode',
+    RIGHT = 'right',
+    HAS_LAYOUT = 'hasLayout',
+    PX = 'px',
+    FILTER = 'filter',
+    FILTERS = 'filters',
+    OPACITY = 'opacity',
+    AUTO = 'auto',
+    CURRENT_STYLE = 'currentStyle';
+
+// use alpha filter for IE opacity
+if (document[DOCUMENT_ELEMENT][STYLE][OPACITY] === UNDEFINED &&
+        document[DOCUMENT_ELEMENT][FILTERS]) {
+    Y.DOM.CUSTOM_STYLES[OPACITY] = {
+        get: function(node) {
+            var val = 100;
+            try { // will error if no DXImageTransform
+                val = node[FILTERS]['DXImageTransform.Microsoft.Alpha'][OPACITY];
+
+            } catch(e) {
+                try { // make sure its in the document
+                    val = node[FILTERS]('alpha')[OPACITY];
+                } catch(err) {
+                    Y.log('getStyle: IE opacity filter not found; returning 1', 'warn', 'DOM');
+                }
+            }
+            return val / 100;
+        },
+
+        set: function(node, val, style) {
+            if (typeof style[FILTER] == 'string') { // in case not appended
+                style[FILTER] = 'alpha(' + OPACITY + '=' + val * 100 + ')';
+                
+                if (!node[CURRENT_STYLE] || !node[CURRENT_STYLE][HAS_LAYOUT]) {
+                    style.zoom = 1; // needs layout 
+                }
+            }
+        }
+    };
+}
+
+// IE getComputedStyle
+// TODO: unit-less lineHeight (e.g. 1.22)
+var re_size = /^width|height$/,
+    re_unit = /^(\d[.\d]*)+(em|ex|px|gd|rem|vw|vh|vm|ch|mm|cm|in|pt|pc|deg|rad|ms|s|hz|khz|%){1}?/i;
+
+var ComputedStyle = {
+    CUSTOM_STYLES: {},
+
+    get: function(el, property) {
+        var value = '',
+            current = el[CURRENT_STYLE][property];
+
+        if (property === OPACITY) {
+            value = Y.DOM.CUSTOM_STYLES[OPACITY].get(el);        
+        } else if (!current || (current.indexOf && current.indexOf(PX) > -1)) { // no need to convert
+            value = current;
+        } else if (Y.DOM.IE.COMPUTED[property]) { // use compute function
+            value = Y.DOM.IE.COMPUTED[property](el, property);
+        } else if (re_unit.test(current)) { // convert to pixel
+            value = Y.DOM.IE.ComputedStyle.getPixel(el, property);
+        } else {
+            value = current;
+        }
+
+        return value;
+    },
+
+    getOffset: function(el, prop) {
+        var current = el[CURRENT_STYLE][prop],                        // value of "width", "top", etc.
+            capped = prop.charAt(0).toUpperCase() + prop.substr(1), // "Width", "Top", etc.
+            offset = 'offset' + capped,                             // "offsetWidth", "offsetTop", etc.
+            pixel = 'pixel' + capped,                               // "pixelWidth", "pixelTop", etc.
+            value = '';
+
+        if (current == AUTO) {
+            var actual = el[offset]; // offsetHeight/Top etc.
+            if (actual === UNDEFINED) { // likely "right" or "bottom"
+                value = 0;
+            }
+
+            value = actual;
+            if (re_size.test(prop)) { // account for box model diff 
+                el[STYLE][prop] = actual; 
+                if (el[offset] > actual) {
+                    // the difference is padding + border (works in Standards & Quirks modes)
+                    value = actual - (el[offset] - actual);
+                }
+                el[STYLE][prop] = AUTO; // revert to auto
+            }
+        } else { // convert units to px
+            if (!el[STYLE][pixel] && !el[STYLE][prop]) { // need to map style.width to currentStyle (no currentStyle.pixelWidth)
+                el[STYLE][prop] = current;              // no style.pixelWidth if no style.width
+            }
+            value = el[STYLE][pixel];
+        }
+        return value + PX;
+    },
+
+    getBorderWidth: function(el, property) {
+        // clientHeight/Width = paddingBox (e.g. offsetWidth - borderWidth)
+        // clientTop/Left = borderWidth
+        var value = null;
+        if (!el[CURRENT_STYLE][HAS_LAYOUT]) { // TODO: unset layout?
+            el[STYLE].zoom = 1; // need layout to measure client
+        }
+
+        switch(property) {
+            case BORDER_TOP_WIDTH:
+                value = el[CLIENT_TOP];
+                break;
+            case BORDER_BOTTOM_WIDTH:
+                value = el.offsetHeight - el.clientHeight - el[CLIENT_TOP];
+                break;
+            case BORDER_LEFT_WIDTH:
+                value = el[CLIENT_LEFT];
+                break;
+            case BORDER_RIGHT_WIDTH:
+                value = el.offsetWidth - el.clientWidth - el[CLIENT_LEFT];
+                break;
+        }
+        return value + PX;
+    },
+
+    getPixel: function(node, att) {
+        // use pixelRight to convert to px
+        var val = null,
+            styleRight = node[CURRENT_STYLE][RIGHT],
+            current = node[CURRENT_STYLE][att];
+
+        node[STYLE][RIGHT] = current;
+        val = node[STYLE].pixelRight;
+        node[STYLE][RIGHT] = styleRight; // revert
+
+        return val + PX;
+    },
+
+    getMargin: function(node, att) {
+        var val;
+        if (node[CURRENT_STYLE][att] == AUTO) {
+            val = 0 + PX;
+        } else {
+            val = Y.DOM.IE.ComputedStyle.getPixel(node, att);
+        }
+        return val;
+    },
+
+    getVisibility: function(node, att) {
+        var current;
+        while ( (current = node[CURRENT_STYLE]) && current[att] == 'inherit') { // NOTE: assignment in test
+            node = node[PARENT_NODE];
+        }
+        return (current) ? current[att] : VISIBLE;
+    },
+
+    getColor: function(node, att) {
+        var current = node[CURRENT_STYLE][att];
+
+        if (!current || current === TRANSPARENT) {
+            Y.DOM.elementByAxis(node, PARENT_NODE, null, function(parent) {
+                current = parent[CURRENT_STYLE][att];
+                if (current && current !== TRANSPARENT) {
+                    node = parent;
+                    return true;
+                }
+            });
+        }
+
+        return Y.Color.toRGB(current);
+    },
+
+    getBorderColor: function(node, att) {
+        var current = node[CURRENT_STYLE];
+        var val = current[att] || current.color;
+        return Y.Color.toRGB(Y.Color.toHex(val));
+    }
+
+};
+
+//fontSize: getPixelFont,
+var IEComputed = {};
+
+IEComputed[WIDTH] = IEComputed[HEIGHT] = ComputedStyle.getOffset;
+
+IEComputed.color = IEComputed.backgroundColor = ComputedStyle.getColor;
+
+IEComputed[BORDER_TOP_WIDTH] = IEComputed[BORDER_RIGHT_WIDTH] =
+        IEComputed[BORDER_BOTTOM_WIDTH] = IEComputed[BORDER_LEFT_WIDTH] =
+        ComputedStyle.getBorderWidth;
+
+IEComputed.marginTop = IEComputed.marginRight = IEComputed.marginBottom =
+        IEComputed.marginLeft = ComputedStyle.getMargin;
+
+IEComputed.visibility = ComputedStyle.getVisibility;
+IEComputed.borderColor = IEComputed.borderTopColor =
+        IEComputed.borderRightColor = IEComputed.borderBottomColor =
+        IEComputed.borderLeftColor = ComputedStyle.getBorderColor;
+
+if (!Y.config.win[GET_COMPUTED_STYLE]) {
+    Y.DOM[GET_COMPUTED_STYLE] = ComputedStyle.get; 
+}
+
+Y.namespace('DOM.IE');
+Y.DOM.IE.COMPUTED = IEComputed;
+Y.DOM.IE.ComputedStyle = ComputedStyle;
+
+
+
+
+}, '3.0.0pr2' ,{skinnable:false, requires:['dom-base']});

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-style-min.js'
--- loggerhead/static/javascript/yui/build/dom/dom-style-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-style-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dom-style",function(B){var h="documentElement",X="defaultView",N="ownerDocument",i="style",e="float",C="cssFloat",R="styleFloat",S="transparent",k="visible",G="width",Z="height",J="borderTopWidth",d="borderRightWidth",D="borderBottomWidth",c="borderLeftWidth",j="getComputedStyle",F=B.config.doc,a=undefined,b=/color$/i;B.mix(B.DOM,{CUSTOM_STYLES:{},setStyle:function(o,Y,p,n){n=o[i],CUSTOM_STYLES=B.DOM.CUSTOM_STYLES;if(n){if(Y in CUSTOM_STYLES){if(CUSTOM_STYLES[Y].set){CUSTOM_STYLES[Y].set(o,p,n);return ;}else{if(typeof CUSTOM_STYLES[Y]==="string"){Y=CUSTOM_STYLES[Y];}}}n[Y]=p;}},getStyle:function(p,Y){var o=p[i],n=B.DOM.CUSTOM_STYLES,q="";if(o){if(Y in n){if(n[Y].get){return n[Y].get(p,Y,o);}else{if(typeof n[Y]==="string"){Y=n[Y];}}}q=o[Y];if(q===""){q=B.DOM[j](p,Y);}}return q;},"setStyles":function(Y,n){B.each(n,function(o,p){B.DOM.setStyle(Y,p,o);},B.DOM);},getComputedStyle:function(n,Y){var p="",o=n[N];if(n[i]){p=o[X][j](n,"")[Y];}return p;}});if(F[h][i][C]!==a){B.DOM.CUSTOM_STYLES[e]=C;}else{if(F[h][i][R]!==a){B.DOM.CUSTOM_STYLES[e]=R;}}if(B.UA.opera){B.DOM[j]=function(o,n){var Y=o[N][X],p=Y[j](o,"")[n];if(b.test(n)){p=B.Color.toRGB(p);}return p;};}if(B.UA.webkit){B.DOM[j]=function(o,n){var Y=o[N][X],p=Y[j](o,"")[n];if(p==="rgba(0, 0, 0, 0)"){p=S;}return p;};}var A="toString",Q=parseInt,P=RegExp;B.Color={KEYWORDS:{black:"000",silver:"c0c0c0",gray:"808080",white:"fff",maroon:"800000",red:"f00",purple:"800080",fuchsia:"f0f",green:"008000",lime:"0f0",olive:"808000",yellow:"ff0",navy:"000080",blue:"00f",teal:"008080",aqua:"0ff"},re_RGB:/^rgb\(([0-9]+)\s*,\s*([0-9]+)\s*,\s*([0-9]+)\)$/i,re_hex:/^#?([0-9A-F]{2})([0-9A-F]{2})([0-9A-F]{2})$/i,re_hex3:/([0-9A-F])/gi,toRGB:function(Y){if(!B.Color.re_RGB.test(Y)){Y=B.Color.toHex(Y);}if(B.Color.re_hex.exec(Y)){Y="rgb("+[Q(P.$1,16),Q(P.$2,16),Q(P.$3,16)].join(", ")+")";}return Y;},toHex:function(p){p=B.Color.KEYWORDS[p]||p;if(B.Color.re_RGB.exec(p)){var o=(P.$1.length===1)?"0"+P.$1:Number(P.$1),n=(P.$2.length===1)?"0"+P.$2:Number(P.$2),Y=(P.$3.length===1)?"0"+P.$3:Number(P.$3);p=[o[A](16),n[A](16),Y[A](16)].join("");}if(p.length<6){p=p.replace(B.Color.re_hex3,"$1$1");}if(p!=="transparent"&&p.indexOf("#")<0){p="#"+p;}return p.toLowerCase();}};var E="clientTop",T="clientLeft",L="parentNode",g="right",U="hasLayout",l="px",I="filter",f="filters",O="opacity",W="auto",M="currentStyle";if(document[h][i][O]===a&&document[h][f]){B.DOM.CUSTOM_STYLES[O]={get:function(n){var p=100;try{p=n[f]["DXImageTransform.Microsoft.Alpha"][O];}catch(o){try{p=n[f]("alpha")[O];}catch(Y){}}return p/100;},set:function(n,o,Y){if(typeof Y[I]=="string"){Y[I]="alpha("+O+"="+o*100+")";if(!n[M]||!n[M][U]){Y.zoom=1;}}}};}var V=/^width|height$/,H=/^(\d[.\d]*)+(em|ex|px|gd|rem|vw|vh|vm|ch|mm|cm|in|pt|pc|deg|rad|ms|s|hz|khz|%){1}?/i;var m={CUSTOM_STYLES:{},get:function(Y,o){var n="",p=Y[M][o];if(o===O){n=B.DOM.CUSTOM_STYLES[O].get(Y);}else{if(!p||(p.indexOf&&p.indexOf(l)>-1)){n=p;}else{if(B.DOM.IE.COMPUTED[o]){n=B.DOM.IE.COMPUTED[o](Y,o);}else{if(H.test(p)){n=B.DOM.IE.ComputedStyle.getPixel(Y,o);}else{n=p;}}}}return n;},getOffset:function(o,t){var q=o[M][t],Y=t.charAt(0).toUpperCase()+t.substr(1),r="offset"+Y,n="pixel"+Y,p="";if(q==W){var s=o[r];if(s===a){p=0;}p=s;if(V.test(t)){o[i][t]=s;if(o[r]>s){p=s-(o[r]-s);}o[i][t]=W;}}else{if(!o[i][n]&&!o[i][t]){o[i][t]=q;}p=o[i][n];}return p+l;},getBorderWidth:function(Y,o){var n=null;if(!Y[M][U]){Y[i].zoom=1;}switch(o){case J:n=Y[E];break;case D:n=Y.offsetHeight-Y.clientHeight-Y[E];break;case c:n=Y[T];break;case d:n=Y.offsetWidth-Y.clientWidth-Y[T];break;}return n+l;},getPixel:function(n,Y){var p=null,q=n[M][g],o=n[M][Y];n[i][g]=o;p=n[i].pixelRight;n[i][g]=q;return p+l;},getMargin:function(n,Y){var o;if(n[M][Y]==W){o=0+l;}else{o=B.DOM.IE.ComputedStyle.getPixel(n,Y);}return o;},getVisibility:function(n,Y){var o;while((o=n[M])&&o[Y]=="inherit"){n=n[L];}return(o)?o[Y]:k;},getColor:function(n,Y){var o=n[M][Y];if(!o||o===S){B.DOM.elementByAxis(n,L,null,function(p){o=p[M][Y];if(o&&o!==S){n=p;return true;}});}return B.Color.toRGB(o);},getBorderColor:function(n,Y){var o=n[M];var p=o[Y]||o.color;return B.Color.toRGB(B.Color.toHex(p));}};var K={};K[G]=K[Z]=m.getOffset;K.color=K.backgroundColor=m.getColor;K[J]=K[d]=K[D]=K[c]=m.getBorderWidth;K.marginTop=K.marginRight=K.marginBottom=K.marginLeft=m.getMargin;K.visibility=m.getVisibility;K.borderColor=K.borderTopColor=K.borderRightColor=K.borderBottomColor=K.borderLeftColor=m.getBorderColor;if(!B.config.win[j]){B.DOM[j]=m.get;}B.namespace("DOM.IE");B.DOM.IE.COMPUTED=K;B.DOM.IE.ComputedStyle=m;},"3.0.0pr2",{skinnable:false,requires:["dom-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dom/dom-style.js'
--- loggerhead/static/javascript/yui/build/dom/dom-style.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom-style.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,454 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dom-style', function(Y) {
+
+/** 
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var DOCUMENT_ELEMENT = 'documentElement',
+    DEFAULT_VIEW = 'defaultView',
+    OWNER_DOCUMENT = 'ownerDocument',
+    STYLE = 'style',
+    FLOAT = 'float',
+    CSS_FLOAT = 'cssFloat',
+    STYLE_FLOAT = 'styleFloat',
+    TRANSPARENT = 'transparent',
+    VISIBLE = 'visible',
+    WIDTH = 'width',
+    HEIGHT = 'height',
+    BORDER_TOP_WIDTH = 'borderTopWidth',
+    BORDER_RIGHT_WIDTH = 'borderRightWidth',
+    BORDER_BOTTOM_WIDTH = 'borderBottomWidth',
+    BORDER_LEFT_WIDTH = 'borderLeftWidth',
+    GET_COMPUTED_STYLE = 'getComputedStyle',
+
+    DOCUMENT = Y.config.doc,
+    UNDEFINED = undefined,
+
+    re_color = /color$/i;
+
+
+Y.mix(Y.DOM, {
+    CUSTOM_STYLES: {},
+
+
+    /**
+     * Sets a style property for a given element.
+     * @method setStyle
+     * @param {HTMLElement} An HTMLElement to apply the style to.
+     * @param {String} att The style property to set. 
+     * @param {String|Number} val The value. 
+     */
+    setStyle: function(node, att, val, style) {
+        style = node[STYLE],
+            CUSTOM_STYLES = Y.DOM.CUSTOM_STYLES;
+
+        if (style) {
+            if (att in CUSTOM_STYLES) {
+                if (CUSTOM_STYLES[att].set) {
+                    CUSTOM_STYLES[att].set(node, val, style);
+                    return; // NOTE: return
+                } else if (typeof CUSTOM_STYLES[att] === 'string') {
+                    att = CUSTOM_STYLES[att];
+                }
+            }
+            style[att] = val; 
+        }
+    },
+
+    /**
+     * Returns the current style value for the given property.
+     * @method getStyle
+     * @param {HTMLElement} An HTMLElement to get the style from.
+     * @param {String} att The style property to get. 
+     */
+    getStyle: function(node, att) {
+        var style = node[STYLE],
+            CUSTOM_STYLES = Y.DOM.CUSTOM_STYLES,
+            val = '';
+
+        if (style) {
+            if (att in CUSTOM_STYLES) {
+                if (CUSTOM_STYLES[att].get) {
+                    return CUSTOM_STYLES[att].get(node, att, style); // NOTE: return
+                } else if (typeof CUSTOM_STYLES[att] === 'string') {
+                    att = CUSTOM_STYLES[att];
+                }
+            }
+            val = style[att];
+            if (val === '') { // TODO: is empty string sufficient?
+                val = Y.DOM[GET_COMPUTED_STYLE](node, att);
+            }
+        }
+
+        return val;
+    },
+
+    /**
+     * Sets multiple style properties.
+     * @method setStyles
+     * @param {HTMLElement} node An HTMLElement to apply the styles to. 
+     * @param {Object} hash An object literal of property:value pairs. 
+     */
+    'setStyles': function(node, hash) {
+        Y.each(hash, function(v, n) {
+            Y.DOM.setStyle(node, n, v);
+        }, Y.DOM);
+    },
+
+    /**
+     * Returns the computed style for the given node.
+     * @method getComputedStyle
+     * @param {HTMLElement} An HTMLElement to get the style from.
+     * @param {String} att The style property to get. 
+     * @return {String} The computed value of the style property. 
+     */
+    getComputedStyle: function(node, att) {
+        var val = '',
+            doc = node[OWNER_DOCUMENT];
+
+        if (node[STYLE]) {
+            val = doc[DEFAULT_VIEW][GET_COMPUTED_STYLE](node, '')[att];
+        }
+        return val;
+    }
+});
+
+if (DOCUMENT[DOCUMENT_ELEMENT][STYLE][CSS_FLOAT] !== UNDEFINED) {
+    Y.DOM.CUSTOM_STYLES[FLOAT] = CSS_FLOAT;
+} else if (DOCUMENT[DOCUMENT_ELEMENT][STYLE][STYLE_FLOAT] !== UNDEFINED) {
+    Y.DOM.CUSTOM_STYLES[FLOAT] = STYLE_FLOAT;
+}
+
+if (Y.UA.opera) { // opera defaults to hex instead of RGB
+    Y.DOM[GET_COMPUTED_STYLE] = function(node, att) {
+        var view = node[OWNER_DOCUMENT][DEFAULT_VIEW],
+            val = view[GET_COMPUTED_STYLE](node, '')[att];
+
+        if (re_color.test(att)) {
+            val = Y.Color.toRGB(val);
+        }
+
+        return val;
+    };
+
+}
+
+if (Y.UA.webkit) { // safari converts transparent to rgba()
+    Y.DOM[GET_COMPUTED_STYLE] = function(node, att) {
+        var view = node[OWNER_DOCUMENT][DEFAULT_VIEW],
+            val = view[GET_COMPUTED_STYLE](node, '')[att];
+
+        if (val === 'rgba(0, 0, 0, 0)') {
+            val = TRANSPARENT; 
+        }
+
+        return val;
+    };
+
+}
+
+
+/**
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var TO_STRING = 'toString',
+    PARSE_INT = parseInt,
+    RE = RegExp;
+
+Y.Color = {
+    KEYWORDS: {
+        black: '000',
+        silver: 'c0c0c0',
+        gray: '808080',
+        white: 'fff',
+        maroon: '800000',
+        red: 'f00',
+        purple: '800080',
+        fuchsia: 'f0f',
+        green: '008000',
+        lime: '0f0',
+        olive: '808000',
+        yellow: 'ff0',
+        navy: '000080',
+        blue: '00f',
+        teal: '008080',
+        aqua: '0ff'
+    },
+
+    re_RGB: /^rgb\(([0-9]+)\s*,\s*([0-9]+)\s*,\s*([0-9]+)\)$/i,
+    re_hex: /^#?([0-9A-F]{2})([0-9A-F]{2})([0-9A-F]{2})$/i,
+    re_hex3: /([0-9A-F])/gi,
+
+    toRGB: function(val) {
+        if (!Y.Color.re_RGB.test(val)) {
+            val = Y.Color.toHex(val);
+        }
+
+        if(Y.Color.re_hex.exec(val)) {
+            val = 'rgb(' + [
+                PARSE_INT(RE.$1, 16),
+                PARSE_INT(RE.$2, 16),
+                PARSE_INT(RE.$3, 16)
+            ].join(', ') + ')';
+        }
+        return val;
+    },
+
+    toHex: function(val) {
+        val = Y.Color.KEYWORDS[val] || val;
+        if (Y.Color.re_RGB.exec(val)) {
+            var r = (RE.$1.length === 1) ? '0' + RE.$1 : Number(RE.$1),
+                g = (RE.$2.length === 1) ? '0' + RE.$2 : Number(RE.$2),
+                b = (RE.$3.length === 1) ? '0' + RE.$3 : Number(RE.$3);
+
+            val = [
+                r[TO_STRING](16),
+                g[TO_STRING](16),
+                b[TO_STRING](16)
+            ].join('');
+        }
+
+        if (val.length < 6) {
+            val = val.replace(Y.Color.re_hex3, '$1$1');
+        }
+
+        if (val !== 'transparent' && val.indexOf('#') < 0) {
+            val = '#' + val;
+        }
+
+        return val.toLowerCase();
+    }
+};
+
+
+/**
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var CLIENT_TOP = 'clientTop',
+    CLIENT_LEFT = 'clientLeft',
+    PARENT_NODE = 'parentNode',
+    RIGHT = 'right',
+    HAS_LAYOUT = 'hasLayout',
+    PX = 'px',
+    FILTER = 'filter',
+    FILTERS = 'filters',
+    OPACITY = 'opacity',
+    AUTO = 'auto',
+    CURRENT_STYLE = 'currentStyle';
+
+// use alpha filter for IE opacity
+if (document[DOCUMENT_ELEMENT][STYLE][OPACITY] === UNDEFINED &&
+        document[DOCUMENT_ELEMENT][FILTERS]) {
+    Y.DOM.CUSTOM_STYLES[OPACITY] = {
+        get: function(node) {
+            var val = 100;
+            try { // will error if no DXImageTransform
+                val = node[FILTERS]['DXImageTransform.Microsoft.Alpha'][OPACITY];
+
+            } catch(e) {
+                try { // make sure its in the document
+                    val = node[FILTERS]('alpha')[OPACITY];
+                } catch(err) {
+                }
+            }
+            return val / 100;
+        },
+
+        set: function(node, val, style) {
+            if (typeof style[FILTER] == 'string') { // in case not appended
+                style[FILTER] = 'alpha(' + OPACITY + '=' + val * 100 + ')';
+                
+                if (!node[CURRENT_STYLE] || !node[CURRENT_STYLE][HAS_LAYOUT]) {
+                    style.zoom = 1; // needs layout 
+                }
+            }
+        }
+    };
+}
+
+// IE getComputedStyle
+// TODO: unit-less lineHeight (e.g. 1.22)
+var re_size = /^width|height$/,
+    re_unit = /^(\d[.\d]*)+(em|ex|px|gd|rem|vw|vh|vm|ch|mm|cm|in|pt|pc|deg|rad|ms|s|hz|khz|%){1}?/i;
+
+var ComputedStyle = {
+    CUSTOM_STYLES: {},
+
+    get: function(el, property) {
+        var value = '',
+            current = el[CURRENT_STYLE][property];
+
+        if (property === OPACITY) {
+            value = Y.DOM.CUSTOM_STYLES[OPACITY].get(el);        
+        } else if (!current || (current.indexOf && current.indexOf(PX) > -1)) { // no need to convert
+            value = current;
+        } else if (Y.DOM.IE.COMPUTED[property]) { // use compute function
+            value = Y.DOM.IE.COMPUTED[property](el, property);
+        } else if (re_unit.test(current)) { // convert to pixel
+            value = Y.DOM.IE.ComputedStyle.getPixel(el, property);
+        } else {
+            value = current;
+        }
+
+        return value;
+    },
+
+    getOffset: function(el, prop) {
+        var current = el[CURRENT_STYLE][prop],                        // value of "width", "top", etc.
+            capped = prop.charAt(0).toUpperCase() + prop.substr(1), // "Width", "Top", etc.
+            offset = 'offset' + capped,                             // "offsetWidth", "offsetTop", etc.
+            pixel = 'pixel' + capped,                               // "pixelWidth", "pixelTop", etc.
+            value = '';
+
+        if (current == AUTO) {
+            var actual = el[offset]; // offsetHeight/Top etc.
+            if (actual === UNDEFINED) { // likely "right" or "bottom"
+                value = 0;
+            }
+
+            value = actual;
+            if (re_size.test(prop)) { // account for box model diff 
+                el[STYLE][prop] = actual; 
+                if (el[offset] > actual) {
+                    // the difference is padding + border (works in Standards & Quirks modes)
+                    value = actual - (el[offset] - actual);
+                }
+                el[STYLE][prop] = AUTO; // revert to auto
+            }
+        } else { // convert units to px
+            if (!el[STYLE][pixel] && !el[STYLE][prop]) { // need to map style.width to currentStyle (no currentStyle.pixelWidth)
+                el[STYLE][prop] = current;              // no style.pixelWidth if no style.width
+            }
+            value = el[STYLE][pixel];
+        }
+        return value + PX;
+    },
+
+    getBorderWidth: function(el, property) {
+        // clientHeight/Width = paddingBox (e.g. offsetWidth - borderWidth)
+        // clientTop/Left = borderWidth
+        var value = null;
+        if (!el[CURRENT_STYLE][HAS_LAYOUT]) { // TODO: unset layout?
+            el[STYLE].zoom = 1; // need layout to measure client
+        }
+
+        switch(property) {
+            case BORDER_TOP_WIDTH:
+                value = el[CLIENT_TOP];
+                break;
+            case BORDER_BOTTOM_WIDTH:
+                value = el.offsetHeight - el.clientHeight - el[CLIENT_TOP];
+                break;
+            case BORDER_LEFT_WIDTH:
+                value = el[CLIENT_LEFT];
+                break;
+            case BORDER_RIGHT_WIDTH:
+                value = el.offsetWidth - el.clientWidth - el[CLIENT_LEFT];
+                break;
+        }
+        return value + PX;
+    },
+
+    getPixel: function(node, att) {
+        // use pixelRight to convert to px
+        var val = null,
+            styleRight = node[CURRENT_STYLE][RIGHT],
+            current = node[CURRENT_STYLE][att];
+
+        node[STYLE][RIGHT] = current;
+        val = node[STYLE].pixelRight;
+        node[STYLE][RIGHT] = styleRight; // revert
+
+        return val + PX;
+    },
+
+    getMargin: function(node, att) {
+        var val;
+        if (node[CURRENT_STYLE][att] == AUTO) {
+            val = 0 + PX;
+        } else {
+            val = Y.DOM.IE.ComputedStyle.getPixel(node, att);
+        }
+        return val;
+    },
+
+    getVisibility: function(node, att) {
+        var current;
+        while ( (current = node[CURRENT_STYLE]) && current[att] == 'inherit') { // NOTE: assignment in test
+            node = node[PARENT_NODE];
+        }
+        return (current) ? current[att] : VISIBLE;
+    },
+
+    getColor: function(node, att) {
+        var current = node[CURRENT_STYLE][att];
+
+        if (!current || current === TRANSPARENT) {
+            Y.DOM.elementByAxis(node, PARENT_NODE, null, function(parent) {
+                current = parent[CURRENT_STYLE][att];
+                if (current && current !== TRANSPARENT) {
+                    node = parent;
+                    return true;
+                }
+            });
+        }
+
+        return Y.Color.toRGB(current);
+    },
+
+    getBorderColor: function(node, att) {
+        var current = node[CURRENT_STYLE];
+        var val = current[att] || current.color;
+        return Y.Color.toRGB(Y.Color.toHex(val));
+    }
+
+};
+
+//fontSize: getPixelFont,
+var IEComputed = {};
+
+IEComputed[WIDTH] = IEComputed[HEIGHT] = ComputedStyle.getOffset;
+
+IEComputed.color = IEComputed.backgroundColor = ComputedStyle.getColor;
+
+IEComputed[BORDER_TOP_WIDTH] = IEComputed[BORDER_RIGHT_WIDTH] =
+        IEComputed[BORDER_BOTTOM_WIDTH] = IEComputed[BORDER_LEFT_WIDTH] =
+        ComputedStyle.getBorderWidth;
+
+IEComputed.marginTop = IEComputed.marginRight = IEComputed.marginBottom =
+        IEComputed.marginLeft = ComputedStyle.getMargin;
+
+IEComputed.visibility = ComputedStyle.getVisibility;
+IEComputed.borderColor = IEComputed.borderTopColor =
+        IEComputed.borderRightColor = IEComputed.borderBottomColor =
+        IEComputed.borderLeftColor = ComputedStyle.getBorderColor;
+
+if (!Y.config.win[GET_COMPUTED_STYLE]) {
+    Y.DOM[GET_COMPUTED_STYLE] = ComputedStyle.get; 
+}
+
+Y.namespace('DOM.IE');
+Y.DOM.IE.COMPUTED = IEComputed;
+Y.DOM.IE.ComputedStyle = ComputedStyle;
+
+
+
+
+}, '3.0.0pr2' ,{skinnable:false, requires:['dom-base']});

=== added file 'loggerhead/static/javascript/yui/build/dom/dom.js'
--- loggerhead/static/javascript/yui/build/dom/dom.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/dom.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,2154 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('dom', function(Y) {
+
+/** 
+ * The DOM utility provides a cross-browser abtraction layer
+ * normalizing DOM tasks, and adds extra helper functionality
+ * for other common tasks. 
+ * @module dom
+ * @submodule dom-base
+ *
+ */
+
+/** 
+ * Provides DOM helper methods.
+ * @class DOM
+ *
+ */
+var NODE_TYPE = 'nodeType',
+    OWNER_DOCUMENT = 'ownerDocument',
+    DOCUMENT_ELEMENT = 'documentElement',
+    DEFAULT_VIEW = 'defaultView',
+    PARENT_WINDOW = 'parentWindow',
+    TAG_NAME = 'tagName',
+    PARENT_NODE = 'parentNode',
+    FIRST_CHILD = 'firstChild',
+    LAST_CHILD = 'lastChild',
+    PREVIOUS_SIBLING = 'previousSibling',
+    NEXT_SIBLING = 'nextSibling',
+    CONTAINS = 'contains',
+    COMPARE_DOCUMENT_POSITION = 'compareDocumentPosition',
+    INNER_TEXT = 'innerText',
+    TEXT_CONTENT = 'textContent',
+    LENGTH = 'length',
+
+    UNDEFINED = undefined;
+
+var re_tag = /<([a-z]+)/i;
+
+var templateCache = {};
+
+Y.DOM = {
+    /**
+     * Returns the HTMLElement with the given ID (Wrapper for document.getElementById).
+     * @method byId         
+     * @param {String} id the id attribute 
+     * @param {Object} doc optional The document to search. Defaults to current document 
+     * @return {HTMLElement | null} The HTMLElement with the id, or null if none found. 
+     */
+    byId: function(id, doc) {
+        return Y.DOM._getDoc(doc).getElementById(id);
+    },
+
+    /**
+     * Returns the text content of the HTMLElement. 
+     * @method getText         
+     * @param {HTMLElement} element The html element. 
+     * @return {String} The text content of the element (includes text of any descending elements).
+     */
+    getText: function(element) {
+        var text = element ? element[TEXT_CONTENT] : '';
+        if (text === UNDEFINED && INNER_TEXT in element) {
+            text = element[INNER_TEXT];
+        } 
+        return text || '';
+    },
+
+    /**
+     * Finds the firstChild of the given HTMLElement. 
+     * @method firstChild
+     * @param {HTMLElement} element The html element. 
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first found is returned.
+     * @return {HTMLElement | null} The first matching child html element.
+     */
+    firstChild: function(element, fn) {
+        return Y.DOM._childBy(element, null, fn);
+    },
+
+    firstChildByTag: function(element, tag, fn) {
+        return Y.DOM._childBy(element, tag, fn);
+    },
+
+    /**
+     * Finds the lastChild of the given HTMLElement.
+     * @method lastChild
+     * @param {HTMLElement} element The html element.
+     * @param {String} tag The tag to search for.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first found is returned.
+     * @return {HTMLElement | null} The first matching child html element.
+     */
+    lastChild: function(element, fn) {
+        return Y.DOM._childBy(element, null, fn, true);
+    },
+
+    lastChildByTag: function(element, tag, fn) {
+        return Y.DOM._childBy(element, tag, fn, true);
+    },
+
+    /**
+     * Finds all HTMLElement childNodes matching the given tag.
+     * @method childrenByTag
+     * @param {HTMLElement} element The html element.
+     * @param {String} tag The tag to search for.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all children with the given tag are collected.
+     * @return {Array} The collection of child elements.
+     */
+    childrenByTag: function() {
+        if (document[DOCUMENT_ELEMENT].children) {
+            return function(element, tag, fn, toArray) { // TODO: keep toArray option?
+                tag = (tag && tag !== '*') ? tag : null;
+                var elements = [];
+                if (element) {
+                    elements = (tag) ? element.children.tags(tag) : element.children; 
+
+                    if (fn || toArray) {
+                        elements = Y.DOM.filterElementsBy(elements, fn);
+                    }
+                }
+
+                return elements;
+            };
+        } else {
+            return function(element, tag, fn) {
+                tag = (tag && tag !== '*') ? tag.toUpperCase() : null;
+                var elements = [],
+                    wrapFn = fn;
+
+                if (element) {
+                    elements = element.childNodes; 
+                    if (tag) { // wrap fn and add tag test TODO: allow tag in filterElementsBy?
+                        wrapFn = function(el) {
+                            return el[TAG_NAME].toUpperCase() === tag && (!fn || fn(el));
+                        };
+                    }
+
+                    elements = Y.DOM.filterElementsBy(elements, wrapFn);
+                }
+                return elements;
+            };
+        }
+    }(),
+
+    /**
+     * Finds all HTMLElement childNodes.
+     * @method children
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all children are collected.
+     * @return {Array} The collection of child elements.
+     */
+    children: function(element, fn) {
+        return Y.DOM.childrenByTag(element, null, fn);
+    },
+
+    /**
+     * Finds the previous sibling of the element.
+     * @method previous
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the first sibling is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    previous: function(element, fn) {
+        return Y.DOM.elementByAxis(element, PREVIOUS_SIBLING, fn);
+    },
+
+    /**
+     * Finds the next sibling of the element.
+     * @method next
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the first sibling is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    next: function(element, fn) {
+        return Y.DOM.elementByAxis(element, NEXT_SIBLING, fn);
+    },
+
+    /**
+     * Finds the ancestor of the element.
+     * @method ancestor
+     * @param {HTMLElement} element The html element.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current DOM node being tested as its only argument.
+     * If no function is given, the parentNode is returned.
+     * @param {Boolean} all optional Whether all node types should be scanned, or just element nodes.
+     * @return {HTMLElement | null} The matching DOM node or null if none found. 
+     */
+    ancestor: function(element, fn) {
+        return Y.DOM.elementByAxis(element, PARENT_NODE, fn);
+    },
+
+    /**
+     * Searches the element by the given axis for the first matching element.
+     * @method elementByAxis
+     * @param {HTMLElement} element The html element.
+     * @param {String} axis The axis to search (parentNode, nextSibling, previousSibling).
+     * @param {Function} fn optional An optional boolean test to apply.
+     * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first element is returned.
+     * @return {HTMLElement | null} The matching element or null if none found.
+     */
+    elementByAxis: function(element, axis, fn, all) {
+        while (element && (element = element[axis])) { // NOTE: assignment
+                if ( (all || element[TAG_NAME]) && (!fn || fn(element)) ) {
+                    return element;
+                }
+        }
+        return null;
+    },
+
+    /**
+     * Finds all elements with the given tag.
+     * @method byTag
+     * @param {String} tag The tag being search for. 
+     * @param {HTMLElement} root optional An optional root element to start from.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all elements with the given tag are returned.
+     * @return {Array} The collection of matching elements.
+     */
+    byTag: function(tag, root, fn) {
+        root = root || Y.config.doc;
+
+        var elements = root.getElementsByTagName(tag),
+            retNodes = [];
+
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if ( !fn || fn(elements[i]) ) {
+                retNodes[retNodes[LENGTH]] = elements[i];
+            }
+        }
+        return retNodes;
+    },
+
+    /**
+     * Finds the first element with the given tag.
+     * @method firstByTag
+     * @param {String} tag The tag being search for. 
+     * @param {HTMLElement} root optional An optional root element to start from.
+     * @param {Function} fn optional An optional boolean test to apply.
+     * The optional function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, the first match is returned. 
+     * @return {HTMLElement} The matching element.
+     */
+    firstByTag: function(tag, root, fn) {
+        root = root || Y.config.doc;
+
+        var elements = root.getElementsByTagName(tag),
+            ret = null;
+
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if ( !fn || fn(elements[i]) ) {
+                ret = elements[i];
+                break;
+            }
+        }
+        return ret;
+    },
+
+    /**
+     * Filters a collection of HTMLElements by the given attributes.
+     * @method filterElementsBy
+     * @param {Array} elements The collection of HTMLElements to filter.
+     * @param {Function} fn A boolean test to apply.
+     * The function is passed the current HTMLElement being tested as its only argument.
+     * If no function is given, all HTMLElements are kept.
+     * @return {Array} The filtered collection of HTMLElements.
+     */
+    filterElementsBy: function(elements, fn, firstOnly) {
+        var ret = (firstOnly) ? null : [];
+        for (var i = 0, len = elements[LENGTH]; i < len; ++i) {
+            if (elements[i][TAG_NAME] && (!fn || fn(elements[i]))) {
+                if (firstOnly) {
+                    ret = elements[i];
+                    break;
+                } else {
+                    ret[ret[LENGTH]] = elements[i];
+                }
+            }
+        }
+
+        return ret;
+    },
+
+    /**
+     * Determines whether or not one HTMLElement is or contains another HTMLElement.
+     * @method contains
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} needle The html element that may be contained.
+     * @return {Boolean} Whether or not the element is or contains the needle.
+     */
+    contains: function(element, needle) {
+        var ret = false;
+
+        if ( !needle || !element || !needle[NODE_TYPE] || !element[NODE_TYPE]) {
+            ret = false;
+        } else if (element[CONTAINS])  {
+            if (Y.UA.opera || needle[NODE_TYPE] === 1) { // IE & SAF contains fail if needle not an ELEMENT_NODE
+                ret = element[CONTAINS](needle);
+            } else {
+                ret = Y.DOM._bruteContains(element, needle); 
+            }
+        } else if (element[COMPARE_DOCUMENT_POSITION]) { // gecko
+            if (element === needle || !!(element[COMPARE_DOCUMENT_POSITION](needle) & 16)) { 
+                ret = true;
+            }
+        }
+
+        return ret;
+    },
+
+    /**
+     * Determines whether or not the HTMLElement is part of the document.
+     * @method inDoc
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} doc optional The document to check.
+     * @return {Boolean} Whether or not the element is attached to the document. 
+     */
+    inDoc: function(element, doc) {
+        doc = doc || Y.config.doc;
+        return Y.DOM.contains(doc.documentElement, element);
+    },
+
+    create: function(html, doc) {
+        doc = doc || Y.config.doc;
+        var m = re_tag.exec(html);
+        var create = Y.DOM._create,
+            custom = Y.DOM.creators,
+            tag, ret;
+
+        if (m && custom[m[1]]) {
+            if (typeof custom[m[1]] === 'function') {
+                create = custom[m[1]];
+            } else {
+                tag = custom[m[1]];
+            }
+        }
+        ret = create(html, doc, tag);
+        return (ret.childNodes.length > 1) ? ret.childNodes : ret.childNodes[0]; // collection or item
+        //return ret.firstChild;
+    },
+
+    _create: function(html, doc, tag) {
+        tag = tag || 'div';
+        var frag = templateCache[tag] || doc.createElement(tag);
+        frag.innerHTML = Y.Lang.trim(html);
+        return frag;
+    },
+
+    /**
+     * Brute force version of contains.
+     * Used for browsers without contains support for non-HTMLElement Nodes (textNodes, etc).
+     * @method _bruteContains
+     * @private
+     * @param {HTMLElement} element The containing html element.
+     * @param {HTMLElement} needle The html element that may be contained.
+     * @return {Boolean} Whether or not the element is or contains the needle.
+     */
+    _bruteContains: function(element, needle) {
+        while (needle) {
+            if (element === needle) {
+                return true;
+            }
+            needle = needle.parentNode;
+        }
+        return false;
+    },
+
+    /**
+     * Memoizes dynamic regular expressions to boost runtime performance. 
+     * @method _getRegExp
+     * @private
+     * @param {String} str The string to convert to a regular expression.
+     * @param {String} flags optional An optinal string of flags.
+     * @return {RegExp} An instance of RegExp
+     */
+    _getRegExp: function(str, flags) {
+        flags = flags || '';
+        Y.DOM._regexCache = Y.DOM._regexCache || {};
+        if (!Y.DOM._regexCache[str + flags]) {
+            Y.DOM._regexCache[str + flags] = new RegExp(str, flags);
+        }
+        return Y.DOM._regexCache[str + flags];
+    },
+
+    /**
+     * returns the appropriate document.
+     * @method _getDoc
+     * @private
+     * @param {HTMLElement} element optional Target element.
+     * @return {Object} The document for the given element or the default document. 
+     */
+    _getDoc: function(element) {
+        element = element || {};
+        return (element[NODE_TYPE] === 9) ? element : element[OWNER_DOCUMENT] ||
+                                                Y.config.doc;
+    },
+
+    /**
+     * returns the appropriate window.
+     * @method _getWin
+     * @private
+     * @param {HTMLElement} element optional Target element.
+     * @return {Object} The window for the given element or the default window. 
+     */
+    _getWin: function(element) {
+        var doc = Y.DOM._getDoc(element);
+        return (element.document) ? element : doc[DEFAULT_VIEW] ||
+                                        doc[PARENT_WINDOW] || Y.config.win;
+    },
+
+    _childBy: function(element, tag, fn, rev) {
+        var ret = null,
+            root, axis;
+
+        if (element) {
+            if (rev) {
+                root = element[LAST_CHILD];
+                axis = PREVIOUS_SIBLING;
+            } else {
+                root = element[FIRST_CHILD];
+                axis = NEXT_SIBLING;
+            }
+
+            if (Y.DOM._testElement(root, tag, fn)) { // is the matching element
+                ret = root;
+            } else { // need to scan nextSibling axis of firstChild to find matching element
+                ret = Y.DOM.elementByAxis(root, axis, fn);
+            }
+        }
+        return ret;
+
+    },
+
+    _testElement: function(element, tag, fn) {
+        tag = (tag && tag !== '*') ? tag.toUpperCase() : null;
+        return (element && element[TAG_NAME] &&
+                (!tag || element[TAG_NAME].toUpperCase() === tag) &&
+                (!fn || fn(element)));
+    },
+
+    creators: {},
+
+    _IESimpleCreate: function(html, doc) {
+        doc = doc || Y.config.doc;
+        return doc.createElement(html);
+    }
+};
+
+
+(function() {
+    var creators = Y.DOM.creators,
+        create = Y.DOM.create,
+        re_tbody = /(?:\/(?:thead|tfoot|tbody|caption|col|colgroup)>)+\s*<tbody/;
+
+    var TABLE_OPEN = '<table>',
+        TABLE_CLOSE = '</table>';
+
+    if (Y.UA.gecko || Y.UA.ie) { // require custom creation code for certain element types
+        Y.mix(creators, {
+            option: function(html, doc) {
+                var frag = create('<select>' + html + '</select>');
+                return frag;
+            },
+
+            tr: function(html, doc) {
+                var frag = creators.tbody('<tbody>' + html + '</tbody>', doc);
+                return frag.firstChild;
+            },
+
+            td: function(html, doc) {
+                var frag = creators.tr('<tr>' + html + '</tr>', doc);
+                return frag.firstChild;
+            }, 
+
+            tbody: function(html, doc) {
+                var frag = create(TABLE_OPEN + html + TABLE_CLOSE, doc);
+                return frag;
+            },
+
+            legend: 'fieldset'
+        });
+
+        creators.col = creators.tbody; // IE wraps in colgroup
+    }
+
+    if (Y.UA.ie) {
+        // TODO: allow multiples ("<link><link>")
+        creators.col = creators.script = creators.link = Y.DOM._IESimpleCreate; 
+
+        // TODO: thead/tfoot with nested tbody
+        creators.tbody = function(html, doc) {
+            var frag = create(TABLE_OPEN + html + TABLE_CLOSE, doc);
+            var tb = frag.children.tags('tbody')[0];
+            if (frag.children.length > 1 && tb && !re_tbody.test(html)) {
+                tb.parentNode.removeChild(tb);
+            }
+            return frag;
+        };
+
+    }
+
+    if (Y.UA.gecko || Y.UA.ie) { // require custom creation code for certain element types
+        Y.mix(creators, {
+                th: creators.td,
+                thead: creators.tbody,
+                tfoot: creators.tbody,
+                caption: creators.tbody,
+                colgroup: creators.tbody,
+                col: creators.tbody,
+                optgroup: creators.option
+        });
+    }
+})();
+
+/** 
+ * The DOM utility provides a cross-browser abtraction layer
+ * normalizing DOM tasks, and adds extra helper functionality
+ * for other common tasks. 
+ * @module dom
+ * @submodule dom-base
+ * @for DOM
+ */
+
+var CLASS_NAME = 'className';
+
+Y.mix(Y.DOM, {
+    /**
+     * Determines whether a DOM element has the given className.
+     * @method hasClass
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to search for
+     * @return {Boolean} Whether or not the element has the given class. 
+     */
+    hasClass: function(node, className) {
+        var re = Y.DOM._getRegExp('(?:^|\\s+)' + className + '(?:\\s+|$)');
+        return re.test(node[CLASS_NAME]);
+    },
+
+    /**
+     * Adds a class name to a given DOM element.
+     * @method addClass         
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to add to the class attribute
+     */
+    addClass: function(node, className) {
+        if (!Y.DOM.hasClass(node, className)) { // skip if already present 
+            node[CLASS_NAME] = Y.Lang.trim([node[CLASS_NAME], className].join(' '));
+        }
+    },
+
+    /**
+     * Removes a class name from a given element.
+     * @method removeClass         
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to remove from the class attribute
+     */
+    removeClass: function(node, className) {
+        if (className && Y.DOM.hasClass(node, className)) {
+            node[CLASS_NAME] = Y.Lang.trim(node[CLASS_NAME].replace(Y.DOM._getRegExp('(?:^|\\s+)' +
+                            className + '(?:\\s+|$)'), ' '));
+
+            if ( Y.DOM.hasClass(node, className) ) { // in case of multiple adjacent
+                Y.DOM.removeClass(node, className);
+            }
+        }                 
+    },
+
+    /**
+     * Replace a class with another class for a given element.
+     * If no oldClassName is present, the newClassName is simply added.
+     * @method replaceClass  
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} oldClassName the class name to be replaced
+     * @param {String} newClassName the class name that will be replacing the old class name
+     */
+    replaceClass: function(node, oldC, newC) {
+        Y.DOM.addClass(node, newC);
+        Y.DOM.removeClass(node, oldC);
+    },
+
+    /**
+     * If the className exists on the node it is removed, if it doesn't exist it is added.
+     * @method toggleClass  
+     * @param {HTMLElement} element The DOM element. 
+     * @param {String} className the class name to be toggled
+     */
+    toggleClass: function(node, className) {
+        if (Y.DOM.hasClass(node, className)) {
+            Y.DOM.removeClass(node, className);
+        } else {
+            Y.DOM.addClass(node, className);
+        }
+    }
+});
+
+
+/** 
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var DOCUMENT_ELEMENT = 'documentElement',
+    DEFAULT_VIEW = 'defaultView',
+    OWNER_DOCUMENT = 'ownerDocument',
+    STYLE = 'style',
+    FLOAT = 'float',
+    CSS_FLOAT = 'cssFloat',
+    STYLE_FLOAT = 'styleFloat',
+    TRANSPARENT = 'transparent',
+    VISIBLE = 'visible',
+    WIDTH = 'width',
+    HEIGHT = 'height',
+    BORDER_TOP_WIDTH = 'borderTopWidth',
+    BORDER_RIGHT_WIDTH = 'borderRightWidth',
+    BORDER_BOTTOM_WIDTH = 'borderBottomWidth',
+    BORDER_LEFT_WIDTH = 'borderLeftWidth',
+    GET_COMPUTED_STYLE = 'getComputedStyle',
+
+    DOCUMENT = Y.config.doc,
+    UNDEFINED = undefined,
+
+    re_color = /color$/i;
+
+
+Y.mix(Y.DOM, {
+    CUSTOM_STYLES: {},
+
+
+    /**
+     * Sets a style property for a given element.
+     * @method setStyle
+     * @param {HTMLElement} An HTMLElement to apply the style to.
+     * @param {String} att The style property to set. 
+     * @param {String|Number} val The value. 
+     */
+    setStyle: function(node, att, val, style) {
+        style = node[STYLE],
+            CUSTOM_STYLES = Y.DOM.CUSTOM_STYLES;
+
+        if (style) {
+            if (att in CUSTOM_STYLES) {
+                if (CUSTOM_STYLES[att].set) {
+                    CUSTOM_STYLES[att].set(node, val, style);
+                    return; // NOTE: return
+                } else if (typeof CUSTOM_STYLES[att] === 'string') {
+                    att = CUSTOM_STYLES[att];
+                }
+            }
+            style[att] = val; 
+        }
+    },
+
+    /**
+     * Returns the current style value for the given property.
+     * @method getStyle
+     * @param {HTMLElement} An HTMLElement to get the style from.
+     * @param {String} att The style property to get. 
+     */
+    getStyle: function(node, att) {
+        var style = node[STYLE],
+            CUSTOM_STYLES = Y.DOM.CUSTOM_STYLES,
+            val = '';
+
+        if (style) {
+            if (att in CUSTOM_STYLES) {
+                if (CUSTOM_STYLES[att].get) {
+                    return CUSTOM_STYLES[att].get(node, att, style); // NOTE: return
+                } else if (typeof CUSTOM_STYLES[att] === 'string') {
+                    att = CUSTOM_STYLES[att];
+                }
+            }
+            val = style[att];
+            if (val === '') { // TODO: is empty string sufficient?
+                val = Y.DOM[GET_COMPUTED_STYLE](node, att);
+            }
+        }
+
+        return val;
+    },
+
+    /**
+     * Sets multiple style properties.
+     * @method setStyles
+     * @param {HTMLElement} node An HTMLElement to apply the styles to. 
+     * @param {Object} hash An object literal of property:value pairs. 
+     */
+    'setStyles': function(node, hash) {
+        Y.each(hash, function(v, n) {
+            Y.DOM.setStyle(node, n, v);
+        }, Y.DOM);
+    },
+
+    /**
+     * Returns the computed style for the given node.
+     * @method getComputedStyle
+     * @param {HTMLElement} An HTMLElement to get the style from.
+     * @param {String} att The style property to get. 
+     * @return {String} The computed value of the style property. 
+     */
+    getComputedStyle: function(node, att) {
+        var val = '',
+            doc = node[OWNER_DOCUMENT];
+
+        if (node[STYLE]) {
+            val = doc[DEFAULT_VIEW][GET_COMPUTED_STYLE](node, '')[att];
+        }
+        return val;
+    }
+});
+
+if (DOCUMENT[DOCUMENT_ELEMENT][STYLE][CSS_FLOAT] !== UNDEFINED) {
+    Y.DOM.CUSTOM_STYLES[FLOAT] = CSS_FLOAT;
+} else if (DOCUMENT[DOCUMENT_ELEMENT][STYLE][STYLE_FLOAT] !== UNDEFINED) {
+    Y.DOM.CUSTOM_STYLES[FLOAT] = STYLE_FLOAT;
+}
+
+if (Y.UA.opera) { // opera defaults to hex instead of RGB
+    Y.DOM[GET_COMPUTED_STYLE] = function(node, att) {
+        var view = node[OWNER_DOCUMENT][DEFAULT_VIEW],
+            val = view[GET_COMPUTED_STYLE](node, '')[att];
+
+        if (re_color.test(att)) {
+            val = Y.Color.toRGB(val);
+        }
+
+        return val;
+    };
+
+}
+
+if (Y.UA.webkit) { // safari converts transparent to rgba()
+    Y.DOM[GET_COMPUTED_STYLE] = function(node, att) {
+        var view = node[OWNER_DOCUMENT][DEFAULT_VIEW],
+            val = view[GET_COMPUTED_STYLE](node, '')[att];
+
+        if (val === 'rgba(0, 0, 0, 0)') {
+            val = TRANSPARENT; 
+        }
+
+        return val;
+    };
+
+}
+
+
+
+/**
+ * Adds position and region management functionality to DOM.
+ * @module dom
+ * @submodule dom-screen
+ * @for DOM
+ */
+
+var OFFSET_TOP = 'offsetTop',
+
+    DOCUMENT_ELEMENT = 'documentElement',
+    COMPAT_MODE = 'compatMode',
+    OFFSET_LEFT = 'offsetLeft',
+    OFFSET_PARENT = 'offsetParent',
+    POSITION = 'position',
+    FIXED = 'fixed',
+    RELATIVE = 'relative',
+    LEFT = 'left',
+    TOP = 'top',
+    SCROLL_LEFT = 'scrollLeft',
+    SCROLL_TOP = 'scrollTop',
+    _BACK_COMPAT = 'BackCompat',
+    MEDIUM = 'medium',
+    HEIGHT = 'height',
+    WIDTH = 'width',
+    BORDER_LEFT_WIDTH = 'borderLeftWidth',
+    BORDER_TOP_WIDTH = 'borderTopWidth',
+    GET_BOUNDING_CLIENT_RECT = 'getBoundingClientRect',
+    GET_COMPUTED_STYLE = 'getComputedStyle',
+    RE_TABLE = /^t(?:able|d|h)$/i;
+
+Y.mix(Y.DOM, {
+
+
+    /**
+     * Returns the inner height of the viewport (exludes scrollbar). 
+     * @method winHeight
+
+     */
+    winHeight: function(node) {
+        var h = Y.DOM._getWinSize(node)[HEIGHT];
+        return h;
+    },
+
+    /**
+     * Returns the inner width of the viewport (exludes scrollbar). 
+     * @method winWidth
+
+     */
+    winWidth: function(node) {
+        var w = Y.DOM._getWinSize(node)[WIDTH];
+        return w;
+    },
+
+    /**
+     * Document height 
+     * @method docHeight
+
+     */
+    docHeight:  function(node) {
+        var h = Y.DOM._getDocSize(node)[HEIGHT];
+        return Math.max(h, Y.DOM._getWinSize(node)[HEIGHT]);
+    },
+
+    /**
+     * Document width 
+     * @method docWidth
+
+     */
+    docWidth:  function(node) {
+        var w = Y.DOM._getDocSize(node)[WIDTH];
+        return Math.max(w, Y.DOM._getWinSize(node)[WIDTH]);
+    },
+
+    /**
+     * Amount page has been scroll vertically 
+     * @method docScrollX
+
+     */
+    docScrollX: function(node) {
+        var doc = Y.DOM._getDoc();
+        return Math.max(doc[DOCUMENT_ELEMENT][SCROLL_LEFT], doc.body[SCROLL_LEFT]);
+    },
+
+    /**
+     * Amount page has been scroll horizontally 
+     * @method docScrollY
+
+     */
+    docScrollY:  function(node) {
+        var doc = Y.DOM._getDoc();
+        return Math.max(doc[DOCUMENT_ELEMENT][SCROLL_TOP], doc.body[SCROLL_TOP]);
+    },
+
+    /**
+     * Gets the current position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getXY
+     * @param element The target element
+     * @return {Array} The XY position of the element
+
+     TODO: test inDocument/display
+     */
+    getXY: function() {
+
+
+
+
+        if (document[DOCUMENT_ELEMENT][GET_BOUNDING_CLIENT_RECT]) {
+            return function(node) {
+                if (!node) {
+                    return false;
+                }
+                var scrollLeft = Y.DOM.docScrollX(node),
+                    scrollTop = Y.DOM.docScrollY(node),
+                    box = node[GET_BOUNDING_CLIENT_RECT](),
+                    doc = Y.DOM._getDoc(node),
+                    //Round the numbers so we get sane data back
+                    xy = [Math.floor(box[LEFT]), Math.floor(box[TOP])];
+
+                    if (Y.UA.ie) {
+                        var off1 = 2, off2 = 2,
+                        mode = doc[COMPAT_MODE],
+                        bLeft = Y.DOM[GET_COMPUTED_STYLE](doc[DOCUMENT_ELEMENT], BORDER_LEFT_WIDTH),
+                        bTop = Y.DOM[GET_COMPUTED_STYLE](doc[DOCUMENT_ELEMENT], BORDER_TOP_WIDTH);
+
+                        if (Y.UA.ie === 6) {
+                            if (mode !== _BACK_COMPAT) {
+                                off1 = 0;
+                                off2 = 0;
+                            }
+                        }
+                        
+                        if ((mode == _BACK_COMPAT)) {
+                            if (bLeft !== MEDIUM) {
+                                off1 = parseInt(bLeft, 10);
+                            }
+                            if (bTop !== MEDIUM) {
+                                off2 = parseInt(bTop, 10);
+                            }
+
+
+
+                        }
+                        
+                        xy[0] -= off1;
+                        xy[1] -= off2;
+
+                    }
+
+                if ((scrollTop || scrollLeft)) {
+                    xy[0] += scrollLeft;
+                    xy[1] += scrollTop;
+                }
+
+                // gecko may return sub-pixel (non-int) values
+                xy[0] = Math.floor(xy[0]);
+                xy[1] = Math.floor(xy[1]);
+
+                return xy;                   
+            };
+        } else {
+            return function(node) { // manually calculate by crawling up offsetParents
+                //Calculate the Top and Left border sizes (assumes pixels)
+                var xy = [node[OFFSET_LEFT], node[OFFSET_TOP]],
+                    parentNode = node,
+                    bCheck = ((Y.UA.gecko || (Y.UA.webkit > 519)) ? true : false);
+
+                while ((parentNode = parentNode[OFFSET_PARENT])) {
+                    xy[0] += parentNode[OFFSET_LEFT];
+                    xy[1] += parentNode[OFFSET_TOP];
+                    if (bCheck) {
+                        xy = Y.DOM._calcBorders(parentNode, xy);
+                    }
+                }
+
+                // account for any scrolled ancestors
+                if (Y.DOM.getStyle(node, POSITION) != FIXED) {
+                    parentNode = node;
+                    var scrollTop, scrollLeft;
+
+                    while ((parentNode = parentNode.parentNode)) {
+                        scrollTop = parentNode[SCROLL_TOP];
+                        scrollLeft = parentNode[SCROLL_LEFT];
+
+                        //Firefox does something funky with borders when overflow is not visible.
+                        if (Y.UA.gecko && (Y.DOM.getStyle(parentNode, 'overflow') !== 'visible')) {
+                                xy = Y.DOM._calcBorders(parentNode, xy);
+                        }
+                        
+
+                        if (scrollTop || scrollLeft) {
+                            xy[0] -= scrollLeft;
+                            xy[1] -= scrollTop;
+                        }
+                    }
+                    xy[0] += Y.DOM.docScrollX(node);
+                    xy[1] += Y.DOM.docScrollY(node);
+
+                } else {
+                    //Fix FIXED position -- add scrollbars
+                    if (Y.UA.opera) {
+                        xy[0] -= Y.DOM.docScrollX(node);
+                        xy[1] -= Y.DOM.docScrollY(node);
+                    } else if (Y.UA.webkit || Y.UA.gecko) {
+                        xy[0] += Y.DOM.docScrollX(node);
+                        xy[1] += Y.DOM.docScrollY(node);
+                    }
+                }
+                //Round the numbers so we get sane data back
+                xy[0] = Math.floor(xy[0]);
+                xy[1] = Math.floor(xy[1]);
+
+                return xy;                
+            };
+        }
+    }(),// NOTE: Executing for loadtime branching
+
+    /**
+     * Gets the current X position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getX
+     * @param element The target element
+     * @return {Int} The X position of the element
+     */
+
+    getX: function(node) {
+        return Y.DOM.getXY(node)[0];
+    },
+
+    /**
+     * Gets the current Y position of an element based on page coordinates. 
+     * Element must be part of the DOM tree to have page coordinates
+     * (display:none or elements not appended return false).
+     * @method getY
+     * @param element The target element
+     * @return {Int} The Y position of the element
+     */
+
+    getY: function(node) {
+        return Y.DOM.getXY(node)[1];
+    },
+
+    /**
+     * Set the position of an html element in page coordinates.
+     * The element must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setXY
+     * @param element The target element
+     * @param {Array} xy Contains X & Y values for new position (coordinates are page-based)
+     * @param {Boolean} noRetry By default we try and set the position a second time if the first fails
+     */
+    setXY: function(node, xy, noRetry) {
+        var pos = Y.DOM.getStyle(node, POSITION),
+            setStyle = Y.DOM.setStyle,
+
+            delta = [ // assuming pixels; if not we will have to retry
+                parseInt( Y.DOM[GET_COMPUTED_STYLE](node, LEFT), 10 ),
+                parseInt( Y.DOM[GET_COMPUTED_STYLE](node, TOP), 10 )
+            ];
+    
+        if (pos == 'static') { // default to relative
+            pos = RELATIVE;
+            setStyle(node, POSITION, pos);
+        }
+
+        var currentXY = Y.DOM.getXY(node);
+
+
+
+
+        if (currentXY === false) { // has to be part of doc to have xy
+
+
+
+
+
+            return false; 
+        }
+        
+        if ( isNaN(delta[0]) ) {// in case of 'auto'
+            delta[0] = (pos == RELATIVE) ? 0 : node[OFFSET_LEFT];
+        } 
+        if ( isNaN(delta[1]) ) { // in case of 'auto'
+            delta[1] = (pos == RELATIVE) ? 0 : node[OFFSET_TOP];
+        } 
+
+        if (xy[0] !== null) {
+            setStyle(node, LEFT, xy[0] - currentXY[0] + delta[0] + 'px');
+        }
+
+        if (xy[1] !== null) {
+            setStyle(node, TOP, xy[1] - currentXY[1] + delta[1] + 'px');
+        }
+      
+        if (!noRetry) {
+            var newXY = Y.DOM.getXY(node);
+
+            // if retry is true, try one more time if we miss 
+           if ( (xy[0] !== null && newXY[0] != xy[0]) || 
+                (xy[1] !== null && newXY[1] != xy[1]) ) {
+               Y.DOM.setXY(node, xy, true);
+           }
+        }        
+
+    },
+
+    /**
+     * Set the X position of an html element in page coordinates, regardless of how the element is positioned.
+     * The element(s) must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setX
+     * @param element The target element
+     * @param {Int} x The X values for new position (coordinates are page-based)
+     */
+    setX: function(node, x) {
+        return Y.DOM.setXY(node, [x, null]);
+    },
+
+    /**
+     * Set the Y position of an html element in page coordinates, regardless of how the element is positioned.
+     * The element(s) must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setY
+     * @param element The target element
+     * @param {Int} y The Y values for new position (coordinates are page-based)
+     */
+    setY: function(node, y) {
+        return Y.DOM.setXY(node, [null, y]);
+    },
+
+    _calcBorders: function(node, xy2) {
+        var t = parseInt(Y.DOM[GET_COMPUTED_STYLE](node, BORDER_TOP_WIDTH), 10) || 0,
+            l = parseInt(Y.DOM[GET_COMPUTED_STYLE](node, BORDER_LEFT_WIDTH), 10) || 0;
+        if (Y.UA.gecko) {
+            if (RE_TABLE.test(node.tagName)) {
+                t = 0;
+                l = 0;
+            }
+        }
+        xy2[0] += l;
+        xy2[1] += t;
+        return xy2;
+    },
+
+    _getWinSize: function(node) {
+        var doc = Y.DOM._getDoc(),
+            win = doc.defaultView || doc.parentWindow,
+            mode = doc[COMPAT_MODE],
+            h = win.innerHeight,
+            w = win.innerWidth,
+            root = doc[DOCUMENT_ELEMENT];
+
+        if ( mode && !Y.UA.opera ) { // IE, Gecko
+            if (mode != 'CSS1Compat') { // Quirks
+                root = doc.body; 
+            }
+            h = root.clientHeight;
+            w = root.clientWidth;
+        }
+        return { height: h, width: w }; 
+    },
+
+    _getDocSize: function(node) {
+        var doc = Y.DOM._getDoc(),
+            root = doc[DOCUMENT_ELEMENT];
+
+        if (doc[COMPAT_MODE] != 'CSS1Compat') {
+            root = doc.body;
+        }
+
+        return { height: root.scrollHeight, width: root.scrollWidth };
+    }
+});
+
+
+
+/**
+ * Adds position and region management functionality to DOM.
+ * @module dom
+ * @submodule dom-screen
+ * @for DOM
+ */
+
+var OFFSET_WIDTH = 'offsetWidth',
+    OFFSET_HEIGHT = 'offsetHeight',
+    TOP = 'top',
+    RIGHT = 'right',
+    BOTTOM = 'bottom',
+    LEFT = 'left',
+    TAG_NAME = 'tagName';
+
+var getOffsets = function(r1, r2) {
+    var t = Math.max(r1[TOP], r2[TOP]),
+        r = Math.min(r1[RIGHT], r2[RIGHT]),
+        b = Math.min(r1[BOTTOM], r2[BOTTOM]),
+        l = Math.max(r1[LEFT], r2[LEFT]),
+        ret = {};
+    
+    ret[TOP] = t;
+    ret[RIGHT] = r;
+    ret[BOTTOM] = b;
+    ret[LEFT] = l;
+    return ret;
+};
+
+var DOM = DOM || Y.DOM;
+Y.mix(DOM, {
+    /**
+     * Returns an Object literal containing the following about this element: (top, right, bottom, left)
+     * @method region
+     * @param {HTMLElement} element The DOM element. 
+     @return {Object} Object literal containing the following about this element: (top, right, bottom, left)
+     */
+    region: function(node) {
+        var x = DOM.getXY(node),
+            ret = false;
+        
+        if (x) {
+            ret = {
+                '0': x[0],
+                '1': x[1],
+                top: x[1],
+                right: x[0] + node[OFFSET_WIDTH],
+                bottom: x[1] + node[OFFSET_HEIGHT],
+                left: x[0],
+                height: node[OFFSET_HEIGHT],
+                width: node[OFFSET_WIDTH]
+            };
+        }
+
+        return ret;
+    },
+
+    /**
+     * Find the intersect information for the passes nodes.
+     * @method intersect
+     * @param {HTMLElement} element The first element 
+     * @param {HTMLElement | Object} element2 The element or region to check the interect with
+     * @param {Object} altRegion An object literal containing the region for the first element if we already have the data (for performance i.e. DragDrop)
+     @return {Object} Object literal containing the following intersection data: (top, right, bottom, left, area, yoff, xoff, inRegion)
+     */
+    intersect: function(node, node2, altRegion) {
+        var r = altRegion || DOM.region(node), region = {};
+
+        var n = node2;
+        if (n[TAG_NAME]) {
+            region = DOM.region(n);
+        } else if (Y.Lang.isObject(node2)) {
+            region = node2;
+        } else {
+            return false;
+        }
+        
+        var off = getOffsets(region, r);
+        return {
+            top: off[TOP],
+            right: off[RIGHT],
+            bottom: off[BOTTOM],
+            left: off[LEFT],
+            area: ((off[BOTTOM] - off[TOP]) * (off[RIGHT] - off[LEFT])),
+            yoff: ((off[BOTTOM] - off[TOP])),
+            xoff: (off[RIGHT] - off[LEFT]),
+            inRegion: DOM.inRegion(node, node2, false, altRegion)
+        };
+        
+    },
+    /**
+     * Check if any part of this node is in the passed region
+     * @method inRegion
+     * @param {Object} node2 The node to get the region from or an Object literal of the region
+     * $param {Boolean} all Should all of the node be inside the region
+     * @param {Object} altRegion An object literal containing the region for this node if we already have the data (for performance i.e. DragDrop)
+     * @return {Boolean} True if in region, false if not.
+     */
+    inRegion: function(node, node2, all, altRegion) {
+        var region = {},
+            r = altRegion || DOM.region(node);
+
+        var n = node2;
+        if (n[TAG_NAME]) {
+            region = DOM.region(n);
+        } else if (Y.Lang.isObject(node2)) {
+            region = node2;
+        } else {
+            return false;
+        }
+            
+        if (all) {
+            return (
+                r[LEFT]   >= region[LEFT]   &&
+                r[RIGHT]  <= region[RIGHT]  && 
+                r[TOP]    >= region[TOP]    && 
+                r[BOTTOM] <= region[BOTTOM]  );
+        } else {
+            var off = getOffsets(region, r);
+            if (off[BOTTOM] >= off[TOP] && off[RIGHT] >= off[LEFT]) {
+                return true;
+            } else {
+                return false;
+            }
+            
+        }
+    },
+
+    /**
+     * Check if any part of this element is in the viewport
+     * @method inViewportRegion
+     * @param {HTMLElement} element The DOM element. 
+     * @param {Boolean} all Should all of the node be inside the region
+     * @param {Object} altRegion An object literal containing the region for this node if we already have the data (for performance i.e. DragDrop)
+     * @return {Boolean} True if in region, false if not.
+     */
+    inViewportRegion: function(node, all, altRegion) {
+        return DOM.inRegion(node, DOM.viewportRegion(node), all, altRegion);
+            
+    },
+
+    /**
+     * Returns an Object literal containing the following about the visible region of viewport: (top, right, bottom, left)
+     * @method viewportRegion
+     @return {Object} Object literal containing the following about the visible region of the viewport: (top, right, bottom, left)
+     */
+    viewportRegion: function(node) {
+        node = node || Y.config.doc.documentElement;
+        var r = {};
+        r[TOP] = DOM.docScrollY(node);
+        r[RIGHT] = DOM.winWidth(node) + DOM.docScrollX(node);
+        r[BOTTOM] = (DOM.docScrollY(node) + DOM.winHeight(node));
+        r[LEFT] = DOM.docScrollX(node);
+
+        return r;
+    }
+});
+
+/**
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var CLIENT_TOP = 'clientTop',
+    CLIENT_LEFT = 'clientLeft',
+    PARENT_NODE = 'parentNode',
+    RIGHT = 'right',
+    HAS_LAYOUT = 'hasLayout',
+    PX = 'px',
+    FILTER = 'filter',
+    FILTERS = 'filters',
+    OPACITY = 'opacity',
+    AUTO = 'auto',
+    CURRENT_STYLE = 'currentStyle';
+
+// use alpha filter for IE opacity
+if (document[DOCUMENT_ELEMENT][STYLE][OPACITY] === UNDEFINED &&
+        document[DOCUMENT_ELEMENT][FILTERS]) {
+    Y.DOM.CUSTOM_STYLES[OPACITY] = {
+        get: function(node) {
+            var val = 100;
+            try { // will error if no DXImageTransform
+                val = node[FILTERS]['DXImageTransform.Microsoft.Alpha'][OPACITY];
+
+            } catch(e) {
+                try { // make sure its in the document
+                    val = node[FILTERS]('alpha')[OPACITY];
+                } catch(err) {
+                }
+            }
+            return val / 100;
+        },
+
+        set: function(node, val, style) {
+            if (typeof style[FILTER] == 'string') { // in case not appended
+                style[FILTER] = 'alpha(' + OPACITY + '=' + val * 100 + ')';
+                
+                if (!node[CURRENT_STYLE] || !node[CURRENT_STYLE][HAS_LAYOUT]) {
+                    style.zoom = 1; // needs layout 
+                }
+            }
+        }
+    };
+}
+
+// IE getComputedStyle
+// TODO: unit-less lineHeight (e.g. 1.22)
+var re_size = /^width|height$/,
+    re_unit = /^(\d[.\d]*)+(em|ex|px|gd|rem|vw|vh|vm|ch|mm|cm|in|pt|pc|deg|rad|ms|s|hz|khz|%){1}?/i;
+
+var ComputedStyle = {
+    CUSTOM_STYLES: {},
+
+    get: function(el, property) {
+        var value = '',
+            current = el[CURRENT_STYLE][property];
+
+        if (property === OPACITY) {
+            value = Y.DOM.CUSTOM_STYLES[OPACITY].get(el);        
+        } else if (!current || (current.indexOf && current.indexOf(PX) > -1)) { // no need to convert
+            value = current;
+        } else if (Y.DOM.IE.COMPUTED[property]) { // use compute function
+            value = Y.DOM.IE.COMPUTED[property](el, property);
+        } else if (re_unit.test(current)) { // convert to pixel
+            value = Y.DOM.IE.ComputedStyle.getPixel(el, property);
+        } else {
+            value = current;
+        }
+
+        return value;
+    },
+
+    getOffset: function(el, prop) {
+        var current = el[CURRENT_STYLE][prop],                        // value of "width", "top", etc.
+            capped = prop.charAt(0).toUpperCase() + prop.substr(1), // "Width", "Top", etc.
+            offset = 'offset' + capped,                             // "offsetWidth", "offsetTop", etc.
+            pixel = 'pixel' + capped,                               // "pixelWidth", "pixelTop", etc.
+            value = '';
+
+        if (current == AUTO) {
+            var actual = el[offset]; // offsetHeight/Top etc.
+            if (actual === UNDEFINED) { // likely "right" or "bottom"
+                value = 0;
+            }
+
+            value = actual;
+            if (re_size.test(prop)) { // account for box model diff 
+                el[STYLE][prop] = actual; 
+                if (el[offset] > actual) {
+                    // the difference is padding + border (works in Standards & Quirks modes)
+                    value = actual - (el[offset] - actual);
+                }
+                el[STYLE][prop] = AUTO; // revert to auto
+            }
+        } else { // convert units to px
+            if (!el[STYLE][pixel] && !el[STYLE][prop]) { // need to map style.width to currentStyle (no currentStyle.pixelWidth)
+                el[STYLE][prop] = current;              // no style.pixelWidth if no style.width
+            }
+            value = el[STYLE][pixel];
+        }
+        return value + PX;
+    },
+
+    getBorderWidth: function(el, property) {
+        // clientHeight/Width = paddingBox (e.g. offsetWidth - borderWidth)
+        // clientTop/Left = borderWidth
+        var value = null;
+        if (!el[CURRENT_STYLE][HAS_LAYOUT]) { // TODO: unset layout?
+            el[STYLE].zoom = 1; // need layout to measure client
+        }
+
+        switch(property) {
+            case BORDER_TOP_WIDTH:
+                value = el[CLIENT_TOP];
+                break;
+            case BORDER_BOTTOM_WIDTH:
+                value = el.offsetHeight - el.clientHeight - el[CLIENT_TOP];
+                break;
+            case BORDER_LEFT_WIDTH:
+                value = el[CLIENT_LEFT];
+                break;
+            case BORDER_RIGHT_WIDTH:
+                value = el.offsetWidth - el.clientWidth - el[CLIENT_LEFT];
+                break;
+        }
+        return value + PX;
+    },
+
+    getPixel: function(node, att) {
+        // use pixelRight to convert to px
+        var val = null,
+            styleRight = node[CURRENT_STYLE][RIGHT],
+            current = node[CURRENT_STYLE][att];
+
+        node[STYLE][RIGHT] = current;
+        val = node[STYLE].pixelRight;
+        node[STYLE][RIGHT] = styleRight; // revert
+
+        return val + PX;
+    },
+
+    getMargin: function(node, att) {
+        var val;
+        if (node[CURRENT_STYLE][att] == AUTO) {
+            val = 0 + PX;
+        } else {
+            val = Y.DOM.IE.ComputedStyle.getPixel(node, att);
+        }
+        return val;
+    },
+
+    getVisibility: function(node, att) {
+        var current;
+        while ( (current = node[CURRENT_STYLE]) && current[att] == 'inherit') { // NOTE: assignment in test
+            node = node[PARENT_NODE];
+        }
+        return (current) ? current[att] : VISIBLE;
+    },
+
+    getColor: function(node, att) {
+        var current = node[CURRENT_STYLE][att];
+
+        if (!current || current === TRANSPARENT) {
+            Y.DOM.elementByAxis(node, PARENT_NODE, null, function(parent) {
+                current = parent[CURRENT_STYLE][att];
+                if (current && current !== TRANSPARENT) {
+                    node = parent;
+                    return true;
+                }
+            });
+        }
+
+        return Y.Color.toRGB(current);
+    },
+
+    getBorderColor: function(node, att) {
+        var current = node[CURRENT_STYLE];
+        var val = current[att] || current.color;
+        return Y.Color.toRGB(Y.Color.toHex(val));
+    }
+
+};
+
+//fontSize: getPixelFont,
+var IEComputed = {};
+
+IEComputed[WIDTH] = IEComputed[HEIGHT] = ComputedStyle.getOffset;
+
+IEComputed.color = IEComputed.backgroundColor = ComputedStyle.getColor;
+
+IEComputed[BORDER_TOP_WIDTH] = IEComputed[BORDER_RIGHT_WIDTH] =
+        IEComputed[BORDER_BOTTOM_WIDTH] = IEComputed[BORDER_LEFT_WIDTH] =
+        ComputedStyle.getBorderWidth;
+
+IEComputed.marginTop = IEComputed.marginRight = IEComputed.marginBottom =
+        IEComputed.marginLeft = ComputedStyle.getMargin;
+
+IEComputed.visibility = ComputedStyle.getVisibility;
+IEComputed.borderColor = IEComputed.borderTopColor =
+        IEComputed.borderRightColor = IEComputed.borderBottomColor =
+        IEComputed.borderLeftColor = ComputedStyle.getBorderColor;
+
+if (!Y.config.win[GET_COMPUTED_STYLE]) {
+    Y.DOM[GET_COMPUTED_STYLE] = ComputedStyle.get; 
+}
+
+Y.namespace('DOM.IE');
+Y.DOM.IE.COMPUTED = IEComputed;
+Y.DOM.IE.ComputedStyle = ComputedStyle;
+
+
+/**
+ * Provides helper methods for collecting and filtering DOM elements.
+ * @module dom
+ * @submodule selector
+ */
+
+/**
+ * Provides helper methods for collecting and filtering DOM elements.
+ * @class Selector
+ * @static
+ */
+
+var TAG = 'tag',
+    PARENT_NODE = 'parentNode',
+    PREVIOUS_SIBLING = 'previousSibling',
+    LENGTH = 'length',
+    NODE_TYPE = 'nodeType',
+    TAG_NAME = 'tagName',
+    ATTRIBUTES = 'attributes',
+    PSEUDOS = 'pseudos',
+    COMBINATOR = 'combinator';
+
+var reNth = /^(?:([\-]?\d*)(n){1}|(odd|even)$)*([\-+]?\d*)$/;
+
+var patterns = {
+    tag: /^((?:-?[_a-z]+[\w\-]*)|\*)/i,
+    attributes: /^\[([a-z]+\w*)+([~\|\^\$\*!=]=?)?['"]?([^\]]*?)['"]?\]/i,
+    pseudos: /^:([\-\w]+)(?:\(['"]?(.+)['"]?\))*/i,
+    combinator: /^\s*([>+~]|\s)\s*/
+};
+
+var Selector = {
+    /**
+     * Default document for use queries 
+     * @property document
+     * @type object
+     * @default window.document
+     */
+    document: Y.config.doc,
+    /**
+     * Mapping of attributes to aliases, normally to work around HTMLAttributes
+     * that conflict with JS reserved words.
+     * @property attrAliases
+     * @type object
+     */
+    attrAliases: {},
+
+    /**
+     * Mapping of shorthand tokens to corresponding attribute selector 
+     * @property shorthand
+     * @type object
+     */
+    shorthand: {
+        '\\#(-?[_a-z]+[-\\w]*)': '[id=$1]',
+        '\\.(-?[_a-z]+[-\\w]*)': '[class~=$1]'
+    },
+
+    /**
+     * List of operators and corresponding boolean functions. 
+     * These functions are passed the attribute and the current node's value of the attribute.
+     * @property operators
+     * @type object
+     */
+    operators: {
+        '=': function(attr, val) { return attr === val; }, // Equality
+        '!=': function(attr, val) { return attr !== val; }, // Inequality
+        '~=': function(attr, val) { // Match one of space seperated words 
+            var s = ' ';
+            return (s + attr + s).indexOf((s + val + s)) > -1;
+        },
+        '|=': function(attr, val) { return Y.DOM._getRegExp('^' + val + '[-]?').test(attr); }, // Match start with value followed by optional hyphen
+        '^=': function(attr, val) { return attr.indexOf(val) === 0; }, // Match starts with value
+        '$=': function(attr, val) { return attr.lastIndexOf(val) === attr[LENGTH] - val[LENGTH]; }, // Match ends with value
+        '*=': function(attr, val) { return attr.indexOf(val) > -1; }, // Match contains value as substring 
+        '': function(attr, val) { return attr; } // Just test for existence of attribute
+    },
+
+    /**
+     * List of pseudo-classes and corresponding boolean functions. 
+     * These functions are called with the current node, and any value that was parsed with the pseudo regex.
+     * @property pseudos
+     * @type object
+     */
+    pseudos: {
+        'root': function(node) {
+            return node === node.ownerDocument.documentElement;
+        },
+
+        'nth-child': function(node, val) {
+            return Selector.getNth(node, val);
+        },
+
+        'nth-last-child': function(node, val) {
+            return Selector.getNth(node, val, null, true);
+        },
+
+        'nth-of-type': function(node, val) {
+            return Selector.getNth(node, val, node[TAG_NAME]);
+        },
+         
+        'nth-last-of-type': function(node, val) {
+            return Selector.getNth(node, val, node[TAG_NAME], true);
+        },
+         
+        'first-child': function(node) {
+            return Y.DOM.firstChild(node[PARENT_NODE]) === node;
+        },
+
+        'last-child': function(node) {
+            return Y.DOM.lastChild(node[PARENT_NODE]) === node;
+        },
+
+        'first-of-type': function(node, val) {
+            return Y.DOM.firstChildByTag(node[PARENT_NODE], node[TAG_NAME]) === node;
+        },
+         
+        'last-of-type': function(node, val) {
+            return Y.DOM.lastChildByTag(node[PARENT_NODE], node[TAG_NAME]) === node;
+        },
+         
+        'only-child': function(node) {
+            var children = Y.DOM.children(node[PARENT_NODE]);
+            return children[LENGTH] === 1 && children[0] === node;
+        },
+
+        'only-of-type': function(node) {
+            return Y.DOM.childrenByTag(node[PARENT_NODE], node[TAG_NAME])[LENGTH] === 1;
+        },
+
+        'empty': function(node) {
+            return node.childNodes[LENGTH] === 0;
+        },
+
+        'not': function(node, simple) {
+            return !Selector.test(node, simple);
+        },
+
+        'contains': function(node, str) {
+            var text = node.innerText || node.textContent || '';
+            return text.indexOf(str) > -1;
+        },
+        'checked': function(node) {
+            return node.checked === true;
+        }
+    },
+
+    /**
+     * Test if the supplied node matches the supplied selector.
+     * @method test
+     *
+     * @param {HTMLElement | String} node An id or node reference to the HTMLElement being tested.
+     * @param {string} selector The CSS Selector to test the node against.
+     * @return{boolean} Whether or not the node matches the selector.
+     * @static
+    
+     */
+    test: function(node, selector) {
+        if (!node) {
+            return false;
+        }
+
+        var groups = selector ? selector.split(',') : [];
+        if (groups[LENGTH]) {
+            for (var i = 0, len = groups[LENGTH]; i < len; ++i) {
+                if ( Selector._testNode(node, groups[i]) ) { // passes if ANY group matches
+                    return true;
+                }
+            }
+            return false;
+        }
+        return Selector._testNode(node, selector);
+    },
+
+    /**
+     * Filters a set of nodes based on a given CSS selector. 
+     * @method filter
+     *
+     * @param {array} nodes A set of nodes/ids to filter. 
+     * @param {string} selector The selector used to test each node.
+     * @return{array} An array of nodes from the supplied array that match the given selector.
+     * @static
+     */
+    filter: function(nodes, selector) {
+        nodes = nodes || [];
+
+        var result = Selector._filter(nodes, Selector._tokenize(selector)[0]);
+        return result;
+    },
+
+    /**
+     * Retrieves a set of nodes based on a given CSS selector. 
+     * @method query
+     *
+     * @param {string} selector The CSS Selector to test the node against.
+     * @param {HTMLElement | String} root optional An id or HTMLElement to start the query from. Defaults to Selector.document.
+     * @param {Boolean} firstOnly optional Whether or not to return only the first match.
+     * @return {Array} An array of nodes that match the given selector.
+     * @static
+     */
+    query: function(selector, root, firstOnly) {
+        var result = Selector._query(selector, root, firstOnly);
+        return result;
+    },
+
+    _query: function(selector, root, firstOnly, deDupe) {
+        var result =  (firstOnly) ? null : [];
+        if (!selector) {
+            return result;
+        }
+
+        root = root || Selector.document;
+        var groups = selector.split(','); // TODO: handle comma in attribute/pseudo
+
+        if (groups[LENGTH] > 1) {
+            var found;
+            for (var i = 0, len = groups[LENGTH]; i < len; ++i) {
+                found = arguments.callee(groups[i], root, firstOnly, true);
+                result = firstOnly ? found : result.concat(found); 
+            }
+            Selector._clearFoundCache();
+            return result;
+        }
+
+        var tokens = Selector._tokenize(selector);
+        var idToken = tokens[Selector._getIdTokenIndex(tokens)],
+            nodes = [],
+            node,
+            id,
+            token = tokens.pop() || {};
+            
+        if (idToken) {
+            id = Selector._getId(idToken[ATTRIBUTES]);
+        }
+
+        // use id shortcut when possible
+        if (id) {
+            node = Selector.document.getElementById(id);
+
+            if (node && (root[NODE_TYPE] === 9 || Y.DOM.contains(root, node))) {
+                if ( Selector._testNode(node, null, idToken) ) {
+                    if (idToken === token) {
+                        nodes = [node]; // simple selector
+                    } else {
+                        root = node; // start from here
+                    }
+                }
+            } else {
+                return result;
+            }
+        }
+
+        if (root && !nodes[LENGTH]) {
+            nodes = root.getElementsByTagName(token[TAG]);
+        }
+
+        if (nodes[LENGTH]) {
+            result = Selector._filter(nodes, token, firstOnly, deDupe); 
+        }
+        return result;
+    },
+
+    _filter: function(nodes, token, firstOnly, deDupe) {
+        var result = firstOnly ? null : [];
+
+        result = Y.DOM.filterElementsBy(nodes, function(node) {
+            if (! Selector._testNode(node, '', token, deDupe)) {
+                return false;
+            }
+
+            if (deDupe) {
+                if (node._found) {
+                    return false;
+                }
+                node._found = true;
+                Selector._foundCache[Selector._foundCache[LENGTH]] = node;
+            }
+            return true;
+        }, firstOnly);
+
+        return result;
+    },
+
+    _testNode: function(node, selector, token, deDupe) {
+        token = token || Selector._tokenize(selector).pop() || {};
+        var ops = Selector.operators,
+            pseudos = Selector.pseudos,
+            prev = token.previous,
+            i, len;
+
+        if (!node[TAG_NAME] ||
+            (token[TAG] !== '*' && node[TAG_NAME].toUpperCase() !== token[TAG]) ||
+            (deDupe && node._found) ) {
+            return false;
+        }
+
+        if (token[ATTRIBUTES][LENGTH]) {
+            var attribute;
+            for (i = 0, len = token[ATTRIBUTES][LENGTH]; i < len; ++i) {
+                attribute = node.getAttribute(token[ATTRIBUTES][i][0], 2);
+                if (attribute === undefined) {
+                    return false;
+                }
+                if ( ops[token[ATTRIBUTES][i][1]] &&
+                        !ops[token[ATTRIBUTES][i][1]](attribute, token[ATTRIBUTES][i][2])) {
+                    return false;
+                }
+            }
+        }
+
+        if (token[PSEUDOS][LENGTH]) {
+            for (i = 0, len = token[PSEUDOS][LENGTH]; i < len; ++i) {
+                if (pseudos[token[PSEUDOS][i][0]] &&
+                        !pseudos[token[PSEUDOS][i][0]](node, token[PSEUDOS][i][1])) {
+                    return false;
+                }
+            }
+        }
+        return (prev && prev[COMBINATOR] !== ',') ?
+                Selector.combinators[prev[COMBINATOR]](node, token) :
+                true;
+    },
+
+
+    _foundCache: [],
+    _regexCache: {},
+
+    _clearFoundCache: function() {
+        for (var i = 0, len = Selector._foundCache[LENGTH]; i < len; ++i) {
+            try { // IE no like delete
+                delete Selector._foundCache[i]._found;
+            } catch(e) {
+                Selector._foundCache[i].removeAttribute('_found');
+            }
+        }
+        Selector._foundCache = [];
+    },
+
+    combinators: {
+        ' ': function(node, token) {
+            while ((node = node[PARENT_NODE])) {
+                if (Selector._testNode(node, '', token.previous)) {
+                    return true;
+                }
+            }  
+            return false;
+        },
+
+        '>': function(node, token) {
+            return Selector._testNode(node[PARENT_NODE], null, token.previous);
+        },
+        '+': function(node, token) {
+            var sib = node[PREVIOUS_SIBLING];
+            while (sib && sib[NODE_TYPE] !== 1) {
+                sib = sib[PREVIOUS_SIBLING];
+            }
+
+            if (sib && Selector._testNode(sib, null, token.previous)) {
+                return true; 
+            }
+            return false;
+        },
+
+        '~': function(node, token) {
+            var sib = node[PREVIOUS_SIBLING];
+            while (sib) {
+                if (sib[NODE_TYPE] === 1 && Selector._testNode(sib, null, token.previous)) {
+                    return true;
+                }
+                sib = sib[PREVIOUS_SIBLING];
+            }
+
+            return false;
+        }
+    },
+
+
+    /*
+        an+b = get every _a_th node starting at the _b_th
+        0n+b = no repeat ("0" and "n" may both be omitted (together) , e.g. "0n+1" or "1", not "0+1"), return only the _b_th element
+        1n+b =  get every element starting from b ("1" may may be omitted, e.g. "1n+0" or "n+0" or "n")
+        an+0 = get every _a_th element, "0" may be omitted 
+    */
+    getNth: function(node, expr, tag, reverse) {
+        reNth.test(expr);
+
+        var a = parseInt(RegExp.$1, 10), // include every _a_ elements (zero means no repeat, just first _a_)
+            n = RegExp.$2, // "n"
+            oddeven = RegExp.$3, // "odd" or "even"
+            b = parseInt(RegExp.$4, 10) || 0, // start scan from element _b_
+            op, i, len, siblings;
+
+        if (tag) {
+            siblings = Y.DOM.childrenByTag(node[PARENT_NODE], tag);
+        } else {
+            siblings = Y.DOM.children(node[PARENT_NODE]);
+        }
+
+        if (oddeven) {
+            a = 2; // always every other
+            op = '+';
+            n = 'n';
+            b = (oddeven === 'odd') ? 1 : 0;
+        } else if ( isNaN(a) ) {
+            a = (n) ? 1 : 0; // start from the first or no repeat
+        }
+
+        if (a === 0) { // just the first
+            if (reverse) {
+                b = siblings[LENGTH] - b + 1; 
+            }
+
+            if (siblings[b - 1] === node) {
+                return true;
+            } else {
+                return false;
+            }
+
+        } else if (a < 0) {
+            reverse = !!reverse;
+            a = Math.abs(a);
+        }
+
+        if (!reverse) {
+            for (i = b - 1, len = siblings[LENGTH]; i < len; i += a) {
+                if ( i >= 0 && siblings[i] === node ) {
+                    return true;
+                }
+            }
+        } else {
+            for (i = siblings[LENGTH] - b, len = siblings[LENGTH]; i >= 0; i -= a) {
+                if ( i < len && siblings[i] === node ) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    },
+
+    _getId: function(attr) {
+        for (var i = 0, len = attr[LENGTH]; i < len; ++i) {
+            if (attr[i][0] == 'id' && attr[i][1] === '=') {
+                return attr[i][2];
+            }
+        }
+    },
+
+    _getIdTokenIndex: function(tokens) {
+        for (var i = 0, len = tokens[LENGTH]; i < len; ++i) {
+            if (Selector._getId(tokens[i][ATTRIBUTES])) {
+                return i;
+            }
+        }
+        return -1;
+    },
+
+    /**
+        Break selector into token units per simple selector.
+        Combinator is attached to left-hand selector.
+     */
+    _tokenize: function(selector) {
+        var token = {},     // one token per simple selector (left selector holds combinator)
+            tokens = [],    // array of tokens
+            found = false,  // whether or not any matches were found this pass
+            match;          // the regex match
+
+        selector = Selector._replaceShorthand(selector); // convert ID and CLASS shortcuts to attributes
+
+        /*
+            Search for selector patterns, store, and strip them from the selector string
+            until no patterns match (invalid selector) or we run out of chars.
+
+            Multiple attributes and pseudos are allowed, in any order.
+            for example:
+                'form:first-child[type=button]:not(button)[lang|=en]'
+        */
+        do {
+            found = false; // reset after full pass
+            for (var re in patterns) {
+                if (patterns.hasOwnProperty(re)) {
+                    if (re != TAG && re != COMBINATOR) { // only one allowed
+                        token[re] = token[re] || [];
+                    }
+                    if ((match = patterns[re].exec(selector))) { // note assignment
+                        found = true;
+                        if (re != TAG && re != COMBINATOR) { // only one allowed
+                            //token[re] = token[re] || [];
+
+                            // capture ID for fast path to element
+                            if (re === ATTRIBUTES && match[1] === 'id') {
+                                token.id = match[3];
+                            }
+
+                            token[re].push(match.slice(1));
+                        } else { // single selector (tag, combinator)
+                            token[re] = match[1];
+                        }
+                        selector = selector.replace(match[0], ''); // strip current match from selector
+                        if (re === COMBINATOR || !selector[LENGTH]) { // next token or done
+                            token[ATTRIBUTES] = Selector._fixAttributes(token[ATTRIBUTES]);
+                            token[PSEUDOS] = token[PSEUDOS] || [];
+                            token[TAG] = token[TAG] ? token[TAG].toUpperCase() : '*';
+                            tokens.push(token);
+
+                            token = { // prep next token
+                                previous: token
+                            };
+                        }
+                    }
+                }
+            }
+        } while (found);
+
+        return tokens;
+    },
+
+    _fixAttributes: function(attr) {
+        var aliases = Selector.attrAliases;
+        attr = attr || [];
+        for (var i = 0, len = attr[LENGTH]; i < len; ++i) {
+            if (aliases[attr[i][0]]) { // convert reserved words, etc
+                attr[i][0] = aliases[attr[i][0]];
+            }
+            if (!attr[i][1]) { // use exists operator
+                attr[i][1] = '';
+            }
+        }
+        return attr;
+    },
+
+    _replaceShorthand: function(selector) {
+        var shorthand = Selector.shorthand;
+        var attrs = selector.match(patterns[ATTRIBUTES]); // pull attributes to avoid false pos on "." and "#"
+        if (attrs) {
+            selector = selector.replace(patterns[ATTRIBUTES], 'REPLACED_ATTRIBUTE');
+        }
+        for (var re in shorthand) {
+            if (shorthand.hasOwnProperty(re)) {
+                selector = selector.replace(Y.DOM._getRegExp(re, 'gi'), shorthand[re]);
+            }
+        }
+
+        if (attrs) {
+            for (var i = 0, len = attrs[LENGTH]; i < len; ++i) {
+                selector = selector.replace('REPLACED_ATTRIBUTE', attrs[i]);
+            }
+        }
+        return selector;
+    }
+
+};
+
+if (Y.UA.ie && Y.UA.ie < 8) { // rewrite class for IE (others use getAttribute('class')
+    Selector.attrAliases['class'] = 'className';
+    Selector.attrAliases['for'] = 'htmlFor';
+}
+
+Y.Selector = Selector;
+Y.Selector.patterns = patterns;
+
+
+/**
+ * Add style management functionality to DOM.
+ * @module dom
+ * @submodule dom-style
+ * @for DOM
+ */
+
+var TO_STRING = 'toString',
+    PARSE_INT = parseInt,
+    RE = RegExp;
+
+Y.Color = {
+    KEYWORDS: {
+        black: '000',
+        silver: 'c0c0c0',
+        gray: '808080',
+        white: 'fff',
+        maroon: '800000',
+        red: 'f00',
+        purple: '800080',
+        fuchsia: 'f0f',
+        green: '008000',
+        lime: '0f0',
+        olive: '808000',
+        yellow: 'ff0',
+        navy: '000080',
+        blue: '00f',
+        teal: '008080',
+        aqua: '0ff'
+    },
+
+    re_RGB: /^rgb\(([0-9]+)\s*,\s*([0-9]+)\s*,\s*([0-9]+)\)$/i,
+    re_hex: /^#?([0-9A-F]{2})([0-9A-F]{2})([0-9A-F]{2})$/i,
+    re_hex3: /([0-9A-F])/gi,
+
+    toRGB: function(val) {
+        if (!Y.Color.re_RGB.test(val)) {
+            val = Y.Color.toHex(val);
+        }
+
+        if(Y.Color.re_hex.exec(val)) {
+            val = 'rgb(' + [
+                PARSE_INT(RE.$1, 16),
+                PARSE_INT(RE.$2, 16),
+                PARSE_INT(RE.$3, 16)
+            ].join(', ') + ')';
+        }
+        return val;
+    },
+
+    toHex: function(val) {
+        val = Y.Color.KEYWORDS[val] || val;
+        if (Y.Color.re_RGB.exec(val)) {
+            var r = (RE.$1.length === 1) ? '0' + RE.$1 : Number(RE.$1),
+                g = (RE.$2.length === 1) ? '0' + RE.$2 : Number(RE.$2),
+                b = (RE.$3.length === 1) ? '0' + RE.$3 : Number(RE.$3);
+
+            val = [
+                r[TO_STRING](16),
+                g[TO_STRING](16),
+                b[TO_STRING](16)
+            ].join('');
+        }
+
+        if (val.length < 6) {
+            val = val.replace(Y.Color.re_hex3, '$1$1');
+        }
+
+        if (val !== 'transparent' && val.indexOf('#') < 0) {
+            val = '#' + val;
+        }
+
+        return val.toLowerCase();
+    }
+};
+
+
+
+
+}, '3.0.0pr2' ,{skinnable:false});

=== added file 'loggerhead/static/javascript/yui/build/dom/selector-debug.js'
--- loggerhead/static/javascript/yui/build/dom/selector-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/selector-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,575 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('selector', function(Y) {
+
+/**
+ * Provides helper methods for collecting and filtering DOM elements.
+ * @module dom
+ * @submodule selector
+ */
+
+/**
+ * Provides helper methods for collecting and filtering DOM elements.
+ * @class Selector
+ * @static
+ */
+
+var TAG = 'tag',
+    PARENT_NODE = 'parentNode',
+    PREVIOUS_SIBLING = 'previousSibling',
+    LENGTH = 'length',
+    NODE_TYPE = 'nodeType',
+    TAG_NAME = 'tagName',
+    ATTRIBUTES = 'attributes',
+    PSEUDOS = 'pseudos',
+    COMBINATOR = 'combinator';
+
+var reNth = /^(?:([\-]?\d*)(n){1}|(odd|even)$)*([\-+]?\d*)$/;
+
+var patterns = {
+    tag: /^((?:-?[_a-z]+[\w\-]*)|\*)/i,
+    attributes: /^\[([a-z]+\w*)+([~\|\^\$\*!=]=?)?['"]?([^\]]*?)['"]?\]/i,
+    pseudos: /^:([\-\w]+)(?:\(['"]?(.+)['"]?\))*/i,
+    combinator: /^\s*([>+~]|\s)\s*/
+};
+
+var Selector = {
+    /**
+     * Default document for use queries 
+     * @property document
+     * @type object
+     * @default window.document
+     */
+    document: Y.config.doc,
+    /**
+     * Mapping of attributes to aliases, normally to work around HTMLAttributes
+     * that conflict with JS reserved words.
+     * @property attrAliases
+     * @type object
+     */
+    attrAliases: {},
+
+    /**
+     * Mapping of shorthand tokens to corresponding attribute selector 
+     * @property shorthand
+     * @type object
+     */
+    shorthand: {
+        '\\#(-?[_a-z]+[-\\w]*)': '[id=$1]',
+        '\\.(-?[_a-z]+[-\\w]*)': '[class~=$1]'
+    },
+
+    /**
+     * List of operators and corresponding boolean functions. 
+     * These functions are passed the attribute and the current node's value of the attribute.
+     * @property operators
+     * @type object
+     */
+    operators: {
+        '=': function(attr, val) { return attr === val; }, // Equality
+        '!=': function(attr, val) { return attr !== val; }, // Inequality
+        '~=': function(attr, val) { // Match one of space seperated words 
+            var s = ' ';
+            return (s + attr + s).indexOf((s + val + s)) > -1;
+        },
+        '|=': function(attr, val) { return Y.DOM._getRegExp('^' + val + '[-]?').test(attr); }, // Match start with value followed by optional hyphen
+        '^=': function(attr, val) { return attr.indexOf(val) === 0; }, // Match starts with value
+        '$=': function(attr, val) { return attr.lastIndexOf(val) === attr[LENGTH] - val[LENGTH]; }, // Match ends with value
+        '*=': function(attr, val) { return attr.indexOf(val) > -1; }, // Match contains value as substring 
+        '': function(attr, val) { return attr; } // Just test for existence of attribute
+    },
+
+    /**
+     * List of pseudo-classes and corresponding boolean functions. 
+     * These functions are called with the current node, and any value that was parsed with the pseudo regex.
+     * @property pseudos
+     * @type object
+     */
+    pseudos: {
+        'root': function(node) {
+            return node === node.ownerDocument.documentElement;
+        },
+
+        'nth-child': function(node, val) {
+            return Selector.getNth(node, val);
+        },
+
+        'nth-last-child': function(node, val) {
+            return Selector.getNth(node, val, null, true);
+        },
+
+        'nth-of-type': function(node, val) {
+            return Selector.getNth(node, val, node[TAG_NAME]);
+        },
+         
+        'nth-last-of-type': function(node, val) {
+            return Selector.getNth(node, val, node[TAG_NAME], true);
+        },
+         
+        'first-child': function(node) {
+            return Y.DOM.firstChild(node[PARENT_NODE]) === node;
+        },
+
+        'last-child': function(node) {
+            return Y.DOM.lastChild(node[PARENT_NODE]) === node;
+        },
+
+        'first-of-type': function(node, val) {
+            return Y.DOM.firstChildByTag(node[PARENT_NODE], node[TAG_NAME]) === node;
+        },
+         
+        'last-of-type': function(node, val) {
+            return Y.DOM.lastChildByTag(node[PARENT_NODE], node[TAG_NAME]) === node;
+        },
+         
+        'only-child': function(node) {
+            var children = Y.DOM.children(node[PARENT_NODE]);
+            return children[LENGTH] === 1 && children[0] === node;
+        },
+
+        'only-of-type': function(node) {
+            return Y.DOM.childrenByTag(node[PARENT_NODE], node[TAG_NAME])[LENGTH] === 1;
+        },
+
+        'empty': function(node) {
+            return node.childNodes[LENGTH] === 0;
+        },
+
+        'not': function(node, simple) {
+            return !Selector.test(node, simple);
+        },
+
+        'contains': function(node, str) {
+            var text = node.innerText || node.textContent || '';
+            return text.indexOf(str) > -1;
+        },
+        'checked': function(node) {
+            return node.checked === true;
+        }
+    },
+
+    /**
+     * Test if the supplied node matches the supplied selector.
+     * @method test
+     *
+     * @param {HTMLElement | String} node An id or node reference to the HTMLElement being tested.
+     * @param {string} selector The CSS Selector to test the node against.
+     * @return{boolean} Whether or not the node matches the selector.
+     * @static
+    
+     */
+    test: function(node, selector) {
+        if (!node) {
+            return false;
+        }
+
+        var groups = selector ? selector.split(',') : [];
+        if (groups[LENGTH]) {
+            for (var i = 0, len = groups[LENGTH]; i < len; ++i) {
+                if ( Selector._testNode(node, groups[i]) ) { // passes if ANY group matches
+                    return true;
+                }
+            }
+            return false;
+        }
+        return Selector._testNode(node, selector);
+    },
+
+    /**
+     * Filters a set of nodes based on a given CSS selector. 
+     * @method filter
+     *
+     * @param {array} nodes A set of nodes/ids to filter. 
+     * @param {string} selector The selector used to test each node.
+     * @return{array} An array of nodes from the supplied array that match the given selector.
+     * @static
+     */
+    filter: function(nodes, selector) {
+        nodes = nodes || [];
+
+        var result = Selector._filter(nodes, Selector._tokenize(selector)[0]);
+        Y.log('filter: returning:' + result[LENGTH], 'info', 'Selector');
+        return result;
+    },
+
+    /**
+     * Retrieves a set of nodes based on a given CSS selector. 
+     * @method query
+     *
+     * @param {string} selector The CSS Selector to test the node against.
+     * @param {HTMLElement | String} root optional An id or HTMLElement to start the query from. Defaults to Selector.document.
+     * @param {Boolean} firstOnly optional Whether or not to return only the first match.
+     * @return {Array} An array of nodes that match the given selector.
+     * @static
+     */
+    query: function(selector, root, firstOnly) {
+        var result = Selector._query(selector, root, firstOnly);
+        //Y.log('query: ' + selector + ' returning ' + result, 'info', 'Selector');
+        return result;
+    },
+
+    _query: function(selector, root, firstOnly, deDupe) {
+        var result =  (firstOnly) ? null : [];
+        if (!selector) {
+            return result;
+        }
+
+        root = root || Selector.document;
+        var groups = selector.split(','); // TODO: handle comma in attribute/pseudo
+
+        if (groups[LENGTH] > 1) {
+            var found;
+            for (var i = 0, len = groups[LENGTH]; i < len; ++i) {
+                found = arguments.callee(groups[i], root, firstOnly, true);
+                result = firstOnly ? found : result.concat(found); 
+            }
+            Selector._clearFoundCache();
+            return result;
+        }
+
+        var tokens = Selector._tokenize(selector);
+        var idToken = tokens[Selector._getIdTokenIndex(tokens)],
+            nodes = [],
+            node,
+            id,
+            token = tokens.pop() || {};
+            
+        if (idToken) {
+            id = Selector._getId(idToken[ATTRIBUTES]);
+        }
+
+        // use id shortcut when possible
+        if (id) {
+            node = Selector.document.getElementById(id);
+
+            if (node && (root[NODE_TYPE] === 9 || Y.DOM.contains(root, node))) {
+                if ( Selector._testNode(node, null, idToken) ) {
+                    if (idToken === token) {
+                        nodes = [node]; // simple selector
+                    } else {
+                        root = node; // start from here
+                    }
+                }
+            } else {
+                return result;
+            }
+        }
+
+        if (root && !nodes[LENGTH]) {
+            nodes = root.getElementsByTagName(token[TAG]);
+        }
+
+        if (nodes[LENGTH]) {
+            result = Selector._filter(nodes, token, firstOnly, deDupe); 
+        }
+        return result;
+    },
+
+    _filter: function(nodes, token, firstOnly, deDupe) {
+        var result = firstOnly ? null : [];
+
+        result = Y.DOM.filterElementsBy(nodes, function(node) {
+            if (! Selector._testNode(node, '', token, deDupe)) {
+                return false;
+            }
+
+            if (deDupe) {
+                if (node._found) {
+                    return false;
+                }
+                node._found = true;
+                Selector._foundCache[Selector._foundCache[LENGTH]] = node;
+            }
+            return true;
+        }, firstOnly);
+
+        return result;
+    },
+
+    _testNode: function(node, selector, token, deDupe) {
+        token = token || Selector._tokenize(selector).pop() || {};
+        var ops = Selector.operators,
+            pseudos = Selector.pseudos,
+            prev = token.previous,
+            i, len;
+
+        if (!node[TAG_NAME] ||
+            (token[TAG] !== '*' && node[TAG_NAME].toUpperCase() !== token[TAG]) ||
+            (deDupe && node._found) ) {
+            return false;
+        }
+
+        if (token[ATTRIBUTES][LENGTH]) {
+            var attribute;
+            for (i = 0, len = token[ATTRIBUTES][LENGTH]; i < len; ++i) {
+                attribute = node.getAttribute(token[ATTRIBUTES][i][0], 2);
+                if (attribute === undefined) {
+                    return false;
+                }
+                if ( ops[token[ATTRIBUTES][i][1]] &&
+                        !ops[token[ATTRIBUTES][i][1]](attribute, token[ATTRIBUTES][i][2])) {
+                    return false;
+                }
+            }
+        }
+
+        if (token[PSEUDOS][LENGTH]) {
+            for (i = 0, len = token[PSEUDOS][LENGTH]; i < len; ++i) {
+                if (pseudos[token[PSEUDOS][i][0]] &&
+                        !pseudos[token[PSEUDOS][i][0]](node, token[PSEUDOS][i][1])) {
+                    return false;
+                }
+            }
+        }
+        return (prev && prev[COMBINATOR] !== ',') ?
+                Selector.combinators[prev[COMBINATOR]](node, token) :
+                true;
+    },
+
+
+    _foundCache: [],
+    _regexCache: {},
+
+    _clearFoundCache: function() {
+        Y.log('getBySelector: clearing found cache of ' + Selector._foundCache[LENGTH] + ' elements');
+        for (var i = 0, len = Selector._foundCache[LENGTH]; i < len; ++i) {
+            try { // IE no like delete
+                delete Selector._foundCache[i]._found;
+            } catch(e) {
+                Selector._foundCache[i].removeAttribute('_found');
+            }
+        }
+        Selector._foundCache = [];
+        Y.log('getBySelector: done clearing Selector._foundCache');
+    },
+
+    combinators: {
+        ' ': function(node, token) {
+            while ((node = node[PARENT_NODE])) {
+                if (Selector._testNode(node, '', token.previous)) {
+                    return true;
+                }
+            }  
+            return false;
+        },
+
+        '>': function(node, token) {
+            return Selector._testNode(node[PARENT_NODE], null, token.previous);
+        },
+        '+': function(node, token) {
+            var sib = node[PREVIOUS_SIBLING];
+            while (sib && sib[NODE_TYPE] !== 1) {
+                sib = sib[PREVIOUS_SIBLING];
+            }
+
+            if (sib && Selector._testNode(sib, null, token.previous)) {
+                return true; 
+            }
+            return false;
+        },
+
+        '~': function(node, token) {
+            var sib = node[PREVIOUS_SIBLING];
+            while (sib) {
+                if (sib[NODE_TYPE] === 1 && Selector._testNode(sib, null, token.previous)) {
+                    return true;
+                }
+                sib = sib[PREVIOUS_SIBLING];
+            }
+
+            return false;
+        }
+    },
+
+
+    /*
+        an+b = get every _a_th node starting at the _b_th
+        0n+b = no repeat ("0" and "n" may both be omitted (together) , e.g. "0n+1" or "1", not "0+1"), return only the _b_th element
+        1n+b =  get every element starting from b ("1" may may be omitted, e.g. "1n+0" or "n+0" or "n")
+        an+0 = get every _a_th element, "0" may be omitted 
+    */
+    getNth: function(node, expr, tag, reverse) {
+        reNth.test(expr);
+
+        var a = parseInt(RegExp.$1, 10), // include every _a_ elements (zero means no repeat, just first _a_)
+            n = RegExp.$2, // "n"
+            oddeven = RegExp.$3, // "odd" or "even"
+            b = parseInt(RegExp.$4, 10) || 0, // start scan from element _b_
+            op, i, len, siblings;
+
+        if (tag) {
+            siblings = Y.DOM.childrenByTag(node[PARENT_NODE], tag);
+        } else {
+            siblings = Y.DOM.children(node[PARENT_NODE]);
+        }
+
+        if (oddeven) {
+            a = 2; // always every other
+            op = '+';
+            n = 'n';
+            b = (oddeven === 'odd') ? 1 : 0;
+        } else if ( isNaN(a) ) {
+            a = (n) ? 1 : 0; // start from the first or no repeat
+        }
+
+        if (a === 0) { // just the first
+            if (reverse) {
+                b = siblings[LENGTH] - b + 1; 
+            }
+
+            if (siblings[b - 1] === node) {
+                return true;
+            } else {
+                return false;
+            }
+
+        } else if (a < 0) {
+            reverse = !!reverse;
+            a = Math.abs(a);
+        }
+
+        if (!reverse) {
+            for (i = b - 1, len = siblings[LENGTH]; i < len; i += a) {
+                if ( i >= 0 && siblings[i] === node ) {
+                    return true;
+                }
+            }
+        } else {
+            for (i = siblings[LENGTH] - b, len = siblings[LENGTH]; i >= 0; i -= a) {
+                if ( i < len && siblings[i] === node ) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    },
+
+    _getId: function(attr) {
+        for (var i = 0, len = attr[LENGTH]; i < len; ++i) {
+            if (attr[i][0] == 'id' && attr[i][1] === '=') {
+                return attr[i][2];
+            }
+        }
+    },
+
+    _getIdTokenIndex: function(tokens) {
+        for (var i = 0, len = tokens[LENGTH]; i < len; ++i) {
+            if (Selector._getId(tokens[i][ATTRIBUTES])) {
+                return i;
+            }
+        }
+        return -1;
+    },
+
+    /**
+        Break selector into token units per simple selector.
+        Combinator is attached to left-hand selector.
+     */
+    _tokenize: function(selector) {
+        var token = {},     // one token per simple selector (left selector holds combinator)
+            tokens = [],    // array of tokens
+            found = false,  // whether or not any matches were found this pass
+            match;          // the regex match
+
+        selector = Selector._replaceShorthand(selector); // convert ID and CLASS shortcuts to attributes
+
+        /*
+            Search for selector patterns, store, and strip them from the selector string
+            until no patterns match (invalid selector) or we run out of chars.
+
+            Multiple attributes and pseudos are allowed, in any order.
+            for example:
+                'form:first-child[type=button]:not(button)[lang|=en]'
+        */
+        do {
+            found = false; // reset after full pass
+            for (var re in patterns) {
+                if (patterns.hasOwnProperty(re)) {
+                    if (re != TAG && re != COMBINATOR) { // only one allowed
+                        token[re] = token[re] || [];
+                    }
+                    if ((match = patterns[re].exec(selector))) { // note assignment
+                        found = true;
+                        if (re != TAG && re != COMBINATOR) { // only one allowed
+                            //token[re] = token[re] || [];
+
+                            // capture ID for fast path to element
+                            if (re === ATTRIBUTES && match[1] === 'id') {
+                                token.id = match[3];
+                            }
+
+                            token[re].push(match.slice(1));
+                        } else { // single selector (tag, combinator)
+                            token[re] = match[1];
+                        }
+                        selector = selector.replace(match[0], ''); // strip current match from selector
+                        if (re === COMBINATOR || !selector[LENGTH]) { // next token or done
+                            token[ATTRIBUTES] = Selector._fixAttributes(token[ATTRIBUTES]);
+                            token[PSEUDOS] = token[PSEUDOS] || [];
+                            token[TAG] = token[TAG] ? token[TAG].toUpperCase() : '*';
+                            tokens.push(token);
+
+                            token = { // prep next token
+                                previous: token
+                            };
+                        }
+                    }
+                }
+            }
+        } while (found);
+
+        return tokens;
+    },
+
+    _fixAttributes: function(attr) {
+        var aliases = Selector.attrAliases;
+        attr = attr || [];
+        for (var i = 0, len = attr[LENGTH]; i < len; ++i) {
+            if (aliases[attr[i][0]]) { // convert reserved words, etc
+                attr[i][0] = aliases[attr[i][0]];
+            }
+            if (!attr[i][1]) { // use exists operator
+                attr[i][1] = '';
+            }
+        }
+        return attr;
+    },
+
+    _replaceShorthand: function(selector) {
+        var shorthand = Selector.shorthand;
+        var attrs = selector.match(patterns[ATTRIBUTES]); // pull attributes to avoid false pos on "." and "#"
+        if (attrs) {
+            selector = selector.replace(patterns[ATTRIBUTES], 'REPLACED_ATTRIBUTE');
+        }
+        for (var re in shorthand) {
+            if (shorthand.hasOwnProperty(re)) {
+                selector = selector.replace(Y.DOM._getRegExp(re, 'gi'), shorthand[re]);
+            }
+        }
+
+        if (attrs) {
+            for (var i = 0, len = attrs[LENGTH]; i < len; ++i) {
+                selector = selector.replace('REPLACED_ATTRIBUTE', attrs[i]);
+            }
+        }
+        return selector;
+    }
+
+};
+
+if (Y.UA.ie && Y.UA.ie < 8) { // rewrite class for IE (others use getAttribute('class')
+    Selector.attrAliases['class'] = 'className';
+    Selector.attrAliases['for'] = 'htmlFor';
+}
+
+Y.Selector = Selector;
+Y.Selector.patterns = patterns;
+
+
+
+
+}, '3.0.0pr2' ,{skinnable:false, requires:['dom-base']});

=== added file 'loggerhead/static/javascript/yui/build/dom/selector-min.js'
--- loggerhead/static/javascript/yui/build/dom/selector-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/selector-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("selector",function(B){var F="tag",L="parentNode",I="previousSibling",C="length",M="nodeType",J="tagName",G="attributes",E="pseudos",H="combinator";var K=/^(?:([\-]?\d*)(n){1}|(odd|even)$)*([\-+]?\d*)$/;var D={tag:/^((?:-?[_a-z]+[\w\-]*)|\*)/i,attributes:/^\[([a-z]+\w*)+([~\|\^\$\*!=]=?)?['"]?([^\]]*?)['"]?\]/i,pseudos:/^:([\-\w]+)(?:\(['"]?(.+)['"]?\))*/i,combinator:/^\s*([>+~]|\s)\s*/};var A={document:B.config.doc,attrAliases:{},shorthand:{"\\#(-?[_a-z]+[-\\w]*)":"[id=$1]","\\.(-?[_a-z]+[-\\w]*)":"[class~=$1]"},operators:{"=":function(N,O){return N===O;},"!=":function(N,O){return N!==O;},"~=":function(N,P){var O=" ";return(O+N+O).indexOf((O+P+O))>-1;},"|=":function(N,O){return B.DOM._getRegExp("^"+O+"[-]?").test(N);},"^=":function(N,O){return N.indexOf(O)===0;},"$=":function(N,O){return N.lastIndexOf(O)===N[C]-O[C];},"*=":function(N,O){return N.indexOf(O)>-1;},"":function(N,O){return N;}},pseudos:{"root":function(N){return N===N.ownerDocument.documentElement;},"nth-child":function(N,O){return A.getNth(N,O);},"nth-last-child":function(N,O){return A.getNth(N,O,null,true);},"nth-of-type":function(N,O){return A.getNth(N,O,N[J]);},"nth-last-of-type":function(N,O){return A.getNth(N,O,N[J],true);},"first-child":function(N){return B.DOM.firstChild(N[L])===N;},"last-child":function(N){return B.DOM.lastChild(N[L])===N;},"first-of-type":function(N,O){return B.DOM.firstChildByTag(N[L],N[J])===N;},"last-of-type":function(N,O){return B.DOM.lastChildByTag(N[L],N[J])===N;},"only-child":function(O){var N=B.DOM.children(O[L]);return N[C]===1&&N[0]===O;},"only-of-type":function(N){return B.DOM.childrenByTag(N[L],N[J])[C]===1;},"empty":function(N){return N.childNodes[C]===0;},"not":function(N,O){return !A.test(N,O);},"contains":function(N,P){var O=N.innerText||N.textContent||"";return O.indexOf(P)>-1;},"checked":function(N){return N.checked===true;}},test:function(R,P){if(!R){return false;}var O=P?P.split(","):[];if(O[C]){for(var Q=0,N=O[C];Q<N;++Q){if(A._testNode(R,O[Q])){return true;}}return false;}return A._testNode(R,P);},filter:function(P,O){P=P||[];var N=A._filter(P,A._tokenize(O)[0]);return N;},query:function(O,P,Q){var N=A._query(O,P,Q);return N;},_query:function(T,Y,Z,R){var b=(Z)?null:[];if(!T){return b;}Y=Y||A.document;var P=T.split(",");if(P[C]>1){var a;for(var U=0,V=P[C];U<V;++U){a=arguments.callee(P[U],Y,Z,true);b=Z?a:b.concat(a);}A._clearFoundCache();return b;}var X=A._tokenize(T);var W=X[A._getIdTokenIndex(X)],N=[],Q,O,S=X.pop()||{};if(W){O=A._getId(W[G]);}if(O){Q=A.document.getElementById(O);if(Q&&(Y[M]===9||B.DOM.contains(Y,Q))){if(A._testNode(Q,null,W)){if(W===S){N=[Q];}else{Y=Q;}}}else{return b;}}if(Y&&!N[C]){N=Y.getElementsByTagName(S[F]);}if(N[C]){b=A._filter(N,S,Z,R);}return b;},_filter:function(P,Q,R,O){var N=R?null:[];N=B.DOM.filterElementsBy(P,function(S){if(!A._testNode(S,"",Q,O)){return false;}if(O){if(S._found){return false;}S._found=true;A._foundCache[A._foundCache[C]]=S;}return true;},R);return N;},_testNode:function(P,T,S,Q){S=S||A._tokenize(T).pop()||{};var O=A.operators,W=A.pseudos,R=S.previous,U,V;if(!P[J]||(S[F]!=="*"&&P[J].toUpperCase()!==S[F])||(Q&&P._found)){return false;}if(S[G][C]){var N;for(U=0,V=S[G][C];U<V;++U){N=P.getAttribute(S[G][U][0],2);if(N===undefined){return false;}if(O[S[G][U][1]]&&!O[S[G][U][1]](N,S[G][U][2])){return false;}}}if(S[E][C]){for(U=0,V=S[E][C];U<V;++U){if(W[S[E][U][0]]&&!W[S[E][U][0]](P,S[E][U][1])){return false;}}}return(R&&R[H]!==",")?A.combinators[R[H]](P,S):true;},_foundCache:[],_regexCache:{},_clearFoundCache:function(){for(var O=0,N=A._foundCache[C];O<N;++O){try{delete A._foundCache[O]._found;}catch(P){A._foundCache[O].removeAttribute("_found");}}A._foundCache=[];},combinators:{" ":function(O,N){while((O=O[L])){if(A._testNode(O,"",N.previous)){return true;}}return false;},">":function(O,N){return A._testNode(O[L],null,N.previous);},"+":function(P,O){var N=P[I];while(N&&N[M]!==1){N=N[I];}if(N&&A._testNode(N,null,O.previous)){return true;}return false;},"~":function(P,O){var N=P[I];while(N){if(N[M]===1&&A._testNode(N,null,O.previous)){return true;}N=N[I];}return false;}},getNth:function(O,X,Y,S){K.test(X);var W=parseInt(RegExp.$1,10),N=RegExp.$2,T=RegExp.$3,U=parseInt(RegExp.$4,10)||0,Q,P,R,V;if(Y){V=B.DOM.childrenByTag(O[L],Y);}else{V=B.DOM.children(O[L]);}if(T){W=2;Q="+";N="n";U=(T==="odd")?1:0;}else{if(isNaN(W)){W=(N)?1:0;}}if(W===0){if(S){U=V[C]-U+1;}if(V[U-1]===O){return true;}else{return false;}}else{if(W<0){S=!!S;W=Math.abs(W);}}if(!S){for(P=U-1,R=V[C];P<R;P+=W){if(P>=0&&V[P]===O){return true;}}}else{for(P=V[C]-U,R=V[C];P>=0;P-=W){if(P<R&&V[P]===O){return true;}}}return false;},_getId:function(O){for(var P=0,N=O[C];P<N;++P){if(O[P][0]=="id"&&O[P][1]==="="){return O[P][2];}}},_getIdTokenIndex:function(P){for(var O=0,N=P[C];O<N;++O){if(A._getId(P[O][G])){return O;}}return -1;},_tokenize:function(N){var P={},S=[],R=false,O;N=A._replaceShorthand(N);do{R=false;for(var Q in D){if(D.hasOwnProperty(Q)){if(Q!=F&&Q!=H){P[Q]=P[Q]||[];}if((O=D[Q].exec(N))){R=true;if(Q!=F&&Q!=H){if(Q===G&&O[1]==="id"){P.id=O[3];}P[Q].push(O.slice(1));}else{P[Q]=O[1];}N=N.replace(O[0],"");if(Q===H||!N[C]){P[G]=A._fixAttributes(P[G]);P[E]=P[E]||[];P[F]=P[F]?P[F].toUpperCase():"*";S.push(P);P={previous:P};}}}}}while(R);return S;},_fixAttributes:function(O){var P=A.attrAliases;O=O||[];for(var Q=0,N=O[C];Q<N;++Q){if(P[O[Q][0]]){O[Q][0]=P[O[Q][0]];}if(!O[Q][1]){O[Q][1]="";}}return O;},_replaceShorthand:function(O){var P=A.shorthand;var Q=O.match(D[G]);if(Q){O=O.replace(D[G],"REPLACED_ATTRIBUTE");}for(var S in P){if(P.hasOwnProperty(S)){O=O.replace(B.DOM._getRegExp(S,"gi"),P[S]);}}if(Q){for(var R=0,N=Q[C];R<N;++R){O=O.replace("REPLACED_ATTRIBUTE",Q[R]);}}return O;}};if(B.UA.ie&&B.UA.ie<8){A.attrAliases["class"]="className";A.attrAliases["for"]="htmlFor";}B.Selector=A;B.Selector.patterns=D;},"3.0.0pr2",{skinnable:false,requires:["dom-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dom/selector.js'
--- loggerhead/static/javascript/yui/build/dom/selector.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dom/selector.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,571 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('selector', function(Y) {
+
+/**
+ * Provides helper methods for collecting and filtering DOM elements.
+ * @module dom
+ * @submodule selector
+ */
+
+/**
+ * Provides helper methods for collecting and filtering DOM elements.
+ * @class Selector
+ * @static
+ */
+
+var TAG = 'tag',
+    PARENT_NODE = 'parentNode',
+    PREVIOUS_SIBLING = 'previousSibling',
+    LENGTH = 'length',
+    NODE_TYPE = 'nodeType',
+    TAG_NAME = 'tagName',
+    ATTRIBUTES = 'attributes',
+    PSEUDOS = 'pseudos',
+    COMBINATOR = 'combinator';
+
+var reNth = /^(?:([\-]?\d*)(n){1}|(odd|even)$)*([\-+]?\d*)$/;
+
+var patterns = {
+    tag: /^((?:-?[_a-z]+[\w\-]*)|\*)/i,
+    attributes: /^\[([a-z]+\w*)+([~\|\^\$\*!=]=?)?['"]?([^\]]*?)['"]?\]/i,
+    pseudos: /^:([\-\w]+)(?:\(['"]?(.+)['"]?\))*/i,
+    combinator: /^\s*([>+~]|\s)\s*/
+};
+
+var Selector = {
+    /**
+     * Default document for use queries 
+     * @property document
+     * @type object
+     * @default window.document
+     */
+    document: Y.config.doc,
+    /**
+     * Mapping of attributes to aliases, normally to work around HTMLAttributes
+     * that conflict with JS reserved words.
+     * @property attrAliases
+     * @type object
+     */
+    attrAliases: {},
+
+    /**
+     * Mapping of shorthand tokens to corresponding attribute selector 
+     * @property shorthand
+     * @type object
+     */
+    shorthand: {
+        '\\#(-?[_a-z]+[-\\w]*)': '[id=$1]',
+        '\\.(-?[_a-z]+[-\\w]*)': '[class~=$1]'
+    },
+
+    /**
+     * List of operators and corresponding boolean functions. 
+     * These functions are passed the attribute and the current node's value of the attribute.
+     * @property operators
+     * @type object
+     */
+    operators: {
+        '=': function(attr, val) { return attr === val; }, // Equality
+        '!=': function(attr, val) { return attr !== val; }, // Inequality
+        '~=': function(attr, val) { // Match one of space seperated words 
+            var s = ' ';
+            return (s + attr + s).indexOf((s + val + s)) > -1;
+        },
+        '|=': function(attr, val) { return Y.DOM._getRegExp('^' + val + '[-]?').test(attr); }, // Match start with value followed by optional hyphen
+        '^=': function(attr, val) { return attr.indexOf(val) === 0; }, // Match starts with value
+        '$=': function(attr, val) { return attr.lastIndexOf(val) === attr[LENGTH] - val[LENGTH]; }, // Match ends with value
+        '*=': function(attr, val) { return attr.indexOf(val) > -1; }, // Match contains value as substring 
+        '': function(attr, val) { return attr; } // Just test for existence of attribute
+    },
+
+    /**
+     * List of pseudo-classes and corresponding boolean functions. 
+     * These functions are called with the current node, and any value that was parsed with the pseudo regex.
+     * @property pseudos
+     * @type object
+     */
+    pseudos: {
+        'root': function(node) {
+            return node === node.ownerDocument.documentElement;
+        },
+
+        'nth-child': function(node, val) {
+            return Selector.getNth(node, val);
+        },
+
+        'nth-last-child': function(node, val) {
+            return Selector.getNth(node, val, null, true);
+        },
+
+        'nth-of-type': function(node, val) {
+            return Selector.getNth(node, val, node[TAG_NAME]);
+        },
+         
+        'nth-last-of-type': function(node, val) {
+            return Selector.getNth(node, val, node[TAG_NAME], true);
+        },
+         
+        'first-child': function(node) {
+            return Y.DOM.firstChild(node[PARENT_NODE]) === node;
+        },
+
+        'last-child': function(node) {
+            return Y.DOM.lastChild(node[PARENT_NODE]) === node;
+        },
+
+        'first-of-type': function(node, val) {
+            return Y.DOM.firstChildByTag(node[PARENT_NODE], node[TAG_NAME]) === node;
+        },
+         
+        'last-of-type': function(node, val) {
+            return Y.DOM.lastChildByTag(node[PARENT_NODE], node[TAG_NAME]) === node;
+        },
+         
+        'only-child': function(node) {
+            var children = Y.DOM.children(node[PARENT_NODE]);
+            return children[LENGTH] === 1 && children[0] === node;
+        },
+
+        'only-of-type': function(node) {
+            return Y.DOM.childrenByTag(node[PARENT_NODE], node[TAG_NAME])[LENGTH] === 1;
+        },
+
+        'empty': function(node) {
+            return node.childNodes[LENGTH] === 0;
+        },
+
+        'not': function(node, simple) {
+            return !Selector.test(node, simple);
+        },
+
+        'contains': function(node, str) {
+            var text = node.innerText || node.textContent || '';
+            return text.indexOf(str) > -1;
+        },
+        'checked': function(node) {
+            return node.checked === true;
+        }
+    },
+
+    /**
+     * Test if the supplied node matches the supplied selector.
+     * @method test
+     *
+     * @param {HTMLElement | String} node An id or node reference to the HTMLElement being tested.
+     * @param {string} selector The CSS Selector to test the node against.
+     * @return{boolean} Whether or not the node matches the selector.
+     * @static
+    
+     */
+    test: function(node, selector) {
+        if (!node) {
+            return false;
+        }
+
+        var groups = selector ? selector.split(',') : [];
+        if (groups[LENGTH]) {
+            for (var i = 0, len = groups[LENGTH]; i < len; ++i) {
+                if ( Selector._testNode(node, groups[i]) ) { // passes if ANY group matches
+                    return true;
+                }
+            }
+            return false;
+        }
+        return Selector._testNode(node, selector);
+    },
+
+    /**
+     * Filters a set of nodes based on a given CSS selector. 
+     * @method filter
+     *
+     * @param {array} nodes A set of nodes/ids to filter. 
+     * @param {string} selector The selector used to test each node.
+     * @return{array} An array of nodes from the supplied array that match the given selector.
+     * @static
+     */
+    filter: function(nodes, selector) {
+        nodes = nodes || [];
+
+        var result = Selector._filter(nodes, Selector._tokenize(selector)[0]);
+        return result;
+    },
+
+    /**
+     * Retrieves a set of nodes based on a given CSS selector. 
+     * @method query
+     *
+     * @param {string} selector The CSS Selector to test the node against.
+     * @param {HTMLElement | String} root optional An id or HTMLElement to start the query from. Defaults to Selector.document.
+     * @param {Boolean} firstOnly optional Whether or not to return only the first match.
+     * @return {Array} An array of nodes that match the given selector.
+     * @static
+     */
+    query: function(selector, root, firstOnly) {
+        var result = Selector._query(selector, root, firstOnly);
+        return result;
+    },
+
+    _query: function(selector, root, firstOnly, deDupe) {
+        var result =  (firstOnly) ? null : [];
+        if (!selector) {
+            return result;
+        }
+
+        root = root || Selector.document;
+        var groups = selector.split(','); // TODO: handle comma in attribute/pseudo
+
+        if (groups[LENGTH] > 1) {
+            var found;
+            for (var i = 0, len = groups[LENGTH]; i < len; ++i) {
+                found = arguments.callee(groups[i], root, firstOnly, true);
+                result = firstOnly ? found : result.concat(found); 
+            }
+            Selector._clearFoundCache();
+            return result;
+        }
+
+        var tokens = Selector._tokenize(selector);
+        var idToken = tokens[Selector._getIdTokenIndex(tokens)],
+            nodes = [],
+            node,
+            id,
+            token = tokens.pop() || {};
+            
+        if (idToken) {
+            id = Selector._getId(idToken[ATTRIBUTES]);
+        }
+
+        // use id shortcut when possible
+        if (id) {
+            node = Selector.document.getElementById(id);
+
+            if (node && (root[NODE_TYPE] === 9 || Y.DOM.contains(root, node))) {
+                if ( Selector._testNode(node, null, idToken) ) {
+                    if (idToken === token) {
+                        nodes = [node]; // simple selector
+                    } else {
+                        root = node; // start from here
+                    }
+                }
+            } else {
+                return result;
+            }
+        }
+
+        if (root && !nodes[LENGTH]) {
+            nodes = root.getElementsByTagName(token[TAG]);
+        }
+
+        if (nodes[LENGTH]) {
+            result = Selector._filter(nodes, token, firstOnly, deDupe); 
+        }
+        return result;
+    },
+
+    _filter: function(nodes, token, firstOnly, deDupe) {
+        var result = firstOnly ? null : [];
+
+        result = Y.DOM.filterElementsBy(nodes, function(node) {
+            if (! Selector._testNode(node, '', token, deDupe)) {
+                return false;
+            }
+
+            if (deDupe) {
+                if (node._found) {
+                    return false;
+                }
+                node._found = true;
+                Selector._foundCache[Selector._foundCache[LENGTH]] = node;
+            }
+            return true;
+        }, firstOnly);
+
+        return result;
+    },
+
+    _testNode: function(node, selector, token, deDupe) {
+        token = token || Selector._tokenize(selector).pop() || {};
+        var ops = Selector.operators,
+            pseudos = Selector.pseudos,
+            prev = token.previous,
+            i, len;
+
+        if (!node[TAG_NAME] ||
+            (token[TAG] !== '*' && node[TAG_NAME].toUpperCase() !== token[TAG]) ||
+            (deDupe && node._found) ) {
+            return false;
+        }
+
+        if (token[ATTRIBUTES][LENGTH]) {
+            var attribute;
+            for (i = 0, len = token[ATTRIBUTES][LENGTH]; i < len; ++i) {
+                attribute = node.getAttribute(token[ATTRIBUTES][i][0], 2);
+                if (attribute === undefined) {
+                    return false;
+                }
+                if ( ops[token[ATTRIBUTES][i][1]] &&
+                        !ops[token[ATTRIBUTES][i][1]](attribute, token[ATTRIBUTES][i][2])) {
+                    return false;
+                }
+            }
+        }
+
+        if (token[PSEUDOS][LENGTH]) {
+            for (i = 0, len = token[PSEUDOS][LENGTH]; i < len; ++i) {
+                if (pseudos[token[PSEUDOS][i][0]] &&
+                        !pseudos[token[PSEUDOS][i][0]](node, token[PSEUDOS][i][1])) {
+                    return false;
+                }
+            }
+        }
+        return (prev && prev[COMBINATOR] !== ',') ?
+                Selector.combinators[prev[COMBINATOR]](node, token) :
+                true;
+    },
+
+
+    _foundCache: [],
+    _regexCache: {},
+
+    _clearFoundCache: function() {
+        for (var i = 0, len = Selector._foundCache[LENGTH]; i < len; ++i) {
+            try { // IE no like delete
+                delete Selector._foundCache[i]._found;
+            } catch(e) {
+                Selector._foundCache[i].removeAttribute('_found');
+            }
+        }
+        Selector._foundCache = [];
+    },
+
+    combinators: {
+        ' ': function(node, token) {
+            while ((node = node[PARENT_NODE])) {
+                if (Selector._testNode(node, '', token.previous)) {
+                    return true;
+                }
+            }  
+            return false;
+        },
+
+        '>': function(node, token) {
+            return Selector._testNode(node[PARENT_NODE], null, token.previous);
+        },
+        '+': function(node, token) {
+            var sib = node[PREVIOUS_SIBLING];
+            while (sib && sib[NODE_TYPE] !== 1) {
+                sib = sib[PREVIOUS_SIBLING];
+            }
+
+            if (sib && Selector._testNode(sib, null, token.previous)) {
+                return true; 
+            }
+            return false;
+        },
+
+        '~': function(node, token) {
+            var sib = node[PREVIOUS_SIBLING];
+            while (sib) {
+                if (sib[NODE_TYPE] === 1 && Selector._testNode(sib, null, token.previous)) {
+                    return true;
+                }
+                sib = sib[PREVIOUS_SIBLING];
+            }
+
+            return false;
+        }
+    },
+
+
+    /*
+        an+b = get every _a_th node starting at the _b_th
+        0n+b = no repeat ("0" and "n" may both be omitted (together) , e.g. "0n+1" or "1", not "0+1"), return only the _b_th element
+        1n+b =  get every element starting from b ("1" may may be omitted, e.g. "1n+0" or "n+0" or "n")
+        an+0 = get every _a_th element, "0" may be omitted 
+    */
+    getNth: function(node, expr, tag, reverse) {
+        reNth.test(expr);
+
+        var a = parseInt(RegExp.$1, 10), // include every _a_ elements (zero means no repeat, just first _a_)
+            n = RegExp.$2, // "n"
+            oddeven = RegExp.$3, // "odd" or "even"
+            b = parseInt(RegExp.$4, 10) || 0, // start scan from element _b_
+            op, i, len, siblings;
+
+        if (tag) {
+            siblings = Y.DOM.childrenByTag(node[PARENT_NODE], tag);
+        } else {
+            siblings = Y.DOM.children(node[PARENT_NODE]);
+        }
+
+        if (oddeven) {
+            a = 2; // always every other
+            op = '+';
+            n = 'n';
+            b = (oddeven === 'odd') ? 1 : 0;
+        } else if ( isNaN(a) ) {
+            a = (n) ? 1 : 0; // start from the first or no repeat
+        }
+
+        if (a === 0) { // just the first
+            if (reverse) {
+                b = siblings[LENGTH] - b + 1; 
+            }
+
+            if (siblings[b - 1] === node) {
+                return true;
+            } else {
+                return false;
+            }
+
+        } else if (a < 0) {
+            reverse = !!reverse;
+            a = Math.abs(a);
+        }
+
+        if (!reverse) {
+            for (i = b - 1, len = siblings[LENGTH]; i < len; i += a) {
+                if ( i >= 0 && siblings[i] === node ) {
+                    return true;
+                }
+            }
+        } else {
+            for (i = siblings[LENGTH] - b, len = siblings[LENGTH]; i >= 0; i -= a) {
+                if ( i < len && siblings[i] === node ) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    },
+
+    _getId: function(attr) {
+        for (var i = 0, len = attr[LENGTH]; i < len; ++i) {
+            if (attr[i][0] == 'id' && attr[i][1] === '=') {
+                return attr[i][2];
+            }
+        }
+    },
+
+    _getIdTokenIndex: function(tokens) {
+        for (var i = 0, len = tokens[LENGTH]; i < len; ++i) {
+            if (Selector._getId(tokens[i][ATTRIBUTES])) {
+                return i;
+            }
+        }
+        return -1;
+    },
+
+    /**
+        Break selector into token units per simple selector.
+        Combinator is attached to left-hand selector.
+     */
+    _tokenize: function(selector) {
+        var token = {},     // one token per simple selector (left selector holds combinator)
+            tokens = [],    // array of tokens
+            found = false,  // whether or not any matches were found this pass
+            match;          // the regex match
+
+        selector = Selector._replaceShorthand(selector); // convert ID and CLASS shortcuts to attributes
+
+        /*
+            Search for selector patterns, store, and strip them from the selector string
+            until no patterns match (invalid selector) or we run out of chars.
+
+            Multiple attributes and pseudos are allowed, in any order.
+            for example:
+                'form:first-child[type=button]:not(button)[lang|=en]'
+        */
+        do {
+            found = false; // reset after full pass
+            for (var re in patterns) {
+                if (patterns.hasOwnProperty(re)) {
+                    if (re != TAG && re != COMBINATOR) { // only one allowed
+                        token[re] = token[re] || [];
+                    }
+                    if ((match = patterns[re].exec(selector))) { // note assignment
+                        found = true;
+                        if (re != TAG && re != COMBINATOR) { // only one allowed
+                            //token[re] = token[re] || [];
+
+                            // capture ID for fast path to element
+                            if (re === ATTRIBUTES && match[1] === 'id') {
+                                token.id = match[3];
+                            }
+
+                            token[re].push(match.slice(1));
+                        } else { // single selector (tag, combinator)
+                            token[re] = match[1];
+                        }
+                        selector = selector.replace(match[0], ''); // strip current match from selector
+                        if (re === COMBINATOR || !selector[LENGTH]) { // next token or done
+                            token[ATTRIBUTES] = Selector._fixAttributes(token[ATTRIBUTES]);
+                            token[PSEUDOS] = token[PSEUDOS] || [];
+                            token[TAG] = token[TAG] ? token[TAG].toUpperCase() : '*';
+                            tokens.push(token);
+
+                            token = { // prep next token
+                                previous: token
+                            };
+                        }
+                    }
+                }
+            }
+        } while (found);
+
+        return tokens;
+    },
+
+    _fixAttributes: function(attr) {
+        var aliases = Selector.attrAliases;
+        attr = attr || [];
+        for (var i = 0, len = attr[LENGTH]; i < len; ++i) {
+            if (aliases[attr[i][0]]) { // convert reserved words, etc
+                attr[i][0] = aliases[attr[i][0]];
+            }
+            if (!attr[i][1]) { // use exists operator
+                attr[i][1] = '';
+            }
+        }
+        return attr;
+    },
+
+    _replaceShorthand: function(selector) {
+        var shorthand = Selector.shorthand;
+        var attrs = selector.match(patterns[ATTRIBUTES]); // pull attributes to avoid false pos on "." and "#"
+        if (attrs) {
+            selector = selector.replace(patterns[ATTRIBUTES], 'REPLACED_ATTRIBUTE');
+        }
+        for (var re in shorthand) {
+            if (shorthand.hasOwnProperty(re)) {
+                selector = selector.replace(Y.DOM._getRegExp(re, 'gi'), shorthand[re]);
+            }
+        }
+
+        if (attrs) {
+            for (var i = 0, len = attrs[LENGTH]; i < len; ++i) {
+                selector = selector.replace('REPLACED_ATTRIBUTE', attrs[i]);
+            }
+        }
+        return selector;
+    }
+
+};
+
+if (Y.UA.ie && Y.UA.ie < 8) { // rewrite class for IE (others use getAttribute('class')
+    Selector.attrAliases['class'] = 'className';
+    Selector.attrAliases['for'] = 'htmlFor';
+}
+
+Y.Selector = Selector;
+Y.Selector.patterns = patterns;
+
+
+
+
+}, '3.0.0pr2' ,{skinnable:false, requires:['dom-base']});

=== added directory 'loggerhead/static/javascript/yui/build/dump'
=== added file 'loggerhead/static/javascript/yui/build/dump/README'
--- loggerhead/static/javascript/yui/build/dump/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dump/README	2008-10-20 07:34:21 +0000
@@ -0,0 +1,5 @@
+YUI dump
+    Stringifies objects
+
+3.0.0pr1
+    Inital release

=== added file 'loggerhead/static/javascript/yui/build/dump/dump-debug.js'
--- loggerhead/static/javascript/yui/build/dump/dump-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dump/dump-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,103 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * Returns a simple string representation of the object or array.
+ * Other types of objects will be returned unprocessed.  Arrays
+ * are expected to be indexed.  Use object notation for
+ * associative arrays.
+ *
+ * If included, the dump method is added to the YUI instance.
+ *
+ * @module dump
+ */
+YUI.add("dump", function(Y) {
+
+    var L=Y.Lang, OBJ="{...}", FUN="f(){...}", COMMA=', ', ARROW=' => ',
+
+    /**
+     * The following methods are added to the YUI instance
+     * @class YUI~dump
+     */
+
+    /**
+     * Returns a simple string representation of the object or array.
+     * Other types of objects will be returned unprocessed.  Arrays
+     * are expected to be indexed.  Use object notation for
+     * associative arrays.
+     *
+     * @TODO dumping a window is causing an unhandled exception in
+     * FireFox.
+     *
+     * This method is in the 'dump' module, which is not bundled with
+     * the core YUI object
+     *
+     * @method dump
+     * @param o {object} The object to dump
+     * @param d {int} How deep to recurse child objects, default 3
+     * @return {string} the dump result
+     */
+    dump = function(o, d) {
+        var i, len, s = [];
+
+
+        // Cast non-objects to string
+        // Skip dates because the std toString is what we want
+        // Skip HTMLElement-like objects because trying to dump 
+        // an element will cause an unhandled exception in FF 2.x
+        if (!L.isObject(o)) {
+            return o + "";
+        } else if (o instanceof Date || ("nodeType" in o && "tagName" in o)) {
+            return o;
+        } else if  (L.isFunction(o)) {
+            return FUN;
+        }
+
+        // dig into child objects the depth specifed. Default 3
+        d = (L.isNumber(d)) ? d : 3;
+
+        // arrays [1, 2, 3]
+        if (L.isArray(o)) {
+            s.push("[");
+            for (i=0,len=o.length;i<len;i=i+1) {
+                if (L.isObject(o[i])) {
+                    s.push((d > 0) ? L.dump(o[i], d-1) : OBJ);
+                } else {
+                    s.push(o[i]);
+                }
+                s.push(COMMA);
+            }
+            if (s.length > 1) {
+                s.pop();
+            }
+            s.push("]");
+        // objects {k1 => v1, k2 => v2}
+        } else {
+            s.push("{");
+            for (i in o) {
+                if (Y.Object.owns(o, i)) {
+                    s.push(i + ARROW);
+                    if (L.isObject(o[i])) {
+                        s.push((d > 0) ? L.dump(o[i], d-1) : OBJ);
+                    } else {
+                        s.push(o[i]);
+                    }
+                    s.push(COMMA);
+                }
+            }
+            if (s.length > 1) {
+                s.pop();
+            }
+            s.push("}");
+        }
+
+        return s.join("");
+    };
+
+    Y.dump = dump;
+    L.dump = dump;
+
+}, "3.0.0pr2");

=== added file 'loggerhead/static/javascript/yui/build/dump/dump-min.js'
--- loggerhead/static/javascript/yui/build/dump/dump-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dump/dump-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("dump",function(G){var B=G.Lang,C="{...}",F="f(){...}",A=", ",D=" => ",E=function(L,K){var I,H,J=[];if(!B.isObject(L)){return L+"";}else{if(L instanceof Date||("nodeType" in L&&"tagName" in L)){return L;}else{if(B.isFunction(L)){return F;}}}K=(B.isNumber(K))?K:3;if(B.isArray(L)){J.push("[");for(I=0,H=L.length;I<H;I=I+1){if(B.isObject(L[I])){J.push((K>0)?B.dump(L[I],K-1):C);}else{J.push(L[I]);}J.push(A);}if(J.length>1){J.pop();}J.push("]");}else{J.push("{");for(I in L){if(G.Object.owns(L,I)){J.push(I+D);if(B.isObject(L[I])){J.push((K>0)?B.dump(L[I],K-1):C);}else{J.push(L[I]);}J.push(A);}}if(J.length>1){J.pop();}J.push("}");}return J.join("");};G.dump=E;B.dump=E;},"3.0.0pr2");
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/dump/dump.js'
--- loggerhead/static/javascript/yui/build/dump/dump.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/dump/dump.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,103 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * Returns a simple string representation of the object or array.
+ * Other types of objects will be returned unprocessed.  Arrays
+ * are expected to be indexed.  Use object notation for
+ * associative arrays.
+ *
+ * If included, the dump method is added to the YUI instance.
+ *
+ * @module dump
+ */
+YUI.add("dump", function(Y) {
+
+    var L=Y.Lang, OBJ="{...}", FUN="f(){...}", COMMA=', ', ARROW=' => ',
+
+    /**
+     * The following methods are added to the YUI instance
+     * @class YUI~dump
+     */
+
+    /**
+     * Returns a simple string representation of the object or array.
+     * Other types of objects will be returned unprocessed.  Arrays
+     * are expected to be indexed.  Use object notation for
+     * associative arrays.
+     *
+     * @TODO dumping a window is causing an unhandled exception in
+     * FireFox.
+     *
+     * This method is in the 'dump' module, which is not bundled with
+     * the core YUI object
+     *
+     * @method dump
+     * @param o {object} The object to dump
+     * @param d {int} How deep to recurse child objects, default 3
+     * @return {string} the dump result
+     */
+    dump = function(o, d) {
+        var i, len, s = [];
+
+
+        // Cast non-objects to string
+        // Skip dates because the std toString is what we want
+        // Skip HTMLElement-like objects because trying to dump 
+        // an element will cause an unhandled exception in FF 2.x
+        if (!L.isObject(o)) {
+            return o + "";
+        } else if (o instanceof Date || ("nodeType" in o && "tagName" in o)) {
+            return o;
+        } else if  (L.isFunction(o)) {
+            return FUN;
+        }
+
+        // dig into child objects the depth specifed. Default 3
+        d = (L.isNumber(d)) ? d : 3;
+
+        // arrays [1, 2, 3]
+        if (L.isArray(o)) {
+            s.push("[");
+            for (i=0,len=o.length;i<len;i=i+1) {
+                if (L.isObject(o[i])) {
+                    s.push((d > 0) ? L.dump(o[i], d-1) : OBJ);
+                } else {
+                    s.push(o[i]);
+                }
+                s.push(COMMA);
+            }
+            if (s.length > 1) {
+                s.pop();
+            }
+            s.push("]");
+        // objects {k1 => v1, k2 => v2}
+        } else {
+            s.push("{");
+            for (i in o) {
+                if (Y.Object.owns(o, i)) {
+                    s.push(i + ARROW);
+                    if (L.isObject(o[i])) {
+                        s.push((d > 0) ? L.dump(o[i], d-1) : OBJ);
+                    } else {
+                        s.push(o[i]);
+                    }
+                    s.push(COMMA);
+                }
+            }
+            if (s.length > 1) {
+                s.pop();
+            }
+            s.push("}");
+        }
+
+        return s.join("");
+    };
+
+    Y.dump = dump;
+    L.dump = dump;
+
+}, "3.0.0pr2");

=== added directory 'loggerhead/static/javascript/yui/build/event'
=== added file 'loggerhead/static/javascript/yui/build/event/README'
--- loggerhead/static/javascript/yui/build/event/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/event/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,28 @@
+YUI Event Utility
+    DOM event utilities and the YUI custom event system
+
+3.0.0pr2
+    - Fixed IE notification error when no arguments are supplied.
+    - Added event-simulate.
+    - getListeners works when the element has no listeners defined.
+    - Event.addListener removed.  Exists only in compat layer.
+    - addListerer triggers 2.x event behavior.
+    - Removed extra undefined parameter passed to DOM event listeners.
+    - Compat layer contains Event.on.
+    - Event adapter support added to Y.on
+    - Added Y.on('focus', 'blur' event adaptors (support for propagation
+      of these events.)
+    - publish and subscribe support an object for the type, allowing for multiple
+      events/subscriptions.
+    - subscriber failures throw an error by default rather than log.
+    - subscriber failures are not routed through Y.fail in order to
+      improve the debug experience.
+    - New facades created every fire()
+    - before method re-added to Event.Target, which delegates to Do.before or
+      subscribe.
+    - Event.Target.after will delegate to Do.after if type is a function
+    - Added keylistener: Y.on('key', fn, element, 'down:13,65+ctrl+shift')
+    - event:ready event deprecated in favor of domready.
+
+3.0.0pr1
+    - Initial Release

=== added file 'loggerhead/static/javascript/yui/build/event/event-debug.js'
--- loggerhead/static/javascript/yui/build/event/event-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/event/event-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,3801 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * The YUI event system
+ * @module event
+ */
+YUI.add("event", function(Y) {
+
+    var FOCUS = Y.UA.ie ? "focusin" : "focus",
+        BLUR = Y.UA.ie ? "focusout" : "blur",
+        CAPTURE = "capture_",
+        Lang = Y.Lang;
+
+    Y.Env.eventAdaptors = {
+
+        /**
+         * Adds a DOM focus listener.  Uses the focusin event in IE,
+         * and the capture phase otherwise so that
+         * the event propagates properly.
+         * @for YUI
+         * @event focus
+         */
+        focus: {
+            on: function() {
+                arguments[0] = CAPTURE + FOCUS;
+                return Y.Event.attach.apply(Y.Event, arguments);
+            },
+
+            detach: function() {
+                arguments[0] = CAPTURE + FOCUS;
+                return Y.Event.detach.apply(Y.Event, arguments);
+
+            }
+        },
+
+        /**
+         * Adds a DOM focus listener.  Uses the focusout event in IE,
+         * and the capture phase otherwise so that
+         * the event propagates properly.
+         * @for YUI
+         * @event blur
+         */
+        blur: {
+            on: function() {
+                arguments[0] = CAPTURE + BLUR;
+                return Y.Event.attach.apply(Y.Event, arguments);
+            },
+
+            detach: function() {
+                arguments[0] = CAPTURE + BLUR;
+                return Y.Event.detach.apply(Y.Event, arguments);
+            }
+        },
+
+        /**
+         * Executes the callback as soon as the specified element 
+         * is detected in the DOM.
+         * @for YUI
+         * @event available
+         */
+        available: {
+            on: function(type, fn, id, o) {
+                var a = arguments.length > 4 ?  Y.Array(arguments, 4, true) : [];
+                return Y.Event.onAvailable.call(Y.Event, id, fn, o, a);
+            }
+        },
+
+        /**
+         * Executes the callback as soon as the specified element 
+         * is detected in the DOM with a nextSibling property
+         * (indicating that the element's children are available)
+         * @for YUI
+         * @event contentready
+         */
+        contentready: {
+            on: function(type, fn, id, o) {
+                var a = arguments.length > 4 ?  Y.Array(arguments, 4, true) : [];
+                return Y.Event.onContentReady.call(Y.Event, id, fn, o, a);
+            }
+        },
+
+        /**
+         * Add a key listener.  The listener will only be notified if the
+         * keystroke detected meets the supplied specification.  The
+         * spec consists of the key event type, followed by a colon,
+         * followed by zero or more comma separated key codes, followed
+         * by zero or more modifiers delimited by a plus sign.  Ex:
+         * press:12,65+shift+ctrl
+         * @event key
+         * @param fn {string} the function to execute
+         * @param id {string} the element(s) to bind
+         * @param spec {string} the keyCode and modifier specification
+         * @param o optional context object
+         * @param args 0..n additional arguments that should be provided 
+         * to the listener.
+         */
+        key: {
+
+            on: function(type, fn, id, spec, o) {
+
+                if (!spec || spec.indexOf(':') == -1) {
+Y.log('Illegal key spec, creating a regular keypress listener instead.', 'info', 'event');
+                    arguments[0] = 'keypress';
+                    return Y.on.apply(Y, arguments);
+                }
+
+                // parse spec ([key event type]:[criteria])
+                var parsed = spec.split(':'),
+
+                    // key event type: 'down', 'up', or 'press'
+                    etype = parsed[0],
+
+                    // list of key codes optionally followed by modifiers
+                    criteria = (parsed[1]) ? parsed[1].split(/,|\+/) : null,
+
+                    // the name of the custom event that will be created for the spec
+                    ename = (Lang.isString(id) ? id : Y.stamp(id)) + spec,
+
+                    a = Y.Array(arguments, 0, true);
+
+
+
+                // subscribe spec validator to the DOM event
+                Y.on(type + etype, function(e) {
+
+                    // Y.log('keylistener: ' + e.keyCode);
+                    
+                    var passed = false, failed = false;
+
+                    for (var i=0; i<criteria.length; i=i+1) {
+                        var crit = criteria[i], critInt = parseInt(crit, 10);
+
+                        // pass this section if any supplied keyCode 
+                        // is found
+                        if (Lang.isNumber(critInt)) {
+
+                            if (e.charCode === critInt) {
+                                // Y.log('passed: ' + crit);
+                                passed = true;
+                            } else {
+                                failed = true;
+                                // Y.log('failed: ' + crit);
+                            }
+
+                        // only check modifier if no keyCode was specified
+                        // or the keyCode check was successful.  pass only 
+                        // if every modifier passes
+                        } else if (passed || !failed) {
+                            passed = (e[crit + 'Key']);
+                            failed = !passed;
+                            // Y.log(crit + ": " + passed);
+                        }                    
+                    }
+
+                    // fire spec custom event if spec if met
+                    if (passed) {
+                        Y.fire(ename, e);
+                    }
+
+                }, id);
+
+                // subscribe supplied listener to custom event for spec validator
+                // remove element and spec.
+                a.splice(2, 2);
+                a[0] = ename;
+
+                return Y.on.apply(Y, a);
+            }
+        }
+
+    };
+
+    /**
+     * Attach an event listener, either to a DOM object
+     * or to an Event.Target.
+     * @param type {string} the event type
+     * @param f {Function} the function to execute
+     * @param o the Event.Target or element to attach to
+     * @param context Optional execution context
+     * @param args* 0..n additional arguments to append
+     * to the signature provided when the event fires.
+     * @method on
+     * @for YUI
+     * @return {Event.Handle} a handle object for 
+     * unsubscribing to this event.
+     */
+    Y.on = function(type, f, o) {
+        
+       var adapt = Y.Env.eventAdaptors[type];
+        
+        if (adapt && adapt.on) {
+            Y.log('Using adaptor for ' + type, 'info', 'event');
+            return adapt.on.apply(Y, arguments);
+        } else {
+            if (adapt || type.indexOf(':') > -1) {
+                return Y.subscribe.apply(Y, arguments);
+            } else {
+                return Y.Event.attach.apply(Y.Event, arguments);
+            }
+        }
+
+    };
+
+    /**
+     * Detach an event listener (either a custom event or a
+     * DOM event
+     * @method detach
+     * @param type the type of event, or a Event.Handle to
+     * for the subscription.  If the Event.Handle is passed
+     * in, the other parameters are not used.
+     * @param f {Function} the subscribed function
+     * @param o the object or element the listener is subscribed
+     * to.
+     * @method detach
+     * @return {YUI} the YUI instance
+     */
+    Y.detach = function(type, f, o) {
+
+        var adapt = Y.Env.eventAdaptors[type];
+
+        if (Lang.isObject(type) && type.detach) {
+            return type.detach();
+        } else {
+            if (adapt && adapt.detach) {
+                return adapt.detach.apply(Y, arguments);
+            } else if (adapt || type.indexOf(':') > -1) {
+                return Y.unsubscribe.apply(Y, arguments);
+            } else {
+                return Y.Event.detach.apply(Y.Event, arguments);
+            }
+        }
+    };
+
+    /**
+     * Executes the callback before a DOM event, custom event
+     * or method.  If the first argument is a function, it
+     * is assumed the target is a method.  For DOM and custom
+     * events, this is an alias for Y.on.
+     *
+     * For DOM and custom events:
+     * type, callback, context, 1-n arguments
+     *  
+     * For methods:
+     * callback, object (method host), methodName, context, 1-n arguments
+     *
+     * @method before
+     * @return unsubscribe handle
+     */
+    Y.before = function(type, f, o) { 
+        if (Lang.isFunction(type)) {
+            return Y.Do.before.apply(Y.Do, arguments);
+        } else {
+            return Y.on.apply(Y, arguments);
+        }
+    };
+
+    var after = Y.after;
+
+    /**
+     * Executes the callback after a DOM event, custom event
+     * or method.  If the first argument is a function, it
+     * is assumed the target is a method.
+     *
+     * For DOM and custom events:
+     * type, callback, context, 1-n arguments
+     *  
+     * For methods:
+     * callback, object (method host), methodName, context, 1-n arguments
+     *
+     * @method after
+     * @return {Event.Handle} unsubscribe handle
+     */
+    Y.after = function(type, f, o) {
+        if (Lang.isFunction(type)) {
+            return Y.Do.after.apply(Y.Do, arguments);
+        } else {
+            return after.apply(Y, arguments);
+        }
+    };
+
+
+}, "3.0.0", {
+    use: [
+          "aop", 
+          "event-custom", 
+          "event-target", 
+          "event-ready",
+          "event-dom", 
+          "event-facade",
+          "event-simulate"
+          ]
+});
+/*
+ * Method displacement
+ * @submodule event-aop
+ * @module event
+ */
+YUI.add("aop", function(Y) {
+
+    var BEFORE = 0,
+        AFTER = 1;
+
+    /**
+     * Allows for the insertion of methods that are executed before or after
+     * a specified method
+     * @class Do
+     * @static
+     */
+    Y.Do = {
+
+        /**
+         * Cache of objects touched by the utility
+         * @property objs
+         * @static
+         */
+        objs: {},
+
+        /**
+         * Execute the supplied method before the specified function
+         * @method before
+         * @param fn {Function} the function to execute
+         * @param obj the object hosting the method to displace
+         * @param sFn {string} the name of the method to displace
+         * @param c The execution context for fn
+         * @return {string} handle for the subscription
+         * @static
+         */
+        before: function(fn, obj, sFn, c) {
+            // Y.log('Do before: ' + sFn, 'info', 'event');
+            var f = fn;
+            if (c) {
+                var a = [fn, c].concat(Y.Array(arguments, 4, true));
+                f = Y.bind.apply(Y, a);
+            }
+
+            return this._inject(BEFORE, f, obj, sFn);
+        },
+
+        /**
+         * Execute the supplied method after the specified function
+         * @method after
+         * @param fn {Function} the function to execute
+         * @param obj the object hosting the method to displace
+         * @param sFn {string} the name of the method to displace
+         * @param c The execution context for fn
+         * @return {string} handle for the subscription
+         * @static
+         */
+        after: function(fn, obj, sFn, c) {
+            var f = fn;
+            if (c) {
+                var a = [fn, c].concat(Y.Array(arguments, 4, true));
+                f = Y.bind.apply(Y, a);
+            }
+
+            return this._inject(AFTER, f, obj, sFn);
+        },
+
+        /**
+         * Execute the supplied method after the specified function
+         * @method _inject
+         * @param when {string} before or after
+         * @param fn {Function} the function to execute
+         * @param obj the object hosting the method to displace
+         * @param sFn {string} the name of the method to displace
+         * @param c The execution context for fn
+         * @return {string} handle for the subscription
+         * @private
+         * @static
+         */
+        _inject: function(when, fn, obj, sFn) {
+
+            // object id
+            var id = Y.stamp(obj);
+
+            if (! this.objs[id]) {
+                // create a map entry for the obj if it doesn't exist
+                this.objs[id] = {};
+            }
+            var o = this.objs[id];
+
+            if (! o[sFn]) {
+                // create a map entry for the method if it doesn't exist
+                o[sFn] = new Y.Do.Method(obj, sFn);
+
+                // re-route the method to our wrapper
+                obj[sFn] = 
+                    function() {
+                        return o[sFn].exec.apply(o[sFn], arguments);
+                    };
+            }
+
+            // subscriber id
+            var sid = id + Y.stamp(fn) + sFn;
+
+            // register the callback
+            o[sFn].register(sid, fn, when);
+
+            return new Y.EventHandle(o[sFn], sid);
+
+        },
+
+        /**
+         * Detach a before or after subscription
+         * @method detach
+         * @param handle {string} the subscription handle
+         */
+        detach: function(handle) {
+
+            if (handle.detach) {
+                handle.detach();
+            }
+
+        },
+
+        _unload: function(e, me) {
+
+        }
+    };
+
+    //////////////////////////////////////////////////////////////////////////
+
+    /**
+     * Wrapper for a displaced method with aop enabled
+     * @class Do.Method
+     * @constructor
+     * @param obj The object to operate on
+     * @param sFn The name of the method to displace
+     */
+    Y.Do.Method = function(obj, sFn) {
+        this.obj = obj;
+        this.methodName = sFn;
+        this.method = obj[sFn];
+        // this.before = [];
+        // this.after = [];
+        this.before = {};
+        this.after = {};
+    };
+
+    /**
+     * Register a aop subscriber
+     * @method register
+     * @param sid {string} the subscriber id
+     * @param fn {Function} the function to execute
+     * @param when {string} when to execute the function
+     */
+    Y.Do.Method.prototype.register = function (sid, fn, when) {
+        if (when) {
+            // this.after.push(fn);
+            this.after[sid] = fn;
+        } else {
+            // this.before.push(fn);
+            this.before[sid] = fn;
+        }
+    };
+
+    /**
+     * Unregister a aop subscriber
+     * @method delete
+     * @param sid {string} the subscriber id
+     * @param fn {Function} the function to execute
+     * @param when {string} when to execute the function
+     */
+    Y.Do.Method.prototype._delete = function (sid) {
+        // Y.log('Y.Do._delete: ' + sid, 'info', 'Event');
+        delete this.before[sid];
+        delete this.after[sid];
+    };
+
+    /**
+     * Execute the wrapped method
+     * @method exec
+     */
+    Y.Do.Method.prototype.exec = function () {
+
+        var args = Y.Array(arguments, 0, true), 
+            i, ret, newRet, 
+            bf = this.before,
+            af = this.after,
+            prevented = false;
+
+        // execute before
+        for (i in bf) {
+            if (bf.hasOwnProperty(i)) {
+                ret = bf[i].apply(this.obj, args);
+                if (ret) {
+                    switch (ret.constructor) {
+                        case Y.Do.Halt:
+                            return ret.retVal;
+                        case Y.Do.AlterArgs:
+                            args = ret.newArgs;
+                            break;
+                        case Y.Do.Prevent:
+                            prevented = true;
+                            break;
+                        default:
+                    }
+                }
+            }
+        }
+
+        // execute method
+        if (!prevented) {
+            ret = this.method.apply(this.obj, args);
+        }
+
+        // execute after methods.
+        for (i in af) {
+            if (af.hasOwnProperty(i)) {
+                newRet = af[i].apply(this.obj, args);
+                // Stop processing if a Halt object is returned
+                if (newRet && newRet.constructor == Y.Do.Halt) {
+                    return newRet.retVal;
+                // Check for a new return value
+                } else if (newRet && newRet.constructor == Y.Do.AlterReturn) {
+                    ret = newRet.newRetVal;
+                }
+            }
+        }
+
+        return ret;
+    };
+
+    //////////////////////////////////////////////////////////////////////////
+
+
+    /**
+     * Return an AlterArgs object when you want to change the arguments that
+     * were passed into the function.  An example would be a service that scrubs
+     * out illegal characters prior to executing the core business logic.
+     * @class Do.AlterArgs
+     */
+    Y.Do.AlterArgs = function(msg, newArgs) {
+        this.msg = msg;
+        this.newArgs = newArgs;
+    };
+
+    /**
+     * Return an AlterReturn object when you want to change the result returned
+     * from the core method to the caller
+     * @class Do.AlterReturn
+     */
+    Y.Do.AlterReturn = function(msg, newRetVal) {
+        this.msg = msg;
+        this.newRetVal = newRetVal;
+    };
+
+    /**
+     * Return a Halt object when you want to terminate the execution
+     * of all subsequent subscribers as well as the wrapped method
+     * if it has not exectued yet.
+     * @class Do.Halt
+     */
+    Y.Do.Halt = function(msg, retVal) {
+        this.msg = msg;
+        this.retVal = retVal;
+    };
+
+    /**
+     * Return a Prevent object when you want to prevent the wrapped function
+     * from executing, but want the remaining listeners to execute
+     * @class Do.Halt
+     */
+    Y.Do.Prevent = function(msg) {
+        this.msg = msg;
+    };
+
+    /**
+     * Return an Error object when you want to terminate the execution
+     * of all subsequent method calls.
+     * @class Do.Error
+     * @deprecated
+     */
+    Y.Do.Error = Y.Do.Halt;
+
+    //////////////////////////////////////////////////////////////////////////
+
+// Y["Event"] && Y.Event.addListener(window, "unload", Y.Do._unload, Y.Do);
+
+}, "3.0.0");
+/*
+ * YUI Custom Events
+ * @submodule event-custom
+ * @module event
+ */
+YUI.add("event-custom", function(Y) {
+
+    var onsubscribeType = "_event:onsub",
+        AFTER = 'after', 
+        CONFIGS = [
+            'broadcast',
+            'bubbles',
+            'context',
+            'configured',
+            'currentTarget',
+            'defaultFn',
+            'details',
+            'emitFacade',
+            'fireOnce',
+            'host',
+            'preventable',
+            'preventedFn',
+            'queuable',
+            'silent',
+            'stoppedFn',
+            'target',
+            'type'
+        ],
+
+        YUI3_SIGNATURE = 9;
+
+    /**
+     * Return value from all subscribe operations
+     * @class Event.Handle
+     * @constructor
+     * @param evt {Event.Custom} the custom event
+     * @param sub {Event.Subscriber} the subscriber
+     */
+    Y.EventHandle = function(evt, sub) {
+
+        /**
+         * The custom event
+         * @type Event.Custom
+         */
+        this.evt = evt;
+
+        /**
+         * The subscriber object
+         * @type Event.Subscriber
+         */
+        this.sub = sub;
+    };
+
+    Y.EventHandle.prototype = {
+        /**
+         * Detaches this subscriber
+         * @method detach
+         */
+        detach: function() {
+
+            if (this.evt) {
+                // Y.log('EventHandle.detach: ' + this.sub, 'info', 'Event');
+                this.evt._delete(this.sub);
+            }
+        }
+    };
+
+    /**
+     * The Event.Custom class lets you define events for your application
+     * that can be subscribed to by one or more independent component.
+     *
+     * @param {String}  type The type of event, which is passed to the callback
+     *                  when the event fires
+     * @param o configuration object
+     * @class Event.Custom
+     * @constructor
+     */
+    Y.CustomEvent = function(type, o) {
+
+        // if (arguments.length > 2) {
+// this.log('CustomEvent context and silent are now in the config', 'warn', 'Event');
+        // }
+
+        o = o || {};
+
+        this.id = Y.stamp(this);
+
+        /**
+         * The type of event, returned to subscribers when the event fires
+         * @property type
+         * @type string
+         */
+        this.type = type;
+
+        /**
+         * The context the the event will fire from by default.  Defaults to the YUI
+         * instance.
+         * @property context
+         * @type object
+         */
+        this.context = Y;
+
+        this.logSystem = (type == "yui:log");
+
+        /**
+         * If 0, this event does not broadcast.  If 1, the YUI instance is notified
+         * every time this event fires.  If 2, the YUI instance and the YUI global
+         * (if event is enabled on the global) are notified every time this event
+         * fires.
+         * @property broadcast
+         * @type int
+         */
+        this.broadcast = 0;
+
+        /**
+         * By default all custom events are logged in the debug build, set silent
+         * to true to disable debug outpu for this event.
+         * @property silent
+         * @type boolean
+         */
+        this.silent = this.logSystem;
+
+        // this.queuable = !(this.logSystem);
+        this.queuable = false;
+
+        /**
+         * The subscribers to this event
+         * @property subscribers
+         * @type Event.Subscriber{}
+         */
+        this.subscribers = {};
+
+        /*
+         * The publisher has configured this event
+         * @property configured
+         * @type boolean
+         * @default true
+         */
+        // this.configured = true;
+
+        /**
+         * 'After' subscribers
+         * @property afters
+         * @type Event.Subscriber{}
+         */
+        this.afters = {};
+
+        /**
+         * This event has fired if true
+         *
+         * @property fired
+         * @type boolean
+         * @default false;
+         */
+        this.fired = false;
+
+        /**
+         * This event should only fire one time if true, and if
+         * it has fired, any new subscribers should be notified
+         * immediately.
+         *
+         * @property fireOnce
+         * @type boolean
+         * @default false;
+         */
+        this.fireOnce = false;
+
+        /**
+         * Flag for stopPropagation that is modified during fire()
+         * 1 means to stop propagation to bubble targets.  2 means
+         * to also stop additional subscribers on this target.
+         * @property stopped
+         * @type int
+         */
+        this.stopped = 0;
+
+        /**
+         * Flag for preventDefault that is modified during fire().
+         * if it is not 0, the default behavior for this event
+         * @property prevented
+         * @type int
+         */
+        this.prevented = 0;
+
+        /**
+         * Specifies the host for this custom event.  This is used
+         * to enable event bubbling
+         * @property host
+         * @type Event.Target
+         */
+        this.host = null;
+
+        /**
+         * The default function to execute after event listeners
+         * have fire, but only if the default action was not
+         * prevented.
+         * @property defaultFn
+         * @type Function
+         */
+        this.defaultFn = null;
+
+        /**
+         * The function to execute if a subscriber calls
+         * stopPropagation or stopImmediatePropagation
+         * @property stoppedFn
+         * @type Function
+         */
+        this.stoppedFn = null;
+
+        /**
+         * The function to execute if a subscriber calls
+         * preventDefault
+         * @property preventedFn
+         * @type Function
+         */
+        this.preventedFn = null;
+
+        /**
+         * Specifies whether or not this event's default function
+         * can be cancelled by a subscriber by executing preventDefault() 
+         * on the event facade 
+         * @property preventable 
+         * @type boolean 
+         * @default true
+         */
+        this.preventable = true;
+
+        /**
+         * Specifies whether or not a subscriber can stop the event propagation
+         * via stopPropagation(), stopImmediatePropagation(), or halt()
+         * @property bubbles
+         * @type boolean
+         * @default true
+         */
+        this.bubbles = true;
+
+        /**
+         * Supports multiple options for listener signatures in order to
+         * port YUI 2 apps.
+         * @property signature
+         * @type int
+         * @default 9
+         */
+        this.signature = YUI3_SIGNATURE;
+
+        /**
+         * If set to true, the custom event will deliver an Event.Facade object
+         * that is similar to a DOM event object.
+         * @property emitFacade
+         * @type boolean
+         * @default false
+         */
+        this.emitFacade = false;
+
+        this.applyConfig(o, true);
+
+        this.log("Creating " + this.type);
+
+        // Only add subscribe events for events that are not generated by 
+        // Event.Custom
+        if (type !== onsubscribeType) {
+
+            /**
+             * Custom events provide a custom event that fires whenever there is
+             * a new subscriber to the event.  This provides an opportunity to
+             * handle the case where there is a non-repeating event that has
+             * already fired has a new subscriber.  
+             *
+             * @event subscribeEvent
+             * @type Event.Custom
+             * @param {Function} fn The function to execute
+             * @param {Object}   obj An object to be passed along when the event 
+             *                       fires
+             * @param {boolean|Object}  override If true, the obj passed in becomes 
+             *                                   the execution context of the listener.
+             *                                   if an object, that object becomes the
+             *                                   the execution context.
+             */
+            this.subscribeEvent = new Y.CustomEvent(onsubscribeType, {
+                    context: this,
+                    silent: true
+                });
+        } 
+
+    };
+
+    Y.CustomEvent.prototype = {
+
+        _YUI_EVENT: true,
+
+        /**
+         * Apply configuration properties.  Only applies the CONFIG whitelist
+         * @method applyConfig
+         * @param o hash of properties to apply
+         * @param force {boolean} if true, properties that exist on the event 
+         * will be overwritten.
+         */
+        applyConfig: function(o, force) {
+            if (o) {
+                Y.mix(this, o, force, CONFIGS);
+            }
+        },
+
+        _subscribe: function(fn, obj, args, when) {
+
+            if (!fn) {
+                Y.fail("Invalid callback for CE: " + this.type);
+            }
+
+            var se = this.subscribeEvent;
+            if (se) {
+                se.fire.apply(se, args);
+            }
+
+            var s = new Y.Subscriber(fn, obj, args, when);
+
+
+            if (this.fireOnce && this.fired) {
+
+                // this._notify(s);
+                // setTimeout(Y.bind(this._notify, this, s), 0);
+                Y.later(0, this, this._notify, s);
+            }
+
+            if (when == AFTER) {
+                this.afters[s.id] = s;
+            } else {
+                this.subscribers[s.id] = s;
+            }
+
+            return new Y.EventHandle(this, s);
+
+        },
+
+        /**
+         * Listen for this event
+         * @method subscribe
+         * @param {Function} fn        The function to execute
+         * @param {Object}   obj       An object to be passed along when the event fires
+         * @param args* 1..n params to provide to the listener
+         * @return {Event.Handle} unsubscribe handle
+         */
+        subscribe: function(fn, obj) {
+            return this._subscribe(fn, obj, arguments, true);
+        },
+
+        /**
+         * Listen for this event after the normal subscribers have been notified and
+         * the default behavior has been applied.  If a normal subscriber prevents the 
+         * default behavior, it also prevents after listeners from firing.
+         * @method after
+         * @param {Function} fn        The function to execute
+         * @param {Object}   obj       An object to be passed along when the event fires
+         * @param args* 1..n params to provide to the listener
+         * @return {Event.Handle} unsubscribe handle
+         */
+        after: function(fn, obj) {
+            return this._subscribe(fn, obj, arguments, AFTER);
+        },
+
+        /**
+         * Unsubscribes subscribers.
+         * @method unsubscribe
+         * @param {Function} fn  The subscribed function to remove, if not supplied
+         *                       all will be removed
+         * @param {Object}   obj  The custom object passed to subscribe.  This is
+         *                        optional, but if supplied will be used to
+         *                        disambiguate multiple listeners that are the same
+         *                        (e.g., you subscribe many object using a function
+         *                        that lives on the prototype)
+         * @return {boolean} True if the subscriber was found and detached.
+         */
+        unsubscribe: function(fn, obj) {
+
+            // if arg[0] typeof unsubscribe handle
+            if (fn && fn.detach) {
+                return fn.detach();
+            }
+
+            if (!fn) {
+                return this.unsubscribeAll();
+            }
+
+            var found = false, subs = this.subscribers;
+            for (var i in subs) {
+                if (subs.hasOwnProperty(i)) {
+                    var s = subs[i];
+                    if (s && s.contains(fn, obj)) {
+                        this._delete(s);
+                        found = true;
+                    }
+                }
+            }
+
+            return found;
+        },
+
+        _getFacade: function(args) {
+
+            var ef = this._facade;
+
+            if (!ef) {
+                ef = new Y.Event.Facade(this, this.currentTarget);
+            }
+
+            // if the first argument is an object literal, apply the
+            // properties to the event facade
+            var o = args && args[0];
+            if (Y.Lang.isObject(o, true) && !o._yuifacade) {
+                Y.mix(ef, o, true);
+            }
+
+            // update the details field with the arguments
+            ef.details = this.details;
+            ef.target = this.target;
+            ef.currentTarget = this.currentTarget;
+            ef.stopped = 0;
+            ef.prevented = 0;
+
+            this._facade = ef;
+
+            return this._facade;
+        },
+
+        /**
+         * Notify a single subscriber
+         * @method _notify
+         * @param s {Event.Subscriber} the subscriber
+         * @param args {Array} the arguments array to apply to the listener
+         * @private
+         */
+        _notify: function(s, args, ef) {
+
+            this.log(this.type + "->" + ": " +  s);
+
+            var ret, c, ct;
+
+            // emit an Event.Facade if this is that sort of event
+            // if (this.emitFacade && (!args[0] || !args[0]._yuifacade)) {
+            if (this.emitFacade) {
+
+                // @TODO object literal support to fire makes it possible for
+                // config info to be passed if we wish.
+                
+                if (!ef) {
+                    ef = this._getFacade(args);
+                    args[0] = ef;
+                }
+
+            }
+
+            // The default context should be the object/element that
+            // the listener was bound to.
+            ct = (args && Y.Lang.isObject(args[0]) && args[0].currentTarget);
+            ret = s.notify(ct || this.context, args, this);
+
+            if (false === ret || this.stopped > 1) {
+                this.log(this.type + " cancelled by subscriber");
+                return false;
+            }
+
+            return true;
+        },
+
+        /**
+         * Logger abstraction to centralize the application of the silent flag
+         * @method log
+         * @param msg {string} message to log
+         * @param cat {string} log category
+         */
+        log: function(msg, cat) {
+            var es = Y.Env._eventstack, s =  es && es.logging;
+            // if (!s && !this.silent) {
+            if (!this.silent) {
+                Y.log(this.id + ': ' + msg, cat || "info", "event");
+            }
+        },
+
+        /**
+         * Notifies the subscribers.  The callback functions will be executed
+         * from the context specified when the event was created, and with the 
+         * following parameters:
+         *   <ul>
+         *   <li>The type of event</li>
+         *   <li>All of the arguments fire() was executed with as an array</li>
+         *   <li>The custom object (if any) that was passed into the subscribe() 
+         *       method</li>
+         *   </ul>
+         * @method fire 
+         * @param {Object*} arguments an arbitrary set of parameters to pass to 
+         *                            the handler.
+         * @return {boolean} false if one of the subscribers returned false, 
+         *                   true otherwise
+         */
+        fire: function() {
+
+            var es = Y.Env._eventstack;
+
+            if (es) {
+
+                // var b = this.bubbles, h = this.host;
+                // if (b && h) {
+                //     b = (h._yuievt.targets.length);
+                // }
+
+                // es.silent = (es.silent || this.silent);
+
+                // queue this event if the current item in the queue bubbles
+                // if (b && this.queuable && this.type != es.next.type) {
+                if (this.queuable && this.type != es.next.type) {
+
+                    this.log('queue ' + this.type);
+
+                    es.queue.push([this, arguments]);
+                    return true;
+                }
+
+            } else {
+
+                Y.Env._eventstack = {
+                   // id of the first event in the stack
+                   id: this.id,
+                   next: this,
+                   silent: this.silent,
+                   logging: (this.type === 'yui:log'),
+                   stopped: 0,
+                   prevented: 0,
+                   queue: []
+                };
+
+                es = Y.Env._eventstack;
+            }
+
+            var ret = true;
+
+            if (this.fireOnce && this.fired) {
+
+                this.log('fireOnce event: ' + this.type + ' already fired');
+
+            } else {
+
+                // var subs = this.subscribers.slice(), len=subs.length,
+                var subs = Y.merge(this.subscribers), s,
+                           args=Y.Array(arguments, 0, true), i;
+
+                this.stopped = 0;
+                this.prevented = 0;
+                this.target = this.target || this.host;
+
+                this.currentTarget = this.host || this.currentTarget;
+
+                this.fired = true;
+                this.details = args.slice(); // original arguments in the details
+
+                // this.log("Firing " + this  + ", " + "args: " + args);
+                this.log("Firing " + this.type);
+
+                var hasSub = false;
+                es.lastLogState = es.logging;
+
+
+                var ef = null;
+                if (this.emitFacade) {
+
+                    // this.fire({
+                    //   foo: 1
+                    //   bar: 2
+                    // }
+                    // this.fire({
+                    //   bar: 2
+                    // } // foo is still 1 unless we create a new facade
+                    this._facade = null;
+
+                    ef = this._getFacade(args);
+                    args[0] = ef;
+                }
+
+                for (i in subs) {
+                    if (subs.hasOwnProperty(i)) {
+
+                        if (!hasSub) {
+                            es.logging = (es.logging || (this.type === 'yui:log'));
+                            hasSub = true;
+                        }
+
+                        // stopImmediatePropagation
+                        if (this.stopped == 2) {
+                            break;
+                        }
+
+                        s = subs[i];
+                        if (s && s.fn) {
+                            ret = this._notify(s, args, ef);
+                            if (false === ret) {
+                                this.stopped = 2;
+                            }
+                        }
+                    }
+                }
+
+                es.logging = (es.lastLogState);
+
+                // bubble if this is hosted in an event target and propagation has not been stopped
+                // @TODO check if we need to worry about defaultFn order
+                if (this.bubbles && this.host && !this.stopped) {
+                    es.stopped = 0;
+                    es.prevented = 0;
+                    ret = this.host.bubble(this);
+
+                    this.stopped = Math.max(this.stopped, es.stopped);
+                    this.prevented = Math.max(this.prevented, es.prevented);
+                }
+
+                // execute the default behavior if not prevented
+                // @TODO need context
+                if (this.defaultFn && !this.prevented) {
+                    this.defaultFn.apply(this.host || this, args);
+                }
+
+                // process after listeners.  If the default behavior was
+                // prevented, the after events don't fire.
+                if (!this.prevented && this.stopped < 2) {
+                    subs = Y.merge(this.afters);
+                    for (i in subs) {
+                        if (subs.hasOwnProperty(i)) {
+
+                            if (!hasSub) {
+                                es.logging = (es.logging || (this.type === 'yui:log'));
+                                hasSub = true;
+                            }
+
+                            // stopImmediatePropagation
+                            if (this.stopped == 2) {
+                                break;
+                            }
+
+                            s = subs[i];
+                            if (s && s.fn) {
+                                ret = this._notify(s, args, ef);
+                                if (false === ret) {
+                                    this.stopped = 2;
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+
+            if (es.id === this.id) {
+// console.log('clearing stack: ' + es.id + ', ' + this);
+
+// reset propragation properties while processing the rest of the queue
+
+// process queued events
+                var queue = es.queue;
+
+                while (queue.length) {
+                    // q[0] = the event, q[1] = arguments to fire
+                    var q = queue.pop(), ce = q[0];
+
+// Y.log('firing queued event ' + ce.type + ', from ' + this);
+                    es.stopped = 0;
+                    es.prevented = 0;
+                    
+// set up stack to allow the next item to be processed
+                    es.next = ce;
+
+                    ret = ce.fire.apply(ce, q[1]);
+                }
+
+                Y.Env._eventstack = null;
+            } 
+
+            return (ret !== false);
+        },
+
+        /**
+         * Removes all listeners
+         * @method unsubscribeAll
+         * @return {int} The number of listeners unsubscribed
+         */
+        unsubscribeAll: function() {
+            var subs = this.subscribers, i;
+            for (i in subs) {
+                if (subs.hasOwnProperty(i)) {
+                    this._delete(subs[i]);
+                }
+            }
+
+            this.subscribers={};
+
+            return i;
+        },
+
+        /**
+         * @method _delete
+         * @param subscriber object
+         * @private
+         */
+        _delete: function(s) {
+
+            if (s) {
+                delete s.fn;
+                delete s.obj;
+                delete this.subscribers[s.id];
+                delete this.afters[s.id];
+            }
+
+        },
+
+        /**
+         * @method toString
+         */
+        toString: function() {
+             // return "{ CE '" + this.type + "' " + "id: " + this.id +
+                  // ", host: " + (this.host && Y.stamp(this.host) + " }");
+             return this.type;
+        },
+
+        /**
+         * Stop propagation to bubble targets
+         * @method stopPropagation
+         */
+        stopPropagation: function() {
+            this.stopped = 1;
+            Y.Env._eventstack.stopped = 1;
+            if (this.stoppedFn) {
+                this.stoppedFn.call(this.host || this, this);
+            }
+        },
+
+        /**
+         * Stops propagation to bubble targets, and prevents any remaining
+         * subscribers on the current target from executing.
+         * @method stopImmediatePropagation
+         */
+        stopImmediatePropagation: function() {
+            this.stopped = 2;
+            Y.Env._eventstack.stopped = 2;
+            if (this.stoppedFn) {
+                this.stoppedFn.call(this.host || this, this);
+            }
+        },
+
+        /**
+         * Prevents the execution of this event's defaultFn
+         * @method preventDefault
+         */
+        preventDefault: function() {
+            if (this.preventable) {
+                this.prevented = 1;
+                Y.Env._eventstack.prevented = 1;
+            }
+            if (this.preventedFn) {
+                this.preventedFn.call(this.host || this, this);
+            }
+        }
+
+    };
+
+    /////////////////////////////////////////////////////////////////////
+
+    /**
+     * Stores the subscriber information to be used when the event fires.
+     * @param {Function} fn       The wrapped function to execute
+     * @param {Object}   obj      An object to be passed along when the event fires
+     * @param {Array} args        subscribe() additional arguments
+     *
+     * @class Event.Subscriber
+     * @constructor
+     */
+    Y.Subscriber = function(fn, obj, args) {
+
+        /**
+         * The callback that will be execute when the event fires
+         * This is wrapped by Y.bind if obj was supplied.
+         * @property fn
+         * @type Function
+         */
+        this.fn = fn;
+
+        /**
+         * An optional custom object that will passed to the callback when
+         * the event fires
+         * @property obj
+         * @type Object
+         */
+        this.obj = obj;
+
+        /**
+         * Unique subscriber id
+         * @property id
+         * @type String
+         */
+        this.id = Y.stamp(this);
+
+        /**
+         * Optional additional arguments supplied to subscribe().  If present,
+         * these will be appended to the arguments supplied to fire()
+         * @property args
+         * @type Array
+         */
+        // this.args = args;
+
+        /**
+         * }
+         * fn bound to obj with additional arguments applied via Y.bind
+         * @property wrappedFn
+         * @type Function
+         */
+        this.wrappedFn = fn;
+        
+        if (obj) {
+            /*
+            var a = (args) ? Y.Array(args) : [];
+            a.unshift(fn, obj);
+            // a.unshift(fn);
+            m = Y.bind.apply(Y, a);
+            */
+            this.wrappedFn = Y.bind.apply(Y, args);
+        }
+        
+
+
+    };
+
+    Y.Subscriber.prototype = {
+
+        /**
+         * Executes the subscriber.
+         * @method notify
+         * @param defaultContext The execution context if not overridden
+         * by the subscriber
+         * @param args {Array} Arguments array for the subscriber
+         * @param ce {Event.Custom} The custom event that sent the notification
+         */
+        notify: function(defaultContext, args, ce) {
+            var c = this.obj || defaultContext, ret = true,
+
+                f = function() {
+                    switch (ce.signature) {
+                        case 0:
+                            ret = this.fn.call(c, ce.type, args, this.obj);
+                            break;
+                        case 1:
+                            ret = this.fn.call(c, args[0] || null, this.obj);
+                            break;
+                        default:
+                            ret = this.wrappedFn.apply(c, args || []);
+                    }
+                };
+
+            // Ease debugging by only catching errors if we will not re-throw
+            // them.
+            if (Y.config.throwFail) {
+                f.call(this);
+            } else {
+                try {
+                    f.call(this);
+                } catch(e) {
+                    Y.fail(this + ' failed: ' + e.message, e);
+                }
+            }
+
+            return ret;
+        },
+
+        /**
+         * Returns true if the fn and obj match this objects properties.
+         * Used by the unsubscribe method to match the right subscriber.
+         *
+         * @method contains
+         * @param {Function} fn the function to execute
+         * @param {Object} obj an object to be passed along when the event fires
+         * @return {boolean} true if the supplied arguments match this 
+         *                   subscriber's signature.
+         */
+        contains: function(fn, obj) {
+            if (obj) {
+                return ((this.fn == fn) && this.obj == obj);
+            } else {
+                return (this.fn == fn);
+            }
+        },
+
+        /**
+         * @method toString
+         */
+        toString: function() {
+            return "Subscriber " + this.id;
+        }
+    };
+
+}, "3.0.0");
+/*
+ * Configures an object to be able to be targeted for events, and to publish events
+ * @submodule event-target
+ * @module event
+ */
+YUI.add("event-target", function(Y) {
+
+    var SILENT = { 'yui:log': true };
+
+    /**
+     * Event.Target is designed to be used with Y.augment to wrap 
+     * Event.Custom in an interface that allows events to be subscribed to 
+     * and fired by name.  This makes it possible for implementing code to
+     * subscribe to an event that either has not been created yet, or will
+     * not be created at all.
+     *
+     * @Class Event.Target
+     */
+    Y.EventTarget = function(opts) { 
+
+        // console.log('Event.Target constructor executed: ' + this._yuid);
+
+        var o = (Y.Lang.isObject(opts)) ? opts : {};
+
+        this._yuievt = {
+
+            events: {},
+
+            targets: {},
+
+            config: o,
+
+            defaults: {
+                context: this, 
+                host: this,
+                emitFacade: o.emitFacade || false,
+                bubbles: ('bubbles' in o) ? o.bubbles : true
+            }
+            
+        };
+
+    };
+
+    var ET = Y.EventTarget;
+
+
+    ET.prototype = {
+
+        /**
+         * Subscribe to a custom event hosted by this object
+         * @method subscribe
+         * @param type    {string}   The type of the event
+         * @param fn {Function} The callback
+         * @param context The execution context
+         * @param args* 1..n params to supply to the callback
+         */
+        subscribe: function(type, fn, context) {
+
+            if (Y.Lang.isObject(type)) {
+
+                var f = fn, c = context, args = Y.Array(arguments, 0, true),
+                    ret = {};
+
+                Y.each(type, function(v, k) {
+
+                    if (v) {
+                        f = v.fn || f;
+                        c = v.context || c;
+                    }
+
+                    args[0] = k;
+                    args[1] = f;
+                    args[2] = c;
+
+                    ret[k] = this.subscribe.apply(this, args); 
+
+                }, this);
+
+                return ret;
+
+            }
+
+            var ce = this._yuievt.events[type] || 
+                // this.publish(type, {
+                //     configured: false
+                // }),
+                this.publish(type),
+                a = Y.Array(arguments, 1, true);
+
+            return ce.subscribe.apply(ce, a);
+
+        },
+
+        /**
+         * Unsubscribes one or more listeners the from the specified event
+         * @method unsubscribe
+         * @param type {string|Object}   Either the handle to the subscriber or the 
+         *                        type of event.  If the type
+         *                        is not specified, it will attempt to remove
+         *                        the listener from all hosted events.
+         * @param fn   {Function} The subscribed function to unsubscribe, if not
+         *                          supplied, all subscribers will be removed.
+         * @param context  {Object}   The custom object passed to subscribe.  This is
+         *                        optional, but if supplied will be used to
+         *                        disambiguate multiple listeners that are the same
+         *                        (e.g., you subscribe many object using a function
+         *                        that lives on the prototype)
+         * @return {boolean} true if the subscriber was found and detached.
+         */
+        unsubscribe: function(type, fn, context) {
+
+            // If this is an event handle, use it to detach
+            if (Y.Lang.isObject(type) && type.detach) {
+                return type.detach();
+            }
+
+            var evts = this._yuievt.events;
+
+            if (type) {
+                var ce = evts[type];
+                if (ce) {
+                    return ce.unsubscribe(fn, context);
+                }
+            } else {
+                var ret = true;
+                for (var i in evts) {
+                    if (Y.Object.owns(evts, i)) {
+                        ret = ret && evts[i].unsubscribe(fn, context);
+                    }
+                }
+                return ret;
+            }
+
+            return false;
+        },
+        
+        /**
+         * Removes all listeners from the specified event.  If the event type
+         * is not specified, all listeners from all hosted custom events will
+         * be removed.
+         * @method unsubscribeAll
+         * @param type {string}   The type, or name of the event
+         */
+        unsubscribeAll: function(type) {
+            return this.unsubscribe(type);
+        },
+
+        /**
+         * Creates a new custom event of the specified type.  If a custom event
+         * by that name already exists, it will not be re-created.  In either
+         * case the custom event is returned. 
+         *
+         * @method publish
+         *
+         * @param type {string} the type, or name of the event
+         * @param opts {object} optional config params.  Valid properties are:
+         *
+         *  <ul>
+         *    <li>
+         *   'broadcast': whether or not the YUI instance and YUI global are notified when the event is fired (false)
+         *    </li>
+         *    <li>
+         *   'bubbles': whether or not this event bubbles (true)
+         *    </li>
+         *    <li>
+         *   'context': the default execution context for the listeners (this)
+         *    </li>
+         *    <li>
+         *   'defaultFn': the default function to execute when this event fires if preventDefault was not called
+         *    </li>
+         *    <li>
+         *   'emitFacade': whether or not this event emits a facade (false)
+         *    </li>
+         *    <li>
+         *   'fireOnce': if an event is configured to fire once, new subscribers after
+         *   the fire will be notified immediately.
+         *    </li>
+         *    <li>
+         *   'preventable': whether or not preventDefault() has an effect (true)
+         *    </li>
+         *    <li>
+         *   'preventedFn': a function that is executed when preventDefault is called
+         *    </li>
+         *    <li>
+         *   'queuable': whether or not this event can be queued during bubbling (false)
+         *    </li>
+         *    <li>
+         *   'silent': if silent is true, debug messages are not provided for this event.
+         *    </li>
+         *    <li>
+         *   'stoppedFn': a function that is executed when stopPropagation is called
+         *    </li>
+         *    <li>
+         *   'type': the event type (valid option if not provided as the first parameter to publish)
+         *    </li>
+         *  </ul>
+         *
+         *  @return {Event.Custom} the custom event
+         *
+         */
+        publish: function(type, opts) {
+
+            if (Y.Lang.isObject(type)) {
+                var ret = {};
+                Y.each(type, function(v, k) {
+                    ret[k] = this.publish(k, v || opts); 
+                }, this);
+
+                return ret;
+            }
+
+            var events = this._yuievt.events, ce = events[type];
+
+            //if (ce && !ce.configured) {
+            if (ce) {
+// ce.log("publish applying config to published event: '"+type+"' exists", 'info', 'event');
+
+                // This event could have been published
+                ce.applyConfig(opts, true);
+                // ce.configured = true;
+
+            } else {
+                var o = opts || {};
+
+                // apply defaults
+                Y.mix(o, this._yuievt.defaults);
+
+                ce = new Y.CustomEvent(type, o);
+
+                events[type] = ce;
+
+                if (o.onSubscribeCallback) {
+                    ce.subscribeEvent.subscribe(o.onSubscribeCallback);
+                }
+
+            }
+
+            return events[type];
+        },
+
+        /**
+         * Registers another Event.Target as a bubble target.  Bubble order
+         * is determined by the order registered.  Multiple targets can
+         * be specified.
+         * @method addTarget
+         * @param o {Event.Target} the target to add
+         */
+        addTarget: function(o) {
+            this._yuievt.targets[Y.stamp(o)] = o;
+            this._yuievt.hasTargets = true;
+        },
+
+        /**
+         * Removes a bubble target
+         * @method removeTarget
+         * @param o {Event.Target} the target to remove
+         */
+        removeTarget: function(o) {
+            delete this._yuievt.targets[Y.stamp(o)];
+        },
+
+       /**
+         * Fire a custom event by name.  The callback functions will be executed
+         * from the context specified when the event was created, and with the 
+         * following parameters.
+         *
+         * If the custom event object hasn't been created, then the event hasn't 
+         * been published and it has no subscribers.  For performance sake, we 
+         * immediate exit in this case.  This means the event won't bubble, so 
+         * if the intention is that a bubble target be notified, the event must 
+         * be published on this object first.
+         *
+         * @method fire
+         * @param type {String|Object} The type of the event, or an object that contains
+         * a 'type' property.
+         * @param arguments {Object*} an arbitrary set of parameters to pass to 
+         * the handler.
+         * @return {boolean} the return value from Event.Custom.fire
+         *                   
+         */
+        fire: function(type) {
+
+            var typeIncluded = Y.Lang.isString(type),
+                t = (typeIncluded) ? type : (type && type.type);
+
+            var ce = this.getEvent(t);
+
+            // this event has not been published or subscribed to
+            if (!ce) {
+                
+                // if this object has bubble targets, we need to publish the
+                // event in order for it to bubble.
+                if (this._yuievt.hasTargets) {
+                    // ce = this.publish(t, {
+                    //     configured: false
+                    // });
+                    ce = this.publish(t);
+                    ce.details = Y.Array(arguments, (typeIncluded) ? 1 : 0, true);
+
+                    return this.bubble(ce);
+                }
+
+                // otherwise there is nothing to be done
+                return true;
+            }
+
+            // Provide this object's subscribers the object they are listening to.
+            // ce.currentTarget = this;
+
+            // This this the target unless target is current not null
+            // (set in bubble()).
+            // ce.target = ce.target || this;
+
+            var a = Y.Array(arguments, (typeIncluded) ? 1 : 0, true);
+            var ret = ce.fire.apply(ce, a);
+
+            // clear target for next fire()
+            ce.target = null;
+
+            return ret;
+        },
+
+        /**
+         * Returns the custom event of the provided type has been created, a
+         * falsy value otherwise
+         * @method getEvent
+         * @param type {string} the type, or name of the event
+         * @return {Event.Custom} the custom event or null
+         */
+        getEvent: function(type) {
+            var e = this._yuievt.events;
+            return (e && type in e) ? e[type] : null;
+        },
+
+        /**
+         * Propagate an event
+         * @method bubble
+         * @param evt {Event.Custom} the custom event to propagate
+         * @return {boolean} the aggregated return value from Event.Custom.fire
+         */
+        bubble: function(evt) {
+
+            var targs = this._yuievt.targets, ret = true;
+
+            if (!evt.stopped && targs) {
+
+                // Y.log('Bubbling ' + evt.type);
+
+                for (var i in targs) {
+                    if (targs.hasOwnProperty(i)) {
+
+                        var t = targs[i], type = evt.type,
+                            ce = t.getEvent(type), targetProp = evt.target || this;
+                            
+                        // if this event was not published on the bubble target,
+                        // publish it with sensible default properties
+                        if (!ce) {
+
+                            // publish the event on the bubble target using this event
+                            // for its configuration
+                            ce = t.publish(type, evt);
+                            // ce.configured = false;
+
+                            // set the host and context appropriately
+                            ce.context = (evt.host === evt.context) ? t : evt.context;
+                            ce.host = t;
+
+                            // clear handlers if specified on this event
+                            ce.defaultFn = null;
+                            ce.preventedFn = null;
+                            ce.stoppedFn = null;
+                        }
+
+                        ce.target = targetProp;
+                        ce.currentTarget = t;
+
+                        // ce.target = evt.target;
+
+                        ret = ret && ce.fire.apply(ce, evt.details);
+
+                        // stopPropagation() was called
+                        if (ce.stopped) {
+                            break;
+                        }
+                    }
+                }
+            }
+
+            return ret;
+        },
+
+        /**
+         * Subscribe to a custom event hosted by this object.  The
+         * supplied callback will execute after any listeners add
+         * via the subscribe method, and after the default function,
+         * if configured for the event, has executed.
+         * @method after
+         * @param type    {string}   The type of the event
+         * @param fn {Function} The callback
+         * @param context The execution context
+         * @param args* 1..n params to supply to the callback
+         */
+        after: function(type, fn) {
+            if (Y.Lang.isFunction(type)) {
+                return Y.Do.after.apply(Y.Do, arguments);
+            } else {
+                var ce = this._yuievt.events[type] || 
+                    // this.publish(type, {
+                    //     configured: false
+                    // }),
+                    this.publish(type),
+                    a = Y.Array(arguments, 1, true);
+
+                return ce.after.apply(ce, a);
+            }
+        },
+
+        before: function(type, fn) {
+            if (Y.Lang.isFunction(type)) {
+                return Y.Do.after.apply(Y.Do, arguments);
+            } else {
+                return this.subscribe.apply(this, arguments);
+            }
+        }
+
+    };
+
+    // make Y an event target
+    Y.mix(Y, ET.prototype, false, false, { 
+        bubbles: false 
+    });
+    ET.call(Y);
+
+
+}, "3.0.0");
+
+/*
+ * DOMReady
+ * @submodule event-ready
+ * @module event
+ */
+
+(function() {
+
+var Env = YUI.Env, 
+    C = YUI.config, 
+    D = C.doc, 
+    POLL_INTERVAL = C.pollInterval || 20;
+
+    if (!Env._ready) {
+
+        Env.windowLoaded = false;
+
+        var _ready = function(e) {
+            YUI.Env._ready();
+        };
+
+        Env._ready = function() {
+            if (!Env.DOMReady) {
+                Env.DOMReady=true;
+
+                // Remove the DOMContentLoaded (FF/Opera)
+                if (D.removeEventListener) {
+                    D.removeEventListener("DOMContentLoaded", _ready, false);
+                }
+            }
+        };
+
+        // create custom event
+
+        /////////////////////////////////////////////////////////////
+        // DOMReady
+        // based on work by: Dean Edwards/John Resig/Matthias Miller 
+
+        // Internet Explorer: use the readyState of a defered script.
+        // This isolates what appears to be a safe moment to manipulate
+        // the DOM prior to when the document's readyState suggests
+        // it is safe to do so.
+        if (navigator.userAgent.match(/MSIE/)) {
+
+            Env._dri = setInterval(function() {
+                try {
+                    // throws an error if doc is not ready
+                    document.documentElement.doScroll('left');
+                    clearInterval(Env._dri);
+                    Env._dri = null;
+                    _ready();
+                } catch (ex) { 
+                }
+            }, POLL_INTERVAL); 
+
+        // FireFox and Opera: These browsers provide a event for this
+        // moment.  The latest WebKit releases now support this event.
+        } else {
+            D.addEventListener("DOMContentLoaded", _ready, false);
+        }
+
+        /////////////////////////////////////////////////////////////
+    }
+
+    YUI.add("event-ready", function(Y) {
+
+        if (Y === YUI) {
+            return;
+        }
+
+        Y.mix(Y.Env.eventAdaptors, {
+
+            /**
+             * Executes the supplied callback when the DOM is first usable.  This
+             * will execute immediately if called after the DOMReady event has
+             * fired.   @todo the DOMContentReady event does not fire when the
+             * script is dynamically injected into the page.  This means the
+             * DOMReady custom event will never fire in FireFox or Opera when the
+             * library is injected.  It _will_ fire in Safari, and the IE 
+             * implementation would allow for us to fire it if the defered script
+             * is not available.  We want this to behave the same in all browsers.
+             * Is there a way to identify when the script has been injected 
+             * instead of included inline?  Is there a way to know whether the 
+             * window onload event has fired without having had a listener attached 
+             * to it when it did so?
+             *
+             * <p>The callback is a Event.Custom, so the signature is:</p>
+             * <p>type &lt;string&gt;, args &lt;array&gt;, customobject &lt;object&gt;</p>
+             * <p>For DOMReady events, there are no fire argments, so the
+             * signature is:</p>
+             * <p>"DOMReady", [], obj</p>
+             *
+             *
+             * @event domready
+             * @for YUI
+             *
+             * @param {function} fn what to execute when the element is found.
+             * @optional context execution context
+             * @optional args 1..n arguments to send to the listener
+             *
+             */
+            domready: {
+
+            },
+
+            /**
+             * Use domready event instead. @see domready
+             * @event event:ready
+             * @for YUI
+             * @deprecated use 'domready' instead
+             */
+            'event:ready': {
+
+                on: function() {
+                    arguments[0] = 'domready';
+                    return Y.subscribe.apply(Y, arguments);
+                },
+
+                detach: function() {
+                    arguments[0] = 'domready';
+                    return Y.unsubscribe.apply(Y, arguments);
+                }
+            }
+
+        });
+
+
+        Y.publish('domready', {
+            fireOnce: true
+        });
+
+        var yready = function() {
+            Y.fire('domready');
+        };
+
+        if (Env.DOMReady) {
+            // Y.log('DOMReady already fired', 'info', 'event');
+            yready();
+        } else {
+            // Y.log('setting up before listener', 'info', 'event');
+            Y.before(yready, Env, "_ready");
+        }
+
+    }, "3.0.0");
+
+})();
+/*
+ * The YUI DOM event system
+ * @submodule event-dom
+ * @module event
+ */
+(function() {
+
+    var add = function(el, type, fn, capture) {
+        if (el.addEventListener) {
+                el.addEventListener(type, fn, !!capture);
+        } else if (el.attachEvent) {
+                el.attachEvent("on" + type, fn);
+        } 
+    },
+
+    remove = function(el, type, fn, capture) {
+        if (el.removeEventListener) {
+                el.removeEventListener(type, fn, !!capture);
+        } else if (el.detachEvent) {
+                el.detachEvent("on" + type, fn);
+        }
+    },
+
+    onLoad = function() {
+        YUI.Env.windowLoaded = true;
+        remove(window, "load", onLoad);
+    },
+
+    EVENT_READY = 'domready',
+
+    COMPAT_ARG = '~yui|2|compat~',
+
+    CAPTURE = "capture_";
+
+add(window, "load", onLoad);
+
+YUI.add("event-dom", function(Y) {
+
+    /**
+     * The event utility provides functions to add and remove event listeners,
+     * event cleansing.  It also tries to automatically remove listeners it
+     * registers during the unload event.
+     *
+     * @class Event
+     * @static
+     */
+    Y.Event = function() {
+
+        /**
+         * True after the onload event has fired
+         * @property loadComplete
+         * @type boolean
+         * @static
+         * @private
+         */
+        var loadComplete =  false;
+
+        /**
+         * The number of times to poll after window.onload.  This number is
+         * increased if additional late-bound handlers are requested after
+         * the page load.
+         * @property _retryCount
+         * @static
+         * @private
+         */
+        var _retryCount = 0;
+
+        /**
+         * onAvailable listeners
+         * @property _avail
+         * @static
+         * @private
+         */
+        var _avail = [];
+
+        /**
+         * Custom event wrappers for DOM events.  Key is 
+         * 'event:' + Element uid stamp + event type
+         * @property _wrappers
+         * @type Y.Event.Custom
+         * @static
+         * @private
+         */
+        var _wrappers = {};
+
+        var _windowLoadKey = null;
+
+        /**
+         * Custom event wrapper map DOM events.  Key is 
+         * Element uid stamp.  Each item is a hash of custom event
+         * wrappers as provided in the _wrappers collection.  This
+         * provides the infrastructure for getListeners.
+         * @property _el_events
+         * @static
+         * @private
+         */
+        var _el_events = {};
+
+        return {
+
+            /**
+             * The number of times we should look for elements that are not
+             * in the DOM at the time the event is requested after the document
+             * has been loaded.  The default is 2000@amp;20 ms, so it will poll
+             * for 40 seconds or until all outstanding handlers are bound
+             * (whichever comes first).
+             * @property POLL_RETRYS
+             * @type int
+             * @static
+             * @final
+             */
+            POLL_RETRYS: 2000,
+
+            /**
+             * The poll interval in milliseconds
+             * @property POLL_INTERVAL
+             * @type int
+             * @static
+             * @final
+             */
+            POLL_INTERVAL: 20,
+
+            /**
+             * addListener/removeListener can throw errors in unexpected scenarios.
+             * These errors are suppressed, the method returns false, and this property
+             * is set
+             * @property lastError
+             * @static
+             * @type Error
+             */
+            lastError: null,
+
+
+            /**
+             * poll handle
+             * @property _interval
+             * @static
+             * @private
+             */
+            _interval: null,
+
+            /**
+             * document readystate poll handle
+             * @property _dri
+             * @static
+             * @private
+             */
+             _dri: null,
+
+            /**
+             * True when the document is initially usable
+             * @property DOMReady
+             * @type boolean
+             * @static
+             */
+            DOMReady: false,
+
+            /**
+             * @method startInterval
+             * @static
+             * @private
+             */
+            startInterval: function() {
+                var E = Y.Event;
+
+                if (!E._interval) {
+E._interval = setInterval(Y.bind(E._tryPreloadAttach, E), E.POLL_INTERVAL);
+                }
+            },
+
+            /**
+             * Executes the supplied callback when the item with the supplied
+             * id is found.  This is meant to be used to execute behavior as
+             * soon as possible as the page loads.  If you use this after the
+             * initial page load it will poll for a fixed time for the element.
+             * The number of times it will poll and the frequency are
+             * configurable.  By default it will poll for 10 seconds.
+             *
+             * <p>The callback is executed with a single parameter:
+             * the custom object parameter, if provided.</p>
+             *
+             * @method onAvailable
+             *
+             * @param {string||string[]}   id the id of the element, or an array
+             * of ids to look for.
+             * @param {function} fn what to execute when the element is found.
+             * @param {object}   p_obj an optional object to be passed back as
+             *                   a parameter to fn.
+             * @param {boolean|object}  p_override If set to true, fn will execute
+             *                   in the context of p_obj, if set to an object it
+             *                   will execute in the context of that object
+             * @param checkContent {boolean} check child node readiness (onContentReady)
+             * @static
+             * @deprecated Use Y.on("available")
+             */
+            // @TODO fix arguments
+            onAvailable: function(id, fn, p_obj, p_override, checkContent, compat) {
+
+                var a = Y.Array(id);
+
+                // Y.log('onAvailable registered for: ' + id);
+
+                for (var i=0; i<a.length; i=i+1) {
+                    _avail.push({ 
+                        id:         a[i], 
+                        fn:         fn, 
+                        obj:        p_obj, 
+                        override:   p_override, 
+                        checkReady: checkContent,
+                        compat:     compat 
+                    });
+                }
+                _retryCount = this.POLL_RETRYS;
+
+                // We want the first test to be immediate, but async
+                setTimeout(Y.bind(Y.Event._tryPreloadAttach, Y.Event), 0);
+
+                return new Y.EventHandle(); // @TODO by id needs a defered handle
+            },
+
+            /**
+             * Works the same way as onAvailable, but additionally checks the
+             * state of sibling elements to determine if the content of the
+             * available element is safe to modify.
+             *
+             * <p>The callback is executed with a single parameter:
+             * the custom object parameter, if provided.</p>
+             *
+             * @method onContentReady
+             *
+             * @param {string}   id the id of the element to look for.
+             * @param {function} fn what to execute when the element is ready.
+             * @param {object}   p_obj an optional object to be passed back as
+             *                   a parameter to fn.
+             * @param {boolean|object}  p_override If set to true, fn will execute
+             *                   in the context of p_obj.  If an object, fn will
+             *                   exectute in the context of that object
+             *
+             * @static
+             * @deprecated Use Y.on("contentready")
+             */
+            // @TODO fix arguments
+            onContentReady: function(id, fn, p_obj, p_override, compat) {
+                return this.onAvailable(id, fn, p_obj, p_override, true, compat);
+            },
+
+
+            /**
+             * Appends an event handler
+             *
+             * @method attach
+             *
+             * @param {String}   type     The type of event to append
+             * @param {Function} fn        The method the event invokes
+             * @param {String|HTMLElement|Array|NodeList} el An id, an element 
+             *  reference, or a collection of ids and/or elements to assign the 
+             *  listener to.
+             * @param {Object}   obj    An arbitrary object that will be 
+             *                             passed as a parameter to the handler
+             * @param {Boolean|object}  args 1..n ar
+             * @return {Boolean} True if the action was successful or defered,
+             *                        false if one or more of the elements 
+             *                        could not have the listener attached,
+             *                        or if the operation throws an exception.
+             * @static
+             */
+            attach: function(type, fn, el, obj) {
+
+                // Y.log('attach: ' + Y.Lang.dump(Y.Array(arguments, 0, true), 1));
+                // Y.log('attach:');
+                // Y.log(Y.Array(arguments, 0, true), 1);
+                // var a=Y.Array(arguments, 1, true), override=a[3], E=Y.Event, aa=Y.Array(arguments, 0, true);
+
+                var args=Y.Array(arguments, 0, true), 
+                    trimmedArgs=args.slice(1),
+                    compat, E=Y.Event, capture = false;
+
+                if (type.indexOf(CAPTURE) > -1) {
+                    type = type.substr(CAPTURE.length);
+                    capture = true;
+                    Y.log('Using capture phase for: ' + type, 'info', 'event');
+                }
+
+                if (trimmedArgs[trimmedArgs.length-1] === COMPAT_ARG) {
+                    compat = true;
+                    trimmedArgs.pop();
+                }
+
+                if (!fn || !fn.call) {
+// throw new TypeError(type + " attach call failed, callback undefined");
+Y.log(type + " attach call failed, invalid callback", "error", "event");
+                    return false;
+                }
+
+                // The el argument can be an array of elements or element ids.
+                if (this._isValidCollection(el)) {
+
+                    // Y.log('collection: ' + el);
+                    // Y.log('collection: ' + el.item(0) + ', ' + el.item(1));
+
+                    var handles=[], i, l;
+                    
+                    Y.each(el, function(v, k) {
+                        args[2] = v;
+                        handles.push(E.attach.apply(E, args));
+                    });
+
+                    return handles;
+
+
+                } else if (Y.Lang.isString(el)) {
+
+                    var oEl = (compat) ? Y.DOM.byId(el) : Y.all(el);
+
+                    // If the el argument is a string, we assume it is 
+                    // actually the id of the element.  If the page is loaded
+                    // we convert el to the actual element, otherwise we 
+                    // defer attaching the event until onload event fires
+
+                    // check to see if we need to delay hooking up the event 
+                    // until after the page loads.
+
+                    // Node collection
+                    // if (oEl && oEl.size && oEl.size() > 0) {
+                    //
+                    // Y.log('node?: ' + (oEl instanceof Y.Node));
+
+                    /*
+                    if (oEl) {
+                        el = oEl;
+                    */
+
+                    if (oEl && (oEl instanceof Y.Node)) {
+                        var size = oEl.size();
+                        if (size > 1) {
+                            // Y.log('more than one: ' + size + ', ' + type);
+                            // args[0] = oEl;
+                            args[2] = oEl;
+                            return E.attach.apply(E, args);
+                        } else {
+                            // Y.log('just one: ' + size + ', ' + type);
+                            el = oEl.item(0);
+                            // el = oEl;
+                        }
+
+                    // HTMLElement
+                    // } else if (compat && oEl) {
+                    } else if (oEl) {
+                        // Y.log('no size: ' + oEl + ', ' + type);
+                        el = oEl;
+
+                    // Not found = defer adding the event until the element is available
+                    } else {
+
+                        // Y.log(el + ' not found');
+
+                        return this.onAvailable(el, function() {
+                            // Y.log('lazy attach: ' + args);
+                            E.attach.apply(E, args);
+                        }, E, true, false, compat);
+                    }
+                }
+
+                // Element should be an html element or an array if we get here.
+                if (!el) {
+                    Y.log("unable to attach event " + type, "warn", "event");
+                    return false;
+                }
+
+                // the custom event key is the uid for the element + type
+
+                var ek = Y.stamp(el), key = 'event:' + ek + type,
+                    cewrapper = _wrappers[key];
+
+
+                if (!cewrapper) {
+                    // create CE wrapper
+                    cewrapper = Y.publish(key, {
+                        silent: true,
+                        // host: this,
+                        bubbles: false
+                    });
+
+                    // cache the dom event details in the custom event
+                    // for later removeListener calls
+                    cewrapper.el = el;
+                    cewrapper.type = type;
+                    cewrapper.fn = function(e) {
+                        cewrapper.fire(E.getEvent(e, el, compat));
+                    };
+
+                    if (el == Y.config.win && type == "load") {
+                        // window load happens once
+                        cewrapper.fireOnce = true;
+                        _windowLoadKey = key;
+
+                        // if the load is complete, fire immediately.
+                        // all subscribers, including the current one
+                        // will be notified.
+                        if (YUI.Env.windowLoaded) {
+                            cewrapper.fire();
+                        }
+                    }
+
+                    _wrappers[key] = cewrapper;
+                    _el_events[ek] = _el_events[ek] || {};
+                    _el_events[ek][key] = cewrapper;
+
+                    // var capture = (Y.lang.isObject(obj) && obj.capture);
+                    // attach a listener that fires the custom event
+
+                    // Y.log("Attaching listener: " + [el, type, cewrapper.fn, capture]);
+                    add(el, type, cewrapper.fn, capture);
+                }
+
+                // switched from obj to trimmedArgs[2] to deal with appened compat param
+                var context = trimmedArgs[2] || ((compat) ? el : Y.get(el));
+                
+                // set the context as the second arg to subscribe
+                trimmedArgs[1] = context;
+
+                // remove the 'obj' param
+                trimmedArgs.splice(2, 1);
+
+                // set context to the Node if not specified
+                return cewrapper.subscribe.apply(cewrapper, trimmedArgs);
+
+            },
+
+            /**
+             * Removes an event listener.  Supports the signature the event was bound
+             * with, but the preferred way to remove listeners is using the handle
+             * that is returned when using Y.on
+             *
+             * @method detach
+             *
+             * @param {String|HTMLElement|Array|NodeList} el An id, an element 
+             *  reference, or a collection of ids and/or elements to remove
+             *  the listener from.
+             * @param {String} type the type of event to remove.
+             * @param {Function} fn the method the event invokes.  If fn is
+             *  undefined, then all event handlers for the type of event are *  removed.
+             * @return {boolean} true if the unbind was successful, false *  otherwise.
+             * @static
+             */
+            detach: function(type, fn, el, obj) {
+
+                var args=Y.Array(arguments, 0, true), compat;
+
+                if (args[args.length-1] === COMPAT_ARG) {
+                    compat = true;
+                    // args.pop();
+                }
+
+                if (type && type.detach) {
+                    return type.detach();
+                }
+
+                var i, len, li;
+
+                // The el argument can be a string
+                if (typeof el == "string") {
+
+                    el = (compat) ? Y.DOM.byId(el) : Y.all(el);
+
+                // The el argument can be an array of elements or element ids.
+                } else if ( this._isValidCollection(el)) {
+
+                    var ok = true;
+                    for (i=0, len=el.length; i<len; ++i) {
+
+                        args[2] = el[i];
+
+                        // ok = ( this.detach(el[i], type, fn) && ok );
+                        ok = ( Y.Event.detach.apply(Y.Event, args) && ok );
+                    }
+
+                    return ok;
+
+                }
+
+                if (!fn || !fn.call) {
+                    return this.purgeElement(el, false, type);
+                }
+
+                var id = 'event:' + Y.stamp(el) + type, 
+                    ce = _wrappers[id];
+                if (ce) {
+                    return ce.unsubscribe(fn);
+                } else {
+                    return false;
+                }
+
+            },
+
+            /**
+             * Finds the event in the window object, the caller's arguments, or
+             * in the arguments of another method in the callstack.  This is
+             * executed automatically for events registered through the event
+             * manager, so the implementer should not normally need to execute
+             * this function at all.
+             * @method getEvent
+             * @param {Event} e the event parameter from the handler
+             * @param {HTMLElement} el the element the listener was attached to
+             * @return {Event} the event 
+             * @static
+             */
+            getEvent: function(e, el, noFacade) {
+                var ev = e || window.event;
+
+                return (noFacade) ? ev : 
+                    new Y.Event.Facade(ev, el, _wrappers['event:' + Y.stamp(el) + e.type]);
+            },
+
+            /**
+             * Generates an unique ID for the element if it does not already 
+             * have one.
+             * @method generateId
+             * @param el the element to create the id for
+             * @return {string} the resulting id of the element
+             * @static
+             */
+            generateId: function(el) {
+                var id = el.id;
+
+                if (!id) {
+                    id = Y.stamp(el);
+                    el.id = id;
+                }
+
+                return id;
+            },
+
+            /**
+             * We want to be able to use getElementsByTagName as a collection
+             * to attach a group of events to.  Unfortunately, different 
+             * browsers return different types of collections.  This function
+             * tests to determine if the object is array-like.  It will also 
+             * fail if the object is an array, but is empty.
+             * @method _isValidCollection
+             * @param o the object to test
+             * @return {boolean} true if the object is array-like and populated
+             * @static
+             * @private
+             */
+            _isValidCollection: function(o) {
+                try {
+                     
+                    // Y.log('node? ' + (o instanceof Y.Node) + ', ' + ((o.size) ? o.size() : ' no size'));
+                    // if (o instanceof Y.Node) {
+                        // o.tagName ="adsf";
+                    // }
+
+                    return ( o                     && // o is something
+                             typeof o !== "string" && // o is not a string
+                             // o.length  && // o is indexed
+                             (o.length && ((!o.size) || (o.size() > 1)))  && // o is indexed
+                             !o.tagName            && // o is not an HTML element
+                             !o.alert              && // o is not a window
+                             (o.item || typeof o[0] !== "undefined") );
+                } catch(ex) {
+                    Y.log("collection check failure", "warn", "event");
+                    return false;
+                }
+
+            },
+
+            /**
+             * hook up any deferred listeners
+             * @method _load
+             * @static
+             * @private
+             */
+            _load: function(e) {
+
+                if (!loadComplete) {
+
+                    // Y.log('Load Complete', 'info', 'event');
+
+                    loadComplete = true;
+
+                    // Just in case DOMReady did not go off for some reason
+                    // E._ready();
+                    if (Y.fire) {
+                        Y.fire(EVENT_READY);
+                    }
+
+                    // Available elements may not have been detected before the
+                    // window load event fires. Try to find them now so that the
+                    // the user is more likely to get the onAvailable notifications
+                    // before the window load notification
+                    Y.Event._tryPreloadAttach();
+
+                }
+            },
+
+            /**
+             * Polling function that runs before the onload event fires, 
+             * attempting to attach to DOM Nodes as soon as they are 
+             * available
+             * @method _tryPreloadAttach
+             * @static
+             * @private
+             */
+            _tryPreloadAttach: function() {
+
+                if (this.locked) {
+                    return;
+                }
+
+                if (Y.UA.ie && !YUI.Env.DOMReady) {
+                    // Hold off if DOMReady has not fired and check current
+                    // readyState to protect against the IE operation aborted
+                    // issue.
+                    this.startInterval();
+                    return;
+                }
+
+                this.locked = true;
+
+                // Y.log.debug("tryPreloadAttach");
+
+                // keep trying until after the page is loaded.  We need to 
+                // check the page load state prior to trying to bind the 
+                // elements so that we can be certain all elements have been 
+                // tested appropriately
+                var tryAgain = !loadComplete;
+                if (!tryAgain) {
+                    tryAgain = (_retryCount > 0);
+                }
+
+                // onAvailable
+                var notAvail = [];
+
+                var executeItem = function (el, item) {
+                    var context, ov = item.override;
+
+                    if (item.compat) {
+
+                        if (item.override) {
+                            if (ov === true) {
+                                context = item.obj;
+                            } else {
+                                context = ov;
+                            }
+                        } else {
+                            context = el;
+                        }
+
+                        item.fn.call(context, item.obj);
+
+                    } else {
+                        context = item.obj || Y.get(el);
+                        item.fn.apply(context, (Y.Lang.isArray(ov)) ? ov : []);
+                    }
+
+                };
+
+                var i, len, item, el;
+
+                // onAvailable
+                for (i=0,len=_avail.length; i<len; ++i) {
+                    item = _avail[i];
+                    if (item && !item.checkReady) {
+
+                        el = (item.compat) ? Y.DOM.byId(item.id) : Y.get(item.id);
+
+                        if (el) {
+                            // Y.log('avail: ' + el);
+                            executeItem(el, item);
+                            _avail[i] = null;
+                        } else {
+                            // Y.log('NOT avail: ' + el);
+                            notAvail.push(item);
+                        }
+                    }
+                }
+
+                // onContentReady
+                for (i=0,len=_avail.length; i<len; ++i) {
+                    item = _avail[i];
+                    if (item && item.checkReady) {
+
+                        el = (item.compat) ? Y.DOM.byId(item.id) : Y.get(item.id);
+
+                        if (el) {
+                            // The element is available, but not necessarily ready
+                            // @todo should we test parentNode.nextSibling?
+                            if (loadComplete || (el.get && el.get('nextSibling')) || el.nextSibling) {
+                                executeItem(el, item);
+                                _avail[i] = null;
+                            }
+                        } else {
+                            notAvail.push(item);
+                        }
+                    }
+                }
+
+                _retryCount = (notAvail.length === 0) ? 0 : _retryCount - 1;
+
+                if (tryAgain) {
+                    // we may need to strip the nulled out items here
+                    this.startInterval();
+                } else {
+                    clearInterval(this._interval);
+                    this._interval = null;
+                }
+
+                this.locked = false;
+
+                return;
+
+            },
+
+            /**
+             * Removes all listeners attached to the given element via addListener.
+             * Optionally, the node's children can also be purged.
+             * Optionally, you can specify a specific type of event to remove.
+             * @method purgeElement
+             * @param {HTMLElement} el the element to purge
+             * @param {boolean} recurse recursively purge this element's children
+             * as well.  Use with caution.
+             * @param {string} type optional type of listener to purge. If
+             * left out, all listeners will be removed
+             * @static
+             */
+            purgeElement: function(el, recurse, type) {
+                var oEl = (Y.Lang.isString(el)) ? Y.get(el) : el,
+                    id = Y.stamp(oEl);
+                var lis = this.getListeners(oEl, type), i, len;
+                if (lis) {
+                    for (i=0,len=lis.length; i<len ; ++i) {
+                        lis[i].unsubscribeAll();
+                    }
+                }
+
+                if (recurse && oEl && oEl.childNodes) {
+                    for (i=0,len=oEl.childNodes.length; i<len ; ++i) {
+                        this.purgeElement(oEl.childNodes[i], recurse, type);
+                    }
+                }
+            },
+
+            /**
+             * Returns all listeners attached to the given element via addListener.
+             * Optionally, you can specify a specific type of event to return.
+             * @method getListeners
+             * @param el {HTMLElement|string} the element or element id to inspect 
+             * @param type {string} optional type of listener to return. If
+             * left out, all listeners will be returned
+             * @return {Y.Custom.Event} the custom event wrapper for the DOM event(s)
+             * @static
+             */           
+            getListeners: function(el, type) {
+                var ek = Y.stamp(el), evts = _el_events[ek];
+
+                if (!evts) {
+                    return null;
+                }
+
+                var results=[] , key = (type) ? 'event:' + type : null;
+
+                if (key) {
+                    if (evts[key]) {
+                        results.push(evts[key]);
+                    }
+                } else {
+                    Y.each(evts, function(v, k) {
+                        results.push(v);
+                    });
+                }
+
+                return (results.length) ? results : null;
+            },
+
+            /**
+             * Removes all listeners registered by pe.event.  Called 
+             * automatically during the unload event.
+             * @method _unload
+             * @static
+             * @private
+             */
+            _unload: function(e) {
+
+                var E = Y.Event;
+
+                Y.each(_wrappers, function(v, k) {
+                    v.unsubscribeAll();
+                    remove(v.el, v.type, v.fn);
+                    delete _wrappers[k];
+                });
+
+                remove(window, "load", E._load);
+                remove(window, "unload", E._unload);
+            },
+
+            
+            /**
+             * Adds a DOM event directly without the caching, cleanup, context adj, etc
+             *
+             * @method nativeAdd
+             * @param {HTMLElement} el      the element to bind the handler to
+             * @param {string}      type   the type of event handler
+             * @param {function}    fn      the callback to invoke
+             * @param {boolen}      capture capture or bubble phase
+             * @static
+             * @private
+             */
+            nativeAdd: add,
+
+            /**
+             * Basic remove listener
+             *
+             * @method nativeRemove
+             * @param {HTMLElement} el      the element to bind the handler to
+             * @param {string}      type   the type of event handler
+             * @param {function}    fn      the callback to invoke
+             * @param {boolen}      capture capture or bubble phase
+             * @static
+             * @private
+             */
+            nativeRemove: remove
+        };
+
+    }();
+
+    var E = Y.Event;
+
+    // Process onAvailable/onContentReady items when when the DOM is ready in IE
+    if (Y.UA.ie && Y.on) {
+        Y.on(EVENT_READY, E._tryPreloadAttach, E, true);
+    }
+
+    E.Custom = Y.CustomEvent;
+    E.Subscriber = Y.Subscriber;
+    E.Target = Y.EventTarget;
+
+    add(window, "load", E._load);
+    add(window, "unload", E._unload);
+
+    E._tryPreloadAttach();
+
+}, "3.0.0");
+
+})();
+/*
+ * A wrapper for DOM events and Custom Events
+ * @submodule event-facade
+ * @module event
+ *
+ * @TODO constants? LEFTBUTTON, MIDDLEBUTTON, RIGHTBUTTON, keys
+ */
+YUI.add("event-facade", function(Y) {
+
+
+    var whitelist = {
+        "altKey"          : 1,
+        // "button"          : 1, // we supply
+        // "bubbles"         : 1, // needed?
+        // "cancelable"      : 1, // needed? 
+        // "charCode"        : 1, // we supply
+        "cancelBubble"    : 1,
+        // "currentTarget"   : 1, // we supply
+        "ctrlKey"         : 1,
+        "clientX"         : 1, // needed?
+        "clientY"         : 1, // needed?
+        "detail"          : 1, // not fully implemented
+        // "fromElement"     : 1,
+        "keyCode"         : 1,
+        // "height"          : 1, // needed?
+        // "initEvent"       : 1, // need the init events?
+        // "initMouseEvent"  : 1,
+        // "initUIEvent"     : 1,
+        // "layerX"          : 1, // needed?
+        // "layerY"          : 1, // needed?
+        "metaKey"         : 1,
+        // "modifiers"       : 1, // needed?
+        // "offsetX"         : 1, // needed?
+        // "offsetY"         : 1, // needed?
+        // "preventDefault"  : 1, // we supply
+        // "reason"          : 1, // IE proprietary
+        // "relatedTarget"   : 1,
+        // "returnValue"     : 1, // needed?
+        "shiftKey"        : 1,
+        // "srcUrn"          : 1, // IE proprietary
+        // "srcElement"      : 1,
+        // "srcFilter"       : 1, IE proprietary
+        // "stopPropagation" : 1, // we supply
+        // "target"          : 1,
+        // "timeStamp"       : 1, // needed?
+        // "toElement"       : 1,
+        "type"            : 1,
+        // "view"            : 1,
+        // "which"           : 1, // we supply
+        // "width"           : 1, // needed?
+        "x"               : 1,
+        "y"               : 1
+    };
+
+    var ua = Y.UA,
+
+        /**
+         * webkit key remapping required for Safari < 3.1
+         * @property webkitKeymap
+         * @private
+         */
+        webkitKeymap = {
+            63232: 38, // up
+            63233: 40, // down
+            63234: 37, // left
+            63235: 39, // right
+            63276: 33, // page up
+            63277: 34, // page down
+            25: 9      // SHIFT-TAB (Safari provides a different key code in
+                       // this case, even though the shiftKey modifier is set)
+        },
+
+        /**
+         * Returns a wrapped node.  Intended to be used on event targets,
+         * so it will return the node's parent if the target is a text
+         * node
+         * @method resolve
+         * @private
+         */
+        resolve = function(n) {
+
+            if (!n) {
+                return null;
+            }
+
+            try {
+                if (ua.webkit && 3 == n.nodeType) {
+                    n = n.parentNode;
+                } 
+            } catch(ex) { }
+
+            return Y.Node.get(n);
+        };
+
+
+    // provide a single event with browser abstractions resolved
+    //
+    // include all properties for both browers?
+    // include only DOM2 spec properties?
+    // provide browser-specific facade?
+
+    /**
+     * Wraps a DOM event, properties requiring browser abstraction are
+     * fixed here.  Provids a security layer when required.
+     * @class Event.Facade
+     * @param ev {Event} the DOM event
+     * @param currentTarget {HTMLElement} the element the listener was attached to
+     * @param wrapper {Event.Custom} the custom event wrapper for this DOM event
+     */
+    Y.Event.Facade = function(ev, currentTarget, wrapper, details) {
+
+        // @TODO the document should be the target's owner document
+
+        var e = ev, ot = currentTarget, d = Y.config.doc, b = d.body,
+            x = e.pageX, y = e.pageY, isCE = (ev._YUI_EVENT);
+
+        // copy all primitives ... this is slow in FF
+        // for (var i in e) {
+        for (var i in whitelist) {
+            // if (!Y.Lang.isObject(e[i])) {
+            if (whitelist.hasOwnProperty(i)) {
+                this[i] = e[i];
+            }
+        }
+
+        //////////////////////////////////////////////////////
+
+        if (!x && 0 !== x) {
+            x = e.clientX || 0;
+            y = e.clientY || 0;
+
+            if (ua.ie) {
+                x += Math.max(d.documentElement.scrollLeft, b.scrollLeft);
+                y += Math.max(d.documentElement.scrollTop, b.scrollTop);
+            }
+        }
+
+        this._yuifacade = true;
+
+        /**
+         * The X location of the event on the page (including scroll)
+         * @property pageX
+         * @type int
+         */
+        this.pageX = x;
+
+        /**
+         * The Y location of the event on the page (including scroll)
+         * @property pageY
+         * @type int
+         */
+        this.pageY = y;
+
+        //////////////////////////////////////////////////////
+
+        /**
+         * The keyCode for key events.  Uses charCode if keyCode is not available
+         * @property keyCode
+         * @type int
+         */
+        var c = e.keyCode || e.charCode || 0;
+
+        if (ua.webkit && (c in webkitKeymap)) {
+            c = webkitKeymap[c];
+        }
+
+        /**
+         * The keyCode for key events.  Uses charCode if keyCode is not available
+         * @property keyCode
+         * @type int
+         */
+        this.keyCode = c;
+
+        /**
+         * The charCode for key events.  Same as keyCode
+         * @property charCode
+         * @type int
+         */
+        this.charCode = c;
+
+        //////////////////////////////////////////////////////
+
+        /**
+         * The button that was pushed.
+         * @property button
+         * @type int
+         */
+        this.button = e.which || e.button;
+
+        /**
+         * The button that was pushed.  Same as button.
+         * @property which
+         * @type int
+         */
+        this.which = this.button;
+
+        /**
+         * The event details.  Currently supported for Custom
+         * Events only, where it contains the arguments that
+         * were passed to fire().
+         * @property details
+         * @type Array
+         */
+        this.details = details;
+
+        //////////////////////////////////////////////////////
+
+        /**
+         * Timestamp for the event
+         * @property time
+         * @type Date
+         */
+        this.time = e.time || new Date().getTime();
+
+        //////////////////////////////////////////////////////
+        
+        /**
+         * Node reference for the targeted element
+         * @propery target
+         * @type Node
+         */
+        this.target = (isCE) ? e.target : resolve(e.target || e.srcElement);
+
+        /**
+         * Node reference for the element that the listener was attached to.
+         * @propery currentTarget
+         * @type Node
+         */
+        this.currentTarget = (isCE) ? ot :  resolve(ot);
+
+        var t = e.relatedTarget;
+        if (!t) {
+            if (e.type == "mouseout") {
+                t = e.toElement;
+            } else if (e.type == "mouseover") {
+                t = e.fromElement;
+            }
+        }
+
+        /**
+         * Node reference to the relatedTarget
+         * @propery relatedTarget
+         * @type Node
+         */
+        this.relatedTarget = (isCE) ? t : resolve(t);
+        
+        //////////////////////////////////////////////////////
+        // methods
+
+        /**
+         * Stops the propagation to the next bubble target
+         * @method stopPropagation
+         */
+        this.stopPropagation = function() {
+            if (e.stopPropagation) {
+                e.stopPropagation();
+            } else {
+                e.cancelBubble = true;
+            }
+            if (wrapper) {
+                wrapper.stopPropagation();
+            }
+        };
+
+        /**
+         * Stops the propagation to the next bubble target and
+         * prevents any additional listeners from being exectued
+         * on the current target.
+         * @method stopImmediatePropagation
+         */
+        this.stopImmediatePropagation = function() {
+
+            if (e.stopImmediatePropagation) {
+                e.stopImmediatePropagation();
+            } else {
+                this.stopPropagation();
+            }
+
+            if (wrapper) {
+                wrapper.stopImmediatePropagation();
+            }
+
+        };
+
+        /**
+         * Prevents the event's default behavior
+         * @method preventDefault
+         */
+        this.preventDefault = function() {
+            if (e.preventDefault) {
+                e.preventDefault();
+            } else {
+                e.returnValue = false;
+            }
+            if (wrapper) {
+                wrapper.preventDefault();
+            }
+        };
+
+        /**
+         * Stops the event propagation and prevents the default
+         * event behavior.
+         * @method halt
+         * @param immediate {boolean} if true additional listeners
+         * on the current target will not be executed
+         */
+        this.halt = function(immediate) {
+            if (immediate) {
+                this.stopImmediatePropagation();
+            } else {
+                this.stopPropagation();
+            }
+            this.preventDefault();
+        };
+
+    };
+
+}, "3.0.0");
+/*
+ * Functionality to simulate events.
+ * @submodule event-simulate
+ * @module event
+ */
+YUI.add("event-simulate", function(Y) {
+
+    //shortcuts
+    var L   = Y.Lang,
+        array       = Y.Array,
+        isFunction  = L.isFunction,
+        isString    = L.isString,
+        isBoolean   = L.isBoolean,
+        isObject    = L.isObject,
+        isNumber    = L.isNumber,
+        
+        //mouse events supported
+        mouseEvents = [
+        
+            /**
+             * Simulates a click on a particular element.
+             * @param {HTMLElement} target The element to click on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method click
+             * @static   
+             * @for Event
+             */        
+            "click", 
+            
+            /**
+             * Simulates a double click on a particular element.
+             * @param {HTMLElement} target The element to double click on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method dblclick
+             * @static
+             */            
+            "dblclick", 
+            
+            /**
+             * Simulates a mouseover event on a particular element. Use "relatedTarget"
+             * on the options object to specify where the mouse moved from.
+             * Quirks: Firefox less than 2.0 doesn't set relatedTarget properly, so
+             * fromElement is assigned in its place. IE doesn't allow fromElement to be
+             * be assigned, so relatedTarget is assigned in its place. Both of these
+             * concessions allow YAHOO.util.Event.getRelatedTarget() to work correctly
+             * in both browsers.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method mouseover
+             * @static
+             */             
+            "mouseover", 
+            
+            /**
+             * Simulates a mouseout event on a particular element. Use "relatedTarget"
+             * on the options object to specify where the mouse moved to.
+             * Quirks: Firefox less than 2.0 doesn't set relatedTarget properly, so
+             * toElement is assigned in its place. IE doesn't allow toElement to be
+             * be assigned, so relatedTarget is assigned in its place. Both of these
+             * concessions allow YAHOO.util.Event.getRelatedTarget() to work correctly
+             * in both browsers.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method mouseout
+             * @static
+             */            
+            "mouseout", 
+            
+            /**
+             * Simulates a mousedown on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method mousedown
+             * @static
+             */            
+            "mousedown", 
+            
+            /**
+             * Simulates a mouseup on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method mouseup
+             * @static
+             */            
+            "mouseup", 
+            
+            /**
+             * Simulates a mousemove on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method mousemove
+             * @static
+             */           
+            "mousemove"
+        ],
+        
+        //key events supported
+        keyEvents   = [
+        
+            /**
+             * Simulates a keydown event on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method keydown
+             * @static
+             */        
+            "keydown", 
+            
+            /**
+             * Simulates a keyup event on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method keyup
+             * @static
+             */            
+            "keyup", 
+            
+            /**
+             * Simulates a keypress on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method keypress
+             * @static
+             */            
+            "keypress"
+        ];
+
+    /**
+     * Note: Intentionally not for YUIDoc generation.
+     * Simulates a key event using the given event information to populate
+     * the generated event object. This method does browser-equalizing
+     * calculations to account for differences in the DOM and IE event models
+     * as well as different browser quirks. Note: keydown causes Safari 2.x to
+     * crash.
+     * @method simulateKeyEvent
+     * @private
+     * @static
+     * @param {HTMLElement} target The target of the given event.
+     * @param {String} type The type of event to fire. This can be any one of
+     *      the following: keyup, keydown, and keypress.
+     * @param {Boolean} bubbles (Optional) Indicates if the event can be
+     *      bubbled up. DOM Level 3 specifies that all key events bubble by
+     *      default. The default is true.
+     * @param {Boolean} cancelable (Optional) Indicates if the event can be
+     *      canceled using preventDefault(). DOM Level 3 specifies that all
+     *      key events can be cancelled. The default 
+     *      is true.
+     * @param {Window} view (Optional) The view containing the target. This is
+     *      typically the window object. The default is window.
+     * @param {Boolean} ctrlKey (Optional) Indicates if one of the CTRL keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} altKey (Optional) Indicates if one of the ALT keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} shiftKey (Optional) Indicates if one of the SHIFT keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} metaKey (Optional) Indicates if one of the META keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {int} keyCode (Optional) The code for the key that is in use. 
+     *      The default is 0.
+     * @param {int} charCode (Optional) The Unicode code for the character
+     *      associated with the key being used. The default is 0.
+     */
+    function simulateKeyEvent(target /*:HTMLElement*/, type /*:String*/, 
+                                 bubbles /*:Boolean*/,  cancelable /*:Boolean*/,    
+                                 view /*:Window*/,
+                                 ctrlKey /*:Boolean*/,    altKey /*:Boolean*/, 
+                                 shiftKey /*:Boolean*/,   metaKey /*:Boolean*/, 
+                                 keyCode /*:int*/,        charCode /*:int*/) /*:Void*/                             
+    {
+        //check target    
+        if (!target){
+            Y.fail("simulateKeyEvent(): Invalid target.");
+        }
+        
+        //check event type
+        if (isString(type)){
+            type = type.toLowerCase();
+            switch(type){
+                case "textevent": //DOM Level 3
+                    type = "keypress";
+                    /*falls through*/
+                case "keyup":
+                case "keydown":
+                case "keypress":
+                    break;
+                default:
+                    Y.fail("simulateKeyEvent(): Event type '" + type + "' not supported.");
+            }
+        } else {
+            Y.fail("simulateKeyEvent(): Event type must be a string.");
+        }
+        
+        //setup default values
+        if (!isBoolean(bubbles)){
+            bubbles = true; //all key events bubble
+        }
+        if (!isBoolean(cancelable)){
+            cancelable = true; //all key events can be cancelled
+        }
+        if (!isObject(view)){
+            view = window; //view is typically window
+        }
+        if (!isBoolean(ctrlKey)){
+            ctrlKey = false;
+        }
+        if (!isBoolean(altKey)){
+            altKey = false;
+        }
+        if (!isBoolean(shiftKey)){
+            shiftKey = false;
+        }
+        if (!isBoolean(metaKey)){
+            metaKey = false;
+        }
+        if (!isNumber(keyCode)){
+            keyCode = 0;
+        }
+        if (!isNumber(charCode)){
+            charCode = 0; 
+        }
+
+        //try to create a mouse event
+        var customEvent /*:MouseEvent*/ = null;
+            
+        //check for DOM-compliant browsers first
+        if (isFunction(document.createEvent)){
+        
+            try {
+                
+                //try to create key event
+                customEvent = document.createEvent("KeyEvents");
+                
+                /*
+                 * Interesting problem: Firefox implemented a non-standard
+                 * version of initKeyEvent() based on DOM Level 2 specs.
+                 * Key event was removed from DOM Level 2 and re-introduced
+                 * in DOM Level 3 with a different interface. Firefox is the
+                 * only browser with any implementation of Key Events, so for
+                 * now, assume it's Firefox if the above line doesn't error.
+                 */
+                //TODO: Decipher between Firefox's implementation and a correct one.
+                customEvent.initKeyEvent(type, bubbles, cancelable, view, ctrlKey,
+                    altKey, shiftKey, metaKey, keyCode, charCode);       
+                
+            } catch (ex /*:Error*/){
+
+                /*
+                 * If it got here, that means key events aren't officially supported. 
+                 * Safari/WebKit is a real problem now. WebKit 522 won't let you
+                 * set keyCode, charCode, or other properties if you use a
+                 * UIEvent, so we first must try to create a generic event. The
+                 * fun part is that this will throw an error on Safari 2.x. The
+                 * end result is that we need another try...catch statement just to
+                 * deal with this mess.
+                 */
+                try {
+
+                    //try to create generic event - will fail in Safari 2.x
+                    customEvent = document.createEvent("Events");
+
+                } catch (uierror /*:Error*/){
+
+                    //the above failed, so create a UIEvent for Safari 2.x
+                    customEvent = document.createEvent("UIEvents");
+
+                } finally {
+
+                    customEvent.initEvent(type, bubbles, cancelable);
+    
+                    //initialize
+                    customEvent.view = view;
+                    customEvent.altKey = altKey;
+                    customEvent.ctrlKey = ctrlKey;
+                    customEvent.shiftKey = shiftKey;
+                    customEvent.metaKey = metaKey;
+                    customEvent.keyCode = keyCode;
+                    customEvent.charCode = charCode;
+          
+                }          
+             
+            }
+            
+            //fire the event
+            target.dispatchEvent(customEvent);
+
+        } else if (isObject(document.createEventObject)){ //IE
+        
+            //create an IE event object
+            customEvent = document.createEventObject();
+            
+            //assign available properties
+            customEvent.bubbles = bubbles;
+            customEvent.cancelable = cancelable;
+            customEvent.view = view;
+            customEvent.ctrlKey = ctrlKey;
+            customEvent.altKey = altKey;
+            customEvent.shiftKey = shiftKey;
+            customEvent.metaKey = metaKey;
+            
+            /*
+             * IE doesn't support charCode explicitly. CharCode should
+             * take precedence over any keyCode value for accurate
+             * representation.
+             */
+            customEvent.keyCode = (charCode > 0) ? charCode : keyCode;
+            
+            //fire the event
+            target.fireEvent("on" + type, customEvent);  
+                    
+        } else {
+            Y.fail("simulateKeyEvent(): No event simulation framework present.");
+        }
+    }
+
+    /*
+     * Note: Intentionally not for YUIDoc generation.
+     * Simulates a mouse event using the given event information to populate
+     * the generated event object. This method does browser-equalizing
+     * calculations to account for differences in the DOM and IE event models
+     * as well as different browser quirks.
+     * @method simulateMouseEvent
+     * @private
+     * @static
+     * @param {HTMLElement} target The target of the given event.
+     * @param {String} type The type of event to fire. This can be any one of
+     *      the following: click, dblclick, mousedown, mouseup, mouseout,
+     *      mouseover, and mousemove.
+     * @param {Boolean} bubbles (Optional) Indicates if the event can be
+     *      bubbled up. DOM Level 2 specifies that all mouse events bubble by
+     *      default. The default is true.
+     * @param {Boolean} cancelable (Optional) Indicates if the event can be
+     *      canceled using preventDefault(). DOM Level 2 specifies that all
+     *      mouse events except mousemove can be cancelled. The default 
+     *      is true for all events except mousemove, for which the default 
+     *      is false.
+     * @param {Window} view (Optional) The view containing the target. This is
+     *      typically the window object. The default is window.
+     * @param {int} detail (Optional) The number of times the mouse button has
+     *      been used. The default value is 1.
+     * @param {int} screenX (Optional) The x-coordinate on the screen at which
+     *      point the event occured. The default is 0.
+     * @param {int} screenY (Optional) The y-coordinate on the screen at which
+     *      point the event occured. The default is 0.
+     * @param {int} clientX (Optional) The x-coordinate on the client at which
+     *      point the event occured. The default is 0.
+     * @param {int} clientY (Optional) The y-coordinate on the client at which
+     *      point the event occured. The default is 0.
+     * @param {Boolean} ctrlKey (Optional) Indicates if one of the CTRL keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} altKey (Optional) Indicates if one of the ALT keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} shiftKey (Optional) Indicates if one of the SHIFT keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} metaKey (Optional) Indicates if one of the META keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {int} button (Optional) The button being pressed while the event
+     *      is executing. The value should be 0 for the primary mouse button
+     *      (typically the left button), 1 for the terciary mouse button
+     *      (typically the middle button), and 2 for the secondary mouse button
+     *      (typically the right button). The default is 0.
+     * @param {HTMLElement} relatedTarget (Optional) For mouseout events,
+     *      this is the element that the mouse has moved to. For mouseover
+     *      events, this is the element that the mouse has moved from. This
+     *      argument is ignored for all other events. The default is null.
+     */
+    function simulateMouseEvent(target /*:HTMLElement*/, type /*:String*/, 
+                                   bubbles /*:Boolean*/,  cancelable /*:Boolean*/,    
+                                   view /*:Window*/,        detail /*:int*/, 
+                                   screenX /*:int*/,        screenY /*:int*/, 
+                                   clientX /*:int*/,        clientY /*:int*/,       
+                                   ctrlKey /*:Boolean*/,    altKey /*:Boolean*/, 
+                                   shiftKey /*:Boolean*/,   metaKey /*:Boolean*/, 
+                                   button /*:int*/,         relatedTarget /*:HTMLElement*/) /*:Void*/
+    {
+        
+        //check target   
+        if (!target){
+            Y.fail("simulateMouseEvent(): Invalid target.");
+        }
+        
+        //check event type
+        if (isString(type)){
+            type = type.toLowerCase();
+            
+            //make sure it's a supported mouse event
+            if (array.indexOf(mouseEvents, type) == -1){
+                Y.fail("simulateMouseEvent(): Event type '" + type + "' not supported.");
+            }
+        } else {
+            Y.fail("simulateMouseEvent(): Event type must be a string.");
+        }
+        
+        //setup default values
+        if (!isBoolean(bubbles)){
+            bubbles = true; //all mouse events bubble
+        }
+        if (!isBoolean(cancelable)){
+            cancelable = (type != "mousemove"); //mousemove is the only one that can't be cancelled
+        }
+        if (!isObject(view)){
+            view = window; //view is typically window
+        }
+        if (!isNumber(detail)){
+            detail = 1;  //number of mouse clicks must be at least one
+        }
+        if (!isNumber(screenX)){
+            screenX = 0; 
+        }
+        if (!isNumber(screenY)){
+            screenY = 0; 
+        }
+        if (!isNumber(clientX)){
+            clientX = 0; 
+        }
+        if (!isNumber(clientY)){
+            clientY = 0; 
+        }
+        if (!isBoolean(ctrlKey)){
+            ctrlKey = false;
+        }
+        if (!isBoolean(altKey)){
+            altKey = false;
+        }
+        if (!isBoolean(shiftKey)){
+            shiftKey = false;
+        }
+        if (!isBoolean(metaKey)){
+            metaKey = false;
+        }
+        if (!isNumber(button)){
+            button = 0; 
+        }
+
+        //try to create a mouse event
+        var customEvent /*:MouseEvent*/ = null;
+            
+        //check for DOM-compliant browsers first
+        if (isFunction(document.createEvent)){
+        
+            customEvent = document.createEvent("MouseEvents");
+        
+            //Safari 2.x (WebKit 418) still doesn't implement initMouseEvent()
+            if (customEvent.initMouseEvent){
+                customEvent.initMouseEvent(type, bubbles, cancelable, view, detail,
+                                     screenX, screenY, clientX, clientY, 
+                                     ctrlKey, altKey, shiftKey, metaKey, 
+                                     button, relatedTarget);
+            } else { //Safari
+            
+                //the closest thing available in Safari 2.x is UIEvents
+                customEvent = document.createEvent("UIEvents");
+                customEvent.initEvent(type, bubbles, cancelable);
+                customEvent.view = view;
+                customEvent.detail = detail;
+                customEvent.screenX = screenX;
+                customEvent.screenY = screenY;
+                customEvent.clientX = clientX;
+                customEvent.clientY = clientY;
+                customEvent.ctrlKey = ctrlKey;
+                customEvent.altKey = altKey;
+                customEvent.metaKey = metaKey;
+                customEvent.shiftKey = shiftKey;
+                customEvent.button = button;
+                customEvent.relatedTarget = relatedTarget;
+            }
+            
+            /*
+             * Check to see if relatedTarget has been assigned. Firefox
+             * versions less than 2.0 don't allow it to be assigned via
+             * initMouseEvent() and the property is readonly after event
+             * creation, so in order to keep YAHOO.util.getRelatedTarget()
+             * working, assign to the IE proprietary toElement property
+             * for mouseout event and fromElement property for mouseover
+             * event.
+             */
+            if (relatedTarget && !customEvent.relatedTarget){
+                if (type == "mouseout"){
+                    customEvent.toElement = relatedTarget;
+                } else if (type == "mouseover"){
+                    customEvent.fromElement = relatedTarget;
+                }
+            }
+            
+            //fire the event
+            target.dispatchEvent(customEvent);
+
+        } else if (isObject(document.createEventObject)){ //IE
+        
+            //create an IE event object
+            customEvent = document.createEventObject();
+            
+            //assign available properties
+            customEvent.bubbles = bubbles;
+            customEvent.cancelable = cancelable;
+            customEvent.view = view;
+            customEvent.detail = detail;
+            customEvent.screenX = screenX;
+            customEvent.screenY = screenY;
+            customEvent.clientX = clientX;
+            customEvent.clientY = clientY;
+            customEvent.ctrlKey = ctrlKey;
+            customEvent.altKey = altKey;
+            customEvent.metaKey = metaKey;
+            customEvent.shiftKey = shiftKey;
+
+            //fix button property for IE's wacky implementation
+            switch(button){
+                case 0:
+                    customEvent.button = 1;
+                    break;
+                case 1:
+                    customEvent.button = 4;
+                    break;
+                case 2:
+                    //leave as is
+                    break;
+                default:
+                    customEvent.button = 0;                    
+            }    
+
+            /*
+             * Have to use relatedTarget because IE won't allow assignment
+             * to toElement or fromElement on generic events. This keeps
+             * YAHOO.util.customEvent.getRelatedTarget() functional.
+             */
+            customEvent.relatedTarget = relatedTarget;
+            
+            //fire the event
+            target.fireEvent("on" + type, customEvent);
+                    
+        } else {
+            Y.fail("simulateMouseEvent(): No event simulation framework present.");
+        }
+    }
+    
+    //add mouse event methods
+    array.each(mouseEvents, function(type){
+        Y.Event[type] = function(target, options){
+            options = options || {};
+            simulateMouseEvent(target, type, options.bubbles,
+                options.cancelable, options.view, options.detail, options.screenX,        
+                options.screenY, options.clientX, options.clientY, options.ctrlKey,
+                options.altKey, options.shiftKey, options.metaKey, options.button,         
+                options.relatedTarget);        
+        };
+    });
+
+    //add key event methods
+    array.each(keyEvents, function(type){
+        Y.Event[type] = function(target, options){
+            options = options || {};
+            simulateKeyEvent(target, type, options.bubbles,
+                options.cancelable, options.view, options.ctrlKey,
+                options.altKey, options.shiftKey, options.metaKey, 
+                options.keyCode, options.charCode);       
+        };
+    });
+    
+    /**
+     * Simulates the event with the given name on a target.
+     * @param {HTMLElement} target The DOM element that's the target of the event.
+     * @param {String} type The type of event to simulate (i.e., "click").
+     * @param {Object} options (Optional) Extra options to copy onto the event object.
+     * @return {void}
+     * @method simulate
+     * @static
+     */
+    Y.Event.simulate = function(target, type, options){
+        if (isFunction(Y.Event[type])){
+            Y.Event[type](target, options);
+        }
+    };
+    
+    /*
+     * TODO: focus(), blur(), submit()
+     */
+
+}, "3.0.0pr2", { requires: ["lang","event-dom"] });

=== added file 'loggerhead/static/javascript/yui/build/event/event-min.js'
--- loggerhead/static/javascript/yui/build/event/event-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/event/event-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,10 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("event",function(F){var A=F.UA.ie?"focusin":"focus",B=F.UA.ie?"focusout":"blur",D="capture_",C=F.Lang;F.Env.eventAdaptors={focus:{on:function(){arguments[0]=D+A;return F.Event.attach.apply(F.Event,arguments);},detach:function(){arguments[0]=D+A;return F.Event.detach.apply(F.Event,arguments);}},blur:{on:function(){arguments[0]=D+B;return F.Event.attach.apply(F.Event,arguments);},detach:function(){arguments[0]=D+B;return F.Event.detach.apply(F.Event,arguments);}},available:{on:function(I,H,K,J){var G=arguments.length>4?F.Array(arguments,4,true):[];return F.Event.onAvailable.call(F.Event,K,H,J,G);}},contentready:{on:function(I,H,K,J){var G=arguments.length>4?F.Array(arguments,4,true):[];return F.Event.onContentReady.call(F.Event,K,H,J,G);}},key:{on:function(J,L,G,P,H){if(!P||P.indexOf(":")==-1){arguments[0]="keypress";return F.on.apply(F,arguments);}var K=P.split(":"),O=K[0],N=(K[1])?K[1].split(/,|\+/):null,I=(C.isString(G)?G:F.stamp(G))+P,M=F.Array(arguments,0,true);F.on(J+O,function(U){var V=false,R=false;for(var S=0;S<N.length;S=S+1){var Q=N[S],T=parseInt(Q,10);if(C.isNumber(T)){if(U.charCode===T){V=true;}else{R=true;}}else{if(V||!R){V=(U[Q+"Key"]);R=!V;}}}if(V){F.fire(I,U);}},G);M.splice(2,2);M[0]=I;return F.on.apply(F,M);}}};F.on=function(H,I,J){var G=F.Env.eventAdaptors[H];if(G&&G.on){return G.on.apply(F,arguments);}else{if(G||H.indexOf(":")>-1){return F.subscribe.apply(F,arguments);}else{return F.Event.attach.apply(F.Event,arguments);}}};F.detach=function(H,I,J){var G=F.Env.eventAdaptors[H];if(C.isObject(H)&&H.detach){return H.detach();}else{if(G&&G.detach){return G.detach.apply(F,arguments);}else{if(G||H.indexOf(":")>-1){return F.unsubscribe.apply(F,arguments);}else{return F.Event.detach.apply(F.Event,arguments);}}}};F.before=function(G,H,I){if(C.isFunction(G)){return F.Do.before.apply(F.Do,arguments);}else{return F.on.apply(F,arguments);}};var E=F.after;F.after=function(G,H,I){if(C.isFunction(G)){return F.Do.after.apply(F.Do,arguments);}else{return E.apply(F,arguments);}};},"3.0.0",{use:["aop","event-custom","event-target","event-ready","event-dom","event-facade","event-simulate"]});YUI.add("aop",function(C){var A=0,B=1;C.Do={objs:{},before:function(E,G,H,I){var F=E;if(I){var D=[E,I].concat(C.Array(arguments,4,true));F=C.bind.apply(C,D);}return this._inject(A,F,G,H);},after:function(E,G,H,I){var F=E;if(I){var D=[E,I].concat(C.Array(arguments,4,true));F=C.bind.apply(C,D);}return this._inject(B,F,G,H);},_inject:function(D,F,G,I){var J=C.stamp(G);if(!this.objs[J]){this.objs[J]={};}var H=this.objs[J];if(!H[I]){H[I]=new C.Do.Method(G,I);G[I]=function(){return H[I].exec.apply(H[I],arguments);};}var E=J+C.stamp(F)+I;H[I].register(E,F,D);return new C.EventHandle(H[I],E);},detach:function(D){if(D.detach){D.detach();}},_unload:function(E,D){}};C.Do.Method=function(D,E){this.obj=D;this.methodName=E;this.method=D[E];this.before={};this.after={};};C.Do.Method.prototype.register=function(E,F,D){if(D){this.after[E]=F;}else{this.before[E]=F;}};C.Do.Method.prototype._delete=function(D){delete this.before[D];delete this.after[D];};C.Do.Method.prototype.exec=function(){var F=C.Array(arguments,0,true),G,E,J,H=this.before,D=this.after,I=false;for(G in H){if(H.hasOwnProperty(G)){E=H[G].apply(this.obj,F);if(E){switch(E.constructor){case C.Do.Halt:return E.retVal;case C.Do.AlterArgs:F=E.newArgs;break;case C.Do.Prevent:I=true;break;default:}}}}if(!I){E=this.method.apply(this.obj,F);}for(G in D){if(D.hasOwnProperty(G)){J=D[G].apply(this.obj,F);if(J&&J.constructor==C.Do.Halt){return J.retVal;}else{if(J&&J.constructor==C.Do.AlterReturn){E=J.newRetVal;}}}}return E;};C.Do.AlterArgs=function(E,D){this.msg=E;this.newArgs=D;};C.Do.AlterReturn=function(E,D){this.msg=E;this.newRetVal=D;};C.Do.Halt=function(E,D){this.msg=E;this.retVal=D;};C.Do.Prevent=function(D){this.msg=D;};C.Do.Error=C.Do.Halt;},"3.0.0");YUI.add("event-custom",function(E){var B="_event:onsub",D="after",A=["broadcast","bubbles","context","configured","currentTarget","defaultFn","details","emitFacade","fireOnce","host","preventable","preventedFn","queuable","silent","stoppedFn","target","type"],C=9;E.EventHandle=function(F,G){this.evt=F;this.sub=G;};E.EventHandle.prototype={detach:function(){if(this.evt){this.evt._delete(this.sub);}}};E.CustomEvent=function(F,G){G=G||{};this.id=E.stamp(this);this.type=F;this.context=E;this.broadcast=0;this.queuable=false;this.subscribers={};this.afters={};this.fired=false;this.fireOnce=false;this.stopped=0;this.prevented=0;this.host=null;this.defaultFn=null;this.stoppedFn=null;this.preventedFn=null;this.preventable=true;this.bubbles=true;this.signature=C;this.emitFacade=false;this.applyConfig(G,true);if(F!==B){this.subscribeEvent=new E.CustomEvent(B,{context:this,silent:true});}};E.CustomEvent.prototype={_YUI_EVENT:true,applyConfig:function(G,F){if(G){E.mix(this,G,F,A);}},_subscribe:function(I,K,G,F){if(!I){E.fail("Invalid callback for CE: "+this.type);}var J=this.subscribeEvent;if(J){J.fire.apply(J,G);}var H=new E.Subscriber(I,K,G,F);if(this.fireOnce&&this.fired){E.later(0,this,this._notify,H);}if(F==D){this.afters[H.id]=H;}else{this.subscribers[H.id]=H;}return new E.EventHandle(this,H);},subscribe:function(F,G){return this._subscribe(F,G,arguments,true);},after:function(F,G){return this._subscribe(F,G,arguments,D);},unsubscribe:function(I,K){if(I&&I.detach){return I.detach();}if(!I){return this.unsubscribeAll();}var J=false,G=this.subscribers;for(var F in G){if(G.hasOwnProperty(F)){var H=G[F];if(H&&H.contains(I,K)){this._delete(H);J=true;}}}return J;},_getFacade:function(G){var F=this._facade;if(!F){F=new E.Event.Facade(this,this.currentTarget);}var H=G&&G[0];if(E.Lang.isObject(H,true)&&!H._yuifacade){E.mix(F,H,true);}F.details=this.details;F.target=this.target;F.currentTarget=this.currentTarget;F.stopped=0;F.prevented=0;this._facade=F;return this._facade;},_notify:function(J,H,F){var G,K,I;if(this.emitFacade){if(!F){F=this._getFacade(H);H[0]=F;}}I=(H&&E.Lang.isObject(H[0])&&H[0].currentTarget);G=J.notify(I||this.context,H,this);
+if(false===G||this.stopped>1){return false;}return true;},log:function(I,F){var H=E.Env._eventstack,G=H&&H.logging;if(!this.silent){}},fire:function(){var O=E.Env._eventstack;if(O){if(this.queuable&&this.type!=O.next.type){O.queue.push([this,arguments]);return true;}}else{E.Env._eventstack={id:this.id,next:this,silent:this.silent,logging:(this.type==="yui:log"),stopped:0,prevented:0,queue:[]};O=E.Env._eventstack;}var M=true;if(this.fireOnce&&this.fired){}else{var H=E.merge(this.subscribers),P,N=E.Array(arguments,0,true),I;this.stopped=0;this.prevented=0;this.target=this.target||this.host;this.currentTarget=this.host||this.currentTarget;this.fired=true;this.details=N.slice();var L=false;O.lastLogState=O.logging;var J=null;if(this.emitFacade){this._facade=null;J=this._getFacade(N);N[0]=J;}for(I in H){if(H.hasOwnProperty(I)){if(!L){O.logging=(O.logging||(this.type==="yui:log"));L=true;}if(this.stopped==2){break;}P=H[I];if(P&&P.fn){M=this._notify(P,N,J);if(false===M){this.stopped=2;}}}}O.logging=(O.lastLogState);if(this.bubbles&&this.host&&!this.stopped){O.stopped=0;O.prevented=0;M=this.host.bubble(this);this.stopped=Math.max(this.stopped,O.stopped);this.prevented=Math.max(this.prevented,O.prevented);}if(this.defaultFn&&!this.prevented){this.defaultFn.apply(this.host||this,N);}if(!this.prevented&&this.stopped<2){H=E.merge(this.afters);for(I in H){if(H.hasOwnProperty(I)){if(!L){O.logging=(O.logging||(this.type==="yui:log"));L=true;}if(this.stopped==2){break;}P=H[I];if(P&&P.fn){M=this._notify(P,N,J);if(false===M){this.stopped=2;}}}}}}if(O.id===this.id){var K=O.queue;while(K.length){var F=K.pop(),G=F[0];O.stopped=0;O.prevented=0;O.next=G;M=G.fire.apply(G,F[1]);}E.Env._eventstack=null;}return(M!==false);},unsubscribeAll:function(){var G=this.subscribers,F;for(F in G){if(G.hasOwnProperty(F)){this._delete(G[F]);}}this.subscribers={};return F;},_delete:function(F){if(F){delete F.fn;delete F.obj;delete this.subscribers[F.id];delete this.afters[F.id];}},toString:function(){return this.type;},stopPropagation:function(){this.stopped=1;E.Env._eventstack.stopped=1;if(this.stoppedFn){this.stoppedFn.call(this.host||this,this);}},stopImmediatePropagation:function(){this.stopped=2;E.Env._eventstack.stopped=2;if(this.stoppedFn){this.stoppedFn.call(this.host||this,this);}},preventDefault:function(){if(this.preventable){this.prevented=1;E.Env._eventstack.prevented=1;}if(this.preventedFn){this.preventedFn.call(this.host||this,this);}}};E.Subscriber=function(G,H,F){this.fn=G;this.obj=H;this.id=E.stamp(this);this.wrappedFn=G;if(H){this.wrappedFn=E.bind.apply(E,F);}};E.Subscriber.prototype={notify:function(F,H,K){var L=this.obj||F,G=true,I=function(){switch(K.signature){case 0:G=this.fn.call(L,K.type,H,this.obj);break;case 1:G=this.fn.call(L,H[0]||null,this.obj);break;default:G=this.wrappedFn.apply(L,H||[]);}};if(E.config.throwFail){I.call(this);}else{try{I.call(this);}catch(J){E.fail(this+" failed: "+J.message,J);}}return G;},contains:function(F,G){if(G){return((this.fn==F)&&this.obj==G);}else{return(this.fn==F);}},toString:function(){return"Subscriber "+this.id;}};},"3.0.0");YUI.add("event-target",function(C){var A={"yui:log":true};C.EventTarget=function(D){var E=(C.Lang.isObject(D))?D:{};this._yuievt={events:{},targets:{},config:E,defaults:{context:this,host:this,emitFacade:E.emitFacade||false,bubbles:("bubbles" in E)?E.bubbles:true}};};var B=C.EventTarget;B.prototype={subscribe:function(J,K,D){if(C.Lang.isObject(J)){var F=K,I=D,H=C.Array(arguments,0,true),G={};C.each(J,function(N,M){if(N){F=N.fn||F;I=N.context||I;}H[0]=M;H[1]=F;H[2]=I;G[M]=this.subscribe.apply(this,H);},this);return G;}var E=this._yuievt.events[J]||this.publish(J),L=C.Array(arguments,1,true);return E.subscribe.apply(E,L);},unsubscribe:function(I,H,G){if(C.Lang.isObject(I)&&I.detach){return I.detach();}var D=this._yuievt.events;if(I){var J=D[I];if(J){return J.unsubscribe(H,G);}}else{var E=true;for(var F in D){if(C.Object.owns(D,F)){E=E&&D[F].unsubscribe(H,G);}}return E;}return false;},unsubscribeAll:function(D){return this.unsubscribe(D);},publish:function(F,G){if(C.Lang.isObject(F)){var D={};C.each(F,function(K,J){D[J]=this.publish(J,K||G);},this);return D;}var E=this._yuievt.events,H=E[F];if(H){H.applyConfig(G,true);}else{var I=G||{};C.mix(I,this._yuievt.defaults);H=new C.CustomEvent(F,I);E[F]=H;if(I.onSubscribeCallback){H.subscribeEvent.subscribe(I.onSubscribeCallback);}}return E[F];},addTarget:function(D){this._yuievt.targets[C.stamp(D)]=D;this._yuievt.hasTargets=true;},removeTarget:function(D){delete this._yuievt.targets[C.stamp(D)];},fire:function(G){var I=C.Lang.isString(G),F=(I)?G:(G&&G.type);var H=this.getEvent(F);if(!H){if(this._yuievt.hasTargets){H=this.publish(F);H.details=C.Array(arguments,(I)?1:0,true);return this.bubble(H);}return true;}var D=C.Array(arguments,(I)?1:0,true);var E=H.fire.apply(H,D);H.target=null;return E;},getEvent:function(D){var E=this._yuievt.events;return(E&&D in E)?E[D]:null;},bubble:function(E){var J=this._yuievt.targets,F=true;if(!E.stopped&&J){for(var H in J){if(J.hasOwnProperty(H)){var G=J[H],I=E.type,K=G.getEvent(I),D=E.target||this;if(!K){K=G.publish(I,E);K.context=(E.host===E.context)?G:E.context;K.host=G;K.defaultFn=null;K.preventedFn=null;K.stoppedFn=null;}K.target=D;K.currentTarget=G;F=F&&K.fire.apply(K,E.details);if(K.stopped){break;}}}}return F;},after:function(F,E){if(C.Lang.isFunction(F)){return C.Do.after.apply(C.Do,arguments);}else{var G=this._yuievt.events[F]||this.publish(F),D=C.Array(arguments,1,true);return G.after.apply(G,D);}},before:function(E,D){if(C.Lang.isFunction(E)){return C.Do.after.apply(C.Do,arguments);}else{return this.subscribe.apply(this,arguments);}}};C.mix(C,B.prototype,false,false,{bubbles:false});B.call(C);},"3.0.0");(function(){var E=YUI.Env,G=YUI.config,F=G.doc,B=G.pollInterval||20;if(!E._ready){E.windowLoaded=false;var A=function(C){YUI.Env._ready();};E._ready=function(){if(!E.DOMReady){E.DOMReady=true;if(F.removeEventListener){F.removeEventListener("DOMContentLoaded",A,false);
+}}};if(navigator.userAgent.match(/MSIE/)){E._dri=setInterval(function(){try{document.documentElement.doScroll("left");clearInterval(E._dri);E._dri=null;A();}catch(C){}},B);}else{F.addEventListener("DOMContentLoaded",A,false);}}YUI.add("event-ready",function(D){if(D===YUI){return;}D.mix(D.Env.eventAdaptors,{domready:{},"event:ready":{on:function(){arguments[0]="domready";return D.subscribe.apply(D,arguments);},detach:function(){arguments[0]="domready";return D.unsubscribe.apply(D,arguments);}}});D.publish("domready",{fireOnce:true});var C=function(){D.fire("domready");};if(E.DOMReady){C();}else{D.before(C,E,"_ready");}},"3.0.0");})();(function(){var E=function(J,I,H,G){if(J.addEventListener){J.addEventListener(I,H,!!G);}else{if(J.attachEvent){J.attachEvent("on"+I,H);}}},A=function(J,I,H,G){if(J.removeEventListener){J.removeEventListener(I,H,!!G);}else{if(J.detachEvent){J.detachEvent("on"+I,H);}}},B=function(){YUI.Env.windowLoaded=true;A(window,"load",B);},F="domready",D="~yui|2|compat~",C="capture_";E(window,"load",B);YUI.add("event-dom",function(H){H.Event=function(){var K=false;var L=0;var J=[];var M={};var I=null;var N={};return{POLL_RETRYS:2000,POLL_INTERVAL:20,lastError:null,_interval:null,_dri:null,DOMReady:false,startInterval:function(){var O=H.Event;if(!O._interval){O._interval=setInterval(H.bind(O._tryPreloadAttach,O),O.POLL_INTERVAL);}},onAvailable:function(V,R,U,T,S,P){var O=H.Array(V);for(var Q=0;Q<O.length;Q=Q+1){J.push({id:O[Q],fn:R,obj:U,override:T,checkReady:S,compat:P});}L=this.POLL_RETRYS;setTimeout(H.bind(H.Event._tryPreloadAttach,H.Event),0);return new H.EventHandle();},onContentReady:function(S,P,R,Q,O){return this.onAvailable(S,P,R,Q,true,O);},attach:function(U,W,P,X){var T=H.Array(arguments,0,true),S=T.slice(1),V,Y=H.Event,b=false;if(U.indexOf(C)>-1){U=U.substr(C.length);b=true;}if(S[S.length-1]===D){V=true;S.pop();}if(!W||!W.call){return false;}if(this._isValidCollection(P)){var O=[],d,c;H.each(P,function(h,g){T[2]=h;O.push(Y.attach.apply(Y,T));});return O;}else{if(H.Lang.isString(P)){var a=(V)?H.DOM.byId(P):H.all(P);if(a&&(a instanceof H.Node)){var Z=a.size();if(Z>1){T[2]=a;return Y.attach.apply(Y,T);}else{P=a.item(0);}}else{if(a){P=a;}else{return this.onAvailable(P,function(){Y.attach.apply(Y,T);},Y,true,false,V);}}}}if(!P){return false;}var Q=H.stamp(P),f="event:"+Q+U,e=M[f];if(!e){e=H.publish(f,{silent:true,bubbles:false});e.el=P;e.type=U;e.fn=function(g){e.fire(Y.getEvent(g,P,V));};if(P==H.config.win&&U=="load"){e.fireOnce=true;I=f;if(YUI.Env.windowLoaded){e.fire();}}M[f]=e;N[Q]=N[Q]||{};N[Q][f]=e;E(P,U,e.fn,b);}var R=S[2]||((V)?P:H.get(P));S[1]=R;S.splice(2,1);return e.subscribe.apply(e,S);},detach:function(V,X,Q,R){var U=H.Array(arguments,0,true),Z;if(U[U.length-1]===D){Z=true;}if(V&&V.detach){return V.detach();}var S,T,Y;if(typeof Q=="string"){Q=(Z)?H.DOM.byId(Q):H.all(Q);}else{if(this._isValidCollection(Q)){var W=true;for(S=0,T=Q.length;S<T;++S){U[2]=Q[S];W=(H.Event.detach.apply(H.Event,U)&&W);}return W;}}if(!X||!X.call){return this.purgeElement(Q,false,V);}var O="event:"+H.stamp(Q)+V,P=M[O];if(P){return P.unsubscribe(X);}else{return false;}},getEvent:function(R,P,O){var Q=R||window.event;return(O)?Q:new H.Event.Facade(Q,P,M["event:"+H.stamp(P)+R.type]);},generateId:function(O){var P=O.id;if(!P){P=H.stamp(O);O.id=P;}return P;},_isValidCollection:function(P){try{return(P&&typeof P!=="string"&&(P.length&&((!P.size)||(P.size()>1)))&&!P.tagName&&!P.alert&&(P.item||typeof P[0]!=="undefined"));}catch(O){return false;}},_load:function(O){if(!K){K=true;if(H.fire){H.fire(F);}H.Event._tryPreloadAttach();}},_tryPreloadAttach:function(){if(this.locked){return;}if(H.UA.ie&&!YUI.Env.DOMReady){this.startInterval();return;}this.locked=true;var T=!K;if(!T){T=(L>0);}var S=[];var U=function(X,Y){var W,V=Y.override;if(Y.compat){if(Y.override){if(V===true){W=Y.obj;}else{W=V;}}else{W=X;}Y.fn.call(W,Y.obj);}else{W=Y.obj||H.get(X);Y.fn.apply(W,(H.Lang.isArray(V))?V:[]);}};var P,O,R,Q;for(P=0,O=J.length;P<O;++P){R=J[P];if(R&&!R.checkReady){Q=(R.compat)?H.DOM.byId(R.id):H.get(R.id);if(Q){U(Q,R);J[P]=null;}else{S.push(R);}}}for(P=0,O=J.length;P<O;++P){R=J[P];if(R&&R.checkReady){Q=(R.compat)?H.DOM.byId(R.id):H.get(R.id);if(Q){if(K||(Q.get&&Q.get("nextSibling"))||Q.nextSibling){U(Q,R);J[P]=null;}}else{S.push(R);}}}L=(S.length===0)?0:L-1;if(T){this.startInterval();}else{clearInterval(this._interval);this._interval=null;}this.locked=false;return;},purgeElement:function(T,U,S){var Q=(H.Lang.isString(T))?H.get(T):T,V=H.stamp(Q);var P=this.getListeners(Q,S),R,O;if(P){for(R=0,O=P.length;R<O;++R){P[R].unsubscribeAll();}}if(U&&Q&&Q.childNodes){for(R=0,O=Q.childNodes.length;R<O;++R){this.purgeElement(Q.childNodes[R],U,S);}}},getListeners:function(S,R){var T=H.stamp(S),O=N[T];if(!O){return null;}var Q=[],P=(R)?"event:"+R:null;if(P){if(O[P]){Q.push(O[P]);}}else{H.each(O,function(V,U){Q.push(V);});}return(Q.length)?Q:null;},_unload:function(P){var O=H.Event;H.each(M,function(R,Q){R.unsubscribeAll();A(R.el,R.type,R.fn);delete M[Q];});A(window,"load",O._load);A(window,"unload",O._unload);},nativeAdd:E,nativeRemove:A};}();var G=H.Event;if(H.UA.ie&&H.on){H.on(F,G._tryPreloadAttach,G,true);}G.Custom=H.CustomEvent;G.Subscriber=H.Subscriber;G.Target=H.EventTarget;E(window,"load",G._load);E(window,"unload",G._unload);G._tryPreloadAttach();},"3.0.0");})();YUI.add("event-facade",function(E){var C={"altKey":1,"cancelBubble":1,"ctrlKey":1,"clientX":1,"clientY":1,"detail":1,"keyCode":1,"metaKey":1,"shiftKey":1,"type":1,"x":1,"y":1};var B=E.UA,A={63232:38,63233:40,63234:37,63235:39,63276:33,63277:34,25:9},D=function(G){if(!G){return null;}try{if(B.webkit&&3==G.nodeType){G=G.parentNode;}}catch(F){}return E.Node.get(G);};E.Event.Facade=function(P,H,G,F){var L=P,J=H,M=E.config.doc,Q=M.body,R=L.pageX,O=L.pageY,I=(P._YUI_EVENT);for(var K in C){if(C.hasOwnProperty(K)){this[K]=L[K];}}if(!R&&0!==R){R=L.clientX||0;O=L.clientY||0;if(B.ie){R+=Math.max(M.documentElement.scrollLeft,Q.scrollLeft);O+=Math.max(M.documentElement.scrollTop,Q.scrollTop);
+}}this._yuifacade=true;this.pageX=R;this.pageY=O;var N=L.keyCode||L.charCode||0;if(B.webkit&&(N in A)){N=A[N];}this.keyCode=N;this.charCode=N;this.button=L.which||L.button;this.which=this.button;this.details=F;this.time=L.time||new Date().getTime();this.target=(I)?L.target:D(L.target||L.srcElement);this.currentTarget=(I)?J:D(J);var S=L.relatedTarget;if(!S){if(L.type=="mouseout"){S=L.toElement;}else{if(L.type=="mouseover"){S=L.fromElement;}}}this.relatedTarget=(I)?S:D(S);this.stopPropagation=function(){if(L.stopPropagation){L.stopPropagation();}else{L.cancelBubble=true;}if(G){G.stopPropagation();}};this.stopImmediatePropagation=function(){if(L.stopImmediatePropagation){L.stopImmediatePropagation();}else{this.stopPropagation();}if(G){G.stopImmediatePropagation();}};this.preventDefault=function(){if(L.preventDefault){L.preventDefault();}else{L.returnValue=false;}if(G){G.preventDefault();}};this.halt=function(T){if(T){this.stopImmediatePropagation();}else{this.stopPropagation();}this.preventDefault();};};},"3.0.0");YUI.add("event-simulate",function(B){var H=B.Lang,G=B.Array,D=H.isFunction,C=H.isString,E=H.isBoolean,K=H.isObject,J=H.isNumber,M=["click","dblclick","mouseover","mouseout","mousedown","mouseup","mousemove"],I=["keydown","keyup","keypress"];function F(R,V,Q,O,X,N,L,W,T,Z,Y){if(!R){B.fail("simulateKeyEvent(): Invalid target.");}if(C(V)){V=V.toLowerCase();switch(V){case"textevent":V="keypress";case"keyup":case"keydown":case"keypress":break;default:B.fail("simulateKeyEvent(): Event type '"+V+"' not supported.");}}else{B.fail("simulateKeyEvent(): Event type must be a string.");}if(!E(Q)){Q=true;}if(!E(O)){O=true;}if(!K(X)){X=window;}if(!E(N)){N=false;}if(!E(L)){L=false;}if(!E(W)){W=false;}if(!E(T)){T=false;}if(!J(Z)){Z=0;}if(!J(Y)){Y=0;}var U=null;if(D(document.createEvent)){try{U=document.createEvent("KeyEvents");U.initKeyEvent(V,Q,O,X,N,L,W,T,Z,Y);}catch(S){try{U=document.createEvent("Events");}catch(P){U=document.createEvent("UIEvents");}finally{U.initEvent(V,Q,O);U.view=X;U.altKey=L;U.ctrlKey=N;U.shiftKey=W;U.metaKey=T;U.keyCode=Z;U.charCode=Y;}}R.dispatchEvent(U);}else{if(K(document.createEventObject)){U=document.createEventObject();U.bubbles=Q;U.cancelable=O;U.view=X;U.ctrlKey=N;U.altKey=L;U.shiftKey=W;U.metaKey=T;U.keyCode=(Y>0)?Y:Z;R.fireEvent("on"+V,U);}else{B.fail("simulateKeyEvent(): No event simulation framework present.");}}}function A(W,b,T,Q,c,V,S,R,P,N,O,L,a,Y,U,X){if(!W){B.fail("simulateMouseEvent(): Invalid target.");}if(C(b)){b=b.toLowerCase();if(G.indexOf(M,b)==-1){B.fail("simulateMouseEvent(): Event type '"+b+"' not supported.");}}else{B.fail("simulateMouseEvent(): Event type must be a string.");}if(!E(T)){T=true;}if(!E(Q)){Q=(b!="mousemove");}if(!K(c)){c=window;}if(!J(V)){V=1;}if(!J(S)){S=0;}if(!J(R)){R=0;}if(!J(P)){P=0;}if(!J(N)){N=0;}if(!E(O)){O=false;}if(!E(L)){L=false;}if(!E(a)){a=false;}if(!E(Y)){Y=false;}if(!J(U)){U=0;}var Z=null;if(D(document.createEvent)){Z=document.createEvent("MouseEvents");if(Z.initMouseEvent){Z.initMouseEvent(b,T,Q,c,V,S,R,P,N,O,L,a,Y,U,X);}else{Z=document.createEvent("UIEvents");Z.initEvent(b,T,Q);Z.view=c;Z.detail=V;Z.screenX=S;Z.screenY=R;Z.clientX=P;Z.clientY=N;Z.ctrlKey=O;Z.altKey=L;Z.metaKey=Y;Z.shiftKey=a;Z.button=U;Z.relatedTarget=X;}if(X&&!Z.relatedTarget){if(b=="mouseout"){Z.toElement=X;}else{if(b=="mouseover"){Z.fromElement=X;}}}W.dispatchEvent(Z);}else{if(K(document.createEventObject)){Z=document.createEventObject();Z.bubbles=T;Z.cancelable=Q;Z.view=c;Z.detail=V;Z.screenX=S;Z.screenY=R;Z.clientX=P;Z.clientY=N;Z.ctrlKey=O;Z.altKey=L;Z.metaKey=Y;Z.shiftKey=a;switch(U){case 0:Z.button=1;break;case 1:Z.button=4;break;case 2:break;default:Z.button=0;}Z.relatedTarget=X;W.fireEvent("on"+b,Z);}else{B.fail("simulateMouseEvent(): No event simulation framework present.");}}}G.each(M,function(L){B.Event[L]=function(O,N){N=N||{};A(O,L,N.bubbles,N.cancelable,N.view,N.detail,N.screenX,N.screenY,N.clientX,N.clientY,N.ctrlKey,N.altKey,N.shiftKey,N.metaKey,N.button,N.relatedTarget);};});G.each(I,function(L){B.Event[L]=function(O,N){N=N||{};F(O,L,N.bubbles,N.cancelable,N.view,N.ctrlKey,N.altKey,N.shiftKey,N.metaKey,N.keyCode,N.charCode);};});B.Event.simulate=function(O,N,L){if(D(B.Event[N])){B.Event[N](O,L);}};},"3.0.0pr2",{requires:["lang","event-dom"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/event/event.js'
--- loggerhead/static/javascript/yui/build/event/event.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/event/event.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,3754 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * The YUI event system
+ * @module event
+ */
+YUI.add("event", function(Y) {
+
+    var FOCUS = Y.UA.ie ? "focusin" : "focus",
+        BLUR = Y.UA.ie ? "focusout" : "blur",
+        CAPTURE = "capture_",
+        Lang = Y.Lang;
+
+    Y.Env.eventAdaptors = {
+
+        /**
+         * Adds a DOM focus listener.  Uses the focusin event in IE,
+         * and the capture phase otherwise so that
+         * the event propagates properly.
+         * @for YUI
+         * @event focus
+         */
+        focus: {
+            on: function() {
+                arguments[0] = CAPTURE + FOCUS;
+                return Y.Event.attach.apply(Y.Event, arguments);
+            },
+
+            detach: function() {
+                arguments[0] = CAPTURE + FOCUS;
+                return Y.Event.detach.apply(Y.Event, arguments);
+
+            }
+        },
+
+        /**
+         * Adds a DOM focus listener.  Uses the focusout event in IE,
+         * and the capture phase otherwise so that
+         * the event propagates properly.
+         * @for YUI
+         * @event blur
+         */
+        blur: {
+            on: function() {
+                arguments[0] = CAPTURE + BLUR;
+                return Y.Event.attach.apply(Y.Event, arguments);
+            },
+
+            detach: function() {
+                arguments[0] = CAPTURE + BLUR;
+                return Y.Event.detach.apply(Y.Event, arguments);
+            }
+        },
+
+        /**
+         * Executes the callback as soon as the specified element 
+         * is detected in the DOM.
+         * @for YUI
+         * @event available
+         */
+        available: {
+            on: function(type, fn, id, o) {
+                var a = arguments.length > 4 ?  Y.Array(arguments, 4, true) : [];
+                return Y.Event.onAvailable.call(Y.Event, id, fn, o, a);
+            }
+        },
+
+        /**
+         * Executes the callback as soon as the specified element 
+         * is detected in the DOM with a nextSibling property
+         * (indicating that the element's children are available)
+         * @for YUI
+         * @event contentready
+         */
+        contentready: {
+            on: function(type, fn, id, o) {
+                var a = arguments.length > 4 ?  Y.Array(arguments, 4, true) : [];
+                return Y.Event.onContentReady.call(Y.Event, id, fn, o, a);
+            }
+        },
+
+        /**
+         * Add a key listener.  The listener will only be notified if the
+         * keystroke detected meets the supplied specification.  The
+         * spec consists of the key event type, followed by a colon,
+         * followed by zero or more comma separated key codes, followed
+         * by zero or more modifiers delimited by a plus sign.  Ex:
+         * press:12,65+shift+ctrl
+         * @event key
+         * @param fn {string} the function to execute
+         * @param id {string} the element(s) to bind
+         * @param spec {string} the keyCode and modifier specification
+         * @param o optional context object
+         * @param args 0..n additional arguments that should be provided 
+         * to the listener.
+         */
+        key: {
+
+            on: function(type, fn, id, spec, o) {
+
+                if (!spec || spec.indexOf(':') == -1) {
+                    arguments[0] = 'keypress';
+                    return Y.on.apply(Y, arguments);
+                }
+
+                // parse spec ([key event type]:[criteria])
+                var parsed = spec.split(':'),
+
+                    // key event type: 'down', 'up', or 'press'
+                    etype = parsed[0],
+
+                    // list of key codes optionally followed by modifiers
+                    criteria = (parsed[1]) ? parsed[1].split(/,|\+/) : null,
+
+                    // the name of the custom event that will be created for the spec
+                    ename = (Lang.isString(id) ? id : Y.stamp(id)) + spec,
+
+                    a = Y.Array(arguments, 0, true);
+
+
+
+                // subscribe spec validator to the DOM event
+                Y.on(type + etype, function(e) {
+
+                    
+                    var passed = false, failed = false;
+
+                    for (var i=0; i<criteria.length; i=i+1) {
+                        var crit = criteria[i], critInt = parseInt(crit, 10);
+
+                        // pass this section if any supplied keyCode 
+                        // is found
+                        if (Lang.isNumber(critInt)) {
+
+                            if (e.charCode === critInt) {
+                                passed = true;
+                            } else {
+                                failed = true;
+                            }
+
+                        // only check modifier if no keyCode was specified
+                        // or the keyCode check was successful.  pass only 
+                        // if every modifier passes
+                        } else if (passed || !failed) {
+                            passed = (e[crit + 'Key']);
+                            failed = !passed;
+                        }                    
+                    }
+
+                    // fire spec custom event if spec if met
+                    if (passed) {
+                        Y.fire(ename, e);
+                    }
+
+                }, id);
+
+                // subscribe supplied listener to custom event for spec validator
+                // remove element and spec.
+                a.splice(2, 2);
+                a[0] = ename;
+
+                return Y.on.apply(Y, a);
+            }
+        }
+
+    };
+
+    /**
+     * Attach an event listener, either to a DOM object
+     * or to an Event.Target.
+     * @param type {string} the event type
+     * @param f {Function} the function to execute
+     * @param o the Event.Target or element to attach to
+     * @param context Optional execution context
+     * @param args* 0..n additional arguments to append
+     * to the signature provided when the event fires.
+     * @method on
+     * @for YUI
+     * @return {Event.Handle} a handle object for 
+     * unsubscribing to this event.
+     */
+    Y.on = function(type, f, o) {
+        
+       var adapt = Y.Env.eventAdaptors[type];
+        
+        if (adapt && adapt.on) {
+            return adapt.on.apply(Y, arguments);
+        } else {
+            if (adapt || type.indexOf(':') > -1) {
+                return Y.subscribe.apply(Y, arguments);
+            } else {
+                return Y.Event.attach.apply(Y.Event, arguments);
+            }
+        }
+
+    };
+
+    /**
+     * Detach an event listener (either a custom event or a
+     * DOM event
+     * @method detach
+     * @param type the type of event, or a Event.Handle to
+     * for the subscription.  If the Event.Handle is passed
+     * in, the other parameters are not used.
+     * @param f {Function} the subscribed function
+     * @param o the object or element the listener is subscribed
+     * to.
+     * @method detach
+     * @return {YUI} the YUI instance
+     */
+    Y.detach = function(type, f, o) {
+
+        var adapt = Y.Env.eventAdaptors[type];
+
+        if (Lang.isObject(type) && type.detach) {
+            return type.detach();
+        } else {
+            if (adapt && adapt.detach) {
+                return adapt.detach.apply(Y, arguments);
+            } else if (adapt || type.indexOf(':') > -1) {
+                return Y.unsubscribe.apply(Y, arguments);
+            } else {
+                return Y.Event.detach.apply(Y.Event, arguments);
+            }
+        }
+    };
+
+    /**
+     * Executes the callback before a DOM event, custom event
+     * or method.  If the first argument is a function, it
+     * is assumed the target is a method.  For DOM and custom
+     * events, this is an alias for Y.on.
+     *
+     * For DOM and custom events:
+     * type, callback, context, 1-n arguments
+     *  
+     * For methods:
+     * callback, object (method host), methodName, context, 1-n arguments
+     *
+     * @method before
+     * @return unsubscribe handle
+     */
+    Y.before = function(type, f, o) { 
+        if (Lang.isFunction(type)) {
+            return Y.Do.before.apply(Y.Do, arguments);
+        } else {
+            return Y.on.apply(Y, arguments);
+        }
+    };
+
+    var after = Y.after;
+
+    /**
+     * Executes the callback after a DOM event, custom event
+     * or method.  If the first argument is a function, it
+     * is assumed the target is a method.
+     *
+     * For DOM and custom events:
+     * type, callback, context, 1-n arguments
+     *  
+     * For methods:
+     * callback, object (method host), methodName, context, 1-n arguments
+     *
+     * @method after
+     * @return {Event.Handle} unsubscribe handle
+     */
+    Y.after = function(type, f, o) {
+        if (Lang.isFunction(type)) {
+            return Y.Do.after.apply(Y.Do, arguments);
+        } else {
+            return after.apply(Y, arguments);
+        }
+    };
+
+
+}, "3.0.0", {
+    use: [
+          "aop", 
+          "event-custom", 
+          "event-target", 
+          "event-ready",
+          "event-dom", 
+          "event-facade",
+          "event-simulate"
+          ]
+});
+/*
+ * Method displacement
+ * @submodule event-aop
+ * @module event
+ */
+YUI.add("aop", function(Y) {
+
+    var BEFORE = 0,
+        AFTER = 1;
+
+    /**
+     * Allows for the insertion of methods that are executed before or after
+     * a specified method
+     * @class Do
+     * @static
+     */
+    Y.Do = {
+
+        /**
+         * Cache of objects touched by the utility
+         * @property objs
+         * @static
+         */
+        objs: {},
+
+        /**
+         * Execute the supplied method before the specified function
+         * @method before
+         * @param fn {Function} the function to execute
+         * @param obj the object hosting the method to displace
+         * @param sFn {string} the name of the method to displace
+         * @param c The execution context for fn
+         * @return {string} handle for the subscription
+         * @static
+         */
+        before: function(fn, obj, sFn, c) {
+            var f = fn;
+            if (c) {
+                var a = [fn, c].concat(Y.Array(arguments, 4, true));
+                f = Y.bind.apply(Y, a);
+            }
+
+            return this._inject(BEFORE, f, obj, sFn);
+        },
+
+        /**
+         * Execute the supplied method after the specified function
+         * @method after
+         * @param fn {Function} the function to execute
+         * @param obj the object hosting the method to displace
+         * @param sFn {string} the name of the method to displace
+         * @param c The execution context for fn
+         * @return {string} handle for the subscription
+         * @static
+         */
+        after: function(fn, obj, sFn, c) {
+            var f = fn;
+            if (c) {
+                var a = [fn, c].concat(Y.Array(arguments, 4, true));
+                f = Y.bind.apply(Y, a);
+            }
+
+            return this._inject(AFTER, f, obj, sFn);
+        },
+
+        /**
+         * Execute the supplied method after the specified function
+         * @method _inject
+         * @param when {string} before or after
+         * @param fn {Function} the function to execute
+         * @param obj the object hosting the method to displace
+         * @param sFn {string} the name of the method to displace
+         * @param c The execution context for fn
+         * @return {string} handle for the subscription
+         * @private
+         * @static
+         */
+        _inject: function(when, fn, obj, sFn) {
+
+            // object id
+            var id = Y.stamp(obj);
+
+            if (! this.objs[id]) {
+                // create a map entry for the obj if it doesn't exist
+                this.objs[id] = {};
+            }
+            var o = this.objs[id];
+
+            if (! o[sFn]) {
+                // create a map entry for the method if it doesn't exist
+                o[sFn] = new Y.Do.Method(obj, sFn);
+
+                // re-route the method to our wrapper
+                obj[sFn] = 
+                    function() {
+                        return o[sFn].exec.apply(o[sFn], arguments);
+                    };
+            }
+
+            // subscriber id
+            var sid = id + Y.stamp(fn) + sFn;
+
+            // register the callback
+            o[sFn].register(sid, fn, when);
+
+            return new Y.EventHandle(o[sFn], sid);
+
+        },
+
+        /**
+         * Detach a before or after subscription
+         * @method detach
+         * @param handle {string} the subscription handle
+         */
+        detach: function(handle) {
+
+            if (handle.detach) {
+                handle.detach();
+            }
+
+        },
+
+        _unload: function(e, me) {
+
+        }
+    };
+
+    //////////////////////////////////////////////////////////////////////////
+
+    /**
+     * Wrapper for a displaced method with aop enabled
+     * @class Do.Method
+     * @constructor
+     * @param obj The object to operate on
+     * @param sFn The name of the method to displace
+     */
+    Y.Do.Method = function(obj, sFn) {
+        this.obj = obj;
+        this.methodName = sFn;
+        this.method = obj[sFn];
+        // this.before = [];
+        // this.after = [];
+        this.before = {};
+        this.after = {};
+    };
+
+    /**
+     * Register a aop subscriber
+     * @method register
+     * @param sid {string} the subscriber id
+     * @param fn {Function} the function to execute
+     * @param when {string} when to execute the function
+     */
+    Y.Do.Method.prototype.register = function (sid, fn, when) {
+        if (when) {
+            // this.after.push(fn);
+            this.after[sid] = fn;
+        } else {
+            // this.before.push(fn);
+            this.before[sid] = fn;
+        }
+    };
+
+    /**
+     * Unregister a aop subscriber
+     * @method delete
+     * @param sid {string} the subscriber id
+     * @param fn {Function} the function to execute
+     * @param when {string} when to execute the function
+     */
+    Y.Do.Method.prototype._delete = function (sid) {
+        delete this.before[sid];
+        delete this.after[sid];
+    };
+
+    /**
+     * Execute the wrapped method
+     * @method exec
+     */
+    Y.Do.Method.prototype.exec = function () {
+
+        var args = Y.Array(arguments, 0, true), 
+            i, ret, newRet, 
+            bf = this.before,
+            af = this.after,
+            prevented = false;
+
+        // execute before
+        for (i in bf) {
+            if (bf.hasOwnProperty(i)) {
+                ret = bf[i].apply(this.obj, args);
+                if (ret) {
+                    switch (ret.constructor) {
+                        case Y.Do.Halt:
+                            return ret.retVal;
+                        case Y.Do.AlterArgs:
+                            args = ret.newArgs;
+                            break;
+                        case Y.Do.Prevent:
+                            prevented = true;
+                            break;
+                        default:
+                    }
+                }
+            }
+        }
+
+        // execute method
+        if (!prevented) {
+            ret = this.method.apply(this.obj, args);
+        }
+
+        // execute after methods.
+        for (i in af) {
+            if (af.hasOwnProperty(i)) {
+                newRet = af[i].apply(this.obj, args);
+                // Stop processing if a Halt object is returned
+                if (newRet && newRet.constructor == Y.Do.Halt) {
+                    return newRet.retVal;
+                // Check for a new return value
+                } else if (newRet && newRet.constructor == Y.Do.AlterReturn) {
+                    ret = newRet.newRetVal;
+                }
+            }
+        }
+
+        return ret;
+    };
+
+    //////////////////////////////////////////////////////////////////////////
+
+
+    /**
+     * Return an AlterArgs object when you want to change the arguments that
+     * were passed into the function.  An example would be a service that scrubs
+     * out illegal characters prior to executing the core business logic.
+     * @class Do.AlterArgs
+     */
+    Y.Do.AlterArgs = function(msg, newArgs) {
+        this.msg = msg;
+        this.newArgs = newArgs;
+    };
+
+    /**
+     * Return an AlterReturn object when you want to change the result returned
+     * from the core method to the caller
+     * @class Do.AlterReturn
+     */
+    Y.Do.AlterReturn = function(msg, newRetVal) {
+        this.msg = msg;
+        this.newRetVal = newRetVal;
+    };
+
+    /**
+     * Return a Halt object when you want to terminate the execution
+     * of all subsequent subscribers as well as the wrapped method
+     * if it has not exectued yet.
+     * @class Do.Halt
+     */
+    Y.Do.Halt = function(msg, retVal) {
+        this.msg = msg;
+        this.retVal = retVal;
+    };
+
+    /**
+     * Return a Prevent object when you want to prevent the wrapped function
+     * from executing, but want the remaining listeners to execute
+     * @class Do.Halt
+     */
+    Y.Do.Prevent = function(msg) {
+        this.msg = msg;
+    };
+
+    /**
+     * Return an Error object when you want to terminate the execution
+     * of all subsequent method calls.
+     * @class Do.Error
+     * @deprecated
+     */
+    Y.Do.Error = Y.Do.Halt;
+
+    //////////////////////////////////////////////////////////////////////////
+
+// Y["Event"] && Y.Event.addListener(window, "unload", Y.Do._unload, Y.Do);
+
+}, "3.0.0");
+/*
+ * YUI Custom Events
+ * @submodule event-custom
+ * @module event
+ */
+YUI.add("event-custom", function(Y) {
+
+    var onsubscribeType = "_event:onsub",
+        AFTER = 'after', 
+        CONFIGS = [
+            'broadcast',
+            'bubbles',
+            'context',
+            'configured',
+            'currentTarget',
+            'defaultFn',
+            'details',
+            'emitFacade',
+            'fireOnce',
+            'host',
+            'preventable',
+            'preventedFn',
+            'queuable',
+            'silent',
+            'stoppedFn',
+            'target',
+            'type'
+        ],
+
+        YUI3_SIGNATURE = 9;
+
+    /**
+     * Return value from all subscribe operations
+     * @class Event.Handle
+     * @constructor
+     * @param evt {Event.Custom} the custom event
+     * @param sub {Event.Subscriber} the subscriber
+     */
+    Y.EventHandle = function(evt, sub) {
+
+        /**
+         * The custom event
+         * @type Event.Custom
+         */
+        this.evt = evt;
+
+        /**
+         * The subscriber object
+         * @type Event.Subscriber
+         */
+        this.sub = sub;
+    };
+
+    Y.EventHandle.prototype = {
+        /**
+         * Detaches this subscriber
+         * @method detach
+         */
+        detach: function() {
+
+            if (this.evt) {
+                this.evt._delete(this.sub);
+            }
+        }
+    };
+
+    /**
+     * The Event.Custom class lets you define events for your application
+     * that can be subscribed to by one or more independent component.
+     *
+     * @param {String}  type The type of event, which is passed to the callback
+     *                  when the event fires
+     * @param o configuration object
+     * @class Event.Custom
+     * @constructor
+     */
+    Y.CustomEvent = function(type, o) {
+
+        // if (arguments.length > 2) {
+        // }
+
+        o = o || {};
+
+        this.id = Y.stamp(this);
+
+        /**
+         * The type of event, returned to subscribers when the event fires
+         * @property type
+         * @type string
+         */
+        this.type = type;
+
+        /**
+         * The context the the event will fire from by default.  Defaults to the YUI
+         * instance.
+         * @property context
+         * @type object
+         */
+        this.context = Y;
+
+
+        /**
+         * If 0, this event does not broadcast.  If 1, the YUI instance is notified
+         * every time this event fires.  If 2, the YUI instance and the YUI global
+         * (if event is enabled on the global) are notified every time this event
+         * fires.
+         * @property broadcast
+         * @type int
+         */
+        this.broadcast = 0;
+
+        /**
+         * By default all custom events are logged in the debug build, set silent
+         * to true to disable debug outpu for this event.
+         * @property silent
+         * @type boolean
+         */
+
+        this.queuable = false;
+
+        /**
+         * The subscribers to this event
+         * @property subscribers
+         * @type Event.Subscriber{}
+         */
+        this.subscribers = {};
+
+        /*
+         * The publisher has configured this event
+         * @property configured
+         * @type boolean
+         * @default true
+         */
+        // this.configured = true;
+
+        /**
+         * 'After' subscribers
+         * @property afters
+         * @type Event.Subscriber{}
+         */
+        this.afters = {};
+
+        /**
+         * This event has fired if true
+         *
+         * @property fired
+         * @type boolean
+         * @default false;
+         */
+        this.fired = false;
+
+        /**
+         * This event should only fire one time if true, and if
+         * it has fired, any new subscribers should be notified
+         * immediately.
+         *
+         * @property fireOnce
+         * @type boolean
+         * @default false;
+         */
+        this.fireOnce = false;
+
+        /**
+         * Flag for stopPropagation that is modified during fire()
+         * 1 means to stop propagation to bubble targets.  2 means
+         * to also stop additional subscribers on this target.
+         * @property stopped
+         * @type int
+         */
+        this.stopped = 0;
+
+        /**
+         * Flag for preventDefault that is modified during fire().
+         * if it is not 0, the default behavior for this event
+         * @property prevented
+         * @type int
+         */
+        this.prevented = 0;
+
+        /**
+         * Specifies the host for this custom event.  This is used
+         * to enable event bubbling
+         * @property host
+         * @type Event.Target
+         */
+        this.host = null;
+
+        /**
+         * The default function to execute after event listeners
+         * have fire, but only if the default action was not
+         * prevented.
+         * @property defaultFn
+         * @type Function
+         */
+        this.defaultFn = null;
+
+        /**
+         * The function to execute if a subscriber calls
+         * stopPropagation or stopImmediatePropagation
+         * @property stoppedFn
+         * @type Function
+         */
+        this.stoppedFn = null;
+
+        /**
+         * The function to execute if a subscriber calls
+         * preventDefault
+         * @property preventedFn
+         * @type Function
+         */
+        this.preventedFn = null;
+
+        /**
+         * Specifies whether or not this event's default function
+         * can be cancelled by a subscriber by executing preventDefault() 
+         * on the event facade 
+         * @property preventable 
+         * @type boolean 
+         * @default true
+         */
+        this.preventable = true;
+
+        /**
+         * Specifies whether or not a subscriber can stop the event propagation
+         * via stopPropagation(), stopImmediatePropagation(), or halt()
+         * @property bubbles
+         * @type boolean
+         * @default true
+         */
+        this.bubbles = true;
+
+        /**
+         * Supports multiple options for listener signatures in order to
+         * port YUI 2 apps.
+         * @property signature
+         * @type int
+         * @default 9
+         */
+        this.signature = YUI3_SIGNATURE;
+
+        /**
+         * If set to true, the custom event will deliver an Event.Facade object
+         * that is similar to a DOM event object.
+         * @property emitFacade
+         * @type boolean
+         * @default false
+         */
+        this.emitFacade = false;
+
+        this.applyConfig(o, true);
+
+
+        // Only add subscribe events for events that are not generated by 
+        // Event.Custom
+        if (type !== onsubscribeType) {
+
+            /**
+             * Custom events provide a custom event that fires whenever there is
+             * a new subscriber to the event.  This provides an opportunity to
+             * handle the case where there is a non-repeating event that has
+             * already fired has a new subscriber.  
+             *
+             * @event subscribeEvent
+             * @type Event.Custom
+             * @param {Function} fn The function to execute
+             * @param {Object}   obj An object to be passed along when the event 
+             *                       fires
+             * @param {boolean|Object}  override If true, the obj passed in becomes 
+             *                                   the execution context of the listener.
+             *                                   if an object, that object becomes the
+             *                                   the execution context.
+             */
+            this.subscribeEvent = new Y.CustomEvent(onsubscribeType, {
+                    context: this,
+                    silent: true
+                });
+        } 
+
+    };
+
+    Y.CustomEvent.prototype = {
+
+        _YUI_EVENT: true,
+
+        /**
+         * Apply configuration properties.  Only applies the CONFIG whitelist
+         * @method applyConfig
+         * @param o hash of properties to apply
+         * @param force {boolean} if true, properties that exist on the event 
+         * will be overwritten.
+         */
+        applyConfig: function(o, force) {
+            if (o) {
+                Y.mix(this, o, force, CONFIGS);
+            }
+        },
+
+        _subscribe: function(fn, obj, args, when) {
+
+            if (!fn) {
+                Y.fail("Invalid callback for CE: " + this.type);
+            }
+
+            var se = this.subscribeEvent;
+            if (se) {
+                se.fire.apply(se, args);
+            }
+
+            var s = new Y.Subscriber(fn, obj, args, when);
+
+
+            if (this.fireOnce && this.fired) {
+
+                // this._notify(s);
+                // setTimeout(Y.bind(this._notify, this, s), 0);
+                Y.later(0, this, this._notify, s);
+            }
+
+            if (when == AFTER) {
+                this.afters[s.id] = s;
+            } else {
+                this.subscribers[s.id] = s;
+            }
+
+            return new Y.EventHandle(this, s);
+
+        },
+
+        /**
+         * Listen for this event
+         * @method subscribe
+         * @param {Function} fn        The function to execute
+         * @param {Object}   obj       An object to be passed along when the event fires
+         * @param args* 1..n params to provide to the listener
+         * @return {Event.Handle} unsubscribe handle
+         */
+        subscribe: function(fn, obj) {
+            return this._subscribe(fn, obj, arguments, true);
+        },
+
+        /**
+         * Listen for this event after the normal subscribers have been notified and
+         * the default behavior has been applied.  If a normal subscriber prevents the 
+         * default behavior, it also prevents after listeners from firing.
+         * @method after
+         * @param {Function} fn        The function to execute
+         * @param {Object}   obj       An object to be passed along when the event fires
+         * @param args* 1..n params to provide to the listener
+         * @return {Event.Handle} unsubscribe handle
+         */
+        after: function(fn, obj) {
+            return this._subscribe(fn, obj, arguments, AFTER);
+        },
+
+        /**
+         * Unsubscribes subscribers.
+         * @method unsubscribe
+         * @param {Function} fn  The subscribed function to remove, if not supplied
+         *                       all will be removed
+         * @param {Object}   obj  The custom object passed to subscribe.  This is
+         *                        optional, but if supplied will be used to
+         *                        disambiguate multiple listeners that are the same
+         *                        (e.g., you subscribe many object using a function
+         *                        that lives on the prototype)
+         * @return {boolean} True if the subscriber was found and detached.
+         */
+        unsubscribe: function(fn, obj) {
+
+            // if arg[0] typeof unsubscribe handle
+            if (fn && fn.detach) {
+                return fn.detach();
+            }
+
+            if (!fn) {
+                return this.unsubscribeAll();
+            }
+
+            var found = false, subs = this.subscribers;
+            for (var i in subs) {
+                if (subs.hasOwnProperty(i)) {
+                    var s = subs[i];
+                    if (s && s.contains(fn, obj)) {
+                        this._delete(s);
+                        found = true;
+                    }
+                }
+            }
+
+            return found;
+        },
+
+        _getFacade: function(args) {
+
+            var ef = this._facade;
+
+            if (!ef) {
+                ef = new Y.Event.Facade(this, this.currentTarget);
+            }
+
+            // if the first argument is an object literal, apply the
+            // properties to the event facade
+            var o = args && args[0];
+            if (Y.Lang.isObject(o, true) && !o._yuifacade) {
+                Y.mix(ef, o, true);
+            }
+
+            // update the details field with the arguments
+            ef.details = this.details;
+            ef.target = this.target;
+            ef.currentTarget = this.currentTarget;
+            ef.stopped = 0;
+            ef.prevented = 0;
+
+            this._facade = ef;
+
+            return this._facade;
+        },
+
+        /**
+         * Notify a single subscriber
+         * @method _notify
+         * @param s {Event.Subscriber} the subscriber
+         * @param args {Array} the arguments array to apply to the listener
+         * @private
+         */
+        _notify: function(s, args, ef) {
+
+
+            var ret, c, ct;
+
+            // emit an Event.Facade if this is that sort of event
+            // if (this.emitFacade && (!args[0] || !args[0]._yuifacade)) {
+            if (this.emitFacade) {
+
+                // @TODO object literal support to fire makes it possible for
+                // config info to be passed if we wish.
+                
+                if (!ef) {
+                    ef = this._getFacade(args);
+                    args[0] = ef;
+                }
+
+            }
+
+            // The default context should be the object/element that
+            // the listener was bound to.
+            ct = (args && Y.Lang.isObject(args[0]) && args[0].currentTarget);
+            ret = s.notify(ct || this.context, args, this);
+
+            if (false === ret || this.stopped > 1) {
+                return false;
+            }
+
+            return true;
+        },
+
+        /**
+         * Logger abstraction to centralize the application of the silent flag
+         * @method log
+         * @param msg {string} message to log
+         * @param cat {string} log category
+         */
+        log: function(msg, cat) {
+            var es = Y.Env._eventstack, s =  es && es.logging;
+            // if (!s && !this.silent) {
+            if (!this.silent) {
+            }
+        },
+
+        /**
+         * Notifies the subscribers.  The callback functions will be executed
+         * from the context specified when the event was created, and with the 
+         * following parameters:
+         *   <ul>
+         *   <li>The type of event</li>
+         *   <li>All of the arguments fire() was executed with as an array</li>
+         *   <li>The custom object (if any) that was passed into the subscribe() 
+         *       method</li>
+         *   </ul>
+         * @method fire 
+         * @param {Object*} arguments an arbitrary set of parameters to pass to 
+         *                            the handler.
+         * @return {boolean} false if one of the subscribers returned false, 
+         *                   true otherwise
+         */
+        fire: function() {
+
+            var es = Y.Env._eventstack;
+
+            if (es) {
+
+                // var b = this.bubbles, h = this.host;
+                // if (b && h) {
+                //     b = (h._yuievt.targets.length);
+                // }
+
+                // es.silent = (es.silent || this.silent);
+
+                // queue this event if the current item in the queue bubbles
+                // if (b && this.queuable && this.type != es.next.type) {
+                if (this.queuable && this.type != es.next.type) {
+
+
+                    es.queue.push([this, arguments]);
+                    return true;
+                }
+
+            } else {
+
+                Y.Env._eventstack = {
+                   // id of the first event in the stack
+                   id: this.id,
+                   next: this,
+                   silent: this.silent,
+                   logging: (this.type === 'yui:log'),
+                   stopped: 0,
+                   prevented: 0,
+                   queue: []
+                };
+
+                es = Y.Env._eventstack;
+            }
+
+            var ret = true;
+
+            if (this.fireOnce && this.fired) {
+
+
+            } else {
+
+                // var subs = this.subscribers.slice(), len=subs.length,
+                var subs = Y.merge(this.subscribers), s,
+                           args=Y.Array(arguments, 0, true), i;
+
+                this.stopped = 0;
+                this.prevented = 0;
+                this.target = this.target || this.host;
+
+                this.currentTarget = this.host || this.currentTarget;
+
+                this.fired = true;
+                this.details = args.slice(); // original arguments in the details
+
+
+                var hasSub = false;
+                es.lastLogState = es.logging;
+
+
+                var ef = null;
+                if (this.emitFacade) {
+
+                    // this.fire({
+                    //   foo: 1
+                    //   bar: 2
+                    // }
+                    // this.fire({
+                    //   bar: 2
+                    // } // foo is still 1 unless we create a new facade
+                    this._facade = null;
+
+                    ef = this._getFacade(args);
+                    args[0] = ef;
+                }
+
+                for (i in subs) {
+                    if (subs.hasOwnProperty(i)) {
+
+                        if (!hasSub) {
+                            es.logging = (es.logging || (this.type === 'yui:log'));
+                            hasSub = true;
+                        }
+
+                        // stopImmediatePropagation
+                        if (this.stopped == 2) {
+                            break;
+                        }
+
+                        s = subs[i];
+                        if (s && s.fn) {
+                            ret = this._notify(s, args, ef);
+                            if (false === ret) {
+                                this.stopped = 2;
+                            }
+                        }
+                    }
+                }
+
+                es.logging = (es.lastLogState);
+
+                // bubble if this is hosted in an event target and propagation has not been stopped
+                // @TODO check if we need to worry about defaultFn order
+                if (this.bubbles && this.host && !this.stopped) {
+                    es.stopped = 0;
+                    es.prevented = 0;
+                    ret = this.host.bubble(this);
+
+                    this.stopped = Math.max(this.stopped, es.stopped);
+                    this.prevented = Math.max(this.prevented, es.prevented);
+                }
+
+                // execute the default behavior if not prevented
+                // @TODO need context
+                if (this.defaultFn && !this.prevented) {
+                    this.defaultFn.apply(this.host || this, args);
+                }
+
+                // process after listeners.  If the default behavior was
+                // prevented, the after events don't fire.
+                if (!this.prevented && this.stopped < 2) {
+                    subs = Y.merge(this.afters);
+                    for (i in subs) {
+                        if (subs.hasOwnProperty(i)) {
+
+                            if (!hasSub) {
+                                es.logging = (es.logging || (this.type === 'yui:log'));
+                                hasSub = true;
+                            }
+
+                            // stopImmediatePropagation
+                            if (this.stopped == 2) {
+                                break;
+                            }
+
+                            s = subs[i];
+                            if (s && s.fn) {
+                                ret = this._notify(s, args, ef);
+                                if (false === ret) {
+                                    this.stopped = 2;
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+
+            if (es.id === this.id) {
+// console.log('clearing stack: ' + es.id + ', ' + this);
+
+// reset propragation properties while processing the rest of the queue
+
+// process queued events
+                var queue = es.queue;
+
+                while (queue.length) {
+                    // q[0] = the event, q[1] = arguments to fire
+                    var q = queue.pop(), ce = q[0];
+
+                    es.stopped = 0;
+                    es.prevented = 0;
+                    
+// set up stack to allow the next item to be processed
+                    es.next = ce;
+
+                    ret = ce.fire.apply(ce, q[1]);
+                }
+
+                Y.Env._eventstack = null;
+            } 
+
+            return (ret !== false);
+        },
+
+        /**
+         * Removes all listeners
+         * @method unsubscribeAll
+         * @return {int} The number of listeners unsubscribed
+         */
+        unsubscribeAll: function() {
+            var subs = this.subscribers, i;
+            for (i in subs) {
+                if (subs.hasOwnProperty(i)) {
+                    this._delete(subs[i]);
+                }
+            }
+
+            this.subscribers={};
+
+            return i;
+        },
+
+        /**
+         * @method _delete
+         * @param subscriber object
+         * @private
+         */
+        _delete: function(s) {
+
+            if (s) {
+                delete s.fn;
+                delete s.obj;
+                delete this.subscribers[s.id];
+                delete this.afters[s.id];
+            }
+
+        },
+
+        /**
+         * @method toString
+         */
+        toString: function() {
+             // return "{ CE '" + this.type + "' " + "id: " + this.id +
+                  // ", host: " + (this.host && Y.stamp(this.host) + " }");
+             return this.type;
+        },
+
+        /**
+         * Stop propagation to bubble targets
+         * @method stopPropagation
+         */
+        stopPropagation: function() {
+            this.stopped = 1;
+            Y.Env._eventstack.stopped = 1;
+            if (this.stoppedFn) {
+                this.stoppedFn.call(this.host || this, this);
+            }
+        },
+
+        /**
+         * Stops propagation to bubble targets, and prevents any remaining
+         * subscribers on the current target from executing.
+         * @method stopImmediatePropagation
+         */
+        stopImmediatePropagation: function() {
+            this.stopped = 2;
+            Y.Env._eventstack.stopped = 2;
+            if (this.stoppedFn) {
+                this.stoppedFn.call(this.host || this, this);
+            }
+        },
+
+        /**
+         * Prevents the execution of this event's defaultFn
+         * @method preventDefault
+         */
+        preventDefault: function() {
+            if (this.preventable) {
+                this.prevented = 1;
+                Y.Env._eventstack.prevented = 1;
+            }
+            if (this.preventedFn) {
+                this.preventedFn.call(this.host || this, this);
+            }
+        }
+
+    };
+
+    /////////////////////////////////////////////////////////////////////
+
+    /**
+     * Stores the subscriber information to be used when the event fires.
+     * @param {Function} fn       The wrapped function to execute
+     * @param {Object}   obj      An object to be passed along when the event fires
+     * @param {Array} args        subscribe() additional arguments
+     *
+     * @class Event.Subscriber
+     * @constructor
+     */
+    Y.Subscriber = function(fn, obj, args) {
+
+        /**
+         * The callback that will be execute when the event fires
+         * This is wrapped by Y.bind if obj was supplied.
+         * @property fn
+         * @type Function
+         */
+        this.fn = fn;
+
+        /**
+         * An optional custom object that will passed to the callback when
+         * the event fires
+         * @property obj
+         * @type Object
+         */
+        this.obj = obj;
+
+        /**
+         * Unique subscriber id
+         * @property id
+         * @type String
+         */
+        this.id = Y.stamp(this);
+
+        /**
+         * Optional additional arguments supplied to subscribe().  If present,
+         * these will be appended to the arguments supplied to fire()
+         * @property args
+         * @type Array
+         */
+        // this.args = args;
+
+        /**
+         * }
+         * fn bound to obj with additional arguments applied via Y.bind
+         * @property wrappedFn
+         * @type Function
+         */
+        this.wrappedFn = fn;
+        
+        if (obj) {
+            /*
+            var a = (args) ? Y.Array(args) : [];
+            a.unshift(fn, obj);
+            // a.unshift(fn);
+            m = Y.bind.apply(Y, a);
+            */
+            this.wrappedFn = Y.bind.apply(Y, args);
+        }
+        
+
+
+    };
+
+    Y.Subscriber.prototype = {
+
+        /**
+         * Executes the subscriber.
+         * @method notify
+         * @param defaultContext The execution context if not overridden
+         * by the subscriber
+         * @param args {Array} Arguments array for the subscriber
+         * @param ce {Event.Custom} The custom event that sent the notification
+         */
+        notify: function(defaultContext, args, ce) {
+            var c = this.obj || defaultContext, ret = true,
+
+                f = function() {
+                    switch (ce.signature) {
+                        case 0:
+                            ret = this.fn.call(c, ce.type, args, this.obj);
+                            break;
+                        case 1:
+                            ret = this.fn.call(c, args[0] || null, this.obj);
+                            break;
+                        default:
+                            ret = this.wrappedFn.apply(c, args || []);
+                    }
+                };
+
+            // Ease debugging by only catching errors if we will not re-throw
+            // them.
+            if (Y.config.throwFail) {
+                f.call(this);
+            } else {
+                try {
+                    f.call(this);
+                } catch(e) {
+                    Y.fail(this + ' failed: ' + e.message, e);
+                }
+            }
+
+            return ret;
+        },
+
+        /**
+         * Returns true if the fn and obj match this objects properties.
+         * Used by the unsubscribe method to match the right subscriber.
+         *
+         * @method contains
+         * @param {Function} fn the function to execute
+         * @param {Object} obj an object to be passed along when the event fires
+         * @return {boolean} true if the supplied arguments match this 
+         *                   subscriber's signature.
+         */
+        contains: function(fn, obj) {
+            if (obj) {
+                return ((this.fn == fn) && this.obj == obj);
+            } else {
+                return (this.fn == fn);
+            }
+        },
+
+        /**
+         * @method toString
+         */
+        toString: function() {
+            return "Subscriber " + this.id;
+        }
+    };
+
+}, "3.0.0");
+/*
+ * Configures an object to be able to be targeted for events, and to publish events
+ * @submodule event-target
+ * @module event
+ */
+YUI.add("event-target", function(Y) {
+
+    var SILENT = { 'yui:log': true };
+
+    /**
+     * Event.Target is designed to be used with Y.augment to wrap 
+     * Event.Custom in an interface that allows events to be subscribed to 
+     * and fired by name.  This makes it possible for implementing code to
+     * subscribe to an event that either has not been created yet, or will
+     * not be created at all.
+     *
+     * @Class Event.Target
+     */
+    Y.EventTarget = function(opts) { 
+
+        // console.log('Event.Target constructor executed: ' + this._yuid);
+
+        var o = (Y.Lang.isObject(opts)) ? opts : {};
+
+        this._yuievt = {
+
+            events: {},
+
+            targets: {},
+
+            config: o,
+
+            defaults: {
+                context: this, 
+                host: this,
+                emitFacade: o.emitFacade || false,
+                bubbles: ('bubbles' in o) ? o.bubbles : true
+            }
+            
+        };
+
+    };
+
+    var ET = Y.EventTarget;
+
+
+    ET.prototype = {
+
+        /**
+         * Subscribe to a custom event hosted by this object
+         * @method subscribe
+         * @param type    {string}   The type of the event
+         * @param fn {Function} The callback
+         * @param context The execution context
+         * @param args* 1..n params to supply to the callback
+         */
+        subscribe: function(type, fn, context) {
+
+            if (Y.Lang.isObject(type)) {
+
+                var f = fn, c = context, args = Y.Array(arguments, 0, true),
+                    ret = {};
+
+                Y.each(type, function(v, k) {
+
+                    if (v) {
+                        f = v.fn || f;
+                        c = v.context || c;
+                    }
+
+                    args[0] = k;
+                    args[1] = f;
+                    args[2] = c;
+
+                    ret[k] = this.subscribe.apply(this, args); 
+
+                }, this);
+
+                return ret;
+
+            }
+
+            var ce = this._yuievt.events[type] || 
+                // this.publish(type, {
+                //     configured: false
+                // }),
+                this.publish(type),
+                a = Y.Array(arguments, 1, true);
+
+            return ce.subscribe.apply(ce, a);
+
+        },
+
+        /**
+         * Unsubscribes one or more listeners the from the specified event
+         * @method unsubscribe
+         * @param type {string|Object}   Either the handle to the subscriber or the 
+         *                        type of event.  If the type
+         *                        is not specified, it will attempt to remove
+         *                        the listener from all hosted events.
+         * @param fn   {Function} The subscribed function to unsubscribe, if not
+         *                          supplied, all subscribers will be removed.
+         * @param context  {Object}   The custom object passed to subscribe.  This is
+         *                        optional, but if supplied will be used to
+         *                        disambiguate multiple listeners that are the same
+         *                        (e.g., you subscribe many object using a function
+         *                        that lives on the prototype)
+         * @return {boolean} true if the subscriber was found and detached.
+         */
+        unsubscribe: function(type, fn, context) {
+
+            // If this is an event handle, use it to detach
+            if (Y.Lang.isObject(type) && type.detach) {
+                return type.detach();
+            }
+
+            var evts = this._yuievt.events;
+
+            if (type) {
+                var ce = evts[type];
+                if (ce) {
+                    return ce.unsubscribe(fn, context);
+                }
+            } else {
+                var ret = true;
+                for (var i in evts) {
+                    if (Y.Object.owns(evts, i)) {
+                        ret = ret && evts[i].unsubscribe(fn, context);
+                    }
+                }
+                return ret;
+            }
+
+            return false;
+        },
+        
+        /**
+         * Removes all listeners from the specified event.  If the event type
+         * is not specified, all listeners from all hosted custom events will
+         * be removed.
+         * @method unsubscribeAll
+         * @param type {string}   The type, or name of the event
+         */
+        unsubscribeAll: function(type) {
+            return this.unsubscribe(type);
+        },
+
+        /**
+         * Creates a new custom event of the specified type.  If a custom event
+         * by that name already exists, it will not be re-created.  In either
+         * case the custom event is returned. 
+         *
+         * @method publish
+         *
+         * @param type {string} the type, or name of the event
+         * @param opts {object} optional config params.  Valid properties are:
+         *
+         *  <ul>
+         *    <li>
+         *   'broadcast': whether or not the YUI instance and YUI global are notified when the event is fired (false)
+         *    </li>
+         *    <li>
+         *   'bubbles': whether or not this event bubbles (true)
+         *    </li>
+         *    <li>
+         *   'context': the default execution context for the listeners (this)
+         *    </li>
+         *    <li>
+         *   'defaultFn': the default function to execute when this event fires if preventDefault was not called
+         *    </li>
+         *    <li>
+         *   'emitFacade': whether or not this event emits a facade (false)
+         *    </li>
+         *    <li>
+         *   'fireOnce': if an event is configured to fire once, new subscribers after
+         *   the fire will be notified immediately.
+         *    </li>
+         *    <li>
+         *   'preventable': whether or not preventDefault() has an effect (true)
+         *    </li>
+         *    <li>
+         *   'preventedFn': a function that is executed when preventDefault is called
+         *    </li>
+         *    <li>
+         *   'queuable': whether or not this event can be queued during bubbling (false)
+         *    </li>
+         *    <li>
+         *   'silent': if silent is true, debug messages are not provided for this event.
+         *    </li>
+         *    <li>
+         *   'stoppedFn': a function that is executed when stopPropagation is called
+         *    </li>
+         *    <li>
+         *   'type': the event type (valid option if not provided as the first parameter to publish)
+         *    </li>
+         *  </ul>
+         *
+         *  @return {Event.Custom} the custom event
+         *
+         */
+        publish: function(type, opts) {
+
+            if (Y.Lang.isObject(type)) {
+                var ret = {};
+                Y.each(type, function(v, k) {
+                    ret[k] = this.publish(k, v || opts); 
+                }, this);
+
+                return ret;
+            }
+
+            var events = this._yuievt.events, ce = events[type];
+
+            //if (ce && !ce.configured) {
+            if (ce) {
+// ce.log("publish applying config to published event: '"+type+"' exists", 'info', 'event');
+
+                // This event could have been published
+                ce.applyConfig(opts, true);
+                // ce.configured = true;
+
+            } else {
+                var o = opts || {};
+
+                // apply defaults
+                Y.mix(o, this._yuievt.defaults);
+
+                ce = new Y.CustomEvent(type, o);
+
+                events[type] = ce;
+
+                if (o.onSubscribeCallback) {
+                    ce.subscribeEvent.subscribe(o.onSubscribeCallback);
+                }
+
+            }
+
+            return events[type];
+        },
+
+        /**
+         * Registers another Event.Target as a bubble target.  Bubble order
+         * is determined by the order registered.  Multiple targets can
+         * be specified.
+         * @method addTarget
+         * @param o {Event.Target} the target to add
+         */
+        addTarget: function(o) {
+            this._yuievt.targets[Y.stamp(o)] = o;
+            this._yuievt.hasTargets = true;
+        },
+
+        /**
+         * Removes a bubble target
+         * @method removeTarget
+         * @param o {Event.Target} the target to remove
+         */
+        removeTarget: function(o) {
+            delete this._yuievt.targets[Y.stamp(o)];
+        },
+
+       /**
+         * Fire a custom event by name.  The callback functions will be executed
+         * from the context specified when the event was created, and with the 
+         * following parameters.
+         *
+         * If the custom event object hasn't been created, then the event hasn't 
+         * been published and it has no subscribers.  For performance sake, we 
+         * immediate exit in this case.  This means the event won't bubble, so 
+         * if the intention is that a bubble target be notified, the event must 
+         * be published on this object first.
+         *
+         * @method fire
+         * @param type {String|Object} The type of the event, or an object that contains
+         * a 'type' property.
+         * @param arguments {Object*} an arbitrary set of parameters to pass to 
+         * the handler.
+         * @return {boolean} the return value from Event.Custom.fire
+         *                   
+         */
+        fire: function(type) {
+
+            var typeIncluded = Y.Lang.isString(type),
+                t = (typeIncluded) ? type : (type && type.type);
+
+            var ce = this.getEvent(t);
+
+            // this event has not been published or subscribed to
+            if (!ce) {
+                
+                // if this object has bubble targets, we need to publish the
+                // event in order for it to bubble.
+                if (this._yuievt.hasTargets) {
+                    // ce = this.publish(t, {
+                    //     configured: false
+                    // });
+                    ce = this.publish(t);
+                    ce.details = Y.Array(arguments, (typeIncluded) ? 1 : 0, true);
+
+                    return this.bubble(ce);
+                }
+
+                // otherwise there is nothing to be done
+                return true;
+            }
+
+            // Provide this object's subscribers the object they are listening to.
+            // ce.currentTarget = this;
+
+            // This this the target unless target is current not null
+            // (set in bubble()).
+            // ce.target = ce.target || this;
+
+            var a = Y.Array(arguments, (typeIncluded) ? 1 : 0, true);
+            var ret = ce.fire.apply(ce, a);
+
+            // clear target for next fire()
+            ce.target = null;
+
+            return ret;
+        },
+
+        /**
+         * Returns the custom event of the provided type has been created, a
+         * falsy value otherwise
+         * @method getEvent
+         * @param type {string} the type, or name of the event
+         * @return {Event.Custom} the custom event or null
+         */
+        getEvent: function(type) {
+            var e = this._yuievt.events;
+            return (e && type in e) ? e[type] : null;
+        },
+
+        /**
+         * Propagate an event
+         * @method bubble
+         * @param evt {Event.Custom} the custom event to propagate
+         * @return {boolean} the aggregated return value from Event.Custom.fire
+         */
+        bubble: function(evt) {
+
+            var targs = this._yuievt.targets, ret = true;
+
+            if (!evt.stopped && targs) {
+
+
+                for (var i in targs) {
+                    if (targs.hasOwnProperty(i)) {
+
+                        var t = targs[i], type = evt.type,
+                            ce = t.getEvent(type), targetProp = evt.target || this;
+                            
+                        // if this event was not published on the bubble target,
+                        // publish it with sensible default properties
+                        if (!ce) {
+
+                            // publish the event on the bubble target using this event
+                            // for its configuration
+                            ce = t.publish(type, evt);
+                            // ce.configured = false;
+
+                            // set the host and context appropriately
+                            ce.context = (evt.host === evt.context) ? t : evt.context;
+                            ce.host = t;
+
+                            // clear handlers if specified on this event
+                            ce.defaultFn = null;
+                            ce.preventedFn = null;
+                            ce.stoppedFn = null;
+                        }
+
+                        ce.target = targetProp;
+                        ce.currentTarget = t;
+
+                        // ce.target = evt.target;
+
+                        ret = ret && ce.fire.apply(ce, evt.details);
+
+                        // stopPropagation() was called
+                        if (ce.stopped) {
+                            break;
+                        }
+                    }
+                }
+            }
+
+            return ret;
+        },
+
+        /**
+         * Subscribe to a custom event hosted by this object.  The
+         * supplied callback will execute after any listeners add
+         * via the subscribe method, and after the default function,
+         * if configured for the event, has executed.
+         * @method after
+         * @param type    {string}   The type of the event
+         * @param fn {Function} The callback
+         * @param context The execution context
+         * @param args* 1..n params to supply to the callback
+         */
+        after: function(type, fn) {
+            if (Y.Lang.isFunction(type)) {
+                return Y.Do.after.apply(Y.Do, arguments);
+            } else {
+                var ce = this._yuievt.events[type] || 
+                    // this.publish(type, {
+                    //     configured: false
+                    // }),
+                    this.publish(type),
+                    a = Y.Array(arguments, 1, true);
+
+                return ce.after.apply(ce, a);
+            }
+        },
+
+        before: function(type, fn) {
+            if (Y.Lang.isFunction(type)) {
+                return Y.Do.after.apply(Y.Do, arguments);
+            } else {
+                return this.subscribe.apply(this, arguments);
+            }
+        }
+
+    };
+
+    // make Y an event target
+    Y.mix(Y, ET.prototype, false, false, { 
+        bubbles: false 
+    });
+    ET.call(Y);
+
+
+}, "3.0.0");
+
+/*
+ * DOMReady
+ * @submodule event-ready
+ * @module event
+ */
+
+(function() {
+
+var Env = YUI.Env, 
+    C = YUI.config, 
+    D = C.doc, 
+    POLL_INTERVAL = C.pollInterval || 20;
+
+    if (!Env._ready) {
+
+        Env.windowLoaded = false;
+
+        var _ready = function(e) {
+            YUI.Env._ready();
+        };
+
+        Env._ready = function() {
+            if (!Env.DOMReady) {
+                Env.DOMReady=true;
+
+                // Remove the DOMContentLoaded (FF/Opera)
+                if (D.removeEventListener) {
+                    D.removeEventListener("DOMContentLoaded", _ready, false);
+                }
+            }
+        };
+
+        // create custom event
+
+        /////////////////////////////////////////////////////////////
+        // DOMReady
+        // based on work by: Dean Edwards/John Resig/Matthias Miller 
+
+        // Internet Explorer: use the readyState of a defered script.
+        // This isolates what appears to be a safe moment to manipulate
+        // the DOM prior to when the document's readyState suggests
+        // it is safe to do so.
+        if (navigator.userAgent.match(/MSIE/)) {
+
+            Env._dri = setInterval(function() {
+                try {
+                    // throws an error if doc is not ready
+                    document.documentElement.doScroll('left');
+                    clearInterval(Env._dri);
+                    Env._dri = null;
+                    _ready();
+                } catch (ex) { 
+                }
+            }, POLL_INTERVAL); 
+
+        // FireFox and Opera: These browsers provide a event for this
+        // moment.  The latest WebKit releases now support this event.
+        } else {
+            D.addEventListener("DOMContentLoaded", _ready, false);
+        }
+
+        /////////////////////////////////////////////////////////////
+    }
+
+    YUI.add("event-ready", function(Y) {
+
+        if (Y === YUI) {
+            return;
+        }
+
+        Y.mix(Y.Env.eventAdaptors, {
+
+            /**
+             * Executes the supplied callback when the DOM is first usable.  This
+             * will execute immediately if called after the DOMReady event has
+             * fired.   @todo the DOMContentReady event does not fire when the
+             * script is dynamically injected into the page.  This means the
+             * DOMReady custom event will never fire in FireFox or Opera when the
+             * library is injected.  It _will_ fire in Safari, and the IE 
+             * implementation would allow for us to fire it if the defered script
+             * is not available.  We want this to behave the same in all browsers.
+             * Is there a way to identify when the script has been injected 
+             * instead of included inline?  Is there a way to know whether the 
+             * window onload event has fired without having had a listener attached 
+             * to it when it did so?
+             *
+             * <p>The callback is a Event.Custom, so the signature is:</p>
+             * <p>type &lt;string&gt;, args &lt;array&gt;, customobject &lt;object&gt;</p>
+             * <p>For DOMReady events, there are no fire argments, so the
+             * signature is:</p>
+             * <p>"DOMReady", [], obj</p>
+             *
+             *
+             * @event domready
+             * @for YUI
+             *
+             * @param {function} fn what to execute when the element is found.
+             * @optional context execution context
+             * @optional args 1..n arguments to send to the listener
+             *
+             */
+            domready: {
+
+            },
+
+            /**
+             * Use domready event instead. @see domready
+             * @event event:ready
+             * @for YUI
+             * @deprecated use 'domready' instead
+             */
+            'event:ready': {
+
+                on: function() {
+                    arguments[0] = 'domready';
+                    return Y.subscribe.apply(Y, arguments);
+                },
+
+                detach: function() {
+                    arguments[0] = 'domready';
+                    return Y.unsubscribe.apply(Y, arguments);
+                }
+            }
+
+        });
+
+
+        Y.publish('domready', {
+            fireOnce: true
+        });
+
+        var yready = function() {
+            Y.fire('domready');
+        };
+
+        if (Env.DOMReady) {
+            yready();
+        } else {
+            Y.before(yready, Env, "_ready");
+        }
+
+    }, "3.0.0");
+
+})();
+/*
+ * The YUI DOM event system
+ * @submodule event-dom
+ * @module event
+ */
+(function() {
+
+    var add = function(el, type, fn, capture) {
+        if (el.addEventListener) {
+                el.addEventListener(type, fn, !!capture);
+        } else if (el.attachEvent) {
+                el.attachEvent("on" + type, fn);
+        } 
+    },
+
+    remove = function(el, type, fn, capture) {
+        if (el.removeEventListener) {
+                el.removeEventListener(type, fn, !!capture);
+        } else if (el.detachEvent) {
+                el.detachEvent("on" + type, fn);
+        }
+    },
+
+    onLoad = function() {
+        YUI.Env.windowLoaded = true;
+        remove(window, "load", onLoad);
+    },
+
+    EVENT_READY = 'domready',
+
+    COMPAT_ARG = '~yui|2|compat~',
+
+    CAPTURE = "capture_";
+
+add(window, "load", onLoad);
+
+YUI.add("event-dom", function(Y) {
+
+    /**
+     * The event utility provides functions to add and remove event listeners,
+     * event cleansing.  It also tries to automatically remove listeners it
+     * registers during the unload event.
+     *
+     * @class Event
+     * @static
+     */
+    Y.Event = function() {
+
+        /**
+         * True after the onload event has fired
+         * @property loadComplete
+         * @type boolean
+         * @static
+         * @private
+         */
+        var loadComplete =  false;
+
+        /**
+         * The number of times to poll after window.onload.  This number is
+         * increased if additional late-bound handlers are requested after
+         * the page load.
+         * @property _retryCount
+         * @static
+         * @private
+         */
+        var _retryCount = 0;
+
+        /**
+         * onAvailable listeners
+         * @property _avail
+         * @static
+         * @private
+         */
+        var _avail = [];
+
+        /**
+         * Custom event wrappers for DOM events.  Key is 
+         * 'event:' + Element uid stamp + event type
+         * @property _wrappers
+         * @type Y.Event.Custom
+         * @static
+         * @private
+         */
+        var _wrappers = {};
+
+        var _windowLoadKey = null;
+
+        /**
+         * Custom event wrapper map DOM events.  Key is 
+         * Element uid stamp.  Each item is a hash of custom event
+         * wrappers as provided in the _wrappers collection.  This
+         * provides the infrastructure for getListeners.
+         * @property _el_events
+         * @static
+         * @private
+         */
+        var _el_events = {};
+
+        return {
+
+            /**
+             * The number of times we should look for elements that are not
+             * in the DOM at the time the event is requested after the document
+             * has been loaded.  The default is 2000@amp;20 ms, so it will poll
+             * for 40 seconds or until all outstanding handlers are bound
+             * (whichever comes first).
+             * @property POLL_RETRYS
+             * @type int
+             * @static
+             * @final
+             */
+            POLL_RETRYS: 2000,
+
+            /**
+             * The poll interval in milliseconds
+             * @property POLL_INTERVAL
+             * @type int
+             * @static
+             * @final
+             */
+            POLL_INTERVAL: 20,
+
+            /**
+             * addListener/removeListener can throw errors in unexpected scenarios.
+             * These errors are suppressed, the method returns false, and this property
+             * is set
+             * @property lastError
+             * @static
+             * @type Error
+             */
+            lastError: null,
+
+
+            /**
+             * poll handle
+             * @property _interval
+             * @static
+             * @private
+             */
+            _interval: null,
+
+            /**
+             * document readystate poll handle
+             * @property _dri
+             * @static
+             * @private
+             */
+             _dri: null,
+
+            /**
+             * True when the document is initially usable
+             * @property DOMReady
+             * @type boolean
+             * @static
+             */
+            DOMReady: false,
+
+            /**
+             * @method startInterval
+             * @static
+             * @private
+             */
+            startInterval: function() {
+                var E = Y.Event;
+
+                if (!E._interval) {
+E._interval = setInterval(Y.bind(E._tryPreloadAttach, E), E.POLL_INTERVAL);
+                }
+            },
+
+            /**
+             * Executes the supplied callback when the item with the supplied
+             * id is found.  This is meant to be used to execute behavior as
+             * soon as possible as the page loads.  If you use this after the
+             * initial page load it will poll for a fixed time for the element.
+             * The number of times it will poll and the frequency are
+             * configurable.  By default it will poll for 10 seconds.
+             *
+             * <p>The callback is executed with a single parameter:
+             * the custom object parameter, if provided.</p>
+             *
+             * @method onAvailable
+             *
+             * @param {string||string[]}   id the id of the element, or an array
+             * of ids to look for.
+             * @param {function} fn what to execute when the element is found.
+             * @param {object}   p_obj an optional object to be passed back as
+             *                   a parameter to fn.
+             * @param {boolean|object}  p_override If set to true, fn will execute
+             *                   in the context of p_obj, if set to an object it
+             *                   will execute in the context of that object
+             * @param checkContent {boolean} check child node readiness (onContentReady)
+             * @static
+             * @deprecated Use Y.on("available")
+             */
+            // @TODO fix arguments
+            onAvailable: function(id, fn, p_obj, p_override, checkContent, compat) {
+
+                var a = Y.Array(id);
+
+
+                for (var i=0; i<a.length; i=i+1) {
+                    _avail.push({ 
+                        id:         a[i], 
+                        fn:         fn, 
+                        obj:        p_obj, 
+                        override:   p_override, 
+                        checkReady: checkContent,
+                        compat:     compat 
+                    });
+                }
+                _retryCount = this.POLL_RETRYS;
+
+                // We want the first test to be immediate, but async
+                setTimeout(Y.bind(Y.Event._tryPreloadAttach, Y.Event), 0);
+
+                return new Y.EventHandle(); // @TODO by id needs a defered handle
+            },
+
+            /**
+             * Works the same way as onAvailable, but additionally checks the
+             * state of sibling elements to determine if the content of the
+             * available element is safe to modify.
+             *
+             * <p>The callback is executed with a single parameter:
+             * the custom object parameter, if provided.</p>
+             *
+             * @method onContentReady
+             *
+             * @param {string}   id the id of the element to look for.
+             * @param {function} fn what to execute when the element is ready.
+             * @param {object}   p_obj an optional object to be passed back as
+             *                   a parameter to fn.
+             * @param {boolean|object}  p_override If set to true, fn will execute
+             *                   in the context of p_obj.  If an object, fn will
+             *                   exectute in the context of that object
+             *
+             * @static
+             * @deprecated Use Y.on("contentready")
+             */
+            // @TODO fix arguments
+            onContentReady: function(id, fn, p_obj, p_override, compat) {
+                return this.onAvailable(id, fn, p_obj, p_override, true, compat);
+            },
+
+
+            /**
+             * Appends an event handler
+             *
+             * @method attach
+             *
+             * @param {String}   type     The type of event to append
+             * @param {Function} fn        The method the event invokes
+             * @param {String|HTMLElement|Array|NodeList} el An id, an element 
+             *  reference, or a collection of ids and/or elements to assign the 
+             *  listener to.
+             * @param {Object}   obj    An arbitrary object that will be 
+             *                             passed as a parameter to the handler
+             * @param {Boolean|object}  args 1..n ar
+             * @return {Boolean} True if the action was successful or defered,
+             *                        false if one or more of the elements 
+             *                        could not have the listener attached,
+             *                        or if the operation throws an exception.
+             * @static
+             */
+            attach: function(type, fn, el, obj) {
+
+                // var a=Y.Array(arguments, 1, true), override=a[3], E=Y.Event, aa=Y.Array(arguments, 0, true);
+
+                var args=Y.Array(arguments, 0, true), 
+                    trimmedArgs=args.slice(1),
+                    compat, E=Y.Event, capture = false;
+
+                if (type.indexOf(CAPTURE) > -1) {
+                    type = type.substr(CAPTURE.length);
+                    capture = true;
+                }
+
+                if (trimmedArgs[trimmedArgs.length-1] === COMPAT_ARG) {
+                    compat = true;
+                    trimmedArgs.pop();
+                }
+
+                if (!fn || !fn.call) {
+// throw new TypeError(type + " attach call failed, callback undefined");
+                    return false;
+                }
+
+                // The el argument can be an array of elements or element ids.
+                if (this._isValidCollection(el)) {
+
+
+                    var handles=[], i, l;
+                    
+                    Y.each(el, function(v, k) {
+                        args[2] = v;
+                        handles.push(E.attach.apply(E, args));
+                    });
+
+                    return handles;
+
+
+                } else if (Y.Lang.isString(el)) {
+
+                    var oEl = (compat) ? Y.DOM.byId(el) : Y.all(el);
+
+                    // If the el argument is a string, we assume it is 
+                    // actually the id of the element.  If the page is loaded
+                    // we convert el to the actual element, otherwise we 
+                    // defer attaching the event until onload event fires
+
+                    // check to see if we need to delay hooking up the event 
+                    // until after the page loads.
+
+                    // Node collection
+                    // if (oEl && oEl.size && oEl.size() > 0) {
+                    //
+
+                    /*
+                    if (oEl) {
+                        el = oEl;
+                    */
+
+                    if (oEl && (oEl instanceof Y.Node)) {
+                        var size = oEl.size();
+                        if (size > 1) {
+                            // args[0] = oEl;
+                            args[2] = oEl;
+                            return E.attach.apply(E, args);
+                        } else {
+                            el = oEl.item(0);
+                            // el = oEl;
+                        }
+
+                    // HTMLElement
+                    // } else if (compat && oEl) {
+                    } else if (oEl) {
+                        el = oEl;
+
+                    // Not found = defer adding the event until the element is available
+                    } else {
+
+
+                        return this.onAvailable(el, function() {
+                            E.attach.apply(E, args);
+                        }, E, true, false, compat);
+                    }
+                }
+
+                // Element should be an html element or an array if we get here.
+                if (!el) {
+                    return false;
+                }
+
+                // the custom event key is the uid for the element + type
+
+                var ek = Y.stamp(el), key = 'event:' + ek + type,
+                    cewrapper = _wrappers[key];
+
+
+                if (!cewrapper) {
+                    // create CE wrapper
+                    cewrapper = Y.publish(key, {
+                        silent: true,
+                        // host: this,
+                        bubbles: false
+                    });
+
+                    // cache the dom event details in the custom event
+                    // for later removeListener calls
+                    cewrapper.el = el;
+                    cewrapper.type = type;
+                    cewrapper.fn = function(e) {
+                        cewrapper.fire(E.getEvent(e, el, compat));
+                    };
+
+                    if (el == Y.config.win && type == "load") {
+                        // window load happens once
+                        cewrapper.fireOnce = true;
+                        _windowLoadKey = key;
+
+                        // if the load is complete, fire immediately.
+                        // all subscribers, including the current one
+                        // will be notified.
+                        if (YUI.Env.windowLoaded) {
+                            cewrapper.fire();
+                        }
+                    }
+
+                    _wrappers[key] = cewrapper;
+                    _el_events[ek] = _el_events[ek] || {};
+                    _el_events[ek][key] = cewrapper;
+
+                    // var capture = (Y.lang.isObject(obj) && obj.capture);
+                    // attach a listener that fires the custom event
+
+                    add(el, type, cewrapper.fn, capture);
+                }
+
+                // switched from obj to trimmedArgs[2] to deal with appened compat param
+                var context = trimmedArgs[2] || ((compat) ? el : Y.get(el));
+                
+                // set the context as the second arg to subscribe
+                trimmedArgs[1] = context;
+
+                // remove the 'obj' param
+                trimmedArgs.splice(2, 1);
+
+                // set context to the Node if not specified
+                return cewrapper.subscribe.apply(cewrapper, trimmedArgs);
+
+            },
+
+            /**
+             * Removes an event listener.  Supports the signature the event was bound
+             * with, but the preferred way to remove listeners is using the handle
+             * that is returned when using Y.on
+             *
+             * @method detach
+             *
+             * @param {String|HTMLElement|Array|NodeList} el An id, an element 
+             *  reference, or a collection of ids and/or elements to remove
+             *  the listener from.
+             * @param {String} type the type of event to remove.
+             * @param {Function} fn the method the event invokes.  If fn is
+             *  undefined, then all event handlers for the type of event are *  removed.
+             * @return {boolean} true if the unbind was successful, false *  otherwise.
+             * @static
+             */
+            detach: function(type, fn, el, obj) {
+
+                var args=Y.Array(arguments, 0, true), compat;
+
+                if (args[args.length-1] === COMPAT_ARG) {
+                    compat = true;
+                    // args.pop();
+                }
+
+                if (type && type.detach) {
+                    return type.detach();
+                }
+
+                var i, len, li;
+
+                // The el argument can be a string
+                if (typeof el == "string") {
+
+                    el = (compat) ? Y.DOM.byId(el) : Y.all(el);
+
+                // The el argument can be an array of elements or element ids.
+                } else if ( this._isValidCollection(el)) {
+
+                    var ok = true;
+                    for (i=0, len=el.length; i<len; ++i) {
+
+                        args[2] = el[i];
+
+                        // ok = ( this.detach(el[i], type, fn) && ok );
+                        ok = ( Y.Event.detach.apply(Y.Event, args) && ok );
+                    }
+
+                    return ok;
+
+                }
+
+                if (!fn || !fn.call) {
+                    return this.purgeElement(el, false, type);
+                }
+
+                var id = 'event:' + Y.stamp(el) + type, 
+                    ce = _wrappers[id];
+                if (ce) {
+                    return ce.unsubscribe(fn);
+                } else {
+                    return false;
+                }
+
+            },
+
+            /**
+             * Finds the event in the window object, the caller's arguments, or
+             * in the arguments of another method in the callstack.  This is
+             * executed automatically for events registered through the event
+             * manager, so the implementer should not normally need to execute
+             * this function at all.
+             * @method getEvent
+             * @param {Event} e the event parameter from the handler
+             * @param {HTMLElement} el the element the listener was attached to
+             * @return {Event} the event 
+             * @static
+             */
+            getEvent: function(e, el, noFacade) {
+                var ev = e || window.event;
+
+                return (noFacade) ? ev : 
+                    new Y.Event.Facade(ev, el, _wrappers['event:' + Y.stamp(el) + e.type]);
+            },
+
+            /**
+             * Generates an unique ID for the element if it does not already 
+             * have one.
+             * @method generateId
+             * @param el the element to create the id for
+             * @return {string} the resulting id of the element
+             * @static
+             */
+            generateId: function(el) {
+                var id = el.id;
+
+                if (!id) {
+                    id = Y.stamp(el);
+                    el.id = id;
+                }
+
+                return id;
+            },
+
+            /**
+             * We want to be able to use getElementsByTagName as a collection
+             * to attach a group of events to.  Unfortunately, different 
+             * browsers return different types of collections.  This function
+             * tests to determine if the object is array-like.  It will also 
+             * fail if the object is an array, but is empty.
+             * @method _isValidCollection
+             * @param o the object to test
+             * @return {boolean} true if the object is array-like and populated
+             * @static
+             * @private
+             */
+            _isValidCollection: function(o) {
+                try {
+                     
+                    // if (o instanceof Y.Node) {
+                        // o.tagName ="adsf";
+                    // }
+
+                    return ( o                     && // o is something
+                             typeof o !== "string" && // o is not a string
+                             // o.length  && // o is indexed
+                             (o.length && ((!o.size) || (o.size() > 1)))  && // o is indexed
+                             !o.tagName            && // o is not an HTML element
+                             !o.alert              && // o is not a window
+                             (o.item || typeof o[0] !== "undefined") );
+                } catch(ex) {
+                    return false;
+                }
+
+            },
+
+            /**
+             * hook up any deferred listeners
+             * @method _load
+             * @static
+             * @private
+             */
+            _load: function(e) {
+
+                if (!loadComplete) {
+
+
+                    loadComplete = true;
+
+                    // Just in case DOMReady did not go off for some reason
+                    // E._ready();
+                    if (Y.fire) {
+                        Y.fire(EVENT_READY);
+                    }
+
+                    // Available elements may not have been detected before the
+                    // window load event fires. Try to find them now so that the
+                    // the user is more likely to get the onAvailable notifications
+                    // before the window load notification
+                    Y.Event._tryPreloadAttach();
+
+                }
+            },
+
+            /**
+             * Polling function that runs before the onload event fires, 
+             * attempting to attach to DOM Nodes as soon as they are 
+             * available
+             * @method _tryPreloadAttach
+             * @static
+             * @private
+             */
+            _tryPreloadAttach: function() {
+
+                if (this.locked) {
+                    return;
+                }
+
+                if (Y.UA.ie && !YUI.Env.DOMReady) {
+                    // Hold off if DOMReady has not fired and check current
+                    // readyState to protect against the IE operation aborted
+                    // issue.
+                    this.startInterval();
+                    return;
+                }
+
+                this.locked = true;
+
+
+                // keep trying until after the page is loaded.  We need to 
+                // check the page load state prior to trying to bind the 
+                // elements so that we can be certain all elements have been 
+                // tested appropriately
+                var tryAgain = !loadComplete;
+                if (!tryAgain) {
+                    tryAgain = (_retryCount > 0);
+                }
+
+                // onAvailable
+                var notAvail = [];
+
+                var executeItem = function (el, item) {
+                    var context, ov = item.override;
+
+                    if (item.compat) {
+
+                        if (item.override) {
+                            if (ov === true) {
+                                context = item.obj;
+                            } else {
+                                context = ov;
+                            }
+                        } else {
+                            context = el;
+                        }
+
+                        item.fn.call(context, item.obj);
+
+                    } else {
+                        context = item.obj || Y.get(el);
+                        item.fn.apply(context, (Y.Lang.isArray(ov)) ? ov : []);
+                    }
+
+                };
+
+                var i, len, item, el;
+
+                // onAvailable
+                for (i=0,len=_avail.length; i<len; ++i) {
+                    item = _avail[i];
+                    if (item && !item.checkReady) {
+
+                        el = (item.compat) ? Y.DOM.byId(item.id) : Y.get(item.id);
+
+                        if (el) {
+                            executeItem(el, item);
+                            _avail[i] = null;
+                        } else {
+                            notAvail.push(item);
+                        }
+                    }
+                }
+
+                // onContentReady
+                for (i=0,len=_avail.length; i<len; ++i) {
+                    item = _avail[i];
+                    if (item && item.checkReady) {
+
+                        el = (item.compat) ? Y.DOM.byId(item.id) : Y.get(item.id);
+
+                        if (el) {
+                            // The element is available, but not necessarily ready
+                            // @todo should we test parentNode.nextSibling?
+                            if (loadComplete || (el.get && el.get('nextSibling')) || el.nextSibling) {
+                                executeItem(el, item);
+                                _avail[i] = null;
+                            }
+                        } else {
+                            notAvail.push(item);
+                        }
+                    }
+                }
+
+                _retryCount = (notAvail.length === 0) ? 0 : _retryCount - 1;
+
+                if (tryAgain) {
+                    // we may need to strip the nulled out items here
+                    this.startInterval();
+                } else {
+                    clearInterval(this._interval);
+                    this._interval = null;
+                }
+
+                this.locked = false;
+
+                return;
+
+            },
+
+            /**
+             * Removes all listeners attached to the given element via addListener.
+             * Optionally, the node's children can also be purged.
+             * Optionally, you can specify a specific type of event to remove.
+             * @method purgeElement
+             * @param {HTMLElement} el the element to purge
+             * @param {boolean} recurse recursively purge this element's children
+             * as well.  Use with caution.
+             * @param {string} type optional type of listener to purge. If
+             * left out, all listeners will be removed
+             * @static
+             */
+            purgeElement: function(el, recurse, type) {
+                var oEl = (Y.Lang.isString(el)) ? Y.get(el) : el,
+                    id = Y.stamp(oEl);
+                var lis = this.getListeners(oEl, type), i, len;
+                if (lis) {
+                    for (i=0,len=lis.length; i<len ; ++i) {
+                        lis[i].unsubscribeAll();
+                    }
+                }
+
+                if (recurse && oEl && oEl.childNodes) {
+                    for (i=0,len=oEl.childNodes.length; i<len ; ++i) {
+                        this.purgeElement(oEl.childNodes[i], recurse, type);
+                    }
+                }
+            },
+
+            /**
+             * Returns all listeners attached to the given element via addListener.
+             * Optionally, you can specify a specific type of event to return.
+             * @method getListeners
+             * @param el {HTMLElement|string} the element or element id to inspect 
+             * @param type {string} optional type of listener to return. If
+             * left out, all listeners will be returned
+             * @return {Y.Custom.Event} the custom event wrapper for the DOM event(s)
+             * @static
+             */           
+            getListeners: function(el, type) {
+                var ek = Y.stamp(el), evts = _el_events[ek];
+
+                if (!evts) {
+                    return null;
+                }
+
+                var results=[] , key = (type) ? 'event:' + type : null;
+
+                if (key) {
+                    if (evts[key]) {
+                        results.push(evts[key]);
+                    }
+                } else {
+                    Y.each(evts, function(v, k) {
+                        results.push(v);
+                    });
+                }
+
+                return (results.length) ? results : null;
+            },
+
+            /**
+             * Removes all listeners registered by pe.event.  Called 
+             * automatically during the unload event.
+             * @method _unload
+             * @static
+             * @private
+             */
+            _unload: function(e) {
+
+                var E = Y.Event;
+
+                Y.each(_wrappers, function(v, k) {
+                    v.unsubscribeAll();
+                    remove(v.el, v.type, v.fn);
+                    delete _wrappers[k];
+                });
+
+                remove(window, "load", E._load);
+                remove(window, "unload", E._unload);
+            },
+
+            
+            /**
+             * Adds a DOM event directly without the caching, cleanup, context adj, etc
+             *
+             * @method nativeAdd
+             * @param {HTMLElement} el      the element to bind the handler to
+             * @param {string}      type   the type of event handler
+             * @param {function}    fn      the callback to invoke
+             * @param {boolen}      capture capture or bubble phase
+             * @static
+             * @private
+             */
+            nativeAdd: add,
+
+            /**
+             * Basic remove listener
+             *
+             * @method nativeRemove
+             * @param {HTMLElement} el      the element to bind the handler to
+             * @param {string}      type   the type of event handler
+             * @param {function}    fn      the callback to invoke
+             * @param {boolen}      capture capture or bubble phase
+             * @static
+             * @private
+             */
+            nativeRemove: remove
+        };
+
+    }();
+
+    var E = Y.Event;
+
+    // Process onAvailable/onContentReady items when when the DOM is ready in IE
+    if (Y.UA.ie && Y.on) {
+        Y.on(EVENT_READY, E._tryPreloadAttach, E, true);
+    }
+
+    E.Custom = Y.CustomEvent;
+    E.Subscriber = Y.Subscriber;
+    E.Target = Y.EventTarget;
+
+    add(window, "load", E._load);
+    add(window, "unload", E._unload);
+
+    E._tryPreloadAttach();
+
+}, "3.0.0");
+
+})();
+/*
+ * A wrapper for DOM events and Custom Events
+ * @submodule event-facade
+ * @module event
+ *
+ * @TODO constants? LEFTBUTTON, MIDDLEBUTTON, RIGHTBUTTON, keys
+ */
+YUI.add("event-facade", function(Y) {
+
+
+    var whitelist = {
+        "altKey"          : 1,
+        // "button"          : 1, // we supply
+        // "bubbles"         : 1, // needed?
+        // "cancelable"      : 1, // needed? 
+        // "charCode"        : 1, // we supply
+        "cancelBubble"    : 1,
+        // "currentTarget"   : 1, // we supply
+        "ctrlKey"         : 1,
+        "clientX"         : 1, // needed?
+        "clientY"         : 1, // needed?
+        "detail"          : 1, // not fully implemented
+        // "fromElement"     : 1,
+        "keyCode"         : 1,
+        // "height"          : 1, // needed?
+        // "initEvent"       : 1, // need the init events?
+        // "initMouseEvent"  : 1,
+        // "initUIEvent"     : 1,
+        // "layerX"          : 1, // needed?
+        // "layerY"          : 1, // needed?
+        "metaKey"         : 1,
+        // "modifiers"       : 1, // needed?
+        // "offsetX"         : 1, // needed?
+        // "offsetY"         : 1, // needed?
+        // "preventDefault"  : 1, // we supply
+        // "reason"          : 1, // IE proprietary
+        // "relatedTarget"   : 1,
+        // "returnValue"     : 1, // needed?
+        "shiftKey"        : 1,
+        // "srcUrn"          : 1, // IE proprietary
+        // "srcElement"      : 1,
+        // "srcFilter"       : 1, IE proprietary
+        // "stopPropagation" : 1, // we supply
+        // "target"          : 1,
+        // "timeStamp"       : 1, // needed?
+        // "toElement"       : 1,
+        "type"            : 1,
+        // "view"            : 1,
+        // "which"           : 1, // we supply
+        // "width"           : 1, // needed?
+        "x"               : 1,
+        "y"               : 1
+    };
+
+    var ua = Y.UA,
+
+        /**
+         * webkit key remapping required for Safari < 3.1
+         * @property webkitKeymap
+         * @private
+         */
+        webkitKeymap = {
+            63232: 38, // up
+            63233: 40, // down
+            63234: 37, // left
+            63235: 39, // right
+            63276: 33, // page up
+            63277: 34, // page down
+            25: 9      // SHIFT-TAB (Safari provides a different key code in
+                       // this case, even though the shiftKey modifier is set)
+        },
+
+        /**
+         * Returns a wrapped node.  Intended to be used on event targets,
+         * so it will return the node's parent if the target is a text
+         * node
+         * @method resolve
+         * @private
+         */
+        resolve = function(n) {
+
+            if (!n) {
+                return null;
+            }
+
+            try {
+                if (ua.webkit && 3 == n.nodeType) {
+                    n = n.parentNode;
+                } 
+            } catch(ex) { }
+
+            return Y.Node.get(n);
+        };
+
+
+    // provide a single event with browser abstractions resolved
+    //
+    // include all properties for both browers?
+    // include only DOM2 spec properties?
+    // provide browser-specific facade?
+
+    /**
+     * Wraps a DOM event, properties requiring browser abstraction are
+     * fixed here.  Provids a security layer when required.
+     * @class Event.Facade
+     * @param ev {Event} the DOM event
+     * @param currentTarget {HTMLElement} the element the listener was attached to
+     * @param wrapper {Event.Custom} the custom event wrapper for this DOM event
+     */
+    Y.Event.Facade = function(ev, currentTarget, wrapper, details) {
+
+        // @TODO the document should be the target's owner document
+
+        var e = ev, ot = currentTarget, d = Y.config.doc, b = d.body,
+            x = e.pageX, y = e.pageY, isCE = (ev._YUI_EVENT);
+
+        // copy all primitives ... this is slow in FF
+        // for (var i in e) {
+        for (var i in whitelist) {
+            // if (!Y.Lang.isObject(e[i])) {
+            if (whitelist.hasOwnProperty(i)) {
+                this[i] = e[i];
+            }
+        }
+
+        //////////////////////////////////////////////////////
+
+        if (!x && 0 !== x) {
+            x = e.clientX || 0;
+            y = e.clientY || 0;
+
+            if (ua.ie) {
+                x += Math.max(d.documentElement.scrollLeft, b.scrollLeft);
+                y += Math.max(d.documentElement.scrollTop, b.scrollTop);
+            }
+        }
+
+        this._yuifacade = true;
+
+        /**
+         * The X location of the event on the page (including scroll)
+         * @property pageX
+         * @type int
+         */
+        this.pageX = x;
+
+        /**
+         * The Y location of the event on the page (including scroll)
+         * @property pageY
+         * @type int
+         */
+        this.pageY = y;
+
+        //////////////////////////////////////////////////////
+
+        /**
+         * The keyCode for key events.  Uses charCode if keyCode is not available
+         * @property keyCode
+         * @type int
+         */
+        var c = e.keyCode || e.charCode || 0;
+
+        if (ua.webkit && (c in webkitKeymap)) {
+            c = webkitKeymap[c];
+        }
+
+        /**
+         * The keyCode for key events.  Uses charCode if keyCode is not available
+         * @property keyCode
+         * @type int
+         */
+        this.keyCode = c;
+
+        /**
+         * The charCode for key events.  Same as keyCode
+         * @property charCode
+         * @type int
+         */
+        this.charCode = c;
+
+        //////////////////////////////////////////////////////
+
+        /**
+         * The button that was pushed.
+         * @property button
+         * @type int
+         */
+        this.button = e.which || e.button;
+
+        /**
+         * The button that was pushed.  Same as button.
+         * @property which
+         * @type int
+         */
+        this.which = this.button;
+
+        /**
+         * The event details.  Currently supported for Custom
+         * Events only, where it contains the arguments that
+         * were passed to fire().
+         * @property details
+         * @type Array
+         */
+        this.details = details;
+
+        //////////////////////////////////////////////////////
+
+        /**
+         * Timestamp for the event
+         * @property time
+         * @type Date
+         */
+        this.time = e.time || new Date().getTime();
+
+        //////////////////////////////////////////////////////
+        
+        /**
+         * Node reference for the targeted element
+         * @propery target
+         * @type Node
+         */
+        this.target = (isCE) ? e.target : resolve(e.target || e.srcElement);
+
+        /**
+         * Node reference for the element that the listener was attached to.
+         * @propery currentTarget
+         * @type Node
+         */
+        this.currentTarget = (isCE) ? ot :  resolve(ot);
+
+        var t = e.relatedTarget;
+        if (!t) {
+            if (e.type == "mouseout") {
+                t = e.toElement;
+            } else if (e.type == "mouseover") {
+                t = e.fromElement;
+            }
+        }
+
+        /**
+         * Node reference to the relatedTarget
+         * @propery relatedTarget
+         * @type Node
+         */
+        this.relatedTarget = (isCE) ? t : resolve(t);
+        
+        //////////////////////////////////////////////////////
+        // methods
+
+        /**
+         * Stops the propagation to the next bubble target
+         * @method stopPropagation
+         */
+        this.stopPropagation = function() {
+            if (e.stopPropagation) {
+                e.stopPropagation();
+            } else {
+                e.cancelBubble = true;
+            }
+            if (wrapper) {
+                wrapper.stopPropagation();
+            }
+        };
+
+        /**
+         * Stops the propagation to the next bubble target and
+         * prevents any additional listeners from being exectued
+         * on the current target.
+         * @method stopImmediatePropagation
+         */
+        this.stopImmediatePropagation = function() {
+
+            if (e.stopImmediatePropagation) {
+                e.stopImmediatePropagation();
+            } else {
+                this.stopPropagation();
+            }
+
+            if (wrapper) {
+                wrapper.stopImmediatePropagation();
+            }
+
+        };
+
+        /**
+         * Prevents the event's default behavior
+         * @method preventDefault
+         */
+        this.preventDefault = function() {
+            if (e.preventDefault) {
+                e.preventDefault();
+            } else {
+                e.returnValue = false;
+            }
+            if (wrapper) {
+                wrapper.preventDefault();
+            }
+        };
+
+        /**
+         * Stops the event propagation and prevents the default
+         * event behavior.
+         * @method halt
+         * @param immediate {boolean} if true additional listeners
+         * on the current target will not be executed
+         */
+        this.halt = function(immediate) {
+            if (immediate) {
+                this.stopImmediatePropagation();
+            } else {
+                this.stopPropagation();
+            }
+            this.preventDefault();
+        };
+
+    };
+
+}, "3.0.0");
+/*
+ * Functionality to simulate events.
+ * @submodule event-simulate
+ * @module event
+ */
+YUI.add("event-simulate", function(Y) {
+
+    //shortcuts
+    var L   = Y.Lang,
+        array       = Y.Array,
+        isFunction  = L.isFunction,
+        isString    = L.isString,
+        isBoolean   = L.isBoolean,
+        isObject    = L.isObject,
+        isNumber    = L.isNumber,
+        
+        //mouse events supported
+        mouseEvents = [
+        
+            /**
+             * Simulates a click on a particular element.
+             * @param {HTMLElement} target The element to click on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method click
+             * @static   
+             * @for Event
+             */        
+            "click", 
+            
+            /**
+             * Simulates a double click on a particular element.
+             * @param {HTMLElement} target The element to double click on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method dblclick
+             * @static
+             */            
+            "dblclick", 
+            
+            /**
+             * Simulates a mouseover event on a particular element. Use "relatedTarget"
+             * on the options object to specify where the mouse moved from.
+             * Quirks: Firefox less than 2.0 doesn't set relatedTarget properly, so
+             * fromElement is assigned in its place. IE doesn't allow fromElement to be
+             * be assigned, so relatedTarget is assigned in its place. Both of these
+             * concessions allow YAHOO.util.Event.getRelatedTarget() to work correctly
+             * in both browsers.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method mouseover
+             * @static
+             */             
+            "mouseover", 
+            
+            /**
+             * Simulates a mouseout event on a particular element. Use "relatedTarget"
+             * on the options object to specify where the mouse moved to.
+             * Quirks: Firefox less than 2.0 doesn't set relatedTarget properly, so
+             * toElement is assigned in its place. IE doesn't allow toElement to be
+             * be assigned, so relatedTarget is assigned in its place. Both of these
+             * concessions allow YAHOO.util.Event.getRelatedTarget() to work correctly
+             * in both browsers.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method mouseout
+             * @static
+             */            
+            "mouseout", 
+            
+            /**
+             * Simulates a mousedown on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method mousedown
+             * @static
+             */            
+            "mousedown", 
+            
+            /**
+             * Simulates a mouseup on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method mouseup
+             * @static
+             */            
+            "mouseup", 
+            
+            /**
+             * Simulates a mousemove on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method mousemove
+             * @static
+             */           
+            "mousemove"
+        ],
+        
+        //key events supported
+        keyEvents   = [
+        
+            /**
+             * Simulates a keydown event on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method keydown
+             * @static
+             */        
+            "keydown", 
+            
+            /**
+             * Simulates a keyup event on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method keyup
+             * @static
+             */            
+            "keyup", 
+            
+            /**
+             * Simulates a keypress on a particular element.
+             * @param {HTMLElement} target The element to act on.
+             * @param {Object} options Additional event options (use DOM standard names).
+             * @method keypress
+             * @static
+             */            
+            "keypress"
+        ];
+
+    /**
+     * Note: Intentionally not for YUIDoc generation.
+     * Simulates a key event using the given event information to populate
+     * the generated event object. This method does browser-equalizing
+     * calculations to account for differences in the DOM and IE event models
+     * as well as different browser quirks. Note: keydown causes Safari 2.x to
+     * crash.
+     * @method simulateKeyEvent
+     * @private
+     * @static
+     * @param {HTMLElement} target The target of the given event.
+     * @param {String} type The type of event to fire. This can be any one of
+     *      the following: keyup, keydown, and keypress.
+     * @param {Boolean} bubbles (Optional) Indicates if the event can be
+     *      bubbled up. DOM Level 3 specifies that all key events bubble by
+     *      default. The default is true.
+     * @param {Boolean} cancelable (Optional) Indicates if the event can be
+     *      canceled using preventDefault(). DOM Level 3 specifies that all
+     *      key events can be cancelled. The default 
+     *      is true.
+     * @param {Window} view (Optional) The view containing the target. This is
+     *      typically the window object. The default is window.
+     * @param {Boolean} ctrlKey (Optional) Indicates if one of the CTRL keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} altKey (Optional) Indicates if one of the ALT keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} shiftKey (Optional) Indicates if one of the SHIFT keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} metaKey (Optional) Indicates if one of the META keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {int} keyCode (Optional) The code for the key that is in use. 
+     *      The default is 0.
+     * @param {int} charCode (Optional) The Unicode code for the character
+     *      associated with the key being used. The default is 0.
+     */
+    function simulateKeyEvent(target /*:HTMLElement*/, type /*:String*/, 
+                                 bubbles /*:Boolean*/,  cancelable /*:Boolean*/,    
+                                 view /*:Window*/,
+                                 ctrlKey /*:Boolean*/,    altKey /*:Boolean*/, 
+                                 shiftKey /*:Boolean*/,   metaKey /*:Boolean*/, 
+                                 keyCode /*:int*/,        charCode /*:int*/) /*:Void*/                             
+    {
+        //check target    
+        if (!target){
+            Y.fail("simulateKeyEvent(): Invalid target.");
+        }
+        
+        //check event type
+        if (isString(type)){
+            type = type.toLowerCase();
+            switch(type){
+                case "textevent": //DOM Level 3
+                    type = "keypress";
+                    /*falls through*/
+                case "keyup":
+                case "keydown":
+                case "keypress":
+                    break;
+                default:
+                    Y.fail("simulateKeyEvent(): Event type '" + type + "' not supported.");
+            }
+        } else {
+            Y.fail("simulateKeyEvent(): Event type must be a string.");
+        }
+        
+        //setup default values
+        if (!isBoolean(bubbles)){
+            bubbles = true; //all key events bubble
+        }
+        if (!isBoolean(cancelable)){
+            cancelable = true; //all key events can be cancelled
+        }
+        if (!isObject(view)){
+            view = window; //view is typically window
+        }
+        if (!isBoolean(ctrlKey)){
+            ctrlKey = false;
+        }
+        if (!isBoolean(altKey)){
+            altKey = false;
+        }
+        if (!isBoolean(shiftKey)){
+            shiftKey = false;
+        }
+        if (!isBoolean(metaKey)){
+            metaKey = false;
+        }
+        if (!isNumber(keyCode)){
+            keyCode = 0;
+        }
+        if (!isNumber(charCode)){
+            charCode = 0; 
+        }
+
+        //try to create a mouse event
+        var customEvent /*:MouseEvent*/ = null;
+            
+        //check for DOM-compliant browsers first
+        if (isFunction(document.createEvent)){
+        
+            try {
+                
+                //try to create key event
+                customEvent = document.createEvent("KeyEvents");
+                
+                /*
+                 * Interesting problem: Firefox implemented a non-standard
+                 * version of initKeyEvent() based on DOM Level 2 specs.
+                 * Key event was removed from DOM Level 2 and re-introduced
+                 * in DOM Level 3 with a different interface. Firefox is the
+                 * only browser with any implementation of Key Events, so for
+                 * now, assume it's Firefox if the above line doesn't error.
+                 */
+                //TODO: Decipher between Firefox's implementation and a correct one.
+                customEvent.initKeyEvent(type, bubbles, cancelable, view, ctrlKey,
+                    altKey, shiftKey, metaKey, keyCode, charCode);       
+                
+            } catch (ex /*:Error*/){
+
+                /*
+                 * If it got here, that means key events aren't officially supported. 
+                 * Safari/WebKit is a real problem now. WebKit 522 won't let you
+                 * set keyCode, charCode, or other properties if you use a
+                 * UIEvent, so we first must try to create a generic event. The
+                 * fun part is that this will throw an error on Safari 2.x. The
+                 * end result is that we need another try...catch statement just to
+                 * deal with this mess.
+                 */
+                try {
+
+                    //try to create generic event - will fail in Safari 2.x
+                    customEvent = document.createEvent("Events");
+
+                } catch (uierror /*:Error*/){
+
+                    //the above failed, so create a UIEvent for Safari 2.x
+                    customEvent = document.createEvent("UIEvents");
+
+                } finally {
+
+                    customEvent.initEvent(type, bubbles, cancelable);
+    
+                    //initialize
+                    customEvent.view = view;
+                    customEvent.altKey = altKey;
+                    customEvent.ctrlKey = ctrlKey;
+                    customEvent.shiftKey = shiftKey;
+                    customEvent.metaKey = metaKey;
+                    customEvent.keyCode = keyCode;
+                    customEvent.charCode = charCode;
+          
+                }          
+             
+            }
+            
+            //fire the event
+            target.dispatchEvent(customEvent);
+
+        } else if (isObject(document.createEventObject)){ //IE
+        
+            //create an IE event object
+            customEvent = document.createEventObject();
+            
+            //assign available properties
+            customEvent.bubbles = bubbles;
+            customEvent.cancelable = cancelable;
+            customEvent.view = view;
+            customEvent.ctrlKey = ctrlKey;
+            customEvent.altKey = altKey;
+            customEvent.shiftKey = shiftKey;
+            customEvent.metaKey = metaKey;
+            
+            /*
+             * IE doesn't support charCode explicitly. CharCode should
+             * take precedence over any keyCode value for accurate
+             * representation.
+             */
+            customEvent.keyCode = (charCode > 0) ? charCode : keyCode;
+            
+            //fire the event
+            target.fireEvent("on" + type, customEvent);  
+                    
+        } else {
+            Y.fail("simulateKeyEvent(): No event simulation framework present.");
+        }
+    }
+
+    /*
+     * Note: Intentionally not for YUIDoc generation.
+     * Simulates a mouse event using the given event information to populate
+     * the generated event object. This method does browser-equalizing
+     * calculations to account for differences in the DOM and IE event models
+     * as well as different browser quirks.
+     * @method simulateMouseEvent
+     * @private
+     * @static
+     * @param {HTMLElement} target The target of the given event.
+     * @param {String} type The type of event to fire. This can be any one of
+     *      the following: click, dblclick, mousedown, mouseup, mouseout,
+     *      mouseover, and mousemove.
+     * @param {Boolean} bubbles (Optional) Indicates if the event can be
+     *      bubbled up. DOM Level 2 specifies that all mouse events bubble by
+     *      default. The default is true.
+     * @param {Boolean} cancelable (Optional) Indicates if the event can be
+     *      canceled using preventDefault(). DOM Level 2 specifies that all
+     *      mouse events except mousemove can be cancelled. The default 
+     *      is true for all events except mousemove, for which the default 
+     *      is false.
+     * @param {Window} view (Optional) The view containing the target. This is
+     *      typically the window object. The default is window.
+     * @param {int} detail (Optional) The number of times the mouse button has
+     *      been used. The default value is 1.
+     * @param {int} screenX (Optional) The x-coordinate on the screen at which
+     *      point the event occured. The default is 0.
+     * @param {int} screenY (Optional) The y-coordinate on the screen at which
+     *      point the event occured. The default is 0.
+     * @param {int} clientX (Optional) The x-coordinate on the client at which
+     *      point the event occured. The default is 0.
+     * @param {int} clientY (Optional) The y-coordinate on the client at which
+     *      point the event occured. The default is 0.
+     * @param {Boolean} ctrlKey (Optional) Indicates if one of the CTRL keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} altKey (Optional) Indicates if one of the ALT keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} shiftKey (Optional) Indicates if one of the SHIFT keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {Boolean} metaKey (Optional) Indicates if one of the META keys
+     *      is pressed while the event is firing. The default is false.
+     * @param {int} button (Optional) The button being pressed while the event
+     *      is executing. The value should be 0 for the primary mouse button
+     *      (typically the left button), 1 for the terciary mouse button
+     *      (typically the middle button), and 2 for the secondary mouse button
+     *      (typically the right button). The default is 0.
+     * @param {HTMLElement} relatedTarget (Optional) For mouseout events,
+     *      this is the element that the mouse has moved to. For mouseover
+     *      events, this is the element that the mouse has moved from. This
+     *      argument is ignored for all other events. The default is null.
+     */
+    function simulateMouseEvent(target /*:HTMLElement*/, type /*:String*/, 
+                                   bubbles /*:Boolean*/,  cancelable /*:Boolean*/,    
+                                   view /*:Window*/,        detail /*:int*/, 
+                                   screenX /*:int*/,        screenY /*:int*/, 
+                                   clientX /*:int*/,        clientY /*:int*/,       
+                                   ctrlKey /*:Boolean*/,    altKey /*:Boolean*/, 
+                                   shiftKey /*:Boolean*/,   metaKey /*:Boolean*/, 
+                                   button /*:int*/,         relatedTarget /*:HTMLElement*/) /*:Void*/
+    {
+        
+        //check target   
+        if (!target){
+            Y.fail("simulateMouseEvent(): Invalid target.");
+        }
+        
+        //check event type
+        if (isString(type)){
+            type = type.toLowerCase();
+            
+            //make sure it's a supported mouse event
+            if (array.indexOf(mouseEvents, type) == -1){
+                Y.fail("simulateMouseEvent(): Event type '" + type + "' not supported.");
+            }
+        } else {
+            Y.fail("simulateMouseEvent(): Event type must be a string.");
+        }
+        
+        //setup default values
+        if (!isBoolean(bubbles)){
+            bubbles = true; //all mouse events bubble
+        }
+        if (!isBoolean(cancelable)){
+            cancelable = (type != "mousemove"); //mousemove is the only one that can't be cancelled
+        }
+        if (!isObject(view)){
+            view = window; //view is typically window
+        }
+        if (!isNumber(detail)){
+            detail = 1;  //number of mouse clicks must be at least one
+        }
+        if (!isNumber(screenX)){
+            screenX = 0; 
+        }
+        if (!isNumber(screenY)){
+            screenY = 0; 
+        }
+        if (!isNumber(clientX)){
+            clientX = 0; 
+        }
+        if (!isNumber(clientY)){
+            clientY = 0; 
+        }
+        if (!isBoolean(ctrlKey)){
+            ctrlKey = false;
+        }
+        if (!isBoolean(altKey)){
+            altKey = false;
+        }
+        if (!isBoolean(shiftKey)){
+            shiftKey = false;
+        }
+        if (!isBoolean(metaKey)){
+            metaKey = false;
+        }
+        if (!isNumber(button)){
+            button = 0; 
+        }
+
+        //try to create a mouse event
+        var customEvent /*:MouseEvent*/ = null;
+            
+        //check for DOM-compliant browsers first
+        if (isFunction(document.createEvent)){
+        
+            customEvent = document.createEvent("MouseEvents");
+        
+            //Safari 2.x (WebKit 418) still doesn't implement initMouseEvent()
+            if (customEvent.initMouseEvent){
+                customEvent.initMouseEvent(type, bubbles, cancelable, view, detail,
+                                     screenX, screenY, clientX, clientY, 
+                                     ctrlKey, altKey, shiftKey, metaKey, 
+                                     button, relatedTarget);
+            } else { //Safari
+            
+                //the closest thing available in Safari 2.x is UIEvents
+                customEvent = document.createEvent("UIEvents");
+                customEvent.initEvent(type, bubbles, cancelable);
+                customEvent.view = view;
+                customEvent.detail = detail;
+                customEvent.screenX = screenX;
+                customEvent.screenY = screenY;
+                customEvent.clientX = clientX;
+                customEvent.clientY = clientY;
+                customEvent.ctrlKey = ctrlKey;
+                customEvent.altKey = altKey;
+                customEvent.metaKey = metaKey;
+                customEvent.shiftKey = shiftKey;
+                customEvent.button = button;
+                customEvent.relatedTarget = relatedTarget;
+            }
+            
+            /*
+             * Check to see if relatedTarget has been assigned. Firefox
+             * versions less than 2.0 don't allow it to be assigned via
+             * initMouseEvent() and the property is readonly after event
+             * creation, so in order to keep YAHOO.util.getRelatedTarget()
+             * working, assign to the IE proprietary toElement property
+             * for mouseout event and fromElement property for mouseover
+             * event.
+             */
+            if (relatedTarget && !customEvent.relatedTarget){
+                if (type == "mouseout"){
+                    customEvent.toElement = relatedTarget;
+                } else if (type == "mouseover"){
+                    customEvent.fromElement = relatedTarget;
+                }
+            }
+            
+            //fire the event
+            target.dispatchEvent(customEvent);
+
+        } else if (isObject(document.createEventObject)){ //IE
+        
+            //create an IE event object
+            customEvent = document.createEventObject();
+            
+            //assign available properties
+            customEvent.bubbles = bubbles;
+            customEvent.cancelable = cancelable;
+            customEvent.view = view;
+            customEvent.detail = detail;
+            customEvent.screenX = screenX;
+            customEvent.screenY = screenY;
+            customEvent.clientX = clientX;
+            customEvent.clientY = clientY;
+            customEvent.ctrlKey = ctrlKey;
+            customEvent.altKey = altKey;
+            customEvent.metaKey = metaKey;
+            customEvent.shiftKey = shiftKey;
+
+            //fix button property for IE's wacky implementation
+            switch(button){
+                case 0:
+                    customEvent.button = 1;
+                    break;
+                case 1:
+                    customEvent.button = 4;
+                    break;
+                case 2:
+                    //leave as is
+                    break;
+                default:
+                    customEvent.button = 0;                    
+            }    
+
+            /*
+             * Have to use relatedTarget because IE won't allow assignment
+             * to toElement or fromElement on generic events. This keeps
+             * YAHOO.util.customEvent.getRelatedTarget() functional.
+             */
+            customEvent.relatedTarget = relatedTarget;
+            
+            //fire the event
+            target.fireEvent("on" + type, customEvent);
+                    
+        } else {
+            Y.fail("simulateMouseEvent(): No event simulation framework present.");
+        }
+    }
+    
+    //add mouse event methods
+    array.each(mouseEvents, function(type){
+        Y.Event[type] = function(target, options){
+            options = options || {};
+            simulateMouseEvent(target, type, options.bubbles,
+                options.cancelable, options.view, options.detail, options.screenX,        
+                options.screenY, options.clientX, options.clientY, options.ctrlKey,
+                options.altKey, options.shiftKey, options.metaKey, options.button,         
+                options.relatedTarget);        
+        };
+    });
+
+    //add key event methods
+    array.each(keyEvents, function(type){
+        Y.Event[type] = function(target, options){
+            options = options || {};
+            simulateKeyEvent(target, type, options.bubbles,
+                options.cancelable, options.view, options.ctrlKey,
+                options.altKey, options.shiftKey, options.metaKey, 
+                options.keyCode, options.charCode);       
+        };
+    });
+    
+    /**
+     * Simulates the event with the given name on a target.
+     * @param {HTMLElement} target The DOM element that's the target of the event.
+     * @param {String} type The type of event to simulate (i.e., "click").
+     * @param {Object} options (Optional) Extra options to copy onto the event object.
+     * @return {void}
+     * @method simulate
+     * @static
+     */
+    Y.Event.simulate = function(target, type, options){
+        if (isFunction(Y.Event[type])){
+            Y.Event[type](target, options);
+        }
+    };
+    
+    /*
+     * TODO: focus(), blur(), submit()
+     */
+
+}, "3.0.0pr2", { requires: ["lang","event-dom"] });

=== added directory 'loggerhead/static/javascript/yui/build/get'
=== added file 'loggerhead/static/javascript/yui/build/get/README'
--- loggerhead/static/javascript/yui/build/get/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/get/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+The Get Utility
+    Fetches and inserts script and link nodes
+
+3.0.0pr2
+    - Protects against trailing commas in array of files to load.
+
+3.0.0pr1
+    - Initial release

=== added file 'loggerhead/static/javascript/yui/build/get/get-debug.js'
--- loggerhead/static/javascript/yui/build/get/get-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/get/get-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,673 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+
+YUI.add("get", function(Y) {
+    
+        var ua=Y.UA, 
+        L=Y.Lang;
+
+/**
+ * Provides a mechanism to fetch remote resources and
+ * insert them into a document.
+ * @module yui
+ * @submodule get
+ */
+
+/**
+ * Fetches and inserts one or more script or link nodes into the document 
+ * @class Get
+ * @static
+ */
+Y.Get = function() {
+
+    /**
+     * hash of queues to manage multiple requests
+     * @property queues
+     * @private
+     */
+    var queues={}, 
+        
+    /**
+     * queue index used to generate transaction ids
+     * @property qidx
+     * @type int
+     * @private
+     */
+        qidx=0, 
+        
+    /**
+     * node index used to generate unique node ids
+     * @property nidx
+     * @type int
+     * @private
+     */
+        nidx=0, 
+
+        // ridx=0,
+
+        // sandboxFrame=null,
+
+    /**
+     * interal property used to prevent multiple simultaneous purge 
+     * processes
+     * @property purging
+     * @type boolean
+     * @private
+     */
+        purging=false;
+
+    
+    /** 
+     * Generates an HTML element, this is not appended to a document
+     * @method _node
+     * @param type {string} the type of element
+     * @param attr {string} the attributes
+     * @param win {Window} optional window to create the element in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _node = function(type, attr, win) {
+        var w = win || Y.config.win, d=w.document, n=d.createElement(type);
+
+        for (var i in attr) {
+            if (attr[i] && Y.Object.owns(attr, i)) {
+                n.setAttribute(i, attr[i]);
+            }
+        }
+
+        return n;
+    };
+
+    /**
+     * Generates a link node
+     * @method _linkNode
+     * @param url {string} the url for the css file
+     * @param win {Window} optional window to create the node in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _linkNode = function(url, win, charset) {
+        var c = charset || "utf-8";
+        return _node("link", {
+                "id":      "yui__dyn_" + (nidx++),
+                "type":    "text/css",
+                "charset": c,
+                "rel":     "stylesheet",
+                "href":    url
+            }, win);
+    };
+
+    /**
+     * Generates a script node
+     * @method _scriptNode
+     * @param url {string} the url for the script file
+     * @param win {Window} optional window to create the node in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _scriptNode = function(url, win, charset) {
+        var c = charset || "utf-8";
+        return _node("script", {
+                "id":      "yui__dyn_" + (nidx++),
+                "type":    "text/javascript",
+                "charset": c,
+                "src":     url
+            }, win);
+    };
+
+    /**
+     * Removes the nodes for the specified queue
+     * @method _purge
+     * @private
+     */
+    var _purge = function(tId) {
+        var q=queues[tId];
+        if (q) {
+            var n=q.nodes, l=n.length, d=q.win.document, 
+                h=d.getElementsByTagName("head")[0];
+
+            if (q.insertBefore) {
+                var s = _get(q.insertBefore, tId);
+                if (s) {
+                    h = s.parentNode;
+                }
+            }
+
+            for (var i=0; i<l; i=i+1) {
+                h.removeChild(n[i]);
+            }
+        }
+        q.nodes = [];
+    };
+
+    /**
+     * Returns the data payload for callback functions
+     * @method _returnData
+     * @private
+     */
+    var _returnData = function(q, msg) {
+        return {
+                tId: q.tId,
+                win: q.win,
+                data: q.data,
+                nodes: q.nodes,
+                msg: msg,
+                purge: function() {
+                    _purge(this.tId);
+                }
+            };
+    };
+
+    /*
+     * The request failed, execute fail handler with whatever
+     * was accomplished.  There isn't a failure case at the
+     * moment unless you count aborted transactions
+     * @method _fail
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _fail = function(id, msg) {
+
+        Y.log("get failure: " + msg, "warn", "get");
+
+        var q = queues[id];
+        if (q.timer) {
+            q.timer.cancel();
+        }
+
+        // execute failure callback
+        if (q.onFailure) {
+            var sc=q.context || q;
+            q.onFailure.call(sc, _returnData(q, msg));
+        }
+    };
+
+    var _get = function(nId, tId) {
+        var q = queues[tId],
+            n = (L.isString(nId)) ? q.win.document.getElementById(nId) : nId;
+        if (!n) {
+            _fail(tId, "target node not found: " + nId);
+        }
+
+        return n;
+    };
+
+
+    /**
+     * The request is complete, so executing the requester's callback
+     * @method _finish
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _finish = function(id) {
+        Y.log("Finishing transaction " + id, "info", "get");
+        var q = queues[id];
+        if (q.timer) {
+            q.timer.cancel();
+        }
+        q.finished = true;
+
+        if (q.aborted) {
+            var msg = "transaction " + id + " was aborted";
+            _fail(id, msg);
+            return;
+        }
+
+        // execute success callback
+        if (q.onSuccess) {
+            var sc=q.context || q;
+            q.onSuccess.call(sc, _returnData(q));
+        }
+    };
+
+    /**
+     * Timeout detected
+     * @method _timeout
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _timeout = function(id) {
+        Y.log("Timeout " + id, "info", "get");
+        var q = queues[id];
+        if (q.onTimeout) {
+            var sc=q.context || q;
+            q.onTimeout.call(sc, _returnData(q));
+        }
+    };
+
+    /**
+     * Loads the next item for a given request
+     * @method _next
+     * @param id {string} the id of the request
+     * @param loaded {string} the url that was just loaded, if any
+     * @private
+     */
+    var _next = function(id, loaded) {
+        Y.log("_next: " + id + ", loaded: " + loaded, "info", "get");
+
+        var q = queues[id];
+
+        if (q.timer) {
+            // Y.log('cancel timer');
+            q.timer.cancel();
+        }
+
+        if (q.aborted) {
+            var msg = "transaction " + id + " was aborted";
+            _fail(id, msg);
+            return;
+        }
+
+        if (loaded) {
+            q.url.shift(); 
+            if (q.varName) {
+                q.varName.shift(); 
+            }
+        } else {
+            // This is the first pass: make sure the url is an array
+            q.url = (L.isString(q.url)) ? [q.url] : q.url;
+            if (q.varName) {
+                q.varName = (L.isString(q.varName)) ? [q.varName] : q.varName;
+            }
+        }
+
+        var w=q.win, d=w.document, h=d.getElementsByTagName("head")[0], n;
+
+        if (q.url.length === 0) {
+            _finish(id);
+            return;
+        } 
+
+        var url = q.url[0];
+
+        // if the url is undefined, this is probably a trailing comma problem in IE
+        if (!url) {
+            q.url.shift(); 
+            Y.log('skipping empty url');
+            return _next(id);
+        }
+
+        Y.log("attempting to load " + url, "info", "get");
+
+        if (q.timeout) {
+            // Y.log('create timer');
+            q.timer = L.later(q.timeout, q, _timeout, id);
+        }
+
+        if (q.type === "script") {
+            n = _scriptNode(url, w, q.charset);
+        } else {
+            n = _linkNode(url, w, q.charset);
+        }
+
+        // track this node's load progress
+        _track(q.type, n, id, url, w, q.url.length);
+
+        // add the node to the queue so we can return it to the user supplied callback
+        q.nodes.push(n);
+
+        // add it to the head or insert it before 'insertBefore'
+        if (q.insertBefore) {
+            var s = _get(q.insertBefore, id);
+            if (s) {
+                s.parentNode.insertBefore(n, s);
+            }
+        } else {
+            h.appendChild(n);
+        }
+        
+        Y.log("Appending node: " + url, "info", "get");
+
+        // FireFox does not support the onload event for link nodes, so there is
+        // no way to make the css requests synchronous. This means that the css 
+        // rules in multiple files could be applied out of order in this browser
+        // if a later request returns before an earlier one.  Safari too.
+        if ((ua.webkit || ua.gecko) && q.type === "css") {
+            _next(id, url);
+        }
+    };
+
+    /**
+     * Removes processed queues and corresponding nodes
+     * @method _autoPurge
+     * @private
+     */
+    var _autoPurge = function() {
+
+        if (purging) {
+            return;
+        }
+
+        purging = true;
+        for (var i in queues) {
+            if (queues.hasOwnProperty(i)) {
+                var q = queues[i];
+                if (q.autopurge && q.finished) {
+                    _purge(q.tId);
+                    delete queues[i];
+                }
+            }
+        }
+
+        purging = false;
+    };
+
+    /**
+     * Saves the state for the request and begins loading
+     * the requested urls
+     * @method queue
+     * @param type {string} the type of node to insert
+     * @param url {string} the url to load
+     * @param opts the hash of options for this request
+     * @private
+     */
+    var _queue = function(type, url, opts) {
+
+        var id = "q" + (qidx++);
+        opts = opts || {};
+
+        if (qidx % Y.Get.PURGE_THRESH === 0) {
+            _autoPurge();
+        }
+
+        queues[id] = Y.merge(opts, {
+            tId: id,
+            type: type,
+            url: url,
+            finished: false,
+            nodes: []
+        });
+
+        var q = queues[id];
+        q.win = q.win || Y.config.win;
+        q.context = q.context || q;
+        q.autopurge = ("autopurge" in q) ? q.autopurge : 
+                      (type === "script") ? true : false;
+
+        L.later(0, q, _next, id);
+
+        return {
+            tId: id
+        };
+    };
+
+    /**
+     * Detects when a node has been loaded.  In the case of
+     * script nodes, this does not guarantee that contained
+     * script is ready to use.
+     * @method _track
+     * @param type {string} the type of node to track
+     * @param n {HTMLElement} the node to track
+     * @param id {string} the id of the request
+     * @param url {string} the url that is being loaded
+     * @param win {Window} the targeted window
+     * @param qlength the number of remaining items in the queue,
+     * including this one
+     * @param trackfn {Function} function to execute when finished
+     * the default is _next
+     * @private
+     */
+    var _track = function(type, n, id, url, win, qlength, trackfn) {
+        var f = trackfn || _next;
+
+        // IE supports the readystatechange event for script and css nodes
+        // Opera only for script nodes.  Opera support onload for script
+        // nodes, but this doesn't fire when there is a load failure.
+        // The onreadystatechange appears to be a better way to respond
+        // to both success and failure.
+        if (ua.ie) {
+            n.onreadystatechange = function() {
+                var rs = this.readyState;
+                if ("loaded" === rs || "complete" === rs) {
+                    Y.log(id + " onreadstatechange " + url, "info", "get");
+                    n.onreadystatechange = null;
+                    f(id, url);
+                }
+            };
+
+        // webkit prior to 3.x is no longer supported
+        } else if (ua.webkit) {
+
+            if (type === "script") {
+                // Safari 3.x supports the load event for script nodes (DOM2)
+                n.addEventListener("load", function() {
+                    Y.log(id + " DOM2 onload " + url, "info", "get");
+                    f(id, url);
+                });
+            } 
+
+        // FireFox and Opera support onload (but not DOM2 in FF) handlers for
+        // script nodes.  Opera, but not FF, supports the onload event for link
+        // nodes.
+        } else { 
+
+            n.onload = function() {
+                Y.log(id + " onload " + url, "info", "get");
+                f(id, url);
+            };
+
+            n.onerror = function(e) {
+                _fail(id, e + ": " + url);
+            };
+        }
+    };
+
+    return {
+
+        /**
+         * The number of request required before an automatic purge.
+         * property PURGE_THRESH
+         * @static
+         * @type int
+         * @default 20
+         */
+        PURGE_THRESH: 20,
+
+        /**
+         * Called by the the helper for detecting script load in Safari
+         * @method _finalize
+         * @static
+         * @param id {string} the transaction id
+         * @private
+         */
+        _finalize: function(id) {
+            Y.log(id + " finalized ", "info", "get");
+            L.later(0, null, _finish, id);
+        },
+
+        /**
+         * Abort a transaction
+         * @method abort
+         * @static
+         * @param o {string|object} Either the tId or the object returned from
+         * script() or css()
+         */
+        abort: function(o) {
+            var id = (L.isString(o)) ? o : o.tId;
+            var q = queues[id];
+            if (q) {
+                Y.log("Aborting " + id, "info", "get");
+                q.aborted = true;
+            }
+        }, 
+
+        /**
+         * Fetches and inserts one or more script nodes into the head
+         * of the current document or the document in a specified window.
+         *
+         * @method script
+         * @static
+         * @param url {string|string[]} the url or urls to the script(s)
+         * @param opts {object} Options: 
+         * <dl>
+         * <dt>onSuccess</dt>
+         * <dd>
+         * callback to execute when the script(s) are finished loading
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>onTimeout</dt>
+         * <dd>
+         * callback to execute when a timeout occurs.
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>onFailure</dt>
+         * <dd>
+         * callback to execute when the script load operation fails
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted successfully</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove any nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>context</dt>
+         * <dd>the execution context for the callbacks</dd>
+         * <dt>win</dt>
+         * <dd>a window other than the one the utility occupies</dd>
+         * <dt>autopurge</dt>
+         * <dd>
+         * setting to true will let the utilities cleanup routine purge 
+         * the script once loaded
+         * </dd>
+         * <dt>data</dt>
+         * <dd>
+         * data that is supplied to the callback when the script(s) are
+         * loaded.
+         * </dd>
+         * <dt>insertBefore</dt>
+         * <dd>node or node id that will become the new node's nextSibling</dd>
+         * </dl>
+         * <dt>charset</dt>
+         * <dd>Node charset, default utf-8</dd>
+         * <dt>timeout</dt>
+         * <dd>Number of milliseconds to wait before aborting and firing the timeout event</dd>
+         * <pre>
+         * &nbsp;&nbsp;Y.Get.script(
+         * &nbsp;&nbsp;["http://yui.yahooapis.com/2.5.2/build/yahoo/yahoo-min.js",
+         * &nbsp;&nbsp;&nbsp;"http://yui.yahooapis.com/2.5.2/build/event/event-min.js"], &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;onSuccess: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;this.log("won't cause error because Y is the context");
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Y.log(o.data); // foo
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Y.log(o.nodes.length === 2) // true
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;// o.purge(); // optionally remove the script nodes immediately
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;onFailure: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Y.log("transaction failed");
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;onTimeout: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Y.log("transaction timed out");
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;data: "foo",
+         * &nbsp;&nbsp;&nbsp;&nbsp;timeout: 10000, // 10 second timeout
+         * &nbsp;&nbsp;&nbsp;&nbsp;context: Y, // make the YUI instance
+         * &nbsp;&nbsp;&nbsp;&nbsp;// win: otherframe // target another window/frame
+         * &nbsp;&nbsp;&nbsp;&nbsp;autopurge: true // allow the utility to choose when to remove the nodes
+         * &nbsp;&nbsp;&#125;);
+         * </pre>
+         * @return {tId: string} an object containing info about the transaction
+         */
+        script: function(url, opts) { 
+            return _queue("script", url, opts); 
+        },
+
+        /**
+         * Fetches and inserts one or more css link nodes into the 
+         * head of the current document or the document in a specified
+         * window.
+         * @method css
+         * @static
+         * @param url {string} the url or urls to the css file(s)
+         * @param opts Options: 
+         * <dl>
+         * <dt>onSuccess</dt>
+         * <dd>
+         * callback to execute when the css file(s) are finished loading
+         * The callback receives an object back with the following
+         * data:
+         * <dl>win</dl>
+         * <dd>the window the link nodes(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>context</dt>
+         * <dd>the execution context for the callbacks</dd>
+         * <dt>win</dt>
+         * <dd>a window other than the one the utility occupies</dd>
+         * <dt>data</dt>
+         * <dd>
+         * data that is supplied to the callbacks when the nodes(s) are
+         * loaded.
+         * </dd>
+         * <dt>insertBefore</dt>
+         * <dd>node or node id that will become the new node's nextSibling</dd>
+         * <dt>charset</dt>
+         * <dd>Node charset, default utf-8</dd>
+         * </dl>
+         * <pre>
+         *      Y.Get.css("http://yui.yahooapis.com/2.3.1/build/menu/assets/skins/sam/menu.css");
+         * </pre>
+         * <pre>
+         * &nbsp;&nbsp;Y.Get.css(
+         * &nbsp;&nbsp;["http://yui.yahooapis.com/2.3.1/build/menu/assets/skins/sam/menu.css",
+         * &nbsp;&nbsp;&nbsp;"http://yui.yahooapis.com/2.3.1/build/logger/assets/skins/sam/logger.css"], &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;insertBefore: 'custom-styles' // nodes will be inserted before the specified node
+         * &nbsp;&nbsp;&#125;);
+         * </pre>
+         * @return {tId: string} an object containing info about the transaction
+         */
+        css: function(url, opts) {
+            return _queue("css", url, opts); 
+        }
+    };
+}();
+
+}, "3.0.0pr2");

=== added file 'loggerhead/static/javascript/yui/build/get/get-min.js'
--- loggerhead/static/javascript/yui/build/get/get-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/get/get-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("get",function(C){var B=C.UA,A=C.Lang;C.Get=function(){var K={},I=0,D=0,R=false;var T=function(X,U,Y){var V=Y||C.config.win,Z=V.document,a=Z.createElement(X);for(var W in U){if(U[W]&&C.Object.owns(U,W)){a.setAttribute(W,U[W]);}}return a;};var Q=function(U,V,X){var W=X||"utf-8";return T("link",{"id":"yui__dyn_"+(D++),"type":"text/css","charset":W,"rel":"stylesheet","href":U},V);};var P=function(U,V,X){var W=X||"utf-8";return T("script",{"id":"yui__dyn_"+(D++),"type":"text/javascript","charset":W,"src":U},V);};var L=function(b){var Y=K[b];if(Y){var a=Y.nodes,U=a.length,Z=Y.win.document,X=Z.getElementsByTagName("head")[0];if(Y.insertBefore){var W=J(Y.insertBefore,b);if(W){X=W.parentNode;}}for(var V=0;V<U;V=V+1){X.removeChild(a[V]);}}Y.nodes=[];};var M=function(U,V){return{tId:U.tId,win:U.win,data:U.data,nodes:U.nodes,msg:V,purge:function(){L(this.tId);}};};var S=function(X,W){var U=K[X];if(U.timer){U.timer.cancel();}if(U.onFailure){var V=U.context||U;U.onFailure.call(V,M(U,W));}};var J=function(U,X){var V=K[X],W=(A.isString(U))?V.win.document.getElementById(U):U;if(!W){S(X,"target node not found: "+U);}return W;};var G=function(X){var U=K[X];if(U.timer){U.timer.cancel();}U.finished=true;if(U.aborted){var W="transaction "+X+" was aborted";S(X,W);return;}if(U.onSuccess){var V=U.context||U;U.onSuccess.call(V,M(U));}};var N=function(W){var U=K[W];if(U.onTimeout){var V=U.context||U;U.onTimeout.call(V,M(U));}};var F=function(W,Z){var V=K[W];if(V.timer){V.timer.cancel();}if(V.aborted){var Y="transaction "+W+" was aborted";S(W,Y);return;}if(Z){V.url.shift();if(V.varName){V.varName.shift();}}else{V.url=(A.isString(V.url))?[V.url]:V.url;if(V.varName){V.varName=(A.isString(V.varName))?[V.varName]:V.varName;}}var c=V.win,b=c.document,a=b.getElementsByTagName("head")[0],X;if(V.url.length===0){G(W);return;}var U=V.url[0];if(!U){V.url.shift();return F(W);}if(V.timeout){V.timer=A.later(V.timeout,V,N,W);}if(V.type==="script"){X=P(U,c,V.charset);}else{X=Q(U,c,V.charset);}H(V.type,X,W,U,c,V.url.length);V.nodes.push(X);if(V.insertBefore){var e=J(V.insertBefore,W);if(e){e.parentNode.insertBefore(X,e);}}else{a.appendChild(X);}if((B.webkit||B.gecko)&&V.type==="css"){F(W,U);}};var E=function(){if(R){return;}R=true;for(var U in K){if(K.hasOwnProperty(U)){var V=K[U];if(V.autopurge&&V.finished){L(V.tId);delete K[U];}}}R=false;};var O=function(V,U,W){var Y="q"+(I++);W=W||{};if(I%C.Get.PURGE_THRESH===0){E();}K[Y]=C.merge(W,{tId:Y,type:V,url:U,finished:false,nodes:[]});var X=K[Y];X.win=X.win||C.config.win;X.context=X.context||X;X.autopurge=("autopurge" in X)?X.autopurge:(V==="script")?true:false;A.later(0,X,F,Y);return{tId:Y};};var H=function(W,b,a,V,Z,Y,U){var X=U||F;if(B.ie){b.onreadystatechange=function(){var c=this.readyState;if("loaded"===c||"complete"===c){b.onreadystatechange=null;X(a,V);}};}else{if(B.webkit){if(W==="script"){b.addEventListener("load",function(){X(a,V);});}}else{b.onload=function(){X(a,V);};b.onerror=function(c){S(a,c+": "+V);};}}};return{PURGE_THRESH:20,_finalize:function(U){A.later(0,null,G,U);},abort:function(V){var W=(A.isString(V))?V:V.tId;var U=K[W];if(U){U.aborted=true;}},script:function(U,V){return O("script",U,V);},css:function(U,V){return O("css",U,V);}};}();},"3.0.0pr2");
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/get/get.js'
--- loggerhead/static/javascript/yui/build/get/get.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/get/get.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,653 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+
+YUI.add("get", function(Y) {
+    
+        var ua=Y.UA, 
+        L=Y.Lang;
+
+/**
+ * Provides a mechanism to fetch remote resources and
+ * insert them into a document.
+ * @module yui
+ * @submodule get
+ */
+
+/**
+ * Fetches and inserts one or more script or link nodes into the document 
+ * @class Get
+ * @static
+ */
+Y.Get = function() {
+
+    /**
+     * hash of queues to manage multiple requests
+     * @property queues
+     * @private
+     */
+    var queues={}, 
+        
+    /**
+     * queue index used to generate transaction ids
+     * @property qidx
+     * @type int
+     * @private
+     */
+        qidx=0, 
+        
+    /**
+     * node index used to generate unique node ids
+     * @property nidx
+     * @type int
+     * @private
+     */
+        nidx=0, 
+
+        // ridx=0,
+
+        // sandboxFrame=null,
+
+    /**
+     * interal property used to prevent multiple simultaneous purge 
+     * processes
+     * @property purging
+     * @type boolean
+     * @private
+     */
+        purging=false;
+
+    
+    /** 
+     * Generates an HTML element, this is not appended to a document
+     * @method _node
+     * @param type {string} the type of element
+     * @param attr {string} the attributes
+     * @param win {Window} optional window to create the element in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _node = function(type, attr, win) {
+        var w = win || Y.config.win, d=w.document, n=d.createElement(type);
+
+        for (var i in attr) {
+            if (attr[i] && Y.Object.owns(attr, i)) {
+                n.setAttribute(i, attr[i]);
+            }
+        }
+
+        return n;
+    };
+
+    /**
+     * Generates a link node
+     * @method _linkNode
+     * @param url {string} the url for the css file
+     * @param win {Window} optional window to create the node in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _linkNode = function(url, win, charset) {
+        var c = charset || "utf-8";
+        return _node("link", {
+                "id":      "yui__dyn_" + (nidx++),
+                "type":    "text/css",
+                "charset": c,
+                "rel":     "stylesheet",
+                "href":    url
+            }, win);
+    };
+
+    /**
+     * Generates a script node
+     * @method _scriptNode
+     * @param url {string} the url for the script file
+     * @param win {Window} optional window to create the node in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _scriptNode = function(url, win, charset) {
+        var c = charset || "utf-8";
+        return _node("script", {
+                "id":      "yui__dyn_" + (nidx++),
+                "type":    "text/javascript",
+                "charset": c,
+                "src":     url
+            }, win);
+    };
+
+    /**
+     * Removes the nodes for the specified queue
+     * @method _purge
+     * @private
+     */
+    var _purge = function(tId) {
+        var q=queues[tId];
+        if (q) {
+            var n=q.nodes, l=n.length, d=q.win.document, 
+                h=d.getElementsByTagName("head")[0];
+
+            if (q.insertBefore) {
+                var s = _get(q.insertBefore, tId);
+                if (s) {
+                    h = s.parentNode;
+                }
+            }
+
+            for (var i=0; i<l; i=i+1) {
+                h.removeChild(n[i]);
+            }
+        }
+        q.nodes = [];
+    };
+
+    /**
+     * Returns the data payload for callback functions
+     * @method _returnData
+     * @private
+     */
+    var _returnData = function(q, msg) {
+        return {
+                tId: q.tId,
+                win: q.win,
+                data: q.data,
+                nodes: q.nodes,
+                msg: msg,
+                purge: function() {
+                    _purge(this.tId);
+                }
+            };
+    };
+
+    /*
+     * The request failed, execute fail handler with whatever
+     * was accomplished.  There isn't a failure case at the
+     * moment unless you count aborted transactions
+     * @method _fail
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _fail = function(id, msg) {
+
+
+        var q = queues[id];
+        if (q.timer) {
+            q.timer.cancel();
+        }
+
+        // execute failure callback
+        if (q.onFailure) {
+            var sc=q.context || q;
+            q.onFailure.call(sc, _returnData(q, msg));
+        }
+    };
+
+    var _get = function(nId, tId) {
+        var q = queues[tId],
+            n = (L.isString(nId)) ? q.win.document.getElementById(nId) : nId;
+        if (!n) {
+            _fail(tId, "target node not found: " + nId);
+        }
+
+        return n;
+    };
+
+
+    /**
+     * The request is complete, so executing the requester's callback
+     * @method _finish
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _finish = function(id) {
+        var q = queues[id];
+        if (q.timer) {
+            q.timer.cancel();
+        }
+        q.finished = true;
+
+        if (q.aborted) {
+            var msg = "transaction " + id + " was aborted";
+            _fail(id, msg);
+            return;
+        }
+
+        // execute success callback
+        if (q.onSuccess) {
+            var sc=q.context || q;
+            q.onSuccess.call(sc, _returnData(q));
+        }
+    };
+
+    /**
+     * Timeout detected
+     * @method _timeout
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _timeout = function(id) {
+        var q = queues[id];
+        if (q.onTimeout) {
+            var sc=q.context || q;
+            q.onTimeout.call(sc, _returnData(q));
+        }
+    };
+
+    /**
+     * Loads the next item for a given request
+     * @method _next
+     * @param id {string} the id of the request
+     * @param loaded {string} the url that was just loaded, if any
+     * @private
+     */
+    var _next = function(id, loaded) {
+
+        var q = queues[id];
+
+        if (q.timer) {
+            q.timer.cancel();
+        }
+
+        if (q.aborted) {
+            var msg = "transaction " + id + " was aborted";
+            _fail(id, msg);
+            return;
+        }
+
+        if (loaded) {
+            q.url.shift(); 
+            if (q.varName) {
+                q.varName.shift(); 
+            }
+        } else {
+            // This is the first pass: make sure the url is an array
+            q.url = (L.isString(q.url)) ? [q.url] : q.url;
+            if (q.varName) {
+                q.varName = (L.isString(q.varName)) ? [q.varName] : q.varName;
+            }
+        }
+
+        var w=q.win, d=w.document, h=d.getElementsByTagName("head")[0], n;
+
+        if (q.url.length === 0) {
+            _finish(id);
+            return;
+        } 
+
+        var url = q.url[0];
+
+        // if the url is undefined, this is probably a trailing comma problem in IE
+        if (!url) {
+            q.url.shift(); 
+            return _next(id);
+        }
+
+
+        if (q.timeout) {
+            q.timer = L.later(q.timeout, q, _timeout, id);
+        }
+
+        if (q.type === "script") {
+            n = _scriptNode(url, w, q.charset);
+        } else {
+            n = _linkNode(url, w, q.charset);
+        }
+
+        // track this node's load progress
+        _track(q.type, n, id, url, w, q.url.length);
+
+        // add the node to the queue so we can return it to the user supplied callback
+        q.nodes.push(n);
+
+        // add it to the head or insert it before 'insertBefore'
+        if (q.insertBefore) {
+            var s = _get(q.insertBefore, id);
+            if (s) {
+                s.parentNode.insertBefore(n, s);
+            }
+        } else {
+            h.appendChild(n);
+        }
+        
+
+        // FireFox does not support the onload event for link nodes, so there is
+        // no way to make the css requests synchronous. This means that the css 
+        // rules in multiple files could be applied out of order in this browser
+        // if a later request returns before an earlier one.  Safari too.
+        if ((ua.webkit || ua.gecko) && q.type === "css") {
+            _next(id, url);
+        }
+    };
+
+    /**
+     * Removes processed queues and corresponding nodes
+     * @method _autoPurge
+     * @private
+     */
+    var _autoPurge = function() {
+
+        if (purging) {
+            return;
+        }
+
+        purging = true;
+        for (var i in queues) {
+            if (queues.hasOwnProperty(i)) {
+                var q = queues[i];
+                if (q.autopurge && q.finished) {
+                    _purge(q.tId);
+                    delete queues[i];
+                }
+            }
+        }
+
+        purging = false;
+    };
+
+    /**
+     * Saves the state for the request and begins loading
+     * the requested urls
+     * @method queue
+     * @param type {string} the type of node to insert
+     * @param url {string} the url to load
+     * @param opts the hash of options for this request
+     * @private
+     */
+    var _queue = function(type, url, opts) {
+
+        var id = "q" + (qidx++);
+        opts = opts || {};
+
+        if (qidx % Y.Get.PURGE_THRESH === 0) {
+            _autoPurge();
+        }
+
+        queues[id] = Y.merge(opts, {
+            tId: id,
+            type: type,
+            url: url,
+            finished: false,
+            nodes: []
+        });
+
+        var q = queues[id];
+        q.win = q.win || Y.config.win;
+        q.context = q.context || q;
+        q.autopurge = ("autopurge" in q) ? q.autopurge : 
+                      (type === "script") ? true : false;
+
+        L.later(0, q, _next, id);
+
+        return {
+            tId: id
+        };
+    };
+
+    /**
+     * Detects when a node has been loaded.  In the case of
+     * script nodes, this does not guarantee that contained
+     * script is ready to use.
+     * @method _track
+     * @param type {string} the type of node to track
+     * @param n {HTMLElement} the node to track
+     * @param id {string} the id of the request
+     * @param url {string} the url that is being loaded
+     * @param win {Window} the targeted window
+     * @param qlength the number of remaining items in the queue,
+     * including this one
+     * @param trackfn {Function} function to execute when finished
+     * the default is _next
+     * @private
+     */
+    var _track = function(type, n, id, url, win, qlength, trackfn) {
+        var f = trackfn || _next;
+
+        // IE supports the readystatechange event for script and css nodes
+        // Opera only for script nodes.  Opera support onload for script
+        // nodes, but this doesn't fire when there is a load failure.
+        // The onreadystatechange appears to be a better way to respond
+        // to both success and failure.
+        if (ua.ie) {
+            n.onreadystatechange = function() {
+                var rs = this.readyState;
+                if ("loaded" === rs || "complete" === rs) {
+                    n.onreadystatechange = null;
+                    f(id, url);
+                }
+            };
+
+        // webkit prior to 3.x is no longer supported
+        } else if (ua.webkit) {
+
+            if (type === "script") {
+                // Safari 3.x supports the load event for script nodes (DOM2)
+                n.addEventListener("load", function() {
+                    f(id, url);
+                });
+            } 
+
+        // FireFox and Opera support onload (but not DOM2 in FF) handlers for
+        // script nodes.  Opera, but not FF, supports the onload event for link
+        // nodes.
+        } else { 
+
+            n.onload = function() {
+                f(id, url);
+            };
+
+            n.onerror = function(e) {
+                _fail(id, e + ": " + url);
+            };
+        }
+    };
+
+    return {
+
+        /**
+         * The number of request required before an automatic purge.
+         * property PURGE_THRESH
+         * @static
+         * @type int
+         * @default 20
+         */
+        PURGE_THRESH: 20,
+
+        /**
+         * Called by the the helper for detecting script load in Safari
+         * @method _finalize
+         * @static
+         * @param id {string} the transaction id
+         * @private
+         */
+        _finalize: function(id) {
+            L.later(0, null, _finish, id);
+        },
+
+        /**
+         * Abort a transaction
+         * @method abort
+         * @static
+         * @param o {string|object} Either the tId or the object returned from
+         * script() or css()
+         */
+        abort: function(o) {
+            var id = (L.isString(o)) ? o : o.tId;
+            var q = queues[id];
+            if (q) {
+                q.aborted = true;
+            }
+        }, 
+
+        /**
+         * Fetches and inserts one or more script nodes into the head
+         * of the current document or the document in a specified window.
+         *
+         * @method script
+         * @static
+         * @param url {string|string[]} the url or urls to the script(s)
+         * @param opts {object} Options: 
+         * <dl>
+         * <dt>onSuccess</dt>
+         * <dd>
+         * callback to execute when the script(s) are finished loading
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>onTimeout</dt>
+         * <dd>
+         * callback to execute when a timeout occurs.
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>onFailure</dt>
+         * <dd>
+         * callback to execute when the script load operation fails
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted successfully</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove any nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>context</dt>
+         * <dd>the execution context for the callbacks</dd>
+         * <dt>win</dt>
+         * <dd>a window other than the one the utility occupies</dd>
+         * <dt>autopurge</dt>
+         * <dd>
+         * setting to true will let the utilities cleanup routine purge 
+         * the script once loaded
+         * </dd>
+         * <dt>data</dt>
+         * <dd>
+         * data that is supplied to the callback when the script(s) are
+         * loaded.
+         * </dd>
+         * <dt>insertBefore</dt>
+         * <dd>node or node id that will become the new node's nextSibling</dd>
+         * </dl>
+         * <dt>charset</dt>
+         * <dd>Node charset, default utf-8</dd>
+         * <dt>timeout</dt>
+         * <dd>Number of milliseconds to wait before aborting and firing the timeout event</dd>
+         * <pre>
+         * &nbsp;&nbsp;Y.Get.script(
+         * &nbsp;&nbsp;["http://yui.yahooapis.com/2.5.2/build/yahoo/yahoo-min.js",
+         * &nbsp;&nbsp;&nbsp;"http://yui.yahooapis.com/2.5.2/build/event/event-min.js"], &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;onSuccess: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;onFailure: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;onTimeout: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;data: "foo",
+         * &nbsp;&nbsp;&nbsp;&nbsp;timeout: 10000, // 10 second timeout
+         * &nbsp;&nbsp;&nbsp;&nbsp;context: Y, // make the YUI instance
+         * &nbsp;&nbsp;&nbsp;&nbsp;// win: otherframe // target another window/frame
+         * &nbsp;&nbsp;&nbsp;&nbsp;autopurge: true // allow the utility to choose when to remove the nodes
+         * &nbsp;&nbsp;&#125;);
+         * </pre>
+         * @return {tId: string} an object containing info about the transaction
+         */
+        script: function(url, opts) { 
+            return _queue("script", url, opts); 
+        },
+
+        /**
+         * Fetches and inserts one or more css link nodes into the 
+         * head of the current document or the document in a specified
+         * window.
+         * @method css
+         * @static
+         * @param url {string} the url or urls to the css file(s)
+         * @param opts Options: 
+         * <dl>
+         * <dt>onSuccess</dt>
+         * <dd>
+         * callback to execute when the css file(s) are finished loading
+         * The callback receives an object back with the following
+         * data:
+         * <dl>win</dl>
+         * <dd>the window the link nodes(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>context</dt>
+         * <dd>the execution context for the callbacks</dd>
+         * <dt>win</dt>
+         * <dd>a window other than the one the utility occupies</dd>
+         * <dt>data</dt>
+         * <dd>
+         * data that is supplied to the callbacks when the nodes(s) are
+         * loaded.
+         * </dd>
+         * <dt>insertBefore</dt>
+         * <dd>node or node id that will become the new node's nextSibling</dd>
+         * <dt>charset</dt>
+         * <dd>Node charset, default utf-8</dd>
+         * </dl>
+         * <pre>
+         *      Y.Get.css("http://yui.yahooapis.com/2.3.1/build/menu/assets/skins/sam/menu.css");
+         * </pre>
+         * <pre>
+         * &nbsp;&nbsp;Y.Get.css(
+         * &nbsp;&nbsp;["http://yui.yahooapis.com/2.3.1/build/menu/assets/skins/sam/menu.css",
+         * &nbsp;&nbsp;&nbsp;"http://yui.yahooapis.com/2.3.1/build/logger/assets/skins/sam/logger.css"], &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;insertBefore: 'custom-styles' // nodes will be inserted before the specified node
+         * &nbsp;&nbsp;&#125;);
+         * </pre>
+         * @return {tId: string} an object containing info about the transaction
+         */
+        css: function(url, opts) {
+            return _queue("css", url, opts); 
+        }
+    };
+}();
+
+}, "3.0.0pr2");

=== added directory 'loggerhead/static/javascript/yui/build/io'
=== added file 'loggerhead/static/javascript/yui/build/io/README'
--- loggerhead/static/javascript/yui/build/io/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,27 @@
+*** version 3.0.0 PR2 ***
+
+* IO is now comprised of several modules, allowing users to specify and
+implement only the needed modules.  These modules are:
+
+- io-base.js: This is the IO base class, using XMLHttpRequest as the transport.
+- io-xdr.js: This sub-module extends IO to enable cross-domain transactions
+using Flash as the transport.
+- io-form.js: This sub-module extends IO to enable the serialization of an HTML
+form as transaction data.
+- io-upload-iframe.js: This sub-module extends IO, to allow file uploads with an
+HTML form, using an iframe transport.
+- io-queue.js: This sub-module extends IO to add transaction queuing
+capabilities.
+
+* [FIXED] SF2262707.  If defined in the configuration object, user-specified,
+HTTP "Content-Type" headers will correctly override POST default headers, for
+HTTP POST transactions.
+
+* XML is not supported as a response datatype when using sub-modules io-xdr.js
+and io-upload-iframe.js.
+
+*** version 3.0.0 PR1 ***
+
+* Initial Release
+
+

=== added file 'loggerhead/static/javascript/yui/build/io/io-base-debug.js'
--- loggerhead/static/javascript/yui/build/io/io-base-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-base-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,752 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-base', function(Y) {
+
+   /**
+	* HTTP communications module.
+	* @module io
+	*/
+
+   /**
+    * The io class is a utility that brokers HTTP requests through a simplified
+    * interface.  Specifically, it allows JavaScript to make HTTP requests to
+    * a resource without a page reload.  The underlying transport for making
+    * same-domain requests is the XMLHttpRequest object.  YUI.io can also use
+    * Flash, if specified as a transport, for cross-domain requests.
+    *
+	* @class io
+	*/
+
+   /**
+	* @event io:start
+	* @description This event is fired by YUI.io when a transaction is initiated..
+	* @type Event Custom
+	*/
+	var E_START = 'io:start',
+
+   /**
+	* @event io:complete
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* all response data are available.
+	* @type Event Custom
+	*/
+	E_COMPLETE = 'io:complete',
+
+   /**
+	* @event io:success
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* the HTTP status resolves to HTTP2xx.
+	* @type Event Custom
+	*/
+	E_SUCCESS = 'io:success',
+
+   /**
+	* @event io:failure
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* the HTTP status resolves to HTTP4xx, 5xx and above.
+	* @type Event Custom
+	*/
+	E_FAILURE = 'io:failure',
+
+   /**
+	* @event io:abort
+	* @description This event is fired by YUI.io when a transaction is aborted
+	* explicitly or by a defined config.timeout.
+	* @type Event Custom
+	*/
+	E_ABORT = 'io:abort',
+
+	//--------------------------------------
+	//  Properties
+	//--------------------------------------
+   /**
+	* @description A transaction counter that increments for each transaction.
+	*
+	* @property transactionId
+	* @private
+	* @static
+	* @type int
+	*/
+	transactionId = 0,
+
+   /**
+	* @description Object of default HTTP headers to be initialized and sent
+	* for all transactions.
+	*
+	* @property _headers
+	* @private
+	* @static
+	* @type object
+	*/
+	_headers = {
+		'X-Requested-With' : 'XMLHttpRequest'
+	},
+
+   /**
+	* @description Object that stores timeout values for any transaction with
+	* a defined "timeout" configuration property.
+	*
+	* @property _timeOut
+	* @private
+	* @static
+	* @type object
+	*/
+	_timeout = {};
+
+	//--------------------------------------
+	//  Methods
+	//--------------------------------------
+
+	// Window reference
+	w = Y.config.win;
+
+   /**
+	* @description Method for requesting a transaction. _io() is implemented as
+	* yui.io().  Each transaction may include a configuration object.  Its
+	* properties are:
+	*
+	* method: HTTP method verb (e.g., GET or POST). If this property is not
+	*         not defined, the default value will be GET.
+	*
+	* data: This is the name-value string that will be sent as the transaction
+    *		data.  If the request is HTTP GET, the data become part of
+    *		querystring. If HTTP POST, the data are sent in the message body.
+	*
+	* xdr: Defines the transport to be used for cross-domain requests.  By
+	*      setting this property, the transaction will use the specified
+	*      transport instead of XMLHttpRequest.  Currently, the only alternate
+	*      transport supported is Flash (e.g., { xdr: 'flash' }).
+	*
+	* form: This is a defined object used to process HTML form as data.  The
+	*       properties are:
+	*       {
+	*	      id: object, //HTML form object or id of HTML form
+	*         useDisabled: boolean, //Allow disabled HTML form field values
+	*                      to be sent as part of the data.
+    *       }
+    *
+    * on: This is a defined object used to create and handle specific
+    *     events during a transaction lifecycle.  These events will fire in
+    *     addition to the global io events. The events are:
+    *	  start - This event is fired when a request is sent to a resource.
+    *     complete - This event fires when the transaction is complete.
+    *     success - This event fires when the response status resolves to
+    *               HTTP 2xx.
+    *     failure - This event fires when the response status resolves to
+    *               HTTP 4xx, 5xx, and beyond.
+    *	  abort - This even is fired when a transaction abort is fire by
+    *             timeout, or when it is manually aborted.
+    *
+    *     The properties are:
+    *     {
+	*       start: function(id, args){},
+	*       complete: function(id, responseobject, args){},
+	*       success: function(id, responseobject, args){},
+	*       failure: function(id, responseobject, args){},
+	*       abort: function(id, args){}
+	*     }
+	*	  Each property can reference a function or be written as an
+	*     inline function.
+	*
+	* context: Object reference for an event handler when it is implemented
+	*          as a method of a base object. Defining "context" will preserve
+	*          the proper reference of "this" used in the event handler.
+	* headers: This is a defined object of client headers, as many as.
+	*         desired for the transaction.  These headers are sentThe object
+	*         pattern is:
+	*		  {
+	*		    header: value
+	*         }
+	*
+	* timeout: This value, defined as milliseconds, is a time threshold for the
+	*          transaction. When this threshold is reached, and the transaction's
+	*          Complete event has not yet fired, the transaction will be aborted.
+	* arguments: Object, array, string, or number passed to all registered
+	*            event handlers.  This value is available as the second
+	*            argument in the "start" and "abort" event handlers; and, it is
+	*            the third argument in the "complete", "success", and "failure"
+	*            event handlers.
+	*
+	* @method _io
+	* @private
+	* @static
+    * @param {string} uri - qualified path to transaction resource.
+    * @param {object} c - configuration object for the transaction.
+    * @return object
+	*/
+	function _io(uri, c) {
+		var c = c || {},
+		o = _create((arguments.length === 3) ? arguments[2] : null, c),
+		m = (c.method) ? c.method.toUpperCase() : 'GET',
+		d = (c.data) ? c.data : null,
+		f;
+
+		/* Determine configuration properties */
+		// If config.form is defined, perform data operations.
+		if (c.form) {
+
+			if (c.form.upload) {
+				u = Y.io._upload(o, uri, c);
+				return u;
+			}
+
+			// Serialize the HTML form into a string of name-value pairs.
+			f = Y.io._serialize(c.form);
+			// If config.data is defined, concatenate the data to the form string.
+			if (d) {
+				f += "&" + d;
+				Y.log('Configuration object.data added to serialized HTML form data. The string is: ' + f, 'info', 'io');
+			}
+
+			if (m === 'POST') {
+				d = f;
+				_setHeader('Content-Type', 'application/x-www-form-urlencoded');
+			}
+			else if (m === 'GET') {
+				uri = _concat(uri, f);
+				Y.log('Configuration object.data added to serialized HTML form data. The querystring is: ' + uri, 'info', 'io');
+			}
+		}
+		else if (d && m === 'GET') {
+			uri = _concat(uri, c.data);
+			Y.log('Configuration object data added to URI. The querystring is: ' + uri, 'info', 'io');
+		}
+		else if (d && m === 'POST') {
+			_setHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
+		}
+
+		if (c.xdr) {
+			Y.io._xdr(uri, o, c);
+			return o;
+		}
+
+		// If config.timeout is defined, and the request is standard XHR,
+		// initialize timeout polling.
+		if (c.timeout) {
+			_startTimeout(o, c);
+		}
+		/* End Configuration Properties */
+
+		o.c.onreadystatechange = function() { _readyState(o, c); };
+		try {
+			_open(o.c, m, uri);
+		}
+		catch (e) {
+		}
+		_setHeaders(o.c, (c.headers || {}));
+
+		o.abort = function () {
+			_ioAbort(o, c);
+		}
+
+		o.isInProgress = function() {
+			return o.c.readyState !== 4 && o.c.readyState !== 0;
+		}
+		// Do not pass null, in the absence of data, as this
+		// will result in a POST request with no Content-Length
+		// defined.
+		_async(o, (d || ''), c);
+
+		return o;
+	};
+
+   /**
+	* @description Method for creating and subscribing transaction events.
+	*
+	* @method _tPubSub
+	* @private
+	* @static
+	* @param {string} e - event to be published
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _tPubSub(e, c){
+			var event = new Y.Event.Target().publish('transaction:' + e);
+			event.subscribe(c.on[e], (c.context || this), c.arguments);
+
+			return event;
+	};
+
+   /**
+	* @description Fires event "io:start" and creates, fires a
+	* transaction-specific start event, if config.on.start is
+	* defined.
+	*
+	* @method _ioStart
+	* @private
+	* @static
+	* @param {number} id - transaction id
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioStart(id, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[id]) ? m[id] : null,
+		event;
+
+		if (fn) {
+			c.on.start = fn.start;
+			delete fn;
+		}
+
+		Y.fire(E_START, id);
+		if (c.on.start) {
+			event = _tPubSub('start', c);
+			event.fire(id);
+		}
+		Y.log('Transaction ' + id + ' started.', 'info', 'io');
+	};
+
+   /**
+	* @description Fires event "io:complete" and creates, fires a
+	* transaction-specific "complete" event, if config.on.complete is
+	* defined.
+	*
+	* @method _ioComplete
+	* @private
+	* @static
+	* @param {object} o - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioComplete(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var event;
+
+		Y.fire(E_COMPLETE, o.id, o.c);
+		if (c.on.complete) {
+			event = _tPubSub('complete', c);
+			event.fire(o.id, o.c);
+		}
+		Y.log('Transaction ' + o.id + ' completed.', 'info', 'io');
+	}
+
+   /**
+	* @description Fires event "io:success" and creates, fires a
+	* transaction-specific "success" event, if config.on.success is
+	* defined.
+	*
+	* @method _ioSuccess
+	* @private
+	* @static
+	* @param {object} o - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioSuccess(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if (fn) {
+			c.on.success = fn.success;
+			delete fn;
+			//Decode the response from IO.swf
+			o.c.responseText = decodeURI(o.c.responseText);
+		}
+
+		Y.fire(E_SUCCESS, o.id, o.c);
+		if (c.on.success) {
+			event = _tPubSub('success', c);
+			event.fire(o.id, o.c);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+		Y.log('HTTP Status evaluates to Success. The transaction is: ' + o.id, 'info', 'io');
+	}
+
+   /**
+	* @description Fires event "io:failure" and creates, fires a
+	* transaction-specific "failure" event, if config.on.failure is
+	* defined.
+	*
+	* @method _ioFailure
+	* @private
+	* @static
+	* @param {object} o - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioFailure(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if (fn) {
+			c.on.failure = fn.failure;
+			delete fn;
+			//Decode the response from IO.swf
+			o.c.responseText = decodeURI(o.c.responseText);
+		}
+
+		Y.fire(E_FAILURE, o.id, o.c);
+		if (c.on.failure) {
+			event = _tPubSub('failure', c);
+			event.fire(o.id, o.c);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+		Y.log('HTTP Status evaluates to Failure. The transaction is: ' + o.id, 'info', 'io');
+	}
+
+   /**
+	* @description Fires event "io:abort" and creates, fires a
+	* transaction-specific "abort" event, if config.on.abort is
+	* defined.
+	*
+	* @method _ioAbort
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+	*
+    * @return void
+	*/
+	function _ioAbort(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if(o && o.c  && !c.xdr) {
+			// Terminate the transaction
+			o.c.abort();
+			if (c) {
+				// Clear the timeout poll for this specific transaction.
+				if (c.timeout) {
+					_clearTimeout(o.id);
+				}
+			}
+		}
+
+		if (fn) {
+			c.on.abort = fn.abort;
+			delete fn;
+		}
+
+		Y.fire(E_ABORT, o.id);
+		if (c.on.abort) {
+			event = _tPubSub('abort', c);
+			event.fire(id);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+		Y.log('Transaction timeout or explicit abort. The transaction is: ' + o.id, 'info', 'io');
+	}
+
+   /**
+	* @description Method that increments _transactionId for each transaction.
+	*
+	* @method _id
+	* @private
+	* @static
+    * @return int
+	*/
+	function _id() {
+		var id = transactionId;
+		transactionId++;
+
+		Y.log('Transaction id generated. The id is: ' + id, 'info', 'io');
+		return id;
+	};
+
+   /**
+	* @description Method that creates a unique transaction object for each
+	* request..
+	*
+	* @method _create
+	* @private
+	* @static
+    * @param {number} s - URI or root data.
+    * @param {number} c - configuration object
+    * @return object
+	*/
+	function _create(i, c) {
+		var o = {};
+		o.id = Y.Lang.isNumber(i) ? i : _id();
+
+		if (c.xdr) {
+			o.c = Y.io._transportMap[c.xdr.use];
+		}
+		else if (c.form && c.form.upload) {
+			o.c = {};
+		}
+		else {
+			o.c = _xhr();
+		}
+
+		return o;
+	};
+
+   /**
+	* @description Method that creates the XMLHttpRequest transport
+	*
+	* @method _xhr
+	* @private
+	* @static
+    * @return object
+	*/
+	function _xhr() {
+		return (w.XMLHttpRequest) ? new XMLHttpRequest() : new ActiveXObject('Microsoft.XMLHTTP');
+	};
+
+   /**
+	* @description Method that concatenates string data for HTTP GET transactions.
+	*
+	* @method _concat
+	* @private
+	* @static
+    * @param {string} s - URI or root data.
+    * @param {string} d - data to be concatenated onto URI.
+    * @return int
+	*/
+	function _concat(s, d) {
+		s += ((s.indexOf('?') == -1) ? '?' : '&') + d;
+		return s;
+	};
+
+   /**
+	* @description Method that stores default client headers for all transactions.
+	* If a label is passed with no value argument, the header will be deleted.
+	*
+	* @method _setHeader
+	* @private
+	* @static
+    * @param {string} l - HTTP header
+    * @param {string} v - HTTP header value
+    * @return int
+	*/
+	function _setHeader(l, v) {
+		if (v) {
+			_headers[l] = v;
+		}
+		else {
+			delete _headers[l];
+		}
+	};
+
+   /**
+	* @description Method that sets all HTTP headers to be sent in a transaction.
+	*
+	* @method _setHeaders
+	* @private
+	* @static
+    * @param {object} o - XHR instance for the specific transaction.
+    * @param {object} h - HTTP headers for the specific transaction, as defined
+    *                     in the configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _setHeaders(o, h) {
+
+		var p;
+
+		for (p in _headers) {
+			if (_headers.hasOwnProperty(p)) {
+				if (h[p]) {
+					// Configuration headers will supersede IO preset headers,
+					// if headers match.
+					Y.log('Matching configuration HTTP header: ' + p + ' found with value of ' + _headers[p], 'info', 'io');
+					break;
+				}
+				else {
+					h[p] = _headers[p];
+					Y.log('HTTP header ' + p + ' found with value of ' + _headers[p], 'info', 'io');
+				}
+			}
+		}
+
+		for (p in h) {
+			if (h.hasOwnProperty(p)) {
+				o.setRequestHeader(p, h[p]);
+				Y.log('HTTP Header ' + p + ' set with value of ' + h[p], 'info', 'io');
+			}
+		}
+	};
+
+	function _open(o, m, uri) {
+		o.open(m, uri, true);
+	};
+
+   /**
+	* @description Method that sends the transaction request.
+	*
+	* @method _async
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {string} d - Transaction data.
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _async(o, d, c) {
+		o.c.send(d);
+		_ioStart(o.id, c);
+	};
+
+   /**
+	* @description Starts timeout count if the configuration object
+	* has a defined timeout property.
+	*
+	* @method _startTimeout
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _startTimeout(o, c) {
+		_timeout[o.id] = w.setTimeout(function() { _ioAbort(o, c); }, c.timeout);
+	};
+
+   /**
+	* @description Clears the timeout interval started by _startTimeout().
+	*
+	* @method _clearTimeout
+	* @private
+	* @static
+    * @param {number} id - Transaction id.
+    * @return void
+	*/
+	function _clearTimeout(id) {
+		w.clearTimeout(_timeout[id]);
+		delete _timeout[id];
+	};
+
+   /**
+	* @description Event handler bound to onreadystatechange.
+	*
+	* @method _readyState
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _readyState(o, c) {
+		if (o.c.readyState === 4) {
+			if (c.timeout) {
+				_clearTimeout(o.id);
+			}
+			_ioComplete(o, c);
+			_handleResponse(o, c);
+		}
+	};
+
+   /**
+	* @description Method that determines if a transaction response qualifies
+	* as success or failure, based on the response HTTP status code, and
+	* fires the appropriate success or failure events.
+	*
+	* @method _handleResponse
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _handleResponse(o, c) {
+		var status;
+		try{
+			if (o.c.status && o.c.status !== 0) {
+				status = o.c.status;
+			}
+			else {
+				status = 0;
+			}
+		}
+		catch(e) {
+			status = 0;
+			Y.log('HTTP status unreadable. The transaction is: ' + o.id, 'warn', 'io');
+		}
+
+		/*
+		 * IE reports HTTP 204 as HTTP 1223.
+		 * However, the response data are still available.
+		 *
+		 * setTimeout() is used to prevent transactions from becoming
+		 * synchronous, in IE, when the response data are read from cache
+		 * (e.g., HTTP 304).
+		 */
+		if (status >= 200 && status < 300 || status === 1223) {
+			w.setTimeout( function() { _ioSuccess(o, c); }, 0);
+		}
+		else {
+			w.setTimeout( function() {_ioFailure(o, c); }, 0);
+		}
+	};
+
+	function _destroy(o, isTransport) {
+		// IE6 will throw a "Type Mismatch" error if the event handler is set to "null".
+		if(w.XMLHttpRequest && !isTransport) {
+			if (o.c) {
+				o.c.onreadystatechange = null;
+			}
+		}
+
+		o.c = null;
+		o = null;
+	};
+
+	_io.start = _ioStart;
+	_io.complete = _ioComplete;
+	_io.success = _ioSuccess;
+	_io.failure = _ioFailure;
+	_io.abort = _ioAbort;
+	_io._id = _id;
+	_io._timeout = _timeout;
+
+   	//--------------------------------------
+   	//  Begin public interface definition
+   	//--------------------------------------
+   /**
+	* @description Method that stores default client headers for all transactions.
+	* If a label is passed with no value argument, the header will be deleted.
+	* This is the interface for _setHeader().
+	*
+	* @method header
+	* @public
+	* @static
+    * @param {string} l - HTTP header
+    * @param {string} v - HTTP header value
+    * @return int
+	*/
+	_io.header = _setHeader;
+
+   /**
+	* @description Method for requesting a transaction. This
+	* is the interface for _io().
+	*
+	* @method io
+	* @public
+	* @static
+    * @param {string} uri - qualified path to transaction resource.
+    * @param {object} c - configuration object for the transaction.
+    * @return object
+    */
+	Y.io = _io;
+
+
+
+}, '3.0.0pr2' );

=== added file 'loggerhead/static/javascript/yui/build/io/io-base-min.js'
--- loggerhead/static/javascript/yui/build/io/io-base-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-base-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("io-base",function(D){var d="io:start",N="io:complete",B="io:success",G="io:failure",Z="io:abort",W=0,M={"X-Requested-With":"XMLHttpRequest"},X={};w=D.config.win;function b(g,l){var l=l||{},k=V((arguments.length===3)?arguments[2]:null,l),Y=(l.method)?l.method.toUpperCase():"GET",j=(l.data)?l.data:null,h;if(l.form){if(l.form.upload){u=D.io._upload(k,g,l);return u;}h=D.io._serialize(l.form);if(j){h+="&"+j;}if(Y==="POST"){j=h;U("Content-Type","application/x-www-form-urlencoded");}else{if(Y==="GET"){g=O(g,h);}}}else{if(j&&Y==="GET"){g=O(g,l.data);}else{if(j&&Y==="POST"){U("Content-Type","application/x-www-form-urlencoded; charset=UTF-8");}}}if(l.xdr){D.io._xdr(g,k,l);return k;}if(l.timeout){P(k,l);}k.c.onreadystatechange=function(){c(k,l);};try{E(k.c,Y,g);}catch(i){}C(k.c,(l.headers||{}));k.abort=function(){Q(k,l);};k.isInProgress=function(){return k.c.readyState!==4&&k.c.readyState!==0;};T(k,(j||""),l);return k;}function A(f,g){var Y=new D.Event.Target().publish("transaction:"+f);Y.subscribe(g.on[f],(g.context||this),g.arguments);return Y;}function R(h,g){g.on=g.on||{};var Y=D.io._fn||{},e=(Y&&Y[h])?Y[h]:null,f;if(e){g.on.start=e.start;delete e;}D.fire(d,h);if(g.on.start){f=A("start",g);f.fire(h);}}function H(e,f){f.on=f.on||{};var Y;D.fire(N,e.id,e.c);if(f.on.complete){Y=A("complete",f);Y.fire(e.id,e.c);}}function S(g,h){h.on=h.on||{};var Y=D.io._fn||{},e=(Y&&Y[g.id])?Y[g.id]:null,f;if(e){h.on.success=e.success;delete e;g.c.responseText=decodeURI(g.c.responseText);}D.fire(B,g.id,g.c);if(h.on.success){f=A("success",h);f.fire(g.id,g.c);}I(g,(h.xdr)?true:false);}function J(g,h){h.on=h.on||{};var Y=D.io._fn||{},e=(Y&&Y[g.id])?Y[g.id]:null,f;if(e){h.on.failure=e.failure;delete e;g.c.responseText=decodeURI(g.c.responseText);}D.fire(G,g.id,g.c);if(h.on.failure){f=A("failure",h);f.fire(g.id,g.c);}I(g,(h.xdr)?true:false);}function Q(g,h){h.on=h.on||{};var Y=D.io._fn||{},e=(Y&&Y[g.id])?Y[g.id]:null,f;if(g&&g.c&&!h.xdr){g.c.abort();if(h){if(h.timeout){L(g.id);}}}if(e){h.on.abort=e.abort;delete e;}D.fire(Z,g.id);if(h.on.abort){f=A("abort",h);f.fire(id);}I(g,(h.xdr)?true:false);}function F(){var Y=W;W++;return Y;}function V(Y,f){var e={};e.id=D.Lang.isNumber(Y)?Y:F();if(f.xdr){e.c=D.io._transportMap[f.xdr.use];}else{if(f.form&&f.form.upload){e.c={};}else{e.c=K();}}return e;}function K(){return(w.XMLHttpRequest)?new XMLHttpRequest():new ActiveXObject("Microsoft.XMLHTTP");}function O(Y,e){Y+=((Y.indexOf("?")==-1)?"?":"&")+e;return Y;}function U(Y,e){if(e){M[Y]=e;}else{delete M[Y];}}function C(f,Y){var e;for(e in M){if(M.hasOwnProperty(e)){if(Y[e]){break;}else{Y[e]=M[e];}}}for(e in Y){if(Y.hasOwnProperty(e)){f.setRequestHeader(e,Y[e]);}}}function E(f,Y,e){f.open(Y,e,true);}function T(e,Y,f){e.c.send(Y);R(e.id,f);}function P(Y,e){X[Y.id]=w.setTimeout(function(){Q(Y,e);},e.timeout);}function L(Y){w.clearTimeout(X[Y]);delete X[Y];}function c(Y,e){if(Y.c.readyState===4){if(e.timeout){L(Y.id);}H(Y,e);a(Y,e);}}function a(g,h){var Y;try{if(g.c.status&&g.c.status!==0){Y=g.c.status;}else{Y=0;}}catch(f){Y=0;}if(Y>=200&&Y<300||Y===1223){w.setTimeout(function(){S(g,h);},0);}else{w.setTimeout(function(){J(g,h);},0);}}function I(e,Y){if(w.XMLHttpRequest&&!Y){if(e.c){e.c.onreadystatechange=null;}}e.c=null;e=null;}b.start=R;b.complete=H;b.success=S;b.failure=J;b.abort=Q;b._id=F;b._timeout=X;b.header=U;D.io=b;},"3.0.0pr2");
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/io/io-base.js'
--- loggerhead/static/javascript/yui/build/io/io-base.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-base.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,739 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-base', function(Y) {
+
+   /**
+	* HTTP communications module.
+	* @module io
+	*/
+
+   /**
+    * The io class is a utility that brokers HTTP requests through a simplified
+    * interface.  Specifically, it allows JavaScript to make HTTP requests to
+    * a resource without a page reload.  The underlying transport for making
+    * same-domain requests is the XMLHttpRequest object.  YUI.io can also use
+    * Flash, if specified as a transport, for cross-domain requests.
+    *
+	* @class io
+	*/
+
+   /**
+	* @event io:start
+	* @description This event is fired by YUI.io when a transaction is initiated..
+	* @type Event Custom
+	*/
+	var E_START = 'io:start',
+
+   /**
+	* @event io:complete
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* all response data are available.
+	* @type Event Custom
+	*/
+	E_COMPLETE = 'io:complete',
+
+   /**
+	* @event io:success
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* the HTTP status resolves to HTTP2xx.
+	* @type Event Custom
+	*/
+	E_SUCCESS = 'io:success',
+
+   /**
+	* @event io:failure
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* the HTTP status resolves to HTTP4xx, 5xx and above.
+	* @type Event Custom
+	*/
+	E_FAILURE = 'io:failure',
+
+   /**
+	* @event io:abort
+	* @description This event is fired by YUI.io when a transaction is aborted
+	* explicitly or by a defined config.timeout.
+	* @type Event Custom
+	*/
+	E_ABORT = 'io:abort',
+
+	//--------------------------------------
+	//  Properties
+	//--------------------------------------
+   /**
+	* @description A transaction counter that increments for each transaction.
+	*
+	* @property transactionId
+	* @private
+	* @static
+	* @type int
+	*/
+	transactionId = 0,
+
+   /**
+	* @description Object of default HTTP headers to be initialized and sent
+	* for all transactions.
+	*
+	* @property _headers
+	* @private
+	* @static
+	* @type object
+	*/
+	_headers = {
+		'X-Requested-With' : 'XMLHttpRequest'
+	},
+
+   /**
+	* @description Object that stores timeout values for any transaction with
+	* a defined "timeout" configuration property.
+	*
+	* @property _timeOut
+	* @private
+	* @static
+	* @type object
+	*/
+	_timeout = {};
+
+	//--------------------------------------
+	//  Methods
+	//--------------------------------------
+
+	// Window reference
+	w = Y.config.win;
+
+   /**
+	* @description Method for requesting a transaction. _io() is implemented as
+	* yui.io().  Each transaction may include a configuration object.  Its
+	* properties are:
+	*
+	* method: HTTP method verb (e.g., GET or POST). If this property is not
+	*         not defined, the default value will be GET.
+	*
+	* data: This is the name-value string that will be sent as the transaction
+    *		data.  If the request is HTTP GET, the data become part of
+    *		querystring. If HTTP POST, the data are sent in the message body.
+	*
+	* xdr: Defines the transport to be used for cross-domain requests.  By
+	*      setting this property, the transaction will use the specified
+	*      transport instead of XMLHttpRequest.  Currently, the only alternate
+	*      transport supported is Flash (e.g., { xdr: 'flash' }).
+	*
+	* form: This is a defined object used to process HTML form as data.  The
+	*       properties are:
+	*       {
+	*	      id: object, //HTML form object or id of HTML form
+	*         useDisabled: boolean, //Allow disabled HTML form field values
+	*                      to be sent as part of the data.
+    *       }
+    *
+    * on: This is a defined object used to create and handle specific
+    *     events during a transaction lifecycle.  These events will fire in
+    *     addition to the global io events. The events are:
+    *	  start - This event is fired when a request is sent to a resource.
+    *     complete - This event fires when the transaction is complete.
+    *     success - This event fires when the response status resolves to
+    *               HTTP 2xx.
+    *     failure - This event fires when the response status resolves to
+    *               HTTP 4xx, 5xx, and beyond.
+    *	  abort - This even is fired when a transaction abort is fire by
+    *             timeout, or when it is manually aborted.
+    *
+    *     The properties are:
+    *     {
+	*       start: function(id, args){},
+	*       complete: function(id, responseobject, args){},
+	*       success: function(id, responseobject, args){},
+	*       failure: function(id, responseobject, args){},
+	*       abort: function(id, args){}
+	*     }
+	*	  Each property can reference a function or be written as an
+	*     inline function.
+	*
+	* context: Object reference for an event handler when it is implemented
+	*          as a method of a base object. Defining "context" will preserve
+	*          the proper reference of "this" used in the event handler.
+	* headers: This is a defined object of client headers, as many as.
+	*         desired for the transaction.  These headers are sentThe object
+	*         pattern is:
+	*		  {
+	*		    header: value
+	*         }
+	*
+	* timeout: This value, defined as milliseconds, is a time threshold for the
+	*          transaction. When this threshold is reached, and the transaction's
+	*          Complete event has not yet fired, the transaction will be aborted.
+	* arguments: Object, array, string, or number passed to all registered
+	*            event handlers.  This value is available as the second
+	*            argument in the "start" and "abort" event handlers; and, it is
+	*            the third argument in the "complete", "success", and "failure"
+	*            event handlers.
+	*
+	* @method _io
+	* @private
+	* @static
+    * @param {string} uri - qualified path to transaction resource.
+    * @param {object} c - configuration object for the transaction.
+    * @return object
+	*/
+	function _io(uri, c) {
+		var c = c || {},
+		o = _create((arguments.length === 3) ? arguments[2] : null, c),
+		m = (c.method) ? c.method.toUpperCase() : 'GET',
+		d = (c.data) ? c.data : null,
+		f;
+
+		/* Determine configuration properties */
+		// If config.form is defined, perform data operations.
+		if (c.form) {
+
+			if (c.form.upload) {
+				u = Y.io._upload(o, uri, c);
+				return u;
+			}
+
+			// Serialize the HTML form into a string of name-value pairs.
+			f = Y.io._serialize(c.form);
+			// If config.data is defined, concatenate the data to the form string.
+			if (d) {
+				f += "&" + d;
+			}
+
+			if (m === 'POST') {
+				d = f;
+				_setHeader('Content-Type', 'application/x-www-form-urlencoded');
+			}
+			else if (m === 'GET') {
+				uri = _concat(uri, f);
+			}
+		}
+		else if (d && m === 'GET') {
+			uri = _concat(uri, c.data);
+		}
+		else if (d && m === 'POST') {
+			_setHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
+		}
+
+		if (c.xdr) {
+			Y.io._xdr(uri, o, c);
+			return o;
+		}
+
+		// If config.timeout is defined, and the request is standard XHR,
+		// initialize timeout polling.
+		if (c.timeout) {
+			_startTimeout(o, c);
+		}
+		/* End Configuration Properties */
+
+		o.c.onreadystatechange = function() { _readyState(o, c); };
+		try {
+			_open(o.c, m, uri);
+		}
+		catch (e) {
+		}
+		_setHeaders(o.c, (c.headers || {}));
+
+		o.abort = function () {
+			_ioAbort(o, c);
+		}
+
+		o.isInProgress = function() {
+			return o.c.readyState !== 4 && o.c.readyState !== 0;
+		}
+		// Do not pass null, in the absence of data, as this
+		// will result in a POST request with no Content-Length
+		// defined.
+		_async(o, (d || ''), c);
+
+		return o;
+	};
+
+   /**
+	* @description Method for creating and subscribing transaction events.
+	*
+	* @method _tPubSub
+	* @private
+	* @static
+	* @param {string} e - event to be published
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _tPubSub(e, c){
+			var event = new Y.Event.Target().publish('transaction:' + e);
+			event.subscribe(c.on[e], (c.context || this), c.arguments);
+
+			return event;
+	};
+
+   /**
+	* @description Fires event "io:start" and creates, fires a
+	* transaction-specific start event, if config.on.start is
+	* defined.
+	*
+	* @method _ioStart
+	* @private
+	* @static
+	* @param {number} id - transaction id
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioStart(id, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[id]) ? m[id] : null,
+		event;
+
+		if (fn) {
+			c.on.start = fn.start;
+			delete fn;
+		}
+
+		Y.fire(E_START, id);
+		if (c.on.start) {
+			event = _tPubSub('start', c);
+			event.fire(id);
+		}
+	};
+
+   /**
+	* @description Fires event "io:complete" and creates, fires a
+	* transaction-specific "complete" event, if config.on.complete is
+	* defined.
+	*
+	* @method _ioComplete
+	* @private
+	* @static
+	* @param {object} o - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioComplete(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var event;
+
+		Y.fire(E_COMPLETE, o.id, o.c);
+		if (c.on.complete) {
+			event = _tPubSub('complete', c);
+			event.fire(o.id, o.c);
+		}
+	}
+
+   /**
+	* @description Fires event "io:success" and creates, fires a
+	* transaction-specific "success" event, if config.on.success is
+	* defined.
+	*
+	* @method _ioSuccess
+	* @private
+	* @static
+	* @param {object} o - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioSuccess(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if (fn) {
+			c.on.success = fn.success;
+			delete fn;
+			//Decode the response from IO.swf
+			o.c.responseText = decodeURI(o.c.responseText);
+		}
+
+		Y.fire(E_SUCCESS, o.id, o.c);
+		if (c.on.success) {
+			event = _tPubSub('success', c);
+			event.fire(o.id, o.c);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+	}
+
+   /**
+	* @description Fires event "io:failure" and creates, fires a
+	* transaction-specific "failure" event, if config.on.failure is
+	* defined.
+	*
+	* @method _ioFailure
+	* @private
+	* @static
+	* @param {object} o - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioFailure(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if (fn) {
+			c.on.failure = fn.failure;
+			delete fn;
+			//Decode the response from IO.swf
+			o.c.responseText = decodeURI(o.c.responseText);
+		}
+
+		Y.fire(E_FAILURE, o.id, o.c);
+		if (c.on.failure) {
+			event = _tPubSub('failure', c);
+			event.fire(o.id, o.c);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+	}
+
+   /**
+	* @description Fires event "io:abort" and creates, fires a
+	* transaction-specific "abort" event, if config.on.abort is
+	* defined.
+	*
+	* @method _ioAbort
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+	*
+    * @return void
+	*/
+	function _ioAbort(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if(o && o.c  && !c.xdr) {
+			// Terminate the transaction
+			o.c.abort();
+			if (c) {
+				// Clear the timeout poll for this specific transaction.
+				if (c.timeout) {
+					_clearTimeout(o.id);
+				}
+			}
+		}
+
+		if (fn) {
+			c.on.abort = fn.abort;
+			delete fn;
+		}
+
+		Y.fire(E_ABORT, o.id);
+		if (c.on.abort) {
+			event = _tPubSub('abort', c);
+			event.fire(id);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+	}
+
+   /**
+	* @description Method that increments _transactionId for each transaction.
+	*
+	* @method _id
+	* @private
+	* @static
+    * @return int
+	*/
+	function _id() {
+		var id = transactionId;
+		transactionId++;
+
+		return id;
+	};
+
+   /**
+	* @description Method that creates a unique transaction object for each
+	* request..
+	*
+	* @method _create
+	* @private
+	* @static
+    * @param {number} s - URI or root data.
+    * @param {number} c - configuration object
+    * @return object
+	*/
+	function _create(i, c) {
+		var o = {};
+		o.id = Y.Lang.isNumber(i) ? i : _id();
+
+		if (c.xdr) {
+			o.c = Y.io._transportMap[c.xdr.use];
+		}
+		else if (c.form && c.form.upload) {
+			o.c = {};
+		}
+		else {
+			o.c = _xhr();
+		}
+
+		return o;
+	};
+
+   /**
+	* @description Method that creates the XMLHttpRequest transport
+	*
+	* @method _xhr
+	* @private
+	* @static
+    * @return object
+	*/
+	function _xhr() {
+		return (w.XMLHttpRequest) ? new XMLHttpRequest() : new ActiveXObject('Microsoft.XMLHTTP');
+	};
+
+   /**
+	* @description Method that concatenates string data for HTTP GET transactions.
+	*
+	* @method _concat
+	* @private
+	* @static
+    * @param {string} s - URI or root data.
+    * @param {string} d - data to be concatenated onto URI.
+    * @return int
+	*/
+	function _concat(s, d) {
+		s += ((s.indexOf('?') == -1) ? '?' : '&') + d;
+		return s;
+	};
+
+   /**
+	* @description Method that stores default client headers for all transactions.
+	* If a label is passed with no value argument, the header will be deleted.
+	*
+	* @method _setHeader
+	* @private
+	* @static
+    * @param {string} l - HTTP header
+    * @param {string} v - HTTP header value
+    * @return int
+	*/
+	function _setHeader(l, v) {
+		if (v) {
+			_headers[l] = v;
+		}
+		else {
+			delete _headers[l];
+		}
+	};
+
+   /**
+	* @description Method that sets all HTTP headers to be sent in a transaction.
+	*
+	* @method _setHeaders
+	* @private
+	* @static
+    * @param {object} o - XHR instance for the specific transaction.
+    * @param {object} h - HTTP headers for the specific transaction, as defined
+    *                     in the configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _setHeaders(o, h) {
+
+		var p;
+
+		for (p in _headers) {
+			if (_headers.hasOwnProperty(p)) {
+				if (h[p]) {
+					// Configuration headers will supersede IO preset headers,
+					// if headers match.
+					break;
+				}
+				else {
+					h[p] = _headers[p];
+				}
+			}
+		}
+
+		for (p in h) {
+			if (h.hasOwnProperty(p)) {
+				o.setRequestHeader(p, h[p]);
+			}
+		}
+	};
+
+	function _open(o, m, uri) {
+		o.open(m, uri, true);
+	};
+
+   /**
+	* @description Method that sends the transaction request.
+	*
+	* @method _async
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {string} d - Transaction data.
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _async(o, d, c) {
+		o.c.send(d);
+		_ioStart(o.id, c);
+	};
+
+   /**
+	* @description Starts timeout count if the configuration object
+	* has a defined timeout property.
+	*
+	* @method _startTimeout
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _startTimeout(o, c) {
+		_timeout[o.id] = w.setTimeout(function() { _ioAbort(o, c); }, c.timeout);
+	};
+
+   /**
+	* @description Clears the timeout interval started by _startTimeout().
+	*
+	* @method _clearTimeout
+	* @private
+	* @static
+    * @param {number} id - Transaction id.
+    * @return void
+	*/
+	function _clearTimeout(id) {
+		w.clearTimeout(_timeout[id]);
+		delete _timeout[id];
+	};
+
+   /**
+	* @description Event handler bound to onreadystatechange.
+	*
+	* @method _readyState
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _readyState(o, c) {
+		if (o.c.readyState === 4) {
+			if (c.timeout) {
+				_clearTimeout(o.id);
+			}
+			_ioComplete(o, c);
+			_handleResponse(o, c);
+		}
+	};
+
+   /**
+	* @description Method that determines if a transaction response qualifies
+	* as success or failure, based on the response HTTP status code, and
+	* fires the appropriate success or failure events.
+	*
+	* @method _handleResponse
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _handleResponse(o, c) {
+		var status;
+		try{
+			if (o.c.status && o.c.status !== 0) {
+				status = o.c.status;
+			}
+			else {
+				status = 0;
+			}
+		}
+		catch(e) {
+			status = 0;
+		}
+
+		/*
+		 * IE reports HTTP 204 as HTTP 1223.
+		 * However, the response data are still available.
+		 *
+		 * setTimeout() is used to prevent transactions from becoming
+		 * synchronous, in IE, when the response data are read from cache
+		 * (e.g., HTTP 304).
+		 */
+		if (status >= 200 && status < 300 || status === 1223) {
+			w.setTimeout( function() { _ioSuccess(o, c); }, 0);
+		}
+		else {
+			w.setTimeout( function() {_ioFailure(o, c); }, 0);
+		}
+	};
+
+	function _destroy(o, isTransport) {
+		// IE6 will throw a "Type Mismatch" error if the event handler is set to "null".
+		if(w.XMLHttpRequest && !isTransport) {
+			if (o.c) {
+				o.c.onreadystatechange = null;
+			}
+		}
+
+		o.c = null;
+		o = null;
+	};
+
+	_io.start = _ioStart;
+	_io.complete = _ioComplete;
+	_io.success = _ioSuccess;
+	_io.failure = _ioFailure;
+	_io.abort = _ioAbort;
+	_io._id = _id;
+	_io._timeout = _timeout;
+
+   	//--------------------------------------
+   	//  Begin public interface definition
+   	//--------------------------------------
+   /**
+	* @description Method that stores default client headers for all transactions.
+	* If a label is passed with no value argument, the header will be deleted.
+	* This is the interface for _setHeader().
+	*
+	* @method header
+	* @public
+	* @static
+    * @param {string} l - HTTP header
+    * @param {string} v - HTTP header value
+    * @return int
+	*/
+	_io.header = _setHeader;
+
+   /**
+	* @description Method for requesting a transaction. This
+	* is the interface for _io().
+	*
+	* @method io
+	* @public
+	* @static
+    * @param {string} uri - qualified path to transaction resource.
+    * @param {object} c - configuration object for the transaction.
+    * @return object
+    */
+	Y.io = _io;
+
+
+
+}, '3.0.0pr2' );

=== added file 'loggerhead/static/javascript/yui/build/io/io-debug.js'
--- loggerhead/static/javascript/yui/build/io/io-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1194 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-base', function(Y) {
+
+   /**
+	* HTTP communications module.
+	* @module io
+	*/
+
+   /**
+    * The io class is a utility that brokers HTTP requests through a simplified
+    * interface.  Specifically, it allows JavaScript to make HTTP requests to
+    * a resource without a page reload.  The underlying transport for making
+    * same-domain requests is the XMLHttpRequest object.  YUI.io can also use
+    * Flash, if specified as a transport, for cross-domain requests.
+    *
+	* @class io
+	*/
+
+   /**
+	* @event io:start
+	* @description This event is fired by YUI.io when a transaction is initiated..
+	* @type Event Custom
+	*/
+	E_START = 'io:start',
+
+   /**
+	* @event io:complete
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* all response data are available.
+	* @type Event Custom
+	*/
+	E_COMPLETE = 'io:complete',
+
+   /**
+	* @event io:success
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* the HTTP status resolves to HTTP2xx.
+	* @type Event Custom
+	*/
+	E_SUCCESS = 'io:success',
+
+   /**
+	* @event io:failure
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* the HTTP status resolves to HTTP4xx, 5xx and above.
+	* @type Event Custom
+	*/
+	E_FAILURE = 'io:failure',
+
+   /**
+	* @event io:abort
+	* @description This event is fired by YUI.io when a transaction is aborted
+	* explicitly or by a defined config.timeout.
+	* @type Event Custom
+	*/
+	E_ABORT = 'io:abort',
+
+	//--------------------------------------
+	//  Properties
+	//--------------------------------------
+   /**
+	* @description A transaction counter that increments for each transaction.
+	*
+	* @property transactionId
+	* @private
+	* @static
+	* @type int
+	*/
+	transactionId = 0,
+
+   /**
+	* @description Object of default HTTP headers to be initialized and sent
+	* for all transactions.
+	*
+	* @property _headers
+	* @private
+	* @static
+	* @type object
+	*/
+	_headers = {
+		'X-Requested-With' : 'XMLHttpRequest'
+	},
+
+   /**
+	* @description Object that stores timeout values for any transaction with
+	* a defined "timeout" configuration property.
+	*
+	* @property _timeOut
+	* @private
+	* @static
+	* @type object
+	*/
+	_timeout = {},
+
+   /**
+	* @description Array of transactions queued for processing
+	*
+	* @property _q
+	* @private
+	* @static
+	* @type array
+	*/
+	_q = [],
+
+   /**
+	* @description Property to determine whether the queue is set to
+	* 1 (active) or 0 (inactive).  When inactive, transactions
+	* will be stored in the queue until the queue is set to active.
+	*
+	* @property _qState
+	* @private
+	* @static
+	* @type int
+	*/
+	_qState = 1,
+
+   /**
+	* @description Queue property to set a maximum queue storage size.  When
+	* this property is set, the queue will not store any more transactions
+	* until the queue size os reduced below this threshold. There is no
+	* maximum queue size until it is explicitly set.
+	*
+	* @property _qMaxSize
+	* @private
+	* @static
+	* @type int
+	*/
+	_qMaxSize = false,
+
+	// Window reference
+	w = Y.config.win;
+
+	//--------------------------------------
+	//  Methods
+	//--------------------------------------
+   /**
+	* @description Method for requesting a transaction, and queueing the
+	* request before it is sent to the resource.
+	*
+	* @method _queue
+	* @private
+	* @static
+    * @return int
+	*/
+	function _queue(uri, c) {
+
+		if (_qMaxSize === false || _q.length < _qMaxSize) {
+			var id = _id();
+			_q.push({ uri: uri, id: id, cfg:c });
+		}
+		else {
+			Y.log('Unable to queue transaction object.  Maximum queue size reached.', 'warn', 'io');
+			return false;
+		}
+
+		if (_qState === 1) {
+			_shift();
+		}
+
+		Y.log('Object queued.  Transaction id is' + id, 'info', 'io');
+		return id;
+	};
+
+   /**
+	* @description Method for promoting a transaction to the top of the queue.
+	*
+	* @method _unshift
+	* @private
+	* @static
+    * @return void
+	*/
+	function _unshift(id) {
+		var r;
+
+		for (var i = 0; i < _q.length; i++) {
+			if (_q[i].id === id) {
+				r = _q.splice(i, 1);
+				var p = _q.unshift(r[0]);
+				Y.log('Object promoted to top of queue.  Transaction id is' + id, 'info', 'io');
+				break;
+			}
+		}
+	};
+
+   /**
+	* @description Method for removing a transaction from the top of the
+	* queue, and sending the transaction to _io().
+	*
+	* @method _shift
+	* @private
+	* @static
+    * @return void
+	*/
+	function _shift() {
+		var c = _q.shift();
+		_io(c.uri, c.cfg, c.id);
+	};
+
+   /**
+	* @description Method to query the current size of the queue, or to
+	* set a maximum queue size.
+	*
+	* @method _size
+	* @private
+	* @static
+    * @return int
+	*/
+	function _size(i) {
+		if (i) {
+			_qMaxSize = i;
+			Y.log('Queue size set to ' + i, 'info', 'io');
+			return i;
+		}
+		else {
+			return _q.length;
+		}
+	};
+
+   /**
+	* @description Method for setting the queue to active. If there are
+	* transactions pending in the queue, they will be processed from the
+	* queue in FIFO order.
+	*
+	* @method _start
+	* @private
+	* @static
+    * @return void
+	*/
+	function _start() {
+		var len = (_q.length > _qMaxSize > 0) ? _qMaxSize : _q.length;
+
+		if (len > 1) {
+			for (var i=0; i < len; i++) {
+				_shift();
+			}
+		}
+		else {
+			_shift();
+		}
+
+		Y.log('Queue started.', 'info', 'io');
+	};
+
+   /**
+	* @description Method for setting queue processing to inactive.
+	* Transaction requests to YUI.io.queue() will be stored in the queue, but
+	* not processed until the queue is reset to "active".
+	*
+	* @method _stop
+	* @private
+	* @static
+    * @return void
+	*/
+	function _stop() {
+		_qState = 0;
+		Y.log('Queue stopped.', 'info', 'io');
+	};
+
+   /**
+	* @description Method for removing a specific, pending transaction from
+	* the queue.
+	*
+	* @method _purge
+	* @private
+	* @static
+    * @return void
+	*/
+	function _purge(id) {
+		if (Y.Lang.isNumber(id)) {
+			for (var i = 0; i < _q.length; i++) {
+				if (_q[i].id === id) {
+					_q.splice(i, 1);
+					Y.log('Object purged from queue.  Transaction id is' + id, 'info', 'io');
+					break;
+				}
+			}
+		}
+	};
+	/* End Queue Functions */
+
+   /**
+	* @description Method for requesting a transaction. _io() is implemented as
+	* yui.io().  Each transaction may include a configuration object.  Its
+	* properties are:
+	*
+	* method: HTTP method verb (e.g., GET or POST). If this property is not
+	*         not defined, the default value will be GET.
+	*
+	* data: This is the name-value string that will be sent as the transaction
+    *		data.  If the request is HTTP GET, the data become part of
+    *		querystring. If HTTP POST, the data are sent in the message body.
+	*
+	* xdr: Defines the transport to be used for cross-domain requests.  By
+	*      setting this property, the transaction will use the specified
+	*      transport instead of XMLHttpRequest.  Currently, the only alternate
+	*      transport supported is Flash (e.g., { xdr: 'flash' }).
+	*
+	* form: This is a defined object used to process HTML form as data.  The
+	*       properties are:
+	*       {
+	*	      id: object, //HTML form object or id of HTML form
+	*         useDisabled: boolean, //Allow disabled HTML form field values
+	*                      to be sent as part of the data.
+    *       }
+    *
+    * on: This is a defined object used to create and handle specific
+    *     events during a transaction lifecycle.  These events will fire in
+    *     addition to the global io events. The events are:
+    *	  start - This event is fired when a request is sent to a resource.
+    *     complete - This event fires when the transaction is complete.
+    *     success - This event fires when the response status resolves to
+    *               HTTP 2xx.
+    *     failure - This event fires when the response status resolves to
+    *               HTTP 4xx, 5xx, and beyond.
+    *	  abort - This even is fired when a transaction abort is fire by
+    *             timeout, or when it is manually aborted.
+    *
+    *     The properties are:
+    *     {
+	*       start: function(id, args){},
+	*       complete: function(id, responseobject, args){},
+	*       success: function(id, responseobject, args){},
+	*       failure: function(id, responseobject, args){},
+	*       abort: function(id, args){}
+	*     }
+	*	  Each property can reference a function or be written as an
+	*     inline function.
+	*
+	* context: Object reference for an event handler when it is implemented
+	*          as a method of a base object. Defining "context" will preserve
+	*          the proper reference of "this" used in the event handler.
+	* headers: This is a defined object of client headers, as many as.
+	*         desired for the transaction.  These headers are sentThe object
+	*         pattern is:
+	*		  {
+	*		    header: value
+	*         }
+	*
+	* timeout: This value, defined as milliseconds, is a time threshold for the
+	*          transaction. When this threshold is reached, and the transaction's
+	*          Complete event has not yet fired, the transaction will be aborted.
+	* arguments: Object, array, string, or number passed to all registered
+	*            event handlers.  This value is available as the second
+	*            argument in the "start" and "abort" event handlers; and, it is
+	*            the third argument in the "complete", "success", and "failure"
+	*            event handlers.
+	*
+	* @method _io
+	* @private
+	* @static
+    * @param {string} uri - qualified path to transaction resource.
+    * @param {object} c - configuration object for the transaction.
+    * @return object
+	*/
+	function _io(uri, c) {
+		var c = c || {},
+		o = _create((arguments.length === 3) ? arguments[2] : null, c),
+		m = (c.method) ? c.method.toUpperCase() : 'GET',
+		d = (c.data) ? c.data : null,
+		f;
+
+		/* Determine configuration properties */
+		// If config.form is defined, perform data operations.
+		if (c.form) {
+
+			if (c.form.upload) {
+				u = Y.io._upload(o, uri, c);
+				return u;
+			}
+
+			// Serialize the HTML form into a string of name-value pairs.
+			f = Y.io._serialize(c.form);
+			// If config.data is defined, concatenate the data to the form string.
+			if (d) {
+				f += "&" + d;
+				Y.log('Configuration object.data added to serialized HTML form data. The string is: ' + f, 'info', 'io');
+			}
+
+			if (m === 'POST') {
+				d = f;
+				_setHeader('Content-Type', 'application/x-www-form-urlencoded');
+			}
+			else if (m === 'GET') {
+				uri = _concat(uri, f);
+				Y.log('Configuration object.data added to serialized HTML form data. The querystring is: ' + uri, 'info', 'io');
+			}
+		}
+		else if (d && m === 'GET') {
+			uri = _concat(uri, c.data);
+			Y.log('Configuration object data added to URI. The querystring is: ' + uri, 'info', 'io');
+		}
+		else if (d && m === 'POST') {
+			_setHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
+		}
+
+		if (c.xdr) {
+			Y.io._xdr(uri, o, c);
+			return o;
+		}
+
+		// If config.timeout is defined, and the request is standard XHR,
+		// initialize timeout polling.
+		if (c.timeout) {
+			_startTimeout(o, c);
+		}
+		/* End Configuration Properties */
+
+		o.c.onreadystatechange = function() { _readyState(o, c); };
+		try {
+			_open(o.c, m, uri);
+		}
+		catch (e) {
+		}
+		_setHeaders(o.c, (c.headers || {}));
+
+		o.abort = function () {
+			_ioAbort(o, c);
+		}
+
+		o.isInProgress = function() {
+			return o.c.readyState !== 4 && o.c.readyState !== 0;
+		}
+		// Do not pass null, in the absence of data, as this
+		// wiil result in a POST request with no Content-Length
+		// defined.
+		_async(o, (d || ''), c);
+
+		return o;
+	};
+
+   /**
+	* @description Method for creating and subscribing transaction events.
+	*
+	* @method _tPubSub
+	* @private
+	* @static
+	* @param {string} e - event to be published
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _tPubSub(e, c){
+			var event = new Y.Event.Target().publish('transaction:' + e);
+			event.subscribe(c.on[e], (c.context || this), c.arguments);
+
+			return event;
+	};
+
+   /**
+	* @description Fires event "io:start" and creates, fires a
+	* transaction-specific start event, if config.on.start is
+	* defined.
+	*
+	* @method _ioStart
+	* @private
+	* @static
+	* @param {number} id - transaction id
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioStart(id, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[id]) ? m[id] : null,
+		event;
+
+		if (fn) {
+			c.on.start = fn.start;
+			delete fn;
+		}
+
+		Y.fire(E_START, id);
+		if (c.on.start) {
+			event = _tPubSub('start', c);
+			event.fire(id);
+		}
+		Y.log('Transaction ' + id + ' started.', 'info', 'io');
+	};
+
+   /**
+	* @description Fires event "io:complete" and creates, fires a
+	* transaction-specific "complete" event, if config.on.complete is
+	* defined.
+	*
+	* @method _ioComplete
+	* @private
+	* @static
+	* @param {object} id - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioComplete(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var event;
+
+		Y.fire(E_COMPLETE, o.id, o.c);
+		if (c.on.complete) {
+			event = _tPubSub('complete', c);
+			event.fire(o.id, o.c);
+		}
+		Y.log('Transaction ' + o.id + ' completed.', 'info', 'io');
+	}
+
+   /**
+	* @description Fires event "io:success" and creates, fires a
+	* transaction-specific "success" event, if config.on.success is
+	* defined.
+	*
+	* @method _ioSuccess
+	* @private
+	* @static
+	* @param {object} o - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioSuccess(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if (fn) {
+			c.on.success = fn.success;
+			delete fn;
+			//Decode the response from IO.swf
+			o.c.responseText = decodeURI(o.c.responseText);
+		}
+
+		Y.fire(E_SUCCESS, o.id, o.c);
+		if (c.on.success) {
+			event = _tPubSub('success', c);
+			event.fire(o.id, o.c);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+		Y.log('HTTP Status evaluates to Success. The transaction is: ' + o.id, 'info', 'io');
+	}
+
+   /**
+	* @description Fires event "io:failure" and creates, fires a
+	* transaction-specific "failure" event, if config.on.failure is
+	* defined.
+	*
+	* @method _ioFailure
+	* @private
+	* @static
+	* @param {object} o - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioFailure(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if (fn) {
+			c.on.failure = fn.failure;
+			delete fn;
+			//Decode the response from IO.swf
+			o.c.responseText = decodeURI(o.c.responseText);
+		}
+
+		Y.fire(E_FAILURE, o.id, o.c);
+		if (c.on.failure) {
+			event = _tPubSub('failure', c);
+			event.fire(o.id, o.c);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+		Y.log('HTTP Status evaluates to Failure. The transaction is: ' + o.id, 'info', 'io');
+	}
+
+   /**
+	* @description Fires event "io:abort" and creates, fires a
+	* transaction-specific "abort" event, if config.on.abort is
+	* defined.
+	*
+	* @method _ioAbort
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+	*
+    * @return void
+	*/
+	function _ioAbort(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if(o && o.c  && !c.xdr) {
+			// Terminate the transaction
+			o.c.abort();
+			if (c) {
+				// Clear the timeout poll for this specific transaction.
+				if (c.timeout) {
+					_clearTimeout(o.id);
+				}
+			}
+		}
+
+		if (fn) {
+			c.on.abort = fn.abort;
+			delete fn;
+		}
+
+		Y.fire(E_ABORT, o.id);
+		if (c.on.abort) {
+			event = _tPubSub('abort', c);
+			event.fire(id);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+		Y.log('Transaction timeout or explicit abort. The transaction is: ' + o.id, 'info', 'io');
+	}
+
+   /**
+	* @description Method that increments _transactionId for each transaction.
+	*
+	* @method _id
+	* @private
+	* @static
+    * @return int
+	*/
+	function _id() {
+		var id = transactionId;
+		transactionId++;
+
+		Y.log('Transaction id generated. The id is: ' + id, 'info', 'io');
+		return id;
+	};
+
+   /**
+	* @description Method that creates a unique transaction object for each
+	* request..
+	*
+	* @method _create
+	* @private
+	* @static
+    * @param {number} s - URI or root data.
+    * @param {number} c - configuration object
+    * @return object
+	*/
+	function _create(i, c) {
+		var o = {};
+		o.id = Y.Lang.isNumber(i) ? i : _id();
+
+		if (c.xdr) {
+			o.c = Y.io._transport[c.xdr.use];
+		}
+		else if (c.form && c.form.upload) {
+			o.c = {};
+		}
+		else {
+			o.c = _xhr();
+		}
+
+		return o;
+	};
+
+   /**
+	* @description Method that creates the XMLHttpRequest transport
+	*
+	* @method _xhr
+	* @private
+	* @static
+    * @return object
+	*/
+	function _xhr() {
+		return (w.XMLHttpRequest) ? new XMLHttpRequest() : new ActiveXObject('Microsoft.XMLHTTP');
+	};
+
+   /**
+	* @description Method that concatenates string data for HTTP GET transactions.
+	*
+	* @method _concat
+	* @private
+	* @static
+    * @param {string} s - URI or root data.
+    * @param {string} d - data to be concatenated onto URI.
+    * @return int
+	*/
+	function _concat(s, d) {
+		s += ((s.indexOf('?') == -1) ? '?' : '&') + d;
+		return s;
+	};
+
+   /**
+	* @description Method that stores default client headers for all transactions.
+	* If a label is passed with no value argument, the header will be deleted.
+	*
+	* @method _setHeader
+	* @private
+	* @static
+    * @param {string} l - HTTP header
+    * @param {string} v - HTTP header value
+    * @return int
+	*/
+	function _setHeader(l, v) {
+		if (v) {
+			_headers[l] = v;
+		}
+		else {
+			delete _headers[l];
+		}
+	};
+
+   /**
+	* @description Method that sets all HTTP headers to be sent in a transaction.
+	*
+	* @method _setHeaders
+	* @private
+	* @static
+    * @param {object} o - XHR instance for the specific transaction.
+    * @param {object} h - HTTP headers for the specific transaction, as defined
+    *                     in the configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _setHeaders(o, h) {
+
+		var p;
+
+		for (p in _headers) {
+			if (_headers.hasOwnProperty(p)) {
+				h[p] = _headers[p];
+				Y.log('Default HTTP header ' + p + ' found with value of ' + _headers[p], 'info', 'io');
+			}
+		}
+
+		for (p in h) {
+			if (h.hasOwnProperty(p)) {
+				o.setRequestHeader(p, h[p]);
+				Y.log('HTTP Header ' + p + ' set with value of ' + h[p], 'info', 'io');
+			}
+		}
+	};
+
+	function _open(o, m, uri) {
+		o.open(m, uri, true);
+	};
+
+   /**
+	* @description Method that sends the transaction request.
+	*
+	* @method _async
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {string} d - Transaction data.
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _async(o, d, c) {
+		o.c.send(d);
+		_ioStart(o.id, c);
+	};
+
+   /**
+	* @description Starts timeout count if the configuration object
+	* has a defined timeout property.
+	*
+	* @method _startTimeout
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _startTimeout(o, c) {
+		_timeout[o.id] = w.setTimeout(function() { _ioAbort(o, c); }, c.timeout);
+	};
+
+   /**
+	* @description Clears the timeout interval started by _startTimeout().
+	*
+	* @method _clearTimeout
+	* @private
+	* @static
+    * @param {number} id - Transaction id.
+    * @return void
+	*/
+	function _clearTimeout(id) {
+		w.clearTimeout(_timeout[id]);
+		delete _timeout[id];
+	};
+
+   /**
+	* @description Event handler bound to onreadystatechange.
+	*
+	* @method _readyState
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _readyState(o, c) {
+		if (o.c.readyState === 4) {
+			if (c.timeout) {
+				_clearTimeout(o.id);
+			}
+			_ioComplete(o, c);
+			_handleResponse(o, c);
+		}
+	};
+
+   /**
+	* @description Method that determines if a transaction response qualifies
+	* as success or failure, based on the response HTTP status code, and
+	* fires the appropriate success or failure events.
+	*
+	* @method _handleResponse
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _handleResponse(o, c) {
+		var status;
+		try{
+			if (o.c.status && o.c.status !== 0) {
+				status = o.c.status;
+			}
+			else {
+				status = 0;
+			}
+		}
+		catch(e) {
+			status = 0;
+			Y.log('HTTP status unreadable. The transaction is: ' + o.id, 'warn', 'io');
+		}
+
+		/*
+		 * IE reports HTTP 204 as HTTP 1223.
+		 * However, the response data are still available.
+		 *
+		 * setTimeout() is used to prevent transactions from becoming
+		 * synchronous, in IE, when the response data are read from cache
+		 * (e.g., HTTP 304).
+		 */
+		if (status >= 200 && status < 300 || status === 1223) {
+			w.setTimeout( function() { _ioSuccess(o, c); }, 0);
+		}
+		else {
+			w.setTimeout( function() {_ioFailure(o, c); }, 0);
+		}
+	};
+
+	function _destroy(o, isTransport) {
+		// IE6 will throw a "Type Mismatch" error if the event handler is set to "null".
+		if(w.XMLHttpRequest && !isTransport) {
+			if (o.c) {
+				o.c.onreadystatechange = null;
+			}
+		}
+
+		o.c = null;
+		o = null;
+	};
+
+	_io.start = _ioStart;
+	_io.complete = _ioComplete;
+	_io.success = _ioSuccess;
+	_io.failure = _ioFailure;
+	_io.abort = _ioAbort;
+	_io.timeout = _timeout;
+
+   	//--------------------------------------
+   	//  Begin public interface definition
+   	//--------------------------------------
+   /**
+	* @description Method that stores default client headers for all transactions.
+	* If a label is passed with no value argument, the header will be deleted.
+	* This is the interface for _setHeader().
+	*
+	* @method header
+	* @public
+	* @static
+    * @param {string} l - HTTP header
+    * @param {string} v - HTTP header value
+    * @return int
+	*/
+	_io.header = _setHeader;
+
+   /**
+	* @description Method for requesting a transaction, and queueing the
+	* request before it is sent to the resource. This is the
+	* interface for _queue().
+	*
+	* @method queue
+	* @public
+	* @static
+    * @param {string} uri - qualified path to transaction resource.
+    * @param {object} c - configuration object for the transaction.
+    * @return int
+	*/
+	_io.queue = _queue;
+
+   /**
+	* @description Method to query the current size of the queue, or to
+	* set a maximum queue size.  This is the interface for _size().
+	*
+	* @method size
+	* @public
+	* @static
+	* @param {number} i - Specified maximum size of queue.
+    * @return number
+	*/
+	_io.queue.size = _size;
+
+   /**
+	* @description Method for setting the queue to "active". If there are
+	* transactions pending in the queue, they will be processed from the
+	* queue in FIFO order. This is the interface for _start().
+	*
+	* @method start
+	* @public
+	* @static
+    * @return void
+	*/
+	_io.queue.start = _start;
+
+   /**
+	* @description Method for setting queue processing to inactive.
+	* Transaction requests to YUI.io.queue() will be stored in the queue, but
+	* not processed until the queue is set to "active". This is the
+	* interface for _stop().
+	*
+	* @method stop
+	* @public
+	* @static
+    * @return void
+	*/
+	_io.queue.stop = _stop;
+
+   /**
+	* @description Method for promoting a transaction to the top of the queue.
+	* This is the interface for _unshift().
+	*
+	* @method promote
+	* @public
+	* @static
+	* @param {number} i - ID of queued transaction.
+    * @return void
+	*/
+	_io.queue.promote = _unshift;
+
+   /**
+	* @description Method for removing a specific, pending transaction from
+	* the queue. This is the interface for _purge().
+	*
+	* @method purge
+	* @public
+	* @static
+	* @param {number} i - ID of queued transaction.
+    * @return void
+	*/
+	_io.queue.purge = _purge;
+
+   /**
+	* @description Method for requesting a transaction. This
+	* is the interface for _io().
+	*
+	* @method io
+	* @public
+	* @static
+    * @param {string} uri - qualified path to transaction resource.
+    * @param {object} c - configuration object for the transaction.
+    * @return object
+    */
+	Y.io = _io;
+
+
+
+}, '3.0.0pr2' );
+
+YUI.add('io-form', function(Y) {
+
+   /*
+	* @module io-base
+	* @submodule io-form
+	*/
+
+    Y.mix(Y.io, {
+       /**
+        * @description Method to enumerate through an HTML form's elements collection
+        * and return a string comprised of key-value pairs.
+        *
+        * @method _serialize
+        * @private
+        * @static
+        * @param {object} f - HTML form object or id.
+        * @return string
+        */
+        _serialize: function(o) {
+            var f = (typeof o.id === 'object') ? o.id : Y.config.doc.getElementById(o.id),
+            eUC = encodeURIComponent,
+            data = [],
+            useDf = o.useDisabled || false,
+            item = 0,
+            e, n, v, d, i, ilen, j, jlen, o;
+
+            // Iterate over the form elements collection to construct the
+            // label-value pairs.
+            for (i = 0, ilen = f.elements.length; i < ilen; ++i) {
+                e = f.elements[i];
+                d = e.disabled;
+                n = e.name;
+
+                if ((useDf) ? n : (n && !d)) {
+                    n = encodeURIComponent(n) + '=';
+                    v = encodeURIComponent(e.value);
+
+                    switch (e.type) {
+                        // Safari, Opera, FF all default opt.value from .text if
+                        // value attribute not specified in markup
+                        case 'select-one':
+                            if (e.selectedIndex > -1) {
+                                o = e.options[e.selectedIndex];
+                                data[item++] = n + eUC((o.attributes.value && o.attributes.value.specified) ? o.value : o.text);
+                            }
+                            break;
+                        case 'select-multiple':
+                            if (e.selectedIndex > -1) {
+                                for (j = e.selectedIndex, jlen = e.options.length; j < jlen; ++j) {
+                                    o = e.options[j];
+                                    if (o.selected) {
+                                      data[item++] = n + eUC((o.attributes.value && opt.attributes.value.specified) ? o.value : o.text);
+                                    }
+                                }
+                            }
+                            break;
+                        case 'radio':
+                        case 'checkbox':
+                            if(e.checked){
+                                data[item++] = n + v;
+                            }
+                            break;
+                        case 'file':
+                            // stub case as XMLHttpRequest will only send the file path as a string.
+                        case undefined:
+                            // stub case for fieldset element which returns undefined.
+                        case 'reset':
+                            // stub case for input type reset button.
+                        case 'button':
+                            // stub case for input type button elements.
+                            break;
+                        case 'submit':
+                            break;
+                        default:
+                            data[item++] = n + v;
+                    }
+                }
+            }
+            Y.log('HTML form serialized. The value is: ' + data.join('&'), 'info', 'io');
+            return data.join('&');
+        }
+    }, true);
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});
+
+YUI.add('io-xdr', function(Y) {
+
+   /*
+	* @module io-base
+	* @submodule io-xdr
+	*/
+
+   /**
+	* @event io:xdrReady
+	* @description This event is fired by YUI.io when a transaction is initiated..
+	* @type Event Custom
+	*/
+	var E_XDR_READY = 'io:xdrReady';
+
+   /**
+	* @description Method that creates the Flash transport swf.
+	*
+	* @method _swf
+	* @private
+	* @static
+	* @param {string} uri - location of IO.swf.
+	* @param {string} yid - YUI instance id.
+	* @return void
+	*/
+	function swf(uri, yid) {
+		var XDR_SWF = '<object id="yuiSwfIo" type="application/x-shockwave-flash" data="' + uri + '" width="0" height="0">' +
+		     		  '<param name="movie" value="' + uri + '">' +
+		     		  '<param name="FlashVars" value="yid=' + yid + '">' +
+                      '<param name="allowScriptAccess" value="sameDomain">' +
+		    	      '</object>';
+		Y.get('body').appendChild(Y.Node.create(XDR_SWF))
+	};
+
+    Y.mix(Y.io, {
+
+	   /**
+		* @description Map of IO transports.
+		*
+		* @property _transport
+		* @private
+		* @static
+		* @type object
+		*/
+		_transport: {},
+
+	   /**
+		* @description Object that stores callback handlers for cross-domain requests
+		* when using Flash as the transport.
+		*
+		* @property _fn
+		* @private
+		* @static
+		* @type object
+		*/
+		_fn: {},
+
+		_xdr: function(uri, o, c){
+			if (c.on) {
+				this._fn[o.id] = c.on;
+			}
+			o.c.send(uri, c, o.id);
+
+			return o;
+		},
+
+	   /**
+		* @description Method to initialize the desired transport medium.
+		*
+		* @method transport
+		* @public
+		* @static
+		* @param {object} o - object of transport configurations.
+		* @return void
+		*/
+		transport: function(o) {
+			switch (o.id) {
+				case 'flash':
+					swf(o.src, o.yid);
+					this._transport.flash = Y.config.doc.getElementById('yuiSwfIo');
+					break;
+				case 'upload':
+					break;
+			}
+		},
+
+	   /**
+		* @description Fires event "io:xdrReady"
+		*
+		* @method xdrReady
+		* @private
+		* @static
+		* @param {number} id - transaction id
+		* @param {object} c - configuration object for the transaction.
+		*
+		* @return void
+		*/
+		xdrReady: function(id) {
+			Y.fire(E_XDR_READY, id);
+		}
+	});
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});
+
+
+
+YUI.add('io', function(Y){}, '3.0.0pr2' ,{use:['io-base', 'io-form', 'io-xdr']});
+

=== added file 'loggerhead/static/javascript/yui/build/io/io-form-debug.js'
--- loggerhead/static/javascript/yui/build/io/io-form-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-form-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,94 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-form', function(Y) {
+
+   /*
+    * Extends the IO base class to enable HTML form data serialization, when specified
+    * in the transaction's configuration object.
+	* @module io-base
+	* @submodule io-form
+	*/
+
+    Y.mix(Y.io, {
+       /**
+        * @description Method to enumerate through an HTML form's elements collection
+        * and return a string comprised of key-value pairs.
+        *
+        * @method _serialize
+        * @private
+        * @static
+        * @param {object} o - HTML form object or id.
+        * @return string
+        */
+        _serialize: function(o) {
+            var f = (typeof o.id === 'object') ? o.id : Y.config.doc.getElementById(o.id),
+            eUC = encodeURIComponent,
+            data = [],
+            useDf = o.useDisabled || false,
+            item = 0,
+            e, n, v, d, i, ilen, j, jlen, o;
+
+            // Iterate over the form elements collection to construct the
+            // label-value pairs.
+            for (i = 0, ilen = f.elements.length; i < ilen; ++i) {
+                e = f.elements[i];
+                d = e.disabled;
+                n = e.name;
+
+                if ((useDf) ? n : (n && !d)) {
+                    n = encodeURIComponent(n) + '=';
+                    v = encodeURIComponent(e.value);
+
+                    switch (e.type) {
+                        // Safari, Opera, FF all default opt.value from .text if
+                        // value attribute not specified in markup
+                        case 'select-one':
+                            if (e.selectedIndex > -1) {
+                                o = e.options[e.selectedIndex];
+                                data[item++] = n + eUC((o.attributes.value && o.attributes.value.specified) ? o.value : o.text);
+                            }
+                            break;
+                        case 'select-multiple':
+                            if (e.selectedIndex > -1) {
+                                for (j = e.selectedIndex, jlen = e.options.length; j < jlen; ++j) {
+                                    o = e.options[j];
+                                    if (o.selected) {
+                                      data[item++] = n + eUC((o.attributes.value && opt.attributes.value.specified) ? o.value : o.text);
+                                    }
+                                }
+                            }
+                            break;
+                        case 'radio':
+                        case 'checkbox':
+                            if(e.checked){
+                                data[item++] = n + v;
+                            }
+                            break;
+                        case 'file':
+                            // stub case as XMLHttpRequest will only send the file path as a string.
+                        case undefined:
+                            // stub case for fieldset element which returns undefined.
+                        case 'reset':
+                            // stub case for input type reset button.
+                        case 'button':
+                            // stub case for input type button elements.
+                            break;
+                        case 'submit':
+                            break;
+                        default:
+                            data[item++] = n + v;
+                    }
+                }
+            }
+            Y.log('HTML form serialized. The value is: ' + data.join('&'), 'info', 'io');
+            return data.join('&');
+        }
+    }, true);
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});

=== added file 'loggerhead/static/javascript/yui/build/io/io-form-min.js'
--- loggerhead/static/javascript/yui/build/io/io-form-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-form-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("io-form",function(A){A.mix(A.io,{_serialize:function(C){var I=(typeof C.id==="object")?C.id:A.config.doc.getElementById(C.id),H=encodeURIComponent,G=[],L=C.useDisabled||false,O=0,J,D,M,K,F,B,E,N,C;for(F=0,B=I.elements.length;F<B;++F){J=I.elements[F];K=J.disabled;D=J.name;if((L)?D:(D&&!K)){D=encodeURIComponent(D)+"=";M=encodeURIComponent(J.value);switch(J.type){case"select-one":if(J.selectedIndex>-1){C=J.options[J.selectedIndex];G[O++]=D+H((C.attributes.value&&C.attributes.value.specified)?C.value:C.text);}break;case"select-multiple":if(J.selectedIndex>-1){for(E=J.selectedIndex,N=J.options.length;E<N;++E){C=J.options[E];if(C.selected){G[O++]=D+H((C.attributes.value&&opt.attributes.value.specified)?C.value:C.text);}}}break;case"radio":case"checkbox":if(J.checked){G[O++]=D+M;}break;case"file":case undefined:case"reset":case"button":break;case"submit":break;default:G[O++]=D+M;}}}return G.join("&");}},true);},"3.0.0pr2",{requires:["io-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/io/io-form.js'
--- loggerhead/static/javascript/yui/build/io/io-form.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-form.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,93 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-form', function(Y) {
+
+   /*
+    * Extends the IO base class to enable HTML form data serialization, when specified
+    * in the transaction's configuration object.
+	* @module io-base
+	* @submodule io-form
+	*/
+
+    Y.mix(Y.io, {
+       /**
+        * @description Method to enumerate through an HTML form's elements collection
+        * and return a string comprised of key-value pairs.
+        *
+        * @method _serialize
+        * @private
+        * @static
+        * @param {object} o - HTML form object or id.
+        * @return string
+        */
+        _serialize: function(o) {
+            var f = (typeof o.id === 'object') ? o.id : Y.config.doc.getElementById(o.id),
+            eUC = encodeURIComponent,
+            data = [],
+            useDf = o.useDisabled || false,
+            item = 0,
+            e, n, v, d, i, ilen, j, jlen, o;
+
+            // Iterate over the form elements collection to construct the
+            // label-value pairs.
+            for (i = 0, ilen = f.elements.length; i < ilen; ++i) {
+                e = f.elements[i];
+                d = e.disabled;
+                n = e.name;
+
+                if ((useDf) ? n : (n && !d)) {
+                    n = encodeURIComponent(n) + '=';
+                    v = encodeURIComponent(e.value);
+
+                    switch (e.type) {
+                        // Safari, Opera, FF all default opt.value from .text if
+                        // value attribute not specified in markup
+                        case 'select-one':
+                            if (e.selectedIndex > -1) {
+                                o = e.options[e.selectedIndex];
+                                data[item++] = n + eUC((o.attributes.value && o.attributes.value.specified) ? o.value : o.text);
+                            }
+                            break;
+                        case 'select-multiple':
+                            if (e.selectedIndex > -1) {
+                                for (j = e.selectedIndex, jlen = e.options.length; j < jlen; ++j) {
+                                    o = e.options[j];
+                                    if (o.selected) {
+                                      data[item++] = n + eUC((o.attributes.value && opt.attributes.value.specified) ? o.value : o.text);
+                                    }
+                                }
+                            }
+                            break;
+                        case 'radio':
+                        case 'checkbox':
+                            if(e.checked){
+                                data[item++] = n + v;
+                            }
+                            break;
+                        case 'file':
+                            // stub case as XMLHttpRequest will only send the file path as a string.
+                        case undefined:
+                            // stub case for fieldset element which returns undefined.
+                        case 'reset':
+                            // stub case for input type reset button.
+                        case 'button':
+                            // stub case for input type button elements.
+                            break;
+                        case 'submit':
+                            break;
+                        default:
+                            data[item++] = n + v;
+                    }
+                }
+            }
+            return data.join('&');
+        }
+    }, true);
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});

=== added file 'loggerhead/static/javascript/yui/build/io/io-min.js'
--- loggerhead/static/javascript/yui/build/io/io-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("io-base",function(D){E_START="io:start",E_COMPLETE="io:complete",E_SUCCESS="io:success",E_FAILURE="io:failure",E_ABORT="io:abort",transactionId=0,_headers={"X-Requested-With":"XMLHttpRequest"},_timeout={},_q=[],_qState=1,_qMaxSize=false,w=D.config.win;function J(Y,e){if(_qMaxSize===false||_q.length<_qMaxSize){var d=F();_q.push({uri:Y,id:d,cfg:e});}else{return false;}if(_qState===1){N();}return d;}function G(f){var d;for(var Y=0;Y<_q.length;Y++){if(_q[Y].id===f){d=_q.splice(Y,1);var e=_q.unshift(d[0]);break;}}}function N(){var Y=_q.shift();b(Y.uri,Y.cfg,Y.id);}function H(Y){if(Y){_qMaxSize=Y;return Y;}else{return _q.length;}}function V(){var Y=(_q.length>_qMaxSize>0)?_qMaxSize:_q.length;if(Y>1){for(var d=0;d<Y;d++){N();}}else{N();}}function K(){_qState=0;}function C(d){if(D.Lang.isNumber(d)){for(var Y=0;Y<_q.length;Y++){if(_q[Y].id===d){_q.splice(Y,1);break;}}}}function b(g,l){var l=l||{},k=Z((arguments.length===3)?arguments[2]:null,l),Y=(l.method)?l.method.toUpperCase():"GET",j=(l.data)?l.data:null,h;if(l.form){if(l.form.upload){u=D.io._upload(k,g,l);return u;}h=D.io._serialize(l.form);if(j){h+="&"+j;}if(Y==="POST"){j=h;X("Content-Type","application/x-www-form-urlencoded");}else{if(Y==="GET"){g=Q(g,h);}}}else{if(j&&Y==="GET"){g=Q(g,l.data);}else{if(j&&Y==="POST"){X("Content-Type","application/x-www-form-urlencoded; charset=UTF-8");}}}if(l.xdr){D.io._xdr(g,k,l);return k;}if(l.timeout){R(k,l);}k.c.onreadystatechange=function(){c(k,l);};try{E(k.c,Y,g);}catch(i){}B(k.c,(l.headers||{}));k.abort=function(){S(k,l);};k.isInProgress=function(){return k.c.readyState!==4&&k.c.readyState!==0;};W(k,(j||""),l);return k;}function A(d,f){var Y=new D.Event.Target().publish("transaction:"+d);Y.subscribe(f.on[d],(f.context||this),f.arguments);return Y;}function T(g,f){f.on=f.on||{};var Y=D.io._fn||{},d=(Y&&Y[g])?Y[g]:null,e;if(d){f.on.start=d.start;delete d;}D.fire(E_START,g);if(f.on.start){e=A("start",f);e.fire(g);}}function I(d,e){e.on=e.on||{};var Y;D.fire(E_COMPLETE,d.id,d.c);if(e.on.complete){Y=A("complete",e);Y.fire(d.id,d.c);}}function U(f,g){g.on=g.on||{};var Y=D.io._fn||{},d=(Y&&Y[f.id])?Y[f.id]:null,e;if(d){g.on.success=d.success;delete d;f.c.responseText=decodeURI(f.c.responseText);}D.fire(E_SUCCESS,f.id,f.c);if(g.on.success){e=A("success",g);e.fire(f.id,f.c);}L(f,(g.xdr)?true:false);}function M(f,g){g.on=g.on||{};var Y=D.io._fn||{},d=(Y&&Y[f.id])?Y[f.id]:null,e;if(d){g.on.failure=d.failure;delete d;f.c.responseText=decodeURI(f.c.responseText);}D.fire(E_FAILURE,f.id,f.c);if(g.on.failure){e=A("failure",g);e.fire(f.id,f.c);}L(f,(g.xdr)?true:false);}function S(f,g){g.on=g.on||{};var Y=D.io._fn||{},d=(Y&&Y[f.id])?Y[f.id]:null,e;if(f&&f.c&&!g.xdr){f.c.abort();if(g){if(g.timeout){P(f.id);}}}if(d){g.on.abort=d.abort;delete d;}D.fire(E_ABORT,f.id);if(g.on.abort){e=A("abort",g);e.fire(id);}L(f,(g.xdr)?true:false);}function F(){var Y=transactionId;transactionId++;return Y;}function Z(Y,e){var d={};d.id=D.Lang.isNumber(Y)?Y:F();if(e.xdr){d.c=D.io._transport[e.xdr.use];}else{if(e.form&&e.form.upload){d.c={};}else{d.c=O();}}return d;}function O(){return(w.XMLHttpRequest)?new XMLHttpRequest():new ActiveXObject("Microsoft.XMLHTTP");}function Q(Y,e){Y+=((Y.indexOf("?")==-1)?"?":"&")+e;return Y;}function X(Y,d){if(d){_headers[Y]=d;}else{delete _headers[Y];}}function B(e,Y){var d;for(d in _headers){if(_headers.hasOwnProperty(d)){Y[d]=_headers[d];}}for(d in Y){if(Y.hasOwnProperty(d)){e.setRequestHeader(d,Y[d]);}}}function E(e,Y,d){e.open(Y,d,true);}function W(e,Y,f){e.c.send(Y);T(e.id,f);}function R(Y,d){_timeout[Y.id]=w.setTimeout(function(){S(Y,d);},d.timeout);}function P(Y){w.clearTimeout(_timeout[Y]);delete _timeout[Y];}function c(Y,d){if(Y.c.readyState===4){if(d.timeout){P(Y.id);}I(Y,d);a(Y,d);}}function a(f,g){var Y;try{if(f.c.status&&f.c.status!==0){Y=f.c.status;}else{Y=0;}}catch(d){Y=0;}if(Y>=200&&Y<300||Y===1223){w.setTimeout(function(){U(f,g);},0);}else{w.setTimeout(function(){M(f,g);},0);}}function L(d,Y){if(w.XMLHttpRequest&&!Y){if(d.c){d.c.onreadystatechange=null;}}d.c=null;d=null;}b.start=T;b.complete=I;b.success=U;b.failure=M;b.abort=S;b.timeout=_timeout;b.header=X;b.queue=J;b.queue.size=H;b.queue.start=V;b.queue.stop=K;b.queue.promote=G;b.queue.purge=C;D.io=b;},"3.0.0pr2");YUI.add("io-form",function(A){A.mix(A.io,{_serialize:function(C){var I=(typeof C.id==="object")?C.id:A.config.doc.getElementById(C.id),H=encodeURIComponent,G=[],L=C.useDisabled||false,O=0,J,D,M,K,F,B,E,N,C;for(F=0,B=I.elements.length;F<B;++F){J=I.elements[F];K=J.disabled;D=J.name;if((L)?D:(D&&!K)){D=encodeURIComponent(D)+"=";M=encodeURIComponent(J.value);switch(J.type){case"select-one":if(J.selectedIndex>-1){C=J.options[J.selectedIndex];G[O++]=D+H((C.attributes.value&&C.attributes.value.specified)?C.value:C.text);}break;case"select-multiple":if(J.selectedIndex>-1){for(E=J.selectedIndex,N=J.options.length;E<N;++E){C=J.options[E];if(C.selected){G[O++]=D+H((C.attributes.value&&opt.attributes.value.specified)?C.value:C.text);}}}break;case"radio":case"checkbox":if(J.checked){G[O++]=D+M;}break;case"file":case undefined:case"reset":case"button":break;case"submit":break;default:G[O++]=D+M;}}}return G.join("&");}},true);},"3.0.0pr2",{requires:["io-base"]});YUI.add("io-xdr",function(C){var A="io:xdrReady";function B(E,F){var D='<object id="yuiSwfIo" type="application/x-shockwave-flash" data="'+E+'" width="0" height="0">'+'<param name="movie" value="'+E+'">'+'<param name="FlashVars" value="yid='+F+'">'+'<param name="allowScriptAccess" value="sameDomain">'+"</object>";C.get("body").appendChild(C.Node.create(D));}C.mix(C.io,{_transport:{},_fn:{},_xdr:function(D,E,F){if(F.on){this._fn[E.id]=F.on;}E.c.send(D,F,E.id);return E;},transport:function(D){switch(D.id){case"flash":B(D.src,D.yid);this._transport.flash=C.config.doc.getElementById("yuiSwfIo");break;case"upload":break;}},xdrReady:function(D){C.fire(A,D);}});},"3.0.0pr2",{requires:["io-base"]});YUI.add("io",function(A){},"3.0.0pr2",{use:["io-base","io-form","io-xdr"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/io/io-queue-debug.js'
--- loggerhead/static/javascript/yui/build/io/io-queue-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-queue-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,262 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-queue', function(Y) {
+
+   /*
+    * Extends the IO base class to include basic queue interfaces for transaction
+    * queuing.
+	* @module io-base
+	* @submodule io-queue
+	*/
+
+   /**
+	* @description Array of transactions queued for processing
+	*
+	* @property _q
+	* @private
+	* @static
+	* @type array
+	*/
+	var _q = [],
+
+   /**
+	* @description Property to determine whether the queue is set to
+	* 1 (active) or 0 (inactive).  When inactive, transactions
+	* will be stored in the queue until the queue is set to active.
+	*
+	* @property _qState
+	* @private
+	* @static
+	* @type int
+	*/
+	_qState = 1,
+
+   /**
+	* @description Queue property to set a maximum queue storage size.  When
+	* this property is set, the queue will not store any more transactions
+	* until the queue size os reduced below this threshold. There is no
+	* maximum queue size until it is explicitly set.
+	*
+	* @property _qMaxSize
+	* @private
+	* @static
+	* @type int
+	*/
+	_qMaxSize = false;
+
+   /**
+	* @description Method for requesting a transaction, and queueing the
+	* request before it is sent to the resource.
+	*
+	* @method _queue
+	* @private
+	* @static
+	* @return int
+	*/
+	function _queue(uri, c) {
+
+		if (_qMaxSize === false || _q.length < _qMaxSize) {
+			var id = Y.io._id();
+			_q.push({ uri: uri, id: id, cfg:c });
+		}
+		else {
+			Y.log('Unable to queue transaction object.  Maximum queue size reached.', 'warn', 'io');
+			return false;
+		}
+
+		if (_qState === 1) {
+			_shift();
+		}
+
+		Y.log('Object queued.  Transaction id is' + id, 'info', 'io');
+		return id;
+	};
+
+   /**
+	* @description Method for promoting a transaction to the top of the queue.
+	*
+	* @method _unshift
+	* @private
+	* @static
+	* @return void
+	*/
+	function _unshift(id) {
+		var r;
+
+		for (var i = 0; i < _q.length; i++) {
+			if (_q[i].id === id) {
+				r = _q.splice(i, 1);
+				var p = _q.unshift(r[0]);
+				Y.log('Object promoted to top of queue.  Transaction id is' + id, 'info', 'io');
+				break;
+			}
+		}
+	};
+
+   /**
+	* @description Method for removing a transaction from the top of the
+	* queue, and sending the transaction to _io().
+	*
+	* @method _shift
+	* @private
+	* @static
+	* @return void
+	*/
+	function _shift() {
+		var c = _q.shift();
+		Y.io(c.uri, c.cfg, c.id);
+	};
+
+   /**
+	* @description Method to query the current size of the queue, or to
+	* set a maximum queue size.
+	*
+	* @method _size
+	* @private
+	* @static
+	* @return int
+	*/
+	function _size(i) {
+		if (i) {
+			_qMaxSize = i;
+			Y.log('Queue size set to ' + i, 'info', 'io');
+			return i;
+		}
+		else {
+			return _q.length;
+		}
+	};
+
+   /**
+	* @description Method for setting the queue to active. If there are
+	* transactions pending in the queue, they will be processed from the
+	* queue in FIFO order.
+	*
+	* @method _start
+	* @private
+	* @static
+	* @return void
+	*/
+	function _start() {
+		var len = (_q.length > _qMaxSize > 0) ? _qMaxSize : _q.length;
+
+		if (len > 1) {
+			for (var i=0; i < len; i++) {
+				_shift();
+			}
+		}
+		else {
+			_shift();
+		}
+
+		Y.log('Queue started.', 'info', 'io');
+	};
+
+   /**
+	* @description Method for setting queue processing to inactive.
+	* Transaction requests to YUI.io.queue() will be stored in the queue, but
+	* not processed until the queue is reset to "active".
+	*
+	* @method _stop
+	* @private
+	* @static
+	* @return void
+	*/
+	function _stop() {
+		_qState = 0;
+		Y.log('Queue stopped.', 'info', 'io');
+	};
+
+   /**
+	* @description Method for removing a specific, pending transaction from
+	* the queue.
+	*
+	* @method _purge
+	* @private
+	* @static
+	* @return void
+	*/
+	function _purge(id) {
+		if (Y.Lang.isNumber(id)) {
+			for (var i = 0; i < _q.length; i++) {
+				if (_q[i].id === id) {
+					_q.splice(i, 1);
+					Y.log('Object purged from queue.  Transaction id is' + id, 'info', 'io');
+					break;
+				}
+			}
+		}
+	};
+
+   /**
+	* @description Method to query the current size of the queue, or to
+	* set a maximum queue size.  This is the interface for _size().
+	*
+	* @method size
+	* @public
+	* @static
+	* @param {number} i - Specified maximum size of queue.
+    * @return number
+	*/
+	_queue.size = _size;
+
+   /**
+	* @description Method for setting the queue to "active". If there are
+	* transactions pending in the queue, they will be processed from the
+	* queue in FIFO order. This is the interface for _start().
+	*
+	* @method start
+	* @public
+	* @static
+    * @return void
+	*/
+	_queue.start = _start;
+
+   /**
+	* @description Method for setting queue processing to inactive.
+	* Transaction requests to YUI.io.queue() will be stored in the queue, but
+	* not processed until the queue is set to "active". This is the
+	* interface for _stop().
+	*
+	* @method stop
+	* @public
+	* @static
+    * @return void
+	*/
+	_queue.stop = _stop;
+
+   /**
+	* @description Method for promoting a transaction to the top of the queue.
+	* This is the interface for _unshift().
+	*
+	* @method promote
+	* @public
+	* @static
+	* @param {number} i - ID of queued transaction.
+    * @return void
+	*/
+	_queue.promote = _unshift;
+
+   /**
+	* @description Method for removing a specific, pending transaction from
+	* the queue. This is the interface for _purge().
+	*
+	* @method purge
+	* @public
+	* @static
+	* @param {number} i - ID of queued transaction.
+    * @return void
+	*/
+	_queue.purge = _purge;
+
+    Y.mix(Y.io, {
+		queue: _queue,
+    }, true);
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});

=== added file 'loggerhead/static/javascript/yui/build/io/io-queue-min.js'
--- loggerhead/static/javascript/yui/build/io/io-queue-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-queue-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("io-queue",function(B){var A=[],K=1,C=false;function I(L,N){if(C===false||A.length<C){var M=B.io._id();A.push({uri:L,id:M,cfg:N});}else{return false;}if(K===1){F();}return M;}function D(O){var M;for(var L=0;L<A.length;L++){if(A[L].id===O){M=A.splice(L,1);var N=A.unshift(M[0]);break;}}}function F(){var L=A.shift();B.io(L.uri,L.cfg,L.id);}function J(L){if(L){C=L;return L;}else{return A.length;}}function E(){var L=(A.length>C>0)?C:A.length;if(L>1){for(var M=0;M<L;M++){F();}}else{F();}}function H(){K=0;}function G(M){if(B.Lang.isNumber(M)){for(var L=0;L<A.length;L++){if(A[L].id===M){A.splice(L,1);break;}}}}I.size=J;I.start=E;I.stop=H;I.promote=D;I.purge=G;B.mix(B.io,{queue:I,},true);},"3.0.0pr2",{requires:["io-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/io/io-queue.js'
--- loggerhead/static/javascript/yui/build/io/io-queue.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-queue.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,255 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-queue', function(Y) {
+
+   /*
+    * Extends the IO base class to include basic queue interfaces for transaction
+    * queuing.
+	* @module io-base
+	* @submodule io-queue
+	*/
+
+   /**
+	* @description Array of transactions queued for processing
+	*
+	* @property _q
+	* @private
+	* @static
+	* @type array
+	*/
+	var _q = [],
+
+   /**
+	* @description Property to determine whether the queue is set to
+	* 1 (active) or 0 (inactive).  When inactive, transactions
+	* will be stored in the queue until the queue is set to active.
+	*
+	* @property _qState
+	* @private
+	* @static
+	* @type int
+	*/
+	_qState = 1,
+
+   /**
+	* @description Queue property to set a maximum queue storage size.  When
+	* this property is set, the queue will not store any more transactions
+	* until the queue size os reduced below this threshold. There is no
+	* maximum queue size until it is explicitly set.
+	*
+	* @property _qMaxSize
+	* @private
+	* @static
+	* @type int
+	*/
+	_qMaxSize = false;
+
+   /**
+	* @description Method for requesting a transaction, and queueing the
+	* request before it is sent to the resource.
+	*
+	* @method _queue
+	* @private
+	* @static
+	* @return int
+	*/
+	function _queue(uri, c) {
+
+		if (_qMaxSize === false || _q.length < _qMaxSize) {
+			var id = Y.io._id();
+			_q.push({ uri: uri, id: id, cfg:c });
+		}
+		else {
+			return false;
+		}
+
+		if (_qState === 1) {
+			_shift();
+		}
+
+		return id;
+	};
+
+   /**
+	* @description Method for promoting a transaction to the top of the queue.
+	*
+	* @method _unshift
+	* @private
+	* @static
+	* @return void
+	*/
+	function _unshift(id) {
+		var r;
+
+		for (var i = 0; i < _q.length; i++) {
+			if (_q[i].id === id) {
+				r = _q.splice(i, 1);
+				var p = _q.unshift(r[0]);
+				break;
+			}
+		}
+	};
+
+   /**
+	* @description Method for removing a transaction from the top of the
+	* queue, and sending the transaction to _io().
+	*
+	* @method _shift
+	* @private
+	* @static
+	* @return void
+	*/
+	function _shift() {
+		var c = _q.shift();
+		Y.io(c.uri, c.cfg, c.id);
+	};
+
+   /**
+	* @description Method to query the current size of the queue, or to
+	* set a maximum queue size.
+	*
+	* @method _size
+	* @private
+	* @static
+	* @return int
+	*/
+	function _size(i) {
+		if (i) {
+			_qMaxSize = i;
+			return i;
+		}
+		else {
+			return _q.length;
+		}
+	};
+
+   /**
+	* @description Method for setting the queue to active. If there are
+	* transactions pending in the queue, they will be processed from the
+	* queue in FIFO order.
+	*
+	* @method _start
+	* @private
+	* @static
+	* @return void
+	*/
+	function _start() {
+		var len = (_q.length > _qMaxSize > 0) ? _qMaxSize : _q.length;
+
+		if (len > 1) {
+			for (var i=0; i < len; i++) {
+				_shift();
+			}
+		}
+		else {
+			_shift();
+		}
+
+	};
+
+   /**
+	* @description Method for setting queue processing to inactive.
+	* Transaction requests to YUI.io.queue() will be stored in the queue, but
+	* not processed until the queue is reset to "active".
+	*
+	* @method _stop
+	* @private
+	* @static
+	* @return void
+	*/
+	function _stop() {
+		_qState = 0;
+	};
+
+   /**
+	* @description Method for removing a specific, pending transaction from
+	* the queue.
+	*
+	* @method _purge
+	* @private
+	* @static
+	* @return void
+	*/
+	function _purge(id) {
+		if (Y.Lang.isNumber(id)) {
+			for (var i = 0; i < _q.length; i++) {
+				if (_q[i].id === id) {
+					_q.splice(i, 1);
+					break;
+				}
+			}
+		}
+	};
+
+   /**
+	* @description Method to query the current size of the queue, or to
+	* set a maximum queue size.  This is the interface for _size().
+	*
+	* @method size
+	* @public
+	* @static
+	* @param {number} i - Specified maximum size of queue.
+    * @return number
+	*/
+	_queue.size = _size;
+
+   /**
+	* @description Method for setting the queue to "active". If there are
+	* transactions pending in the queue, they will be processed from the
+	* queue in FIFO order. This is the interface for _start().
+	*
+	* @method start
+	* @public
+	* @static
+    * @return void
+	*/
+	_queue.start = _start;
+
+   /**
+	* @description Method for setting queue processing to inactive.
+	* Transaction requests to YUI.io.queue() will be stored in the queue, but
+	* not processed until the queue is set to "active". This is the
+	* interface for _stop().
+	*
+	* @method stop
+	* @public
+	* @static
+    * @return void
+	*/
+	_queue.stop = _stop;
+
+   /**
+	* @description Method for promoting a transaction to the top of the queue.
+	* This is the interface for _unshift().
+	*
+	* @method promote
+	* @public
+	* @static
+	* @param {number} i - ID of queued transaction.
+    * @return void
+	*/
+	_queue.promote = _unshift;
+
+   /**
+	* @description Method for removing a specific, pending transaction from
+	* the queue. This is the interface for _purge().
+	*
+	* @method purge
+	* @public
+	* @static
+	* @param {number} i - ID of queued transaction.
+    * @return void
+	*/
+	_queue.purge = _purge;
+
+    Y.mix(Y.io, {
+		queue: _queue,
+    }, true);
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});

=== added file 'loggerhead/static/javascript/yui/build/io/io-upload-iframe-debug.js'
--- loggerhead/static/javascript/yui/build/io/io-upload-iframe-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-upload-iframe-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,191 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-upload-iframe', function(Y) {
+
+   /*
+   	* Extends the IO base class to enable file uploads, with HTML forms,
+   	* using an iframe as the transport medium.
+	* @module io-base
+	* @submodule io-upload-iframe
+	*/
+
+	var w = Y.config.win;
+   /**
+	* @description Parses the POST data object and creates hidden form elements
+	* for each key-value, and appends them to the HTML form object.
+	* @method appendData
+	* @private
+	* @static
+	* @param {object} d The key-value hash map.
+	* @return {array} e Array of created fields.
+	*/
+
+	function _addData(f, d) {
+		var e = [], i;
+		for (p in d) {
+			if (d.hasOwnProperty(d, p)) {
+				e[i] = document.createElement('input');
+				e[i].type = 'hidden';
+				e[i].name = p;
+				e[i].value = d[p].
+				f.appendChild(e[i]);
+			}
+		}
+
+		return e;
+	};
+
+	function _removeData(f, e) {
+		var i, l;
+		if (e && e.length > 0) {
+			for(i = 0, l = e.length; i < l; i++){
+				f.removeChild(e[i]);
+			}
+		}
+	};
+
+	function _create(o, c) {
+		var UPLOAD_IFRAME = '<iframe id="ioupload' + o.id + '" name="ioupload' + o.id + '" />',
+		cfg = {
+			position: 'absolute',
+			top: '-1000',
+			left: '-1000'
+		},
+		i = Y.Node.create(UPLOAD_IFRAME);
+		i.setStyles(cfg);
+
+		Y.get('body').appendChild(i);
+
+		// Bind the onload handler to the iframe to detect the file upload response.
+		Y.on("load", function() { _handle(o, c) }, '#ioupload' + o.id);
+	};
+
+	// Create the upload callback handler that fires when the iframe
+	// receives the load event.  Subsequently, the event handler is detached
+	// and the iframe removed from the document.
+	function _handle(o, c) {
+
+		if (c.timeout) {
+			_clearTimeout(o.id);
+		}
+
+		var p, d = Y.get('#ioupload' + o.id).get('contentWindow.document'),
+			d = Y.get('#ioupload' + o.id).get('contentWindow'),
+		b = d.get('body');
+
+		if (b) {
+			p = b.getElementsByTagName('pre');
+			o.c.responseText = (p) ? p.item(0).get('innerHTML') : b.get('innerHTML');
+		}
+
+		Y.io.complete(o, c);
+
+		setTimeout( function() { _destroy(o.id); }, 100);
+	};
+
+   /**
+	* @description Starts timeout count if the configuration object
+	* has a defined timeout property.
+	*
+	* @method _startTimeout
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _startTimeout(o, c) {
+		Y.io._timeout[o.id] = w.setTimeout(function() { Y.io.abort(o, c); }, c.timeout);
+	};
+
+   /**
+	* @description Clears the timeout interval started by _startTimeout().
+	*
+	* @method _clearTimeout
+	* @private
+	* @static
+    * @param {number} id - Transaction id.
+    * @return void
+	*/
+	function _clearTimeout(id) {
+		w.clearTimeout(Y.io._timeout[id]);
+		delete Y.io._timeout[id];
+	};
+
+	function _destroy(id) {
+		Y.Event.purgeElement('#ioupload' + id, false, "load");
+		Y.get('body').removeChild(Y.get('#ioupload' + id));
+	};
+
+	Y.mix(Y.io, {
+
+	   /**
+		* @description Uploads HTML form, inclusive of files/attachments, using the
+		* iframe created in createFrame to facilitate the transaction.
+		* @method _upload
+		* @private
+		* @static
+		* @param {o} o The transaction object
+		* @param {object} uri Qualified path to transaction resource.
+		* @param {object} c - configuration object for the transaction.
+		* @return {void}
+		*/
+		_upload: function(o, uri, c) {
+			var f = (typeof c.form.id === 'string') ? document.getElementById(c.form.id) : c.form.id,
+			e, fields, i, p, attr;
+
+			_create(o, c);
+			// Track original HTML form attribute values.
+			attr = {
+				action: f.getAttribute('action'),
+				target: f.getAttribute('target')
+			};
+
+			// Initialize the HTML form properties in case they are
+			// not defined in the HTML form.
+			f.setAttribute('action', uri);
+			f.setAttribute('method', 'POST');
+			f.setAttribute('target', 'ioupload' + o.id );
+			f.setAttribute((Y.UA.ie) ? 'encoding' : 'enctype', 'multipart/form-data');
+
+			if (c.data) {
+				fields = _addData(f, c.data);
+			}
+
+			// Start polling if a callback is present and the timeout
+			// property has been defined.
+			if (c.timeout) {
+				_startTimeout(o, c);
+			}
+
+			// Start file upload.
+			f.submit();
+
+			Y.io.start(o.id, c);
+
+			if (c.data) {
+				_removeData(f, fields);
+			}
+
+			// Restore HTML form attributes to their original
+			// values prior to file upload.
+			for (p in attr) {
+				if (attr.hasOwnProperty(attr, p)) {
+					if (attr[p]) {
+				  		f.setAttribute(p, f[prop]);
+					}
+					else {
+				  		f.removeAttribute(p);
+					}
+			  	}
+			}
+		}
+	});
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});

=== added file 'loggerhead/static/javascript/yui/build/io/io-upload-iframe-min.js'
--- loggerhead/static/javascript/yui/build/io/io-upload-iframe-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-upload-iframe-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("io-upload-iframe",function(B){var H=B.config.win;function D(K,M){var L=[],J;for(p in M){if(M.hasOwnProperty(M,p)){L[J]=document.createElement("input");L[J].type="hidden";L[J].name=p;L[J].value=M[p].f.appendChild(L[J]);}}return L;}function E(L,M){var K,J;if(M&&M.length>0){for(K=0,J=M.length;K<J;K++){L.removeChild(M[K]);}}}function I(M,N){var K='<iframe id="ioupload'+M.id+'" name="ioupload'+M.id+'" />',J={position:"absolute",top:"-1000",left:"-1000"},L=B.Node.create(K);L.setStyles(J);B.get("body").appendChild(L);B.on("load",function(){A(M,N);},"#ioupload"+M.id);}function A(M,N){if(N.timeout){G(M.id);}var K,L=B.get("#ioupload"+M.id).get("contentWindow.document"),L=B.get("#ioupload"+M.id).get("contentWindow"),J=L.get("body");if(J){K=J.getElementsByTagName("pre");M.c.responseText=(K)?K.item(0).get("innerHTML"):J.get("innerHTML");}B.io.complete(M,N);setTimeout(function(){F(M.id);},100);}function C(J,K){B.io._timeout[J.id]=H.setTimeout(function(){B.io.abort(J,K);},K.timeout);}function G(J){H.clearTimeout(B.io._timeout[J]);delete B.io._timeout[J];}function F(J){B.Event.purgeElement("#ioupload"+J,false,"load");B.get("body").removeChild(B.get("#ioupload"+J));}B.mix(B.io,{_upload:function(K,L,R){var O=(typeof R.form.id==="string")?document.getElementById(R.form.id):R.form.id,Q,N,M,J,P;I(K,R);P={action:O.getAttribute("action"),target:O.getAttribute("target")};O.setAttribute("action",L);O.setAttribute("method","POST");O.setAttribute("target","ioupload"+K.id);O.setAttribute((B.UA.ie)?"encoding":"enctype","multipart/form-data");if(R.data){N=D(O,R.data);}if(R.timeout){C(K,R);}O.submit();B.io.start(K.id,R);if(R.data){E(O,N);}for(J in P){if(P.hasOwnProperty(P,J)){if(P[J]){O.setAttribute(J,O[prop]);}else{O.removeAttribute(J);}}}}});},"3.0.0pr2",{requires:["io-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/io/io-upload-iframe.js'
--- loggerhead/static/javascript/yui/build/io/io-upload-iframe.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-upload-iframe.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,191 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-upload-iframe', function(Y) {
+
+   /*
+   	* Extends the IO base class to enable file uploads, with HTML forms,
+   	* using an iframe as the transport medium.
+	* @module io-base
+	* @submodule io-upload-iframe
+	*/
+
+	var w = Y.config.win;
+   /**
+	* @description Parses the POST data object and creates hidden form elements
+	* for each key-value, and appends them to the HTML form object.
+	* @method appendData
+	* @private
+	* @static
+	* @param {object} d The key-value hash map.
+	* @return {array} e Array of created fields.
+	*/
+
+	function _addData(f, d) {
+		var e = [], i;
+		for (p in d) {
+			if (d.hasOwnProperty(d, p)) {
+				e[i] = document.createElement('input');
+				e[i].type = 'hidden';
+				e[i].name = p;
+				e[i].value = d[p].
+				f.appendChild(e[i]);
+			}
+		}
+
+		return e;
+	};
+
+	function _removeData(f, e) {
+		var i, l;
+		if (e && e.length > 0) {
+			for(i = 0, l = e.length; i < l; i++){
+				f.removeChild(e[i]);
+			}
+		}
+	};
+
+	function _create(o, c) {
+		var UPLOAD_IFRAME = '<iframe id="ioupload' + o.id + '" name="ioupload' + o.id + '" />',
+		cfg = {
+			position: 'absolute',
+			top: '-1000',
+			left: '-1000'
+		},
+		i = Y.Node.create(UPLOAD_IFRAME);
+		i.setStyles(cfg);
+
+		Y.get('body').appendChild(i);
+
+		// Bind the onload handler to the iframe to detect the file upload response.
+		Y.on("load", function() { _handle(o, c) }, '#ioupload' + o.id);
+	};
+
+	// Create the upload callback handler that fires when the iframe
+	// receives the load event.  Subsequently, the event handler is detached
+	// and the iframe removed from the document.
+	function _handle(o, c) {
+
+		if (c.timeout) {
+			_clearTimeout(o.id);
+		}
+
+		var p, d = Y.get('#ioupload' + o.id).get('contentWindow.document'),
+			d = Y.get('#ioupload' + o.id).get('contentWindow'),
+		b = d.get('body');
+
+		if (b) {
+			p = b.getElementsByTagName('pre');
+			o.c.responseText = (p) ? p.item(0).get('innerHTML') : b.get('innerHTML');
+		}
+
+		Y.io.complete(o, c);
+
+		setTimeout( function() { _destroy(o.id); }, 100);
+	};
+
+   /**
+	* @description Starts timeout count if the configuration object
+	* has a defined timeout property.
+	*
+	* @method _startTimeout
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _startTimeout(o, c) {
+		Y.io._timeout[o.id] = w.setTimeout(function() { Y.io.abort(o, c); }, c.timeout);
+	};
+
+   /**
+	* @description Clears the timeout interval started by _startTimeout().
+	*
+	* @method _clearTimeout
+	* @private
+	* @static
+    * @param {number} id - Transaction id.
+    * @return void
+	*/
+	function _clearTimeout(id) {
+		w.clearTimeout(Y.io._timeout[id]);
+		delete Y.io._timeout[id];
+	};
+
+	function _destroy(id) {
+		Y.Event.purgeElement('#ioupload' + id, false, "load");
+		Y.get('body').removeChild(Y.get('#ioupload' + id));
+	};
+
+	Y.mix(Y.io, {
+
+	   /**
+		* @description Uploads HTML form, inclusive of files/attachments, using the
+		* iframe created in createFrame to facilitate the transaction.
+		* @method _upload
+		* @private
+		* @static
+		* @param {o} o The transaction object
+		* @param {object} uri Qualified path to transaction resource.
+		* @param {object} c - configuration object for the transaction.
+		* @return {void}
+		*/
+		_upload: function(o, uri, c) {
+			var f = (typeof c.form.id === 'string') ? document.getElementById(c.form.id) : c.form.id,
+			e, fields, i, p, attr;
+
+			_create(o, c);
+			// Track original HTML form attribute values.
+			attr = {
+				action: f.getAttribute('action'),
+				target: f.getAttribute('target')
+			};
+
+			// Initialize the HTML form properties in case they are
+			// not defined in the HTML form.
+			f.setAttribute('action', uri);
+			f.setAttribute('method', 'POST');
+			f.setAttribute('target', 'ioupload' + o.id );
+			f.setAttribute((Y.UA.ie) ? 'encoding' : 'enctype', 'multipart/form-data');
+
+			if (c.data) {
+				fields = _addData(f, c.data);
+			}
+
+			// Start polling if a callback is present and the timeout
+			// property has been defined.
+			if (c.timeout) {
+				_startTimeout(o, c);
+			}
+
+			// Start file upload.
+			f.submit();
+
+			Y.io.start(o.id, c);
+
+			if (c.data) {
+				_removeData(f, fields);
+			}
+
+			// Restore HTML form attributes to their original
+			// values prior to file upload.
+			for (p in attr) {
+				if (attr.hasOwnProperty(attr, p)) {
+					if (attr[p]) {
+				  		f.setAttribute(p, f[prop]);
+					}
+					else {
+				  		f.removeAttribute(p);
+					}
+			  	}
+			}
+		}
+	});
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});

=== added file 'loggerhead/static/javascript/yui/build/io/io-xdr-debug.js'
--- loggerhead/static/javascript/yui/build/io/io-xdr-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-xdr-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,124 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-xdr', function(Y) {
+
+   /*
+    * Extends the IO base class to provide an alternate, Flash transport, for making
+    * cross-domain requests.
+	* @module io-base
+	* @submodule io-xdr
+	*/
+
+   /**
+	* @event io:xdrReady
+	* @description This event is fired by YUI.io when the specified transport is
+	* ready for use.
+	* @type Event Custom
+	*/
+	var E_XDR_READY = 'io:xdrReady';
+
+   /**
+	* @description Method that creates the Flash transport swf.
+	*
+	* @method _swf
+	* @private
+	* @static
+	* @param {string} uri - location of IO.swf.
+	* @param {string} yid - YUI instance id.
+	* @return void
+	*/
+	function _swf(uri, yid) {
+		var XDR_SWF = '<object id="yuiIoSwf" type="application/x-shockwave-flash" data="' + uri + '" width="0" height="0">' +
+		     		  '<param name="movie" value="' + uri + '">' +
+		     		  '<param name="FlashVars" value="yid=' + yid + '">' +
+                      '<param name="allowScriptAccess" value="sameDomain">' +
+		    	      '</object>';
+		Y.get('body').appendChild(Y.Node.create(XDR_SWF))
+	};
+
+    Y.mix(Y.io, {
+
+	   /**
+		* @description Map of IO transports.
+		*
+		* @property _transportMap
+		* @private
+		* @static
+		* @type object
+		*/
+		_transportMap: {},
+
+	   /**
+		* @description Object that stores callback handlers for cross-domain requests
+		* when using Flash as the transport.
+		*
+		* @property _fn
+		* @private
+		* @static
+		* @type object
+		*/
+		_fn: {},
+
+	   /**
+	   	* @description Method for accessing the transport's interface for making a
+	   	* cross-domain transaction.
+	   	*
+		* @method _xdr
+		* @private
+		* @static
+		* @param {string} uri - qualified path to transaction resource.
+    	* @param {object} o - Transaction object generated by _create() in io-base.
+		* @param {object} c - configuration object for the transaction.
+		* @return object
+		*/
+		_xdr: function(uri, o, c){
+			if (c.on) {
+				this._fn[o.id] = c.on;
+			}
+			o.c.send(uri, c, o.id);
+
+			return o;
+		},
+
+
+	   /**
+		* @description Fires event "io:xdrReady"
+		*
+		* @method xdrReady
+		* @private
+		* @static
+		* @param {number} id - transaction id
+		* @param {object} c - configuration object for the transaction.
+		*
+		* @return void
+		*/
+		xdrReady: function(id) {
+			Y.fire(E_XDR_READY, id);
+		},
+
+	   /**
+		* @description Method to initialize the desired transport.
+		*
+		* @method transport
+		* @public
+		* @static
+		* @param {object} o - object of transport configurations.
+		* @return void
+		*/
+		transport: function(o) {
+			switch (o.id) {
+				case 'flash':
+					_swf(o.src, o.yid);
+					this._transportMap.flash = Y.config.doc.getElementById('yuiIoSwf');
+					break;
+			}
+		}
+	});
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});

=== added file 'loggerhead/static/javascript/yui/build/io/io-xdr-min.js'
--- loggerhead/static/javascript/yui/build/io/io-xdr-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-xdr-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("io-xdr",function(C){var A="io:xdrReady";function B(E,F){var D='<object id="yuiIoSwf" type="application/x-shockwave-flash" data="'+E+'" width="0" height="0">'+'<param name="movie" value="'+E+'">'+'<param name="FlashVars" value="yid='+F+'">'+'<param name="allowScriptAccess" value="sameDomain">'+"</object>";C.get("body").appendChild(C.Node.create(D));}C.mix(C.io,{_transportMap:{},_fn:{},_xdr:function(D,E,F){if(F.on){this._fn[E.id]=F.on;}E.c.send(D,F,E.id);return E;},xdrReady:function(D){C.fire(A,D);},transport:function(D){switch(D.id){case"flash":B(D.src,D.yid);this._transportMap.flash=C.config.doc.getElementById("yuiIoSwf");break;}}});},"3.0.0pr2",{requires:["io-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/io/io-xdr.js'
--- loggerhead/static/javascript/yui/build/io/io-xdr.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io-xdr.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,124 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-xdr', function(Y) {
+
+   /*
+    * Extends the IO base class to provide an alternate, Flash transport, for making
+    * cross-domain requests.
+	* @module io-base
+	* @submodule io-xdr
+	*/
+
+   /**
+	* @event io:xdrReady
+	* @description This event is fired by YUI.io when the specified transport is
+	* ready for use.
+	* @type Event Custom
+	*/
+	var E_XDR_READY = 'io:xdrReady';
+
+   /**
+	* @description Method that creates the Flash transport swf.
+	*
+	* @method _swf
+	* @private
+	* @static
+	* @param {string} uri - location of IO.swf.
+	* @param {string} yid - YUI instance id.
+	* @return void
+	*/
+	function _swf(uri, yid) {
+		var XDR_SWF = '<object id="yuiIoSwf" type="application/x-shockwave-flash" data="' + uri + '" width="0" height="0">' +
+		     		  '<param name="movie" value="' + uri + '">' +
+		     		  '<param name="FlashVars" value="yid=' + yid + '">' +
+                      '<param name="allowScriptAccess" value="sameDomain">' +
+		    	      '</object>';
+		Y.get('body').appendChild(Y.Node.create(XDR_SWF))
+	};
+
+    Y.mix(Y.io, {
+
+	   /**
+		* @description Map of IO transports.
+		*
+		* @property _transportMap
+		* @private
+		* @static
+		* @type object
+		*/
+		_transportMap: {},
+
+	   /**
+		* @description Object that stores callback handlers for cross-domain requests
+		* when using Flash as the transport.
+		*
+		* @property _fn
+		* @private
+		* @static
+		* @type object
+		*/
+		_fn: {},
+
+	   /**
+	   	* @description Method for accessing the transport's interface for making a
+	   	* cross-domain transaction.
+	   	*
+		* @method _xdr
+		* @private
+		* @static
+		* @param {string} uri - qualified path to transaction resource.
+    	* @param {object} o - Transaction object generated by _create() in io-base.
+		* @param {object} c - configuration object for the transaction.
+		* @return object
+		*/
+		_xdr: function(uri, o, c){
+			if (c.on) {
+				this._fn[o.id] = c.on;
+			}
+			o.c.send(uri, c, o.id);
+
+			return o;
+		},
+
+
+	   /**
+		* @description Fires event "io:xdrReady"
+		*
+		* @method xdrReady
+		* @private
+		* @static
+		* @param {number} id - transaction id
+		* @param {object} c - configuration object for the transaction.
+		*
+		* @return void
+		*/
+		xdrReady: function(id) {
+			Y.fire(E_XDR_READY, id);
+		},
+
+	   /**
+		* @description Method to initialize the desired transport.
+		*
+		* @method transport
+		* @public
+		* @static
+		* @param {object} o - object of transport configurations.
+		* @return void
+		*/
+		transport: function(o) {
+			switch (o.id) {
+				case 'flash':
+					_swf(o.src, o.yid);
+					this._transportMap.flash = Y.config.doc.getElementById('yuiIoSwf');
+					break;
+			}
+		}
+	});
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});

=== added file 'loggerhead/static/javascript/yui/build/io/io.js'
--- loggerhead/static/javascript/yui/build/io/io.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/io/io.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1174 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('io-base', function(Y) {
+
+   /**
+	* HTTP communications module.
+	* @module io
+	*/
+
+   /**
+    * The io class is a utility that brokers HTTP requests through a simplified
+    * interface.  Specifically, it allows JavaScript to make HTTP requests to
+    * a resource without a page reload.  The underlying transport for making
+    * same-domain requests is the XMLHttpRequest object.  YUI.io can also use
+    * Flash, if specified as a transport, for cross-domain requests.
+    *
+	* @class io
+	*/
+
+   /**
+	* @event io:start
+	* @description This event is fired by YUI.io when a transaction is initiated..
+	* @type Event Custom
+	*/
+	E_START = 'io:start',
+
+   /**
+	* @event io:complete
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* all response data are available.
+	* @type Event Custom
+	*/
+	E_COMPLETE = 'io:complete',
+
+   /**
+	* @event io:success
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* the HTTP status resolves to HTTP2xx.
+	* @type Event Custom
+	*/
+	E_SUCCESS = 'io:success',
+
+   /**
+	* @event io:failure
+	* @description This event is fired by YUI.io when a transaction is complete and
+	* the HTTP status resolves to HTTP4xx, 5xx and above.
+	* @type Event Custom
+	*/
+	E_FAILURE = 'io:failure',
+
+   /**
+	* @event io:abort
+	* @description This event is fired by YUI.io when a transaction is aborted
+	* explicitly or by a defined config.timeout.
+	* @type Event Custom
+	*/
+	E_ABORT = 'io:abort',
+
+	//--------------------------------------
+	//  Properties
+	//--------------------------------------
+   /**
+	* @description A transaction counter that increments for each transaction.
+	*
+	* @property transactionId
+	* @private
+	* @static
+	* @type int
+	*/
+	transactionId = 0,
+
+   /**
+	* @description Object of default HTTP headers to be initialized and sent
+	* for all transactions.
+	*
+	* @property _headers
+	* @private
+	* @static
+	* @type object
+	*/
+	_headers = {
+		'X-Requested-With' : 'XMLHttpRequest'
+	},
+
+   /**
+	* @description Object that stores timeout values for any transaction with
+	* a defined "timeout" configuration property.
+	*
+	* @property _timeOut
+	* @private
+	* @static
+	* @type object
+	*/
+	_timeout = {},
+
+   /**
+	* @description Array of transactions queued for processing
+	*
+	* @property _q
+	* @private
+	* @static
+	* @type array
+	*/
+	_q = [],
+
+   /**
+	* @description Property to determine whether the queue is set to
+	* 1 (active) or 0 (inactive).  When inactive, transactions
+	* will be stored in the queue until the queue is set to active.
+	*
+	* @property _qState
+	* @private
+	* @static
+	* @type int
+	*/
+	_qState = 1,
+
+   /**
+	* @description Queue property to set a maximum queue storage size.  When
+	* this property is set, the queue will not store any more transactions
+	* until the queue size os reduced below this threshold. There is no
+	* maximum queue size until it is explicitly set.
+	*
+	* @property _qMaxSize
+	* @private
+	* @static
+	* @type int
+	*/
+	_qMaxSize = false,
+
+	// Window reference
+	w = Y.config.win;
+
+	//--------------------------------------
+	//  Methods
+	//--------------------------------------
+   /**
+	* @description Method for requesting a transaction, and queueing the
+	* request before it is sent to the resource.
+	*
+	* @method _queue
+	* @private
+	* @static
+    * @return int
+	*/
+	function _queue(uri, c) {
+
+		if (_qMaxSize === false || _q.length < _qMaxSize) {
+			var id = _id();
+			_q.push({ uri: uri, id: id, cfg:c });
+		}
+		else {
+			return false;
+		}
+
+		if (_qState === 1) {
+			_shift();
+		}
+
+		return id;
+	};
+
+   /**
+	* @description Method for promoting a transaction to the top of the queue.
+	*
+	* @method _unshift
+	* @private
+	* @static
+    * @return void
+	*/
+	function _unshift(id) {
+		var r;
+
+		for (var i = 0; i < _q.length; i++) {
+			if (_q[i].id === id) {
+				r = _q.splice(i, 1);
+				var p = _q.unshift(r[0]);
+				break;
+			}
+		}
+	};
+
+   /**
+	* @description Method for removing a transaction from the top of the
+	* queue, and sending the transaction to _io().
+	*
+	* @method _shift
+	* @private
+	* @static
+    * @return void
+	*/
+	function _shift() {
+		var c = _q.shift();
+		_io(c.uri, c.cfg, c.id);
+	};
+
+   /**
+	* @description Method to query the current size of the queue, or to
+	* set a maximum queue size.
+	*
+	* @method _size
+	* @private
+	* @static
+    * @return int
+	*/
+	function _size(i) {
+		if (i) {
+			_qMaxSize = i;
+			return i;
+		}
+		else {
+			return _q.length;
+		}
+	};
+
+   /**
+	* @description Method for setting the queue to active. If there are
+	* transactions pending in the queue, they will be processed from the
+	* queue in FIFO order.
+	*
+	* @method _start
+	* @private
+	* @static
+    * @return void
+	*/
+	function _start() {
+		var len = (_q.length > _qMaxSize > 0) ? _qMaxSize : _q.length;
+
+		if (len > 1) {
+			for (var i=0; i < len; i++) {
+				_shift();
+			}
+		}
+		else {
+			_shift();
+		}
+
+	};
+
+   /**
+	* @description Method for setting queue processing to inactive.
+	* Transaction requests to YUI.io.queue() will be stored in the queue, but
+	* not processed until the queue is reset to "active".
+	*
+	* @method _stop
+	* @private
+	* @static
+    * @return void
+	*/
+	function _stop() {
+		_qState = 0;
+	};
+
+   /**
+	* @description Method for removing a specific, pending transaction from
+	* the queue.
+	*
+	* @method _purge
+	* @private
+	* @static
+    * @return void
+	*/
+	function _purge(id) {
+		if (Y.Lang.isNumber(id)) {
+			for (var i = 0; i < _q.length; i++) {
+				if (_q[i].id === id) {
+					_q.splice(i, 1);
+					break;
+				}
+			}
+		}
+	};
+	/* End Queue Functions */
+
+   /**
+	* @description Method for requesting a transaction. _io() is implemented as
+	* yui.io().  Each transaction may include a configuration object.  Its
+	* properties are:
+	*
+	* method: HTTP method verb (e.g., GET or POST). If this property is not
+	*         not defined, the default value will be GET.
+	*
+	* data: This is the name-value string that will be sent as the transaction
+    *		data.  If the request is HTTP GET, the data become part of
+    *		querystring. If HTTP POST, the data are sent in the message body.
+	*
+	* xdr: Defines the transport to be used for cross-domain requests.  By
+	*      setting this property, the transaction will use the specified
+	*      transport instead of XMLHttpRequest.  Currently, the only alternate
+	*      transport supported is Flash (e.g., { xdr: 'flash' }).
+	*
+	* form: This is a defined object used to process HTML form as data.  The
+	*       properties are:
+	*       {
+	*	      id: object, //HTML form object or id of HTML form
+	*         useDisabled: boolean, //Allow disabled HTML form field values
+	*                      to be sent as part of the data.
+    *       }
+    *
+    * on: This is a defined object used to create and handle specific
+    *     events during a transaction lifecycle.  These events will fire in
+    *     addition to the global io events. The events are:
+    *	  start - This event is fired when a request is sent to a resource.
+    *     complete - This event fires when the transaction is complete.
+    *     success - This event fires when the response status resolves to
+    *               HTTP 2xx.
+    *     failure - This event fires when the response status resolves to
+    *               HTTP 4xx, 5xx, and beyond.
+    *	  abort - This even is fired when a transaction abort is fire by
+    *             timeout, or when it is manually aborted.
+    *
+    *     The properties are:
+    *     {
+	*       start: function(id, args){},
+	*       complete: function(id, responseobject, args){},
+	*       success: function(id, responseobject, args){},
+	*       failure: function(id, responseobject, args){},
+	*       abort: function(id, args){}
+	*     }
+	*	  Each property can reference a function or be written as an
+	*     inline function.
+	*
+	* context: Object reference for an event handler when it is implemented
+	*          as a method of a base object. Defining "context" will preserve
+	*          the proper reference of "this" used in the event handler.
+	* headers: This is a defined object of client headers, as many as.
+	*         desired for the transaction.  These headers are sentThe object
+	*         pattern is:
+	*		  {
+	*		    header: value
+	*         }
+	*
+	* timeout: This value, defined as milliseconds, is a time threshold for the
+	*          transaction. When this threshold is reached, and the transaction's
+	*          Complete event has not yet fired, the transaction will be aborted.
+	* arguments: Object, array, string, or number passed to all registered
+	*            event handlers.  This value is available as the second
+	*            argument in the "start" and "abort" event handlers; and, it is
+	*            the third argument in the "complete", "success", and "failure"
+	*            event handlers.
+	*
+	* @method _io
+	* @private
+	* @static
+    * @param {string} uri - qualified path to transaction resource.
+    * @param {object} c - configuration object for the transaction.
+    * @return object
+	*/
+	function _io(uri, c) {
+		var c = c || {},
+		o = _create((arguments.length === 3) ? arguments[2] : null, c),
+		m = (c.method) ? c.method.toUpperCase() : 'GET',
+		d = (c.data) ? c.data : null,
+		f;
+
+		/* Determine configuration properties */
+		// If config.form is defined, perform data operations.
+		if (c.form) {
+
+			if (c.form.upload) {
+				u = Y.io._upload(o, uri, c);
+				return u;
+			}
+
+			// Serialize the HTML form into a string of name-value pairs.
+			f = Y.io._serialize(c.form);
+			// If config.data is defined, concatenate the data to the form string.
+			if (d) {
+				f += "&" + d;
+			}
+
+			if (m === 'POST') {
+				d = f;
+				_setHeader('Content-Type', 'application/x-www-form-urlencoded');
+			}
+			else if (m === 'GET') {
+				uri = _concat(uri, f);
+			}
+		}
+		else if (d && m === 'GET') {
+			uri = _concat(uri, c.data);
+		}
+		else if (d && m === 'POST') {
+			_setHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
+		}
+
+		if (c.xdr) {
+			Y.io._xdr(uri, o, c);
+			return o;
+		}
+
+		// If config.timeout is defined, and the request is standard XHR,
+		// initialize timeout polling.
+		if (c.timeout) {
+			_startTimeout(o, c);
+		}
+		/* End Configuration Properties */
+
+		o.c.onreadystatechange = function() { _readyState(o, c); };
+		try {
+			_open(o.c, m, uri);
+		}
+		catch (e) {
+		}
+		_setHeaders(o.c, (c.headers || {}));
+
+		o.abort = function () {
+			_ioAbort(o, c);
+		}
+
+		o.isInProgress = function() {
+			return o.c.readyState !== 4 && o.c.readyState !== 0;
+		}
+		// Do not pass null, in the absence of data, as this
+		// wiil result in a POST request with no Content-Length
+		// defined.
+		_async(o, (d || ''), c);
+
+		return o;
+	};
+
+   /**
+	* @description Method for creating and subscribing transaction events.
+	*
+	* @method _tPubSub
+	* @private
+	* @static
+	* @param {string} e - event to be published
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _tPubSub(e, c){
+			var event = new Y.Event.Target().publish('transaction:' + e);
+			event.subscribe(c.on[e], (c.context || this), c.arguments);
+
+			return event;
+	};
+
+   /**
+	* @description Fires event "io:start" and creates, fires a
+	* transaction-specific start event, if config.on.start is
+	* defined.
+	*
+	* @method _ioStart
+	* @private
+	* @static
+	* @param {number} id - transaction id
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioStart(id, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[id]) ? m[id] : null,
+		event;
+
+		if (fn) {
+			c.on.start = fn.start;
+			delete fn;
+		}
+
+		Y.fire(E_START, id);
+		if (c.on.start) {
+			event = _tPubSub('start', c);
+			event.fire(id);
+		}
+	};
+
+   /**
+	* @description Fires event "io:complete" and creates, fires a
+	* transaction-specific "complete" event, if config.on.complete is
+	* defined.
+	*
+	* @method _ioComplete
+	* @private
+	* @static
+	* @param {object} id - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioComplete(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var event;
+
+		Y.fire(E_COMPLETE, o.id, o.c);
+		if (c.on.complete) {
+			event = _tPubSub('complete', c);
+			event.fire(o.id, o.c);
+		}
+	}
+
+   /**
+	* @description Fires event "io:success" and creates, fires a
+	* transaction-specific "success" event, if config.on.success is
+	* defined.
+	*
+	* @method _ioSuccess
+	* @private
+	* @static
+	* @param {object} o - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioSuccess(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if (fn) {
+			c.on.success = fn.success;
+			delete fn;
+			//Decode the response from IO.swf
+			o.c.responseText = decodeURI(o.c.responseText);
+		}
+
+		Y.fire(E_SUCCESS, o.id, o.c);
+		if (c.on.success) {
+			event = _tPubSub('success', c);
+			event.fire(o.id, o.c);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+	}
+
+   /**
+	* @description Fires event "io:failure" and creates, fires a
+	* transaction-specific "failure" event, if config.on.failure is
+	* defined.
+	*
+	* @method _ioFailure
+	* @private
+	* @static
+	* @param {object} o - transaction object.
+	* @param {object} c - configuration object for the transaction.
+	*
+    * @return void
+	*/
+	function _ioFailure(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if (fn) {
+			c.on.failure = fn.failure;
+			delete fn;
+			//Decode the response from IO.swf
+			o.c.responseText = decodeURI(o.c.responseText);
+		}
+
+		Y.fire(E_FAILURE, o.id, o.c);
+		if (c.on.failure) {
+			event = _tPubSub('failure', c);
+			event.fire(o.id, o.c);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+	}
+
+   /**
+	* @description Fires event "io:abort" and creates, fires a
+	* transaction-specific "abort" event, if config.on.abort is
+	* defined.
+	*
+	* @method _ioAbort
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+	*
+    * @return void
+	*/
+	function _ioAbort(o, c) {
+		// Set default value of argument c, property "on" to Object if
+		// the property is null or undefined.
+		c.on = c.on || {};
+		var m = Y.io._fn || {},
+		fn = (m && m[o.id]) ? m[o.id] : null,
+		event;
+
+		if(o && o.c  && !c.xdr) {
+			// Terminate the transaction
+			o.c.abort();
+			if (c) {
+				// Clear the timeout poll for this specific transaction.
+				if (c.timeout) {
+					_clearTimeout(o.id);
+				}
+			}
+		}
+
+		if (fn) {
+			c.on.abort = fn.abort;
+			delete fn;
+		}
+
+		Y.fire(E_ABORT, o.id);
+		if (c.on.abort) {
+			event = _tPubSub('abort', c);
+			event.fire(id);
+		}
+
+		_destroy(o, (c.xdr) ? true : false );
+	}
+
+   /**
+	* @description Method that increments _transactionId for each transaction.
+	*
+	* @method _id
+	* @private
+	* @static
+    * @return int
+	*/
+	function _id() {
+		var id = transactionId;
+		transactionId++;
+
+		return id;
+	};
+
+   /**
+	* @description Method that creates a unique transaction object for each
+	* request..
+	*
+	* @method _create
+	* @private
+	* @static
+    * @param {number} s - URI or root data.
+    * @param {number} c - configuration object
+    * @return object
+	*/
+	function _create(i, c) {
+		var o = {};
+		o.id = Y.Lang.isNumber(i) ? i : _id();
+
+		if (c.xdr) {
+			o.c = Y.io._transport[c.xdr.use];
+		}
+		else if (c.form && c.form.upload) {
+			o.c = {};
+		}
+		else {
+			o.c = _xhr();
+		}
+
+		return o;
+	};
+
+   /**
+	* @description Method that creates the XMLHttpRequest transport
+	*
+	* @method _xhr
+	* @private
+	* @static
+    * @return object
+	*/
+	function _xhr() {
+		return (w.XMLHttpRequest) ? new XMLHttpRequest() : new ActiveXObject('Microsoft.XMLHTTP');
+	};
+
+   /**
+	* @description Method that concatenates string data for HTTP GET transactions.
+	*
+	* @method _concat
+	* @private
+	* @static
+    * @param {string} s - URI or root data.
+    * @param {string} d - data to be concatenated onto URI.
+    * @return int
+	*/
+	function _concat(s, d) {
+		s += ((s.indexOf('?') == -1) ? '?' : '&') + d;
+		return s;
+	};
+
+   /**
+	* @description Method that stores default client headers for all transactions.
+	* If a label is passed with no value argument, the header will be deleted.
+	*
+	* @method _setHeader
+	* @private
+	* @static
+    * @param {string} l - HTTP header
+    * @param {string} v - HTTP header value
+    * @return int
+	*/
+	function _setHeader(l, v) {
+		if (v) {
+			_headers[l] = v;
+		}
+		else {
+			delete _headers[l];
+		}
+	};
+
+   /**
+	* @description Method that sets all HTTP headers to be sent in a transaction.
+	*
+	* @method _setHeaders
+	* @private
+	* @static
+    * @param {object} o - XHR instance for the specific transaction.
+    * @param {object} h - HTTP headers for the specific transaction, as defined
+    *                     in the configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _setHeaders(o, h) {
+
+		var p;
+
+		for (p in _headers) {
+			if (_headers.hasOwnProperty(p)) {
+				h[p] = _headers[p];
+			}
+		}
+
+		for (p in h) {
+			if (h.hasOwnProperty(p)) {
+				o.setRequestHeader(p, h[p]);
+			}
+		}
+	};
+
+	function _open(o, m, uri) {
+		o.open(m, uri, true);
+	};
+
+   /**
+	* @description Method that sends the transaction request.
+	*
+	* @method _async
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {string} d - Transaction data.
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _async(o, d, c) {
+		o.c.send(d);
+		_ioStart(o.id, c);
+	};
+
+   /**
+	* @description Starts timeout count if the configuration object
+	* has a defined timeout property.
+	*
+	* @method _startTimeout
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _startTimeout(o, c) {
+		_timeout[o.id] = w.setTimeout(function() { _ioAbort(o, c); }, c.timeout);
+	};
+
+   /**
+	* @description Clears the timeout interval started by _startTimeout().
+	*
+	* @method _clearTimeout
+	* @private
+	* @static
+    * @param {number} id - Transaction id.
+    * @return void
+	*/
+	function _clearTimeout(id) {
+		w.clearTimeout(_timeout[id]);
+		delete _timeout[id];
+	};
+
+   /**
+	* @description Event handler bound to onreadystatechange.
+	*
+	* @method _readyState
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _readyState(o, c) {
+		if (o.c.readyState === 4) {
+			if (c.timeout) {
+				_clearTimeout(o.id);
+			}
+			_ioComplete(o, c);
+			_handleResponse(o, c);
+		}
+	};
+
+   /**
+	* @description Method that determines if a transaction response qualifies
+	* as success or failure, based on the response HTTP status code, and
+	* fires the appropriate success or failure events.
+	*
+	* @method _handleResponse
+	* @private
+	* @static
+    * @param {object} o - Transaction object generated by _create().
+    * @param {object} c - Configuration object passed to YUI.io().
+    * @return void
+	*/
+	function _handleResponse(o, c) {
+		var status;
+		try{
+			if (o.c.status && o.c.status !== 0) {
+				status = o.c.status;
+			}
+			else {
+				status = 0;
+			}
+		}
+		catch(e) {
+			status = 0;
+		}
+
+		/*
+		 * IE reports HTTP 204 as HTTP 1223.
+		 * However, the response data are still available.
+		 *
+		 * setTimeout() is used to prevent transactions from becoming
+		 * synchronous, in IE, when the response data are read from cache
+		 * (e.g., HTTP 304).
+		 */
+		if (status >= 200 && status < 300 || status === 1223) {
+			w.setTimeout( function() { _ioSuccess(o, c); }, 0);
+		}
+		else {
+			w.setTimeout( function() {_ioFailure(o, c); }, 0);
+		}
+	};
+
+	function _destroy(o, isTransport) {
+		// IE6 will throw a "Type Mismatch" error if the event handler is set to "null".
+		if(w.XMLHttpRequest && !isTransport) {
+			if (o.c) {
+				o.c.onreadystatechange = null;
+			}
+		}
+
+		o.c = null;
+		o = null;
+	};
+
+	_io.start = _ioStart;
+	_io.complete = _ioComplete;
+	_io.success = _ioSuccess;
+	_io.failure = _ioFailure;
+	_io.abort = _ioAbort;
+	_io.timeout = _timeout;
+
+   	//--------------------------------------
+   	//  Begin public interface definition
+   	//--------------------------------------
+   /**
+	* @description Method that stores default client headers for all transactions.
+	* If a label is passed with no value argument, the header will be deleted.
+	* This is the interface for _setHeader().
+	*
+	* @method header
+	* @public
+	* @static
+    * @param {string} l - HTTP header
+    * @param {string} v - HTTP header value
+    * @return int
+	*/
+	_io.header = _setHeader;
+
+   /**
+	* @description Method for requesting a transaction, and queueing the
+	* request before it is sent to the resource. This is the
+	* interface for _queue().
+	*
+	* @method queue
+	* @public
+	* @static
+    * @param {string} uri - qualified path to transaction resource.
+    * @param {object} c - configuration object for the transaction.
+    * @return int
+	*/
+	_io.queue = _queue;
+
+   /**
+	* @description Method to query the current size of the queue, or to
+	* set a maximum queue size.  This is the interface for _size().
+	*
+	* @method size
+	* @public
+	* @static
+	* @param {number} i - Specified maximum size of queue.
+    * @return number
+	*/
+	_io.queue.size = _size;
+
+   /**
+	* @description Method for setting the queue to "active". If there are
+	* transactions pending in the queue, they will be processed from the
+	* queue in FIFO order. This is the interface for _start().
+	*
+	* @method start
+	* @public
+	* @static
+    * @return void
+	*/
+	_io.queue.start = _start;
+
+   /**
+	* @description Method for setting queue processing to inactive.
+	* Transaction requests to YUI.io.queue() will be stored in the queue, but
+	* not processed until the queue is set to "active". This is the
+	* interface for _stop().
+	*
+	* @method stop
+	* @public
+	* @static
+    * @return void
+	*/
+	_io.queue.stop = _stop;
+
+   /**
+	* @description Method for promoting a transaction to the top of the queue.
+	* This is the interface for _unshift().
+	*
+	* @method promote
+	* @public
+	* @static
+	* @param {number} i - ID of queued transaction.
+    * @return void
+	*/
+	_io.queue.promote = _unshift;
+
+   /**
+	* @description Method for removing a specific, pending transaction from
+	* the queue. This is the interface for _purge().
+	*
+	* @method purge
+	* @public
+	* @static
+	* @param {number} i - ID of queued transaction.
+    * @return void
+	*/
+	_io.queue.purge = _purge;
+
+   /**
+	* @description Method for requesting a transaction. This
+	* is the interface for _io().
+	*
+	* @method io
+	* @public
+	* @static
+    * @param {string} uri - qualified path to transaction resource.
+    * @param {object} c - configuration object for the transaction.
+    * @return object
+    */
+	Y.io = _io;
+
+
+
+}, '3.0.0pr2' );
+
+YUI.add('io-form', function(Y) {
+
+   /*
+	* @module io-base
+	* @submodule io-form
+	*/
+
+    Y.mix(Y.io, {
+       /**
+        * @description Method to enumerate through an HTML form's elements collection
+        * and return a string comprised of key-value pairs.
+        *
+        * @method _serialize
+        * @private
+        * @static
+        * @param {object} f - HTML form object or id.
+        * @return string
+        */
+        _serialize: function(o) {
+            var f = (typeof o.id === 'object') ? o.id : Y.config.doc.getElementById(o.id),
+            eUC = encodeURIComponent,
+            data = [],
+            useDf = o.useDisabled || false,
+            item = 0,
+            e, n, v, d, i, ilen, j, jlen, o;
+
+            // Iterate over the form elements collection to construct the
+            // label-value pairs.
+            for (i = 0, ilen = f.elements.length; i < ilen; ++i) {
+                e = f.elements[i];
+                d = e.disabled;
+                n = e.name;
+
+                if ((useDf) ? n : (n && !d)) {
+                    n = encodeURIComponent(n) + '=';
+                    v = encodeURIComponent(e.value);
+
+                    switch (e.type) {
+                        // Safari, Opera, FF all default opt.value from .text if
+                        // value attribute not specified in markup
+                        case 'select-one':
+                            if (e.selectedIndex > -1) {
+                                o = e.options[e.selectedIndex];
+                                data[item++] = n + eUC((o.attributes.value && o.attributes.value.specified) ? o.value : o.text);
+                            }
+                            break;
+                        case 'select-multiple':
+                            if (e.selectedIndex > -1) {
+                                for (j = e.selectedIndex, jlen = e.options.length; j < jlen; ++j) {
+                                    o = e.options[j];
+                                    if (o.selected) {
+                                      data[item++] = n + eUC((o.attributes.value && opt.attributes.value.specified) ? o.value : o.text);
+                                    }
+                                }
+                            }
+                            break;
+                        case 'radio':
+                        case 'checkbox':
+                            if(e.checked){
+                                data[item++] = n + v;
+                            }
+                            break;
+                        case 'file':
+                            // stub case as XMLHttpRequest will only send the file path as a string.
+                        case undefined:
+                            // stub case for fieldset element which returns undefined.
+                        case 'reset':
+                            // stub case for input type reset button.
+                        case 'button':
+                            // stub case for input type button elements.
+                            break;
+                        case 'submit':
+                            break;
+                        default:
+                            data[item++] = n + v;
+                    }
+                }
+            }
+            return data.join('&');
+        }
+    }, true);
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});
+
+YUI.add('io-xdr', function(Y) {
+
+   /*
+	* @module io-base
+	* @submodule io-xdr
+	*/
+
+   /**
+	* @event io:xdrReady
+	* @description This event is fired by YUI.io when a transaction is initiated..
+	* @type Event Custom
+	*/
+	var E_XDR_READY = 'io:xdrReady';
+
+   /**
+	* @description Method that creates the Flash transport swf.
+	*
+	* @method _swf
+	* @private
+	* @static
+	* @param {string} uri - location of IO.swf.
+	* @param {string} yid - YUI instance id.
+	* @return void
+	*/
+	function swf(uri, yid) {
+		var XDR_SWF = '<object id="yuiSwfIo" type="application/x-shockwave-flash" data="' + uri + '" width="0" height="0">' +
+		     		  '<param name="movie" value="' + uri + '">' +
+		     		  '<param name="FlashVars" value="yid=' + yid + '">' +
+                      '<param name="allowScriptAccess" value="sameDomain">' +
+		    	      '</object>';
+		Y.get('body').appendChild(Y.Node.create(XDR_SWF))
+	};
+
+    Y.mix(Y.io, {
+
+	   /**
+		* @description Map of IO transports.
+		*
+		* @property _transport
+		* @private
+		* @static
+		* @type object
+		*/
+		_transport: {},
+
+	   /**
+		* @description Object that stores callback handlers for cross-domain requests
+		* when using Flash as the transport.
+		*
+		* @property _fn
+		* @private
+		* @static
+		* @type object
+		*/
+		_fn: {},
+
+		_xdr: function(uri, o, c){
+			if (c.on) {
+				this._fn[o.id] = c.on;
+			}
+			o.c.send(uri, c, o.id);
+
+			return o;
+		},
+
+	   /**
+		* @description Method to initialize the desired transport medium.
+		*
+		* @method transport
+		* @public
+		* @static
+		* @param {object} o - object of transport configurations.
+		* @return void
+		*/
+		transport: function(o) {
+			switch (o.id) {
+				case 'flash':
+					swf(o.src, o.yid);
+					this._transport.flash = Y.config.doc.getElementById('yuiSwfIo');
+					break;
+				case 'upload':
+					break;
+			}
+		},
+
+	   /**
+		* @description Fires event "io:xdrReady"
+		*
+		* @method xdrReady
+		* @private
+		* @static
+		* @param {number} id - transaction id
+		* @param {object} c - configuration object for the transaction.
+		*
+		* @return void
+		*/
+		xdrReady: function(id) {
+			Y.fire(E_XDR_READY, id);
+		}
+	});
+
+
+
+}, '3.0.0pr2' ,{requires:['io-base']});
+
+
+
+YUI.add('io', function(Y){}, '3.0.0pr2' ,{use:['io-base', 'io-form', 'io-xdr']});
+

=== added file 'loggerhead/static/javascript/yui/build/io/io.swf'
Binary files loggerhead/static/javascript/yui/build/io/io.swf and loggerhead/static/javascript/yui/build/io/io.swf differ
=== added directory 'loggerhead/static/javascript/yui/build/json'
=== added file 'loggerhead/static/javascript/yui/build/json/README'
--- loggerhead/static/javascript/yui/build/json/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/json/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,13 @@
+The JSON Utility
+    Provides static methods to serialize objects to JSON strings and deserialize objects from JSON strings.
+
+    Three modules are available:
+        json           - Both parse and stringify functionality
+        json-parse     - Parse valid JSON strings into JavaScript objects
+        json-stringify - Serialize JavaScipt objects into valid JSON strings
+
+3.0.0pr1
+    Initial release
+
+3.0.0pr2
+    No changes

=== added file 'loggerhead/static/javascript/yui/build/json/json-debug.js'
--- loggerhead/static/javascript/yui/build/json/json-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/json/json-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,359 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('json-parse', function(Y) {
+
+/**
+ * The JSON Utility provides methods to serialize JavaScript objects into
+ * JSON strings and parse JavaScript objects from strings containing JSON data.
+ * Three modules are available for inclusion:
+ * <ol>
+ * <li>1. <code>json-parse</code> for parsing JSON strings into native JavaScript data</li>
+ * <li>2. <code>json-stringify</code> for stringification of JavaScript objects into JSON strings</li>
+ * <li>3. <code>json</code> for both parsing and stringification</li>
+ * </ol>
+ * 
+ * Both <code>json-parse</code> and <code>json-stringify</code> create functions in a static JSON class under your YUI instance (e.g. Y.JSON.parse(..)).
+ * @module json
+ * @class JSON
+ * @static
+ */
+
+/**
+ * Provides Y.JSON.parse method to take JSON strings and return native
+ * JavaScript objects.
+ * @module json
+ * @submodule json-parse
+ * @for JSON
+ * @static
+ */
+Y.JSON = Y.JSON || {};
+
+// All internals kept private for security reasons
+
+/**
+ * Replace certain Unicode characters that JavaScript may handle incorrectly
+ * during eval--either by deleting them or treating them as line endings--with
+ * escae sequences.
+ * IMPORTANT NOTE: This regex will be used to modify the input if a match is
+ * found.
+ * @property _UNICODE_EXCEPTIONS
+ * @type {RegExp}
+ * @private
+ */
+var _UNICODE_EXCEPTIONS = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+
+
+/**
+ * First step in the validation.  Regex used to replace all escape
+ * sequences (i.e. "\\", etc) with '@' characters (a non-JSON character).
+ * @property _ESCAPES
+ * @type {RegExp}
+ * @private
+ */
+    _ESCAPES = /\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,
+
+/**
+ * Second step in the validation.  Regex used to replace all simple
+ * values with ']' characters.
+ * @property _VALUES
+ * @type {RegExp}
+ * @private
+ */
+    _VALUES  = /"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,
+
+/**
+ * Third step in the validation.  Regex used to remove all open square
+ * brackets following a colon, comma, or at the beginning of the string.
+ * @property _BRACKETS
+ * @type {RegExp}
+ * @private
+ */
+
+    _BRACKETS = /(?:^|:|,)(?:\s*\[)+/g,
+
+/**
+ * Final step in the validation.  Regex used to test the string left after
+ * all previous replacements for invalid characters.
+ * @property _INVALID
+ * @type {RegExp}
+ * @private
+ */
+    _INVALID  = /^[\],:{}\s]*$/,
+
+    has = Object.prototype.hasOwnProperty,
+/**
+ * Traverses nested objects, applying a reviver function to each (key,value)
+ * from the scope if the key:value's containing object.  The value returned
+ * from the function will replace the original value in the key:value pair.
+ * If the value returned is undefined, the key will be omitted from the
+ * returned object.
+ * @method _revive
+ * @param data {MIXED} Any JavaScript data
+ * @param reviver {Function} filter or mutation function
+ * @return {MIXED} The results of the filtered data
+ * @private
+ */
+    _revive = function (data, reviver) {
+        var walk = function (o,key) {
+            var k,v,value = o[key];
+            if (value && typeof value === 'object') {
+                for (k in value) {
+                    if (has.call(value,k)) {
+                        v = walk(value, k);
+                        if (v === undefined) {
+                            delete value[k];
+                        } else {
+                            value[k] = v;
+                        }
+                    }
+                }
+            }
+            return reviver.call(o,key,value);
+        };
+
+        return typeof reviver === 'function' ? walk({'':data},'') : data;
+    };
+
+/**
+ * Parse a JSON string, returning the native JavaScript representation.
+ * @param s {string} JSON string data
+ * @param reviver {function} (optional) function(k,v) passed each key value pair of object literals, allowing pruning or altering values
+ * @return {MIXED} the native JavaScript representation of the JSON string
+ * @throws SyntaxError
+ * @method parse
+ * @static
+ * @public
+ */
+Y.JSON.parse = function (s,reviver) {
+    // Ensure valid JSON
+    if (typeof s === 'string') {
+        // Replace certain Unicode characters that are otherwise handled
+        // incorrectly by some browser implementations.
+        // NOTE: This modifies the input if such characters are found!
+        s = s.replace(_UNICODE_EXCEPTIONS, function (c) {
+            return '\\u'+('0000'+(+(c.charCodeAt(0))).toString(16)).slice(-4);
+        });
+        
+        // Test for validity
+        if (_INVALID.test(s.replace(_ESCAPES,'@').
+                            replace(_VALUES,']').
+                            replace(_BRACKETS,''))) {
+
+            // Eval the text into a JavaScript data structure, apply any
+            // reviver function, and return
+            return _revive( eval('(' + s + ')'), reviver );
+        }
+    }
+
+    // The text is not JSON parsable
+    throw new SyntaxError('parseJSON');
+};
+
+
+}, '3.0.0pr2' );
+YUI.add('json-stringify', function(Y) {
+
+/**
+ * Provides Y.JSON.stringify method for converting objects to JSON strings.
+ * @module json
+ * @submodule json-stringify
+ * @for JSON
+ * @static
+ */
+var isA = Y.Lang.isArray;
+
+Y.JSON = Y.JSON || {};
+
+Y.mix(Y.JSON,{
+    /**
+     * Regex used to capture characters that need escaping before enclosing
+     * their containing string in quotes.
+     * @property _SPECIAL_CHARS
+     * @type {RegExp}
+     * @private
+     */
+    _SPECIAL_CHARS : /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+
+    /**
+     * Character substitution map for common escapes and special characters.
+     * @property _CHARS
+     * @type {Object}
+     * @static
+     * @private
+     */
+    _CHARS : {
+        '\b': '\\b',
+        '\t': '\\t',
+        '\n': '\\n',
+        '\f': '\\f',
+        '\r': '\\r',
+        '"' : '\\"',
+        '\\': '\\\\'
+    },
+
+    /**
+     * Serializes a Date instance as a UTC date string.  Used internally by
+     * stringify.  Override this method if you need Dates serialized in a
+     * different format.
+     * @method dateToString
+     * @param d {Date} The Date to serialize
+     * @return {String} stringified Date in UTC format YYYY-MM-DDTHH:mm:SSZ
+     * @static
+     */
+    dateToString : function (d) {
+        function _zeroPad(v) {
+            return v < 10 ? '0' + v : v;
+        }
+
+        return '"' + d.getUTCFullYear()   + '-' +
+            _zeroPad(d.getUTCMonth() + 1) + '-' +
+            _zeroPad(d.getUTCDate())      + 'T' +
+            _zeroPad(d.getUTCHours())     + ':' +
+            _zeroPad(d.getUTCMinutes())   + ':' +
+            _zeroPad(d.getUTCSeconds())   + 'Z"';
+    },
+
+    /**
+     * Converts an arbitrary value to a JSON string representation.
+     * Cyclical object or array references are replaced with null.
+     * If a whitelist is provided, only matching object keys will be included.
+     * If a depth limit is provided, objects and arrays at that depth will
+     * be stringified as empty.
+     * @method stringify
+     * @param o {MIXED} any arbitrary object to convert to JSON string
+     * @param w {Array|Function} (optional) whitelist of acceptable object
+     *                  keys to include, or a replacer function to modify the
+     *                  raw value before serialization
+     * @param d {number} (optional) depth limit to recurse objects/arrays
+     *                   (practical minimum 1)
+     * @return {string} JSON string representation of the input
+     * @static
+     * @public
+     */
+    stringify : function (o,w,d) {
+
+        var m      = Y.JSON._CHARS,
+            str_re = Y.JSON._SPECIAL_CHARS,
+            rep    = typeof w === 'function' ? w : null,
+            pstack = []; // Processing stack used for cyclical ref protection
+
+        if (rep || typeof w !== 'object') {
+            w = undefined;
+        }
+
+        // escape encode special characters
+        var _char = function (c) {
+            if (!m[c]) {
+                m[c]='\\u'+('0000'+(+(c.charCodeAt(0))).toString(16)).slice(-4);
+            }
+            return m[c];
+        };
+
+        // Enclose the escaped string in double quotes
+        var _string = function (s) {
+            return '"' + s.replace(str_re, _char) + '"';
+        };
+
+        // Use the configured date conversion
+        var _date = Y.JSON.dateToString;
+    
+        // Worker function.  Fork behavior on data type and recurse objects and
+        // arrays per the configured depth.
+        var _stringify = function (h,key,d) {
+            var o = typeof rep === 'function' ? rep.call(h,key,h[key]) : h[key],
+                t = typeof o,
+                i,len,j, // array iteration
+                k,v,     // object iteration
+                a;       // composition array for performance over string concat
+
+            // String
+            if (t === 'string') {
+                return _string(o);
+            }
+
+            // native boolean and Boolean instance
+            if (t === 'boolean' || o instanceof Boolean) {
+                return String(o);
+            }
+
+            // native number and Number instance
+            if (t === 'number' || o instanceof Number) {
+                return isFinite(o) ? String(o) : 'null';
+            }
+
+            // Date
+            if (o instanceof Date) {
+                return _date(o);
+            }
+
+            // Object types
+            if (t === 'object') {
+                if (!o) {
+                    return 'null';
+                }
+
+                // Check for cyclical references
+                for (i = pstack.length - 1; i >= 0; --i) {
+                    if (pstack[i] === o) {
+                        return 'null';
+                    }
+                }
+
+                // Add the object to the processing stack
+                pstack[pstack.length] = o;
+
+                a = [];
+
+                // Only recurse if we're above depth config
+                if (d > 0) {
+                    // Array
+                    if (isA(o)) {
+                        for (i = o.length - 1; i >= 0; --i) {
+                            a[i] = _stringify(o,i,d-1) || 'null';
+                        }
+
+                    // Object
+                    } else {
+                        // If whitelist provided, take only those keys
+                        k = isA(w) ? w : Y.Object.keys(w||o);
+
+                        for (i = 0, j = 0, len = k.length; i < len; ++i) {
+                            if (typeof k[i] === 'string') {
+                                v = _stringify(o,k[i],d-1);
+                                if (v) {
+                                    a[j++] = _string(k[i]) + ':' + v;
+                                }
+                            }
+                        }
+
+                        a.sort();
+                    }
+                }
+
+                // remove the array from the stack
+                pstack.pop();
+
+                return isA(o) ? '['+a.join(',')+']' : '{'+a.join(',')+'}';
+            }
+
+            return undefined; // invalid input
+        };
+
+        // Default depth to POSITIVE_INFINITY
+        d = d >= 0 ? d : 1/0;
+
+        // process the input
+        return _stringify({'':o},'',d);
+    }
+});
+
+
+}, '3.0.0pr2' );
+
+
+YUI.add('json', function(Y){}, '3.0.0pr2' ,{use:['json-parse', 'json-stringify']});
+

=== added file 'loggerhead/static/javascript/yui/build/json/json-min.js'
--- loggerhead/static/javascript/yui/build/json/json-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/json/json-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("json-parse",function(Y){Y.JSON=Y.JSON||{};var _UNICODE_EXCEPTIONS=/[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,_ESCAPES=/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,_VALUES=/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,_BRACKETS=/(?:^|:|,)(?:\s*\[)+/g,_INVALID=/^[\],:{}\s]*$/,has=Object.prototype.hasOwnProperty,_revive=function(data,reviver){var walk=function(o,key){var k,v,value=o[key];if(value&&typeof value==="object"){for(k in value){if(has.call(value,k)){v=walk(value,k);if(v===undefined){delete value[k];}else{value[k]=v;}}}}return reviver.call(o,key,value);};return typeof reviver==="function"?walk({"":data},""):data;};Y.JSON.parse=function(s,reviver){if(typeof s==="string"){s=s.replace(_UNICODE_EXCEPTIONS,function(c){return"\\u"+("0000"+(+(c.charCodeAt(0))).toString(16)).slice(-4);});if(_INVALID.test(s.replace(_ESCAPES,"@").replace(_VALUES,"]").replace(_BRACKETS,""))){return _revive(eval("("+s+")"),reviver);}}throw new SyntaxError("parseJSON");};},"3.0.0pr2");YUI.add("json-stringify",function(B){var A=B.Lang.isArray;B.JSON=B.JSON||{};B.mix(B.JSON,{_SPECIAL_CHARS:/[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,_CHARS:{"\b":"\\b","\t":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"},dateToString:function(D){function C(E){return E<10?"0"+E:E;}return'"'+D.getUTCFullYear()+"-"+C(D.getUTCMonth()+1)+"-"+C(D.getUTCDate())+"T"+C(D.getUTCHours())+":"+C(D.getUTCMinutes())+":"+C(D.getUTCSeconds())+'Z"';},stringify:function(E,K,G){var F=B.JSON._CHARS,C=B.JSON._SPECIAL_CHARS,I=typeof K==="function"?K:null,D=[];if(I||typeof K!=="object"){K=undefined;}var J=function(N){if(!F[N]){F[N]="\\u"+("0000"+(+(N.charCodeAt(0))).toString(16)).slice(-4);}return F[N];};var M=function(N){return'"'+N.replace(C,J)+'"';};var L=B.JSON.dateToString;var H=function(R,W,T){var N=typeof I==="function"?I.call(R,W,R[W]):R[W],X=typeof N,Q,S,P,O,V,U;if(X==="string"){return M(N);}if(X==="boolean"||N instanceof Boolean){return String(N);}if(X==="number"||N instanceof Number){return isFinite(N)?String(N):"null";}if(N instanceof Date){return L(N);}if(X==="object"){if(!N){return"null";}for(Q=D.length-1;Q>=0;--Q){if(D[Q]===N){return"null";}}D[D.length]=N;U=[];if(T>0){if(A(N)){for(Q=N.length-1;Q>=0;--Q){U[Q]=H(N,Q,T-1)||"null";}}else{O=A(K)?K:B.Object.keys(K||N);for(Q=0,P=0,S=O.length;Q<S;++Q){if(typeof O[Q]==="string"){V=H(N,O[Q],T-1);if(V){U[P++]=M(O[Q])+":"+V;}}}U.sort();}}D.pop();return A(N)?"["+U.join(",")+"]":"{"+U.join(",")+"}";}return undefined;};G=G>=0?G:1/0;return H({"":E},"",G);}});},"3.0.0pr2");YUI.add("json",function(A){},"3.0.0pr2",{use:["json-parse","json-stringify"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/json/json-parse-debug.js'
--- loggerhead/static/javascript/yui/build/json/json-parse-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/json/json-parse-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,157 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('json-parse', function(Y) {
+
+/**
+ * The JSON Utility provides methods to serialize JavaScript objects into
+ * JSON strings and parse JavaScript objects from strings containing JSON data.
+ * Three modules are available for inclusion:
+ * <ol>
+ * <li>1. <code>json-parse</code> for parsing JSON strings into native JavaScript data</li>
+ * <li>2. <code>json-stringify</code> for stringification of JavaScript objects into JSON strings</li>
+ * <li>3. <code>json</code> for both parsing and stringification</li>
+ * </ol>
+ * 
+ * Both <code>json-parse</code> and <code>json-stringify</code> create functions in a static JSON class under your YUI instance (e.g. Y.JSON.parse(..)).
+ * @module json
+ * @class JSON
+ * @static
+ */
+
+/**
+ * Provides Y.JSON.parse method to take JSON strings and return native
+ * JavaScript objects.
+ * @module json
+ * @submodule json-parse
+ * @for JSON
+ * @static
+ */
+Y.JSON = Y.JSON || {};
+
+// All internals kept private for security reasons
+
+/**
+ * Replace certain Unicode characters that JavaScript may handle incorrectly
+ * during eval--either by deleting them or treating them as line endings--with
+ * escae sequences.
+ * IMPORTANT NOTE: This regex will be used to modify the input if a match is
+ * found.
+ * @property _UNICODE_EXCEPTIONS
+ * @type {RegExp}
+ * @private
+ */
+var _UNICODE_EXCEPTIONS = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+
+
+/**
+ * First step in the validation.  Regex used to replace all escape
+ * sequences (i.e. "\\", etc) with '@' characters (a non-JSON character).
+ * @property _ESCAPES
+ * @type {RegExp}
+ * @private
+ */
+    _ESCAPES = /\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,
+
+/**
+ * Second step in the validation.  Regex used to replace all simple
+ * values with ']' characters.
+ * @property _VALUES
+ * @type {RegExp}
+ * @private
+ */
+    _VALUES  = /"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,
+
+/**
+ * Third step in the validation.  Regex used to remove all open square
+ * brackets following a colon, comma, or at the beginning of the string.
+ * @property _BRACKETS
+ * @type {RegExp}
+ * @private
+ */
+
+    _BRACKETS = /(?:^|:|,)(?:\s*\[)+/g,
+
+/**
+ * Final step in the validation.  Regex used to test the string left after
+ * all previous replacements for invalid characters.
+ * @property _INVALID
+ * @type {RegExp}
+ * @private
+ */
+    _INVALID  = /^[\],:{}\s]*$/,
+
+    has = Object.prototype.hasOwnProperty,
+/**
+ * Traverses nested objects, applying a reviver function to each (key,value)
+ * from the scope if the key:value's containing object.  The value returned
+ * from the function will replace the original value in the key:value pair.
+ * If the value returned is undefined, the key will be omitted from the
+ * returned object.
+ * @method _revive
+ * @param data {MIXED} Any JavaScript data
+ * @param reviver {Function} filter or mutation function
+ * @return {MIXED} The results of the filtered data
+ * @private
+ */
+    _revive = function (data, reviver) {
+        var walk = function (o,key) {
+            var k,v,value = o[key];
+            if (value && typeof value === 'object') {
+                for (k in value) {
+                    if (has.call(value,k)) {
+                        v = walk(value, k);
+                        if (v === undefined) {
+                            delete value[k];
+                        } else {
+                            value[k] = v;
+                        }
+                    }
+                }
+            }
+            return reviver.call(o,key,value);
+        };
+
+        return typeof reviver === 'function' ? walk({'':data},'') : data;
+    };
+
+/**
+ * Parse a JSON string, returning the native JavaScript representation.
+ * @param s {string} JSON string data
+ * @param reviver {function} (optional) function(k,v) passed each key value pair of object literals, allowing pruning or altering values
+ * @return {MIXED} the native JavaScript representation of the JSON string
+ * @throws SyntaxError
+ * @method parse
+ * @static
+ * @public
+ */
+Y.JSON.parse = function (s,reviver) {
+    // Ensure valid JSON
+    if (typeof s === 'string') {
+        // Replace certain Unicode characters that are otherwise handled
+        // incorrectly by some browser implementations.
+        // NOTE: This modifies the input if such characters are found!
+        s = s.replace(_UNICODE_EXCEPTIONS, function (c) {
+            return '\\u'+('0000'+(+(c.charCodeAt(0))).toString(16)).slice(-4);
+        });
+        
+        // Test for validity
+        if (_INVALID.test(s.replace(_ESCAPES,'@').
+                            replace(_VALUES,']').
+                            replace(_BRACKETS,''))) {
+
+            // Eval the text into a JavaScript data structure, apply any
+            // reviver function, and return
+            return _revive( eval('(' + s + ')'), reviver );
+        }
+    }
+
+    // The text is not JSON parsable
+    throw new SyntaxError('parseJSON');
+};
+
+
+}, '3.0.0pr2' );

=== added file 'loggerhead/static/javascript/yui/build/json/json-parse-min.js'
--- loggerhead/static/javascript/yui/build/json/json-parse-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/json/json-parse-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("json-parse",function(Y){Y.JSON=Y.JSON||{};var _UNICODE_EXCEPTIONS=/[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,_ESCAPES=/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,_VALUES=/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,_BRACKETS=/(?:^|:|,)(?:\s*\[)+/g,_INVALID=/^[\],:{}\s]*$/,has=Object.prototype.hasOwnProperty,_revive=function(data,reviver){var walk=function(o,key){var k,v,value=o[key];if(value&&typeof value==="object"){for(k in value){if(has.call(value,k)){v=walk(value,k);if(v===undefined){delete value[k];}else{value[k]=v;}}}}return reviver.call(o,key,value);};return typeof reviver==="function"?walk({"":data},""):data;};Y.JSON.parse=function(s,reviver){if(typeof s==="string"){s=s.replace(_UNICODE_EXCEPTIONS,function(c){return"\\u"+("0000"+(+(c.charCodeAt(0))).toString(16)).slice(-4);});if(_INVALID.test(s.replace(_ESCAPES,"@").replace(_VALUES,"]").replace(_BRACKETS,""))){return _revive(eval("("+s+")"),reviver);}}throw new SyntaxError("parseJSON");};},"3.0.0pr2");
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/json/json-parse.js'
--- loggerhead/static/javascript/yui/build/json/json-parse.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/json/json-parse.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,157 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('json-parse', function(Y) {
+
+/**
+ * The JSON Utility provides methods to serialize JavaScript objects into
+ * JSON strings and parse JavaScript objects from strings containing JSON data.
+ * Three modules are available for inclusion:
+ * <ol>
+ * <li>1. <code>json-parse</code> for parsing JSON strings into native JavaScript data</li>
+ * <li>2. <code>json-stringify</code> for stringification of JavaScript objects into JSON strings</li>
+ * <li>3. <code>json</code> for both parsing and stringification</li>
+ * </ol>
+ * 
+ * Both <code>json-parse</code> and <code>json-stringify</code> create functions in a static JSON class under your YUI instance (e.g. Y.JSON.parse(..)).
+ * @module json
+ * @class JSON
+ * @static
+ */
+
+/**
+ * Provides Y.JSON.parse method to take JSON strings and return native
+ * JavaScript objects.
+ * @module json
+ * @submodule json-parse
+ * @for JSON
+ * @static
+ */
+Y.JSON = Y.JSON || {};
+
+// All internals kept private for security reasons
+
+/**
+ * Replace certain Unicode characters that JavaScript may handle incorrectly
+ * during eval--either by deleting them or treating them as line endings--with
+ * escae sequences.
+ * IMPORTANT NOTE: This regex will be used to modify the input if a match is
+ * found.
+ * @property _UNICODE_EXCEPTIONS
+ * @type {RegExp}
+ * @private
+ */
+var _UNICODE_EXCEPTIONS = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+
+
+/**
+ * First step in the validation.  Regex used to replace all escape
+ * sequences (i.e. "\\", etc) with '@' characters (a non-JSON character).
+ * @property _ESCAPES
+ * @type {RegExp}
+ * @private
+ */
+    _ESCAPES = /\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,
+
+/**
+ * Second step in the validation.  Regex used to replace all simple
+ * values with ']' characters.
+ * @property _VALUES
+ * @type {RegExp}
+ * @private
+ */
+    _VALUES  = /"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,
+
+/**
+ * Third step in the validation.  Regex used to remove all open square
+ * brackets following a colon, comma, or at the beginning of the string.
+ * @property _BRACKETS
+ * @type {RegExp}
+ * @private
+ */
+
+    _BRACKETS = /(?:^|:|,)(?:\s*\[)+/g,
+
+/**
+ * Final step in the validation.  Regex used to test the string left after
+ * all previous replacements for invalid characters.
+ * @property _INVALID
+ * @type {RegExp}
+ * @private
+ */
+    _INVALID  = /^[\],:{}\s]*$/,
+
+    has = Object.prototype.hasOwnProperty,
+/**
+ * Traverses nested objects, applying a reviver function to each (key,value)
+ * from the scope if the key:value's containing object.  The value returned
+ * from the function will replace the original value in the key:value pair.
+ * If the value returned is undefined, the key will be omitted from the
+ * returned object.
+ * @method _revive
+ * @param data {MIXED} Any JavaScript data
+ * @param reviver {Function} filter or mutation function
+ * @return {MIXED} The results of the filtered data
+ * @private
+ */
+    _revive = function (data, reviver) {
+        var walk = function (o,key) {
+            var k,v,value = o[key];
+            if (value && typeof value === 'object') {
+                for (k in value) {
+                    if (has.call(value,k)) {
+                        v = walk(value, k);
+                        if (v === undefined) {
+                            delete value[k];
+                        } else {
+                            value[k] = v;
+                        }
+                    }
+                }
+            }
+            return reviver.call(o,key,value);
+        };
+
+        return typeof reviver === 'function' ? walk({'':data},'') : data;
+    };
+
+/**
+ * Parse a JSON string, returning the native JavaScript representation.
+ * @param s {string} JSON string data
+ * @param reviver {function} (optional) function(k,v) passed each key value pair of object literals, allowing pruning or altering values
+ * @return {MIXED} the native JavaScript representation of the JSON string
+ * @throws SyntaxError
+ * @method parse
+ * @static
+ * @public
+ */
+Y.JSON.parse = function (s,reviver) {
+    // Ensure valid JSON
+    if (typeof s === 'string') {
+        // Replace certain Unicode characters that are otherwise handled
+        // incorrectly by some browser implementations.
+        // NOTE: This modifies the input if such characters are found!
+        s = s.replace(_UNICODE_EXCEPTIONS, function (c) {
+            return '\\u'+('0000'+(+(c.charCodeAt(0))).toString(16)).slice(-4);
+        });
+        
+        // Test for validity
+        if (_INVALID.test(s.replace(_ESCAPES,'@').
+                            replace(_VALUES,']').
+                            replace(_BRACKETS,''))) {
+
+            // Eval the text into a JavaScript data structure, apply any
+            // reviver function, and return
+            return _revive( eval('(' + s + ')'), reviver );
+        }
+    }
+
+    // The text is not JSON parsable
+    throw new SyntaxError('parseJSON');
+};
+
+
+}, '3.0.0pr2' );

=== added file 'loggerhead/static/javascript/yui/build/json/json-stringify-debug.js'
--- loggerhead/static/javascript/yui/build/json/json-stringify-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/json/json-stringify-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,204 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('json-stringify', function(Y) {
+
+/**
+ * Provides Y.JSON.stringify method for converting objects to JSON strings.
+ * @module json
+ * @submodule json-stringify
+ * @for JSON
+ * @static
+ */
+var isA = Y.Lang.isArray;
+
+Y.JSON = Y.JSON || {};
+
+Y.mix(Y.JSON,{
+    /**
+     * Regex used to capture characters that need escaping before enclosing
+     * their containing string in quotes.
+     * @property _SPECIAL_CHARS
+     * @type {RegExp}
+     * @private
+     */
+    _SPECIAL_CHARS : /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+
+    /**
+     * Character substitution map for common escapes and special characters.
+     * @property _CHARS
+     * @type {Object}
+     * @static
+     * @private
+     */
+    _CHARS : {
+        '\b': '\\b',
+        '\t': '\\t',
+        '\n': '\\n',
+        '\f': '\\f',
+        '\r': '\\r',
+        '"' : '\\"',
+        '\\': '\\\\'
+    },
+
+    /**
+     * Serializes a Date instance as a UTC date string.  Used internally by
+     * stringify.  Override this method if you need Dates serialized in a
+     * different format.
+     * @method dateToString
+     * @param d {Date} The Date to serialize
+     * @return {String} stringified Date in UTC format YYYY-MM-DDTHH:mm:SSZ
+     * @static
+     */
+    dateToString : function (d) {
+        function _zeroPad(v) {
+            return v < 10 ? '0' + v : v;
+        }
+
+        return '"' + d.getUTCFullYear()   + '-' +
+            _zeroPad(d.getUTCMonth() + 1) + '-' +
+            _zeroPad(d.getUTCDate())      + 'T' +
+            _zeroPad(d.getUTCHours())     + ':' +
+            _zeroPad(d.getUTCMinutes())   + ':' +
+            _zeroPad(d.getUTCSeconds())   + 'Z"';
+    },
+
+    /**
+     * Converts an arbitrary value to a JSON string representation.
+     * Cyclical object or array references are replaced with null.
+     * If a whitelist is provided, only matching object keys will be included.
+     * If a depth limit is provided, objects and arrays at that depth will
+     * be stringified as empty.
+     * @method stringify
+     * @param o {MIXED} any arbitrary object to convert to JSON string
+     * @param w {Array|Function} (optional) whitelist of acceptable object
+     *                  keys to include, or a replacer function to modify the
+     *                  raw value before serialization
+     * @param d {number} (optional) depth limit to recurse objects/arrays
+     *                   (practical minimum 1)
+     * @return {string} JSON string representation of the input
+     * @static
+     * @public
+     */
+    stringify : function (o,w,d) {
+
+        var m      = Y.JSON._CHARS,
+            str_re = Y.JSON._SPECIAL_CHARS,
+            rep    = typeof w === 'function' ? w : null,
+            pstack = []; // Processing stack used for cyclical ref protection
+
+        if (rep || typeof w !== 'object') {
+            w = undefined;
+        }
+
+        // escape encode special characters
+        var _char = function (c) {
+            if (!m[c]) {
+                m[c]='\\u'+('0000'+(+(c.charCodeAt(0))).toString(16)).slice(-4);
+            }
+            return m[c];
+        };
+
+        // Enclose the escaped string in double quotes
+        var _string = function (s) {
+            return '"' + s.replace(str_re, _char) + '"';
+        };
+
+        // Use the configured date conversion
+        var _date = Y.JSON.dateToString;
+    
+        // Worker function.  Fork behavior on data type and recurse objects and
+        // arrays per the configured depth.
+        var _stringify = function (h,key,d) {
+            var o = typeof rep === 'function' ? rep.call(h,key,h[key]) : h[key],
+                t = typeof o,
+                i,len,j, // array iteration
+                k,v,     // object iteration
+                a;       // composition array for performance over string concat
+
+            // String
+            if (t === 'string') {
+                return _string(o);
+            }
+
+            // native boolean and Boolean instance
+            if (t === 'boolean' || o instanceof Boolean) {
+                return String(o);
+            }
+
+            // native number and Number instance
+            if (t === 'number' || o instanceof Number) {
+                return isFinite(o) ? String(o) : 'null';
+            }
+
+            // Date
+            if (o instanceof Date) {
+                return _date(o);
+            }
+
+            // Object types
+            if (t === 'object') {
+                if (!o) {
+                    return 'null';
+                }
+
+                // Check for cyclical references
+                for (i = pstack.length - 1; i >= 0; --i) {
+                    if (pstack[i] === o) {
+                        return 'null';
+                    }
+                }
+
+                // Add the object to the processing stack
+                pstack[pstack.length] = o;
+
+                a = [];
+
+                // Only recurse if we're above depth config
+                if (d > 0) {
+                    // Array
+                    if (isA(o)) {
+                        for (i = o.length - 1; i >= 0; --i) {
+                            a[i] = _stringify(o,i,d-1) || 'null';
+                        }
+
+                    // Object
+                    } else {
+                        // If whitelist provided, take only those keys
+                        k = isA(w) ? w : Y.Object.keys(w||o);
+
+                        for (i = 0, j = 0, len = k.length; i < len; ++i) {
+                            if (typeof k[i] === 'string') {
+                                v = _stringify(o,k[i],d-1);
+                                if (v) {
+                                    a[j++] = _string(k[i]) + ':' + v;
+                                }
+                            }
+                        }
+
+                        a.sort();
+                    }
+                }
+
+                // remove the array from the stack
+                pstack.pop();
+
+                return isA(o) ? '['+a.join(',')+']' : '{'+a.join(',')+'}';
+            }
+
+            return undefined; // invalid input
+        };
+
+        // Default depth to POSITIVE_INFINITY
+        d = d >= 0 ? d : 1/0;
+
+        // process the input
+        return _stringify({'':o},'',d);
+    }
+});
+
+
+}, '3.0.0pr2' );

=== added file 'loggerhead/static/javascript/yui/build/json/json-stringify-min.js'
--- loggerhead/static/javascript/yui/build/json/json-stringify-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/json/json-stringify-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("json-stringify",function(B){var A=B.Lang.isArray;B.JSON=B.JSON||{};B.mix(B.JSON,{_SPECIAL_CHARS:/[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,_CHARS:{"\b":"\\b","\t":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"},dateToString:function(D){function C(E){return E<10?"0"+E:E;}return'"'+D.getUTCFullYear()+"-"+C(D.getUTCMonth()+1)+"-"+C(D.getUTCDate())+"T"+C(D.getUTCHours())+":"+C(D.getUTCMinutes())+":"+C(D.getUTCSeconds())+'Z"';},stringify:function(E,K,G){var F=B.JSON._CHARS,C=B.JSON._SPECIAL_CHARS,I=typeof K==="function"?K:null,D=[];if(I||typeof K!=="object"){K=undefined;}var J=function(N){if(!F[N]){F[N]="\\u"+("0000"+(+(N.charCodeAt(0))).toString(16)).slice(-4);}return F[N];};var M=function(N){return'"'+N.replace(C,J)+'"';};var L=B.JSON.dateToString;var H=function(R,W,T){var N=typeof I==="function"?I.call(R,W,R[W]):R[W],X=typeof N,Q,S,P,O,V,U;if(X==="string"){return M(N);}if(X==="boolean"||N instanceof Boolean){return String(N);}if(X==="number"||N instanceof Number){return isFinite(N)?String(N):"null";}if(N instanceof Date){return L(N);}if(X==="object"){if(!N){return"null";}for(Q=D.length-1;Q>=0;--Q){if(D[Q]===N){return"null";}}D[D.length]=N;U=[];if(T>0){if(A(N)){for(Q=N.length-1;Q>=0;--Q){U[Q]=H(N,Q,T-1)||"null";}}else{O=A(K)?K:B.Object.keys(K||N);for(Q=0,P=0,S=O.length;Q<S;++Q){if(typeof O[Q]==="string"){V=H(N,O[Q],T-1);if(V){U[P++]=M(O[Q])+":"+V;}}}U.sort();}}D.pop();return A(N)?"["+U.join(",")+"]":"{"+U.join(",")+"}";}return undefined;};G=G>=0?G:1/0;return H({"":E},"",G);}});},"3.0.0pr2");
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/json/json-stringify.js'
--- loggerhead/static/javascript/yui/build/json/json-stringify.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/json/json-stringify.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,204 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('json-stringify', function(Y) {
+
+/**
+ * Provides Y.JSON.stringify method for converting objects to JSON strings.
+ * @module json
+ * @submodule json-stringify
+ * @for JSON
+ * @static
+ */
+var isA = Y.Lang.isArray;
+
+Y.JSON = Y.JSON || {};
+
+Y.mix(Y.JSON,{
+    /**
+     * Regex used to capture characters that need escaping before enclosing
+     * their containing string in quotes.
+     * @property _SPECIAL_CHARS
+     * @type {RegExp}
+     * @private
+     */
+    _SPECIAL_CHARS : /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+
+    /**
+     * Character substitution map for common escapes and special characters.
+     * @property _CHARS
+     * @type {Object}
+     * @static
+     * @private
+     */
+    _CHARS : {
+        '\b': '\\b',
+        '\t': '\\t',
+        '\n': '\\n',
+        '\f': '\\f',
+        '\r': '\\r',
+        '"' : '\\"',
+        '\\': '\\\\'
+    },
+
+    /**
+     * Serializes a Date instance as a UTC date string.  Used internally by
+     * stringify.  Override this method if you need Dates serialized in a
+     * different format.
+     * @method dateToString
+     * @param d {Date} The Date to serialize
+     * @return {String} stringified Date in UTC format YYYY-MM-DDTHH:mm:SSZ
+     * @static
+     */
+    dateToString : function (d) {
+        function _zeroPad(v) {
+            return v < 10 ? '0' + v : v;
+        }
+
+        return '"' + d.getUTCFullYear()   + '-' +
+            _zeroPad(d.getUTCMonth() + 1) + '-' +
+            _zeroPad(d.getUTCDate())      + 'T' +
+            _zeroPad(d.getUTCHours())     + ':' +
+            _zeroPad(d.getUTCMinutes())   + ':' +
+            _zeroPad(d.getUTCSeconds())   + 'Z"';
+    },
+
+    /**
+     * Converts an arbitrary value to a JSON string representation.
+     * Cyclical object or array references are replaced with null.
+     * If a whitelist is provided, only matching object keys will be included.
+     * If a depth limit is provided, objects and arrays at that depth will
+     * be stringified as empty.
+     * @method stringify
+     * @param o {MIXED} any arbitrary object to convert to JSON string
+     * @param w {Array|Function} (optional) whitelist of acceptable object
+     *                  keys to include, or a replacer function to modify the
+     *                  raw value before serialization
+     * @param d {number} (optional) depth limit to recurse objects/arrays
+     *                   (practical minimum 1)
+     * @return {string} JSON string representation of the input
+     * @static
+     * @public
+     */
+    stringify : function (o,w,d) {
+
+        var m      = Y.JSON._CHARS,
+            str_re = Y.JSON._SPECIAL_CHARS,
+            rep    = typeof w === 'function' ? w : null,
+            pstack = []; // Processing stack used for cyclical ref protection
+
+        if (rep || typeof w !== 'object') {
+            w = undefined;
+        }
+
+        // escape encode special characters
+        var _char = function (c) {
+            if (!m[c]) {
+                m[c]='\\u'+('0000'+(+(c.charCodeAt(0))).toString(16)).slice(-4);
+            }
+            return m[c];
+        };
+
+        // Enclose the escaped string in double quotes
+        var _string = function (s) {
+            return '"' + s.replace(str_re, _char) + '"';
+        };
+
+        // Use the configured date conversion
+        var _date = Y.JSON.dateToString;
+    
+        // Worker function.  Fork behavior on data type and recurse objects and
+        // arrays per the configured depth.
+        var _stringify = function (h,key,d) {
+            var o = typeof rep === 'function' ? rep.call(h,key,h[key]) : h[key],
+                t = typeof o,
+                i,len,j, // array iteration
+                k,v,     // object iteration
+                a;       // composition array for performance over string concat
+
+            // String
+            if (t === 'string') {
+                return _string(o);
+            }
+
+            // native boolean and Boolean instance
+            if (t === 'boolean' || o instanceof Boolean) {
+                return String(o);
+            }
+
+            // native number and Number instance
+            if (t === 'number' || o instanceof Number) {
+                return isFinite(o) ? String(o) : 'null';
+            }
+
+            // Date
+            if (o instanceof Date) {
+                return _date(o);
+            }
+
+            // Object types
+            if (t === 'object') {
+                if (!o) {
+                    return 'null';
+                }
+
+                // Check for cyclical references
+                for (i = pstack.length - 1; i >= 0; --i) {
+                    if (pstack[i] === o) {
+                        return 'null';
+                    }
+                }
+
+                // Add the object to the processing stack
+                pstack[pstack.length] = o;
+
+                a = [];
+
+                // Only recurse if we're above depth config
+                if (d > 0) {
+                    // Array
+                    if (isA(o)) {
+                        for (i = o.length - 1; i >= 0; --i) {
+                            a[i] = _stringify(o,i,d-1) || 'null';
+                        }
+
+                    // Object
+                    } else {
+                        // If whitelist provided, take only those keys
+                        k = isA(w) ? w : Y.Object.keys(w||o);
+
+                        for (i = 0, j = 0, len = k.length; i < len; ++i) {
+                            if (typeof k[i] === 'string') {
+                                v = _stringify(o,k[i],d-1);
+                                if (v) {
+                                    a[j++] = _string(k[i]) + ':' + v;
+                                }
+                            }
+                        }
+
+                        a.sort();
+                    }
+                }
+
+                // remove the array from the stack
+                pstack.pop();
+
+                return isA(o) ? '['+a.join(',')+']' : '{'+a.join(',')+'}';
+            }
+
+            return undefined; // invalid input
+        };
+
+        // Default depth to POSITIVE_INFINITY
+        d = d >= 0 ? d : 1/0;
+
+        // process the input
+        return _stringify({'':o},'',d);
+    }
+});
+
+
+}, '3.0.0pr2' );

=== added file 'loggerhead/static/javascript/yui/build/json/json.js'
--- loggerhead/static/javascript/yui/build/json/json.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/json/json.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,359 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('json-parse', function(Y) {
+
+/**
+ * The JSON Utility provides methods to serialize JavaScript objects into
+ * JSON strings and parse JavaScript objects from strings containing JSON data.
+ * Three modules are available for inclusion:
+ * <ol>
+ * <li>1. <code>json-parse</code> for parsing JSON strings into native JavaScript data</li>
+ * <li>2. <code>json-stringify</code> for stringification of JavaScript objects into JSON strings</li>
+ * <li>3. <code>json</code> for both parsing and stringification</li>
+ * </ol>
+ * 
+ * Both <code>json-parse</code> and <code>json-stringify</code> create functions in a static JSON class under your YUI instance (e.g. Y.JSON.parse(..)).
+ * @module json
+ * @class JSON
+ * @static
+ */
+
+/**
+ * Provides Y.JSON.parse method to take JSON strings and return native
+ * JavaScript objects.
+ * @module json
+ * @submodule json-parse
+ * @for JSON
+ * @static
+ */
+Y.JSON = Y.JSON || {};
+
+// All internals kept private for security reasons
+
+/**
+ * Replace certain Unicode characters that JavaScript may handle incorrectly
+ * during eval--either by deleting them or treating them as line endings--with
+ * escae sequences.
+ * IMPORTANT NOTE: This regex will be used to modify the input if a match is
+ * found.
+ * @property _UNICODE_EXCEPTIONS
+ * @type {RegExp}
+ * @private
+ */
+var _UNICODE_EXCEPTIONS = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+
+
+/**
+ * First step in the validation.  Regex used to replace all escape
+ * sequences (i.e. "\\", etc) with '@' characters (a non-JSON character).
+ * @property _ESCAPES
+ * @type {RegExp}
+ * @private
+ */
+    _ESCAPES = /\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,
+
+/**
+ * Second step in the validation.  Regex used to replace all simple
+ * values with ']' characters.
+ * @property _VALUES
+ * @type {RegExp}
+ * @private
+ */
+    _VALUES  = /"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,
+
+/**
+ * Third step in the validation.  Regex used to remove all open square
+ * brackets following a colon, comma, or at the beginning of the string.
+ * @property _BRACKETS
+ * @type {RegExp}
+ * @private
+ */
+
+    _BRACKETS = /(?:^|:|,)(?:\s*\[)+/g,
+
+/**
+ * Final step in the validation.  Regex used to test the string left after
+ * all previous replacements for invalid characters.
+ * @property _INVALID
+ * @type {RegExp}
+ * @private
+ */
+    _INVALID  = /^[\],:{}\s]*$/,
+
+    has = Object.prototype.hasOwnProperty,
+/**
+ * Traverses nested objects, applying a reviver function to each (key,value)
+ * from the scope if the key:value's containing object.  The value returned
+ * from the function will replace the original value in the key:value pair.
+ * If the value returned is undefined, the key will be omitted from the
+ * returned object.
+ * @method _revive
+ * @param data {MIXED} Any JavaScript data
+ * @param reviver {Function} filter or mutation function
+ * @return {MIXED} The results of the filtered data
+ * @private
+ */
+    _revive = function (data, reviver) {
+        var walk = function (o,key) {
+            var k,v,value = o[key];
+            if (value && typeof value === 'object') {
+                for (k in value) {
+                    if (has.call(value,k)) {
+                        v = walk(value, k);
+                        if (v === undefined) {
+                            delete value[k];
+                        } else {
+                            value[k] = v;
+                        }
+                    }
+                }
+            }
+            return reviver.call(o,key,value);
+        };
+
+        return typeof reviver === 'function' ? walk({'':data},'') : data;
+    };
+
+/**
+ * Parse a JSON string, returning the native JavaScript representation.
+ * @param s {string} JSON string data
+ * @param reviver {function} (optional) function(k,v) passed each key value pair of object literals, allowing pruning or altering values
+ * @return {MIXED} the native JavaScript representation of the JSON string
+ * @throws SyntaxError
+ * @method parse
+ * @static
+ * @public
+ */
+Y.JSON.parse = function (s,reviver) {
+    // Ensure valid JSON
+    if (typeof s === 'string') {
+        // Replace certain Unicode characters that are otherwise handled
+        // incorrectly by some browser implementations.
+        // NOTE: This modifies the input if such characters are found!
+        s = s.replace(_UNICODE_EXCEPTIONS, function (c) {
+            return '\\u'+('0000'+(+(c.charCodeAt(0))).toString(16)).slice(-4);
+        });
+        
+        // Test for validity
+        if (_INVALID.test(s.replace(_ESCAPES,'@').
+                            replace(_VALUES,']').
+                            replace(_BRACKETS,''))) {
+
+            // Eval the text into a JavaScript data structure, apply any
+            // reviver function, and return
+            return _revive( eval('(' + s + ')'), reviver );
+        }
+    }
+
+    // The text is not JSON parsable
+    throw new SyntaxError('parseJSON');
+};
+
+
+}, '3.0.0pr2' );
+YUI.add('json-stringify', function(Y) {
+
+/**
+ * Provides Y.JSON.stringify method for converting objects to JSON strings.
+ * @module json
+ * @submodule json-stringify
+ * @for JSON
+ * @static
+ */
+var isA = Y.Lang.isArray;
+
+Y.JSON = Y.JSON || {};
+
+Y.mix(Y.JSON,{
+    /**
+     * Regex used to capture characters that need escaping before enclosing
+     * their containing string in quotes.
+     * @property _SPECIAL_CHARS
+     * @type {RegExp}
+     * @private
+     */
+    _SPECIAL_CHARS : /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+
+    /**
+     * Character substitution map for common escapes and special characters.
+     * @property _CHARS
+     * @type {Object}
+     * @static
+     * @private
+     */
+    _CHARS : {
+        '\b': '\\b',
+        '\t': '\\t',
+        '\n': '\\n',
+        '\f': '\\f',
+        '\r': '\\r',
+        '"' : '\\"',
+        '\\': '\\\\'
+    },
+
+    /**
+     * Serializes a Date instance as a UTC date string.  Used internally by
+     * stringify.  Override this method if you need Dates serialized in a
+     * different format.
+     * @method dateToString
+     * @param d {Date} The Date to serialize
+     * @return {String} stringified Date in UTC format YYYY-MM-DDTHH:mm:SSZ
+     * @static
+     */
+    dateToString : function (d) {
+        function _zeroPad(v) {
+            return v < 10 ? '0' + v : v;
+        }
+
+        return '"' + d.getUTCFullYear()   + '-' +
+            _zeroPad(d.getUTCMonth() + 1) + '-' +
+            _zeroPad(d.getUTCDate())      + 'T' +
+            _zeroPad(d.getUTCHours())     + ':' +
+            _zeroPad(d.getUTCMinutes())   + ':' +
+            _zeroPad(d.getUTCSeconds())   + 'Z"';
+    },
+
+    /**
+     * Converts an arbitrary value to a JSON string representation.
+     * Cyclical object or array references are replaced with null.
+     * If a whitelist is provided, only matching object keys will be included.
+     * If a depth limit is provided, objects and arrays at that depth will
+     * be stringified as empty.
+     * @method stringify
+     * @param o {MIXED} any arbitrary object to convert to JSON string
+     * @param w {Array|Function} (optional) whitelist of acceptable object
+     *                  keys to include, or a replacer function to modify the
+     *                  raw value before serialization
+     * @param d {number} (optional) depth limit to recurse objects/arrays
+     *                   (practical minimum 1)
+     * @return {string} JSON string representation of the input
+     * @static
+     * @public
+     */
+    stringify : function (o,w,d) {
+
+        var m      = Y.JSON._CHARS,
+            str_re = Y.JSON._SPECIAL_CHARS,
+            rep    = typeof w === 'function' ? w : null,
+            pstack = []; // Processing stack used for cyclical ref protection
+
+        if (rep || typeof w !== 'object') {
+            w = undefined;
+        }
+
+        // escape encode special characters
+        var _char = function (c) {
+            if (!m[c]) {
+                m[c]='\\u'+('0000'+(+(c.charCodeAt(0))).toString(16)).slice(-4);
+            }
+            return m[c];
+        };
+
+        // Enclose the escaped string in double quotes
+        var _string = function (s) {
+            return '"' + s.replace(str_re, _char) + '"';
+        };
+
+        // Use the configured date conversion
+        var _date = Y.JSON.dateToString;
+    
+        // Worker function.  Fork behavior on data type and recurse objects and
+        // arrays per the configured depth.
+        var _stringify = function (h,key,d) {
+            var o = typeof rep === 'function' ? rep.call(h,key,h[key]) : h[key],
+                t = typeof o,
+                i,len,j, // array iteration
+                k,v,     // object iteration
+                a;       // composition array for performance over string concat
+
+            // String
+            if (t === 'string') {
+                return _string(o);
+            }
+
+            // native boolean and Boolean instance
+            if (t === 'boolean' || o instanceof Boolean) {
+                return String(o);
+            }
+
+            // native number and Number instance
+            if (t === 'number' || o instanceof Number) {
+                return isFinite(o) ? String(o) : 'null';
+            }
+
+            // Date
+            if (o instanceof Date) {
+                return _date(o);
+            }
+
+            // Object types
+            if (t === 'object') {
+                if (!o) {
+                    return 'null';
+                }
+
+                // Check for cyclical references
+                for (i = pstack.length - 1; i >= 0; --i) {
+                    if (pstack[i] === o) {
+                        return 'null';
+                    }
+                }
+
+                // Add the object to the processing stack
+                pstack[pstack.length] = o;
+
+                a = [];
+
+                // Only recurse if we're above depth config
+                if (d > 0) {
+                    // Array
+                    if (isA(o)) {
+                        for (i = o.length - 1; i >= 0; --i) {
+                            a[i] = _stringify(o,i,d-1) || 'null';
+                        }
+
+                    // Object
+                    } else {
+                        // If whitelist provided, take only those keys
+                        k = isA(w) ? w : Y.Object.keys(w||o);
+
+                        for (i = 0, j = 0, len = k.length; i < len; ++i) {
+                            if (typeof k[i] === 'string') {
+                                v = _stringify(o,k[i],d-1);
+                                if (v) {
+                                    a[j++] = _string(k[i]) + ':' + v;
+                                }
+                            }
+                        }
+
+                        a.sort();
+                    }
+                }
+
+                // remove the array from the stack
+                pstack.pop();
+
+                return isA(o) ? '['+a.join(',')+']' : '{'+a.join(',')+'}';
+            }
+
+            return undefined; // invalid input
+        };
+
+        // Default depth to POSITIVE_INFINITY
+        d = d >= 0 ? d : 1/0;
+
+        // process the input
+        return _stringify({'':o},'',d);
+    }
+});
+
+
+}, '3.0.0pr2' );
+
+
+YUI.add('json', function(Y){}, '3.0.0pr2' ,{use:['json-parse', 'json-stringify']});
+

=== added directory 'loggerhead/static/javascript/yui/build/loader'
=== added file 'loggerhead/static/javascript/yui/build/loader/README'
--- loggerhead/static/javascript/yui/build/loader/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/loader/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,21 @@
+YUI Loader
+    Adds dynamic loading of YUI and external script and css files.
+    Calculates dependencies and optimizes the selection of file includes.
+
+
+3.0.0pr2
+    - get requires yui-base
+    - loader requires get
+    - combo url build process defends against undefined modules
+    - Added combo handler support for CSS
+    - Filters are correctly applied to combo and fullpath urls
+    - Added compat, profiler, yuitest, widget, stylesheet, classnamemanager,
+            overlay, plugin, slider, console
+    - Added io submodules
+    - queue requires event
+    - Added submodule metadata logic
+    - Added plugin metadata logic
+    - Added skin metadata logic
+
+3.0.0pr1
+    Initial Release

=== added file 'loggerhead/static/javascript/yui/build/loader/loader-debug.js'
--- loggerhead/static/javascript/yui/build/loader/loader-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/loader/loader-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1851 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * Loader dynamically loads script and css files.  It includes the dependency
+ * info for the version of the library in use, and will automatically pull in
+ * dependencies for the modules requested.  It supports rollup files and will
+ * automatically use these when appropriate in order to minimize the number of
+ * http connections required to load all of the dependencies.  It can load the
+ * files from the Yahoo! CDN, and it can utilize the combo service provided on
+ * this network to reduce the number of http connections required to download 
+ * YUI files.
+ *
+ * @module yui
+ * @submodule loader
+ */
+
+/**
+ * Loader dynamically loads script and css files.  It includes the dependency
+ * info for the version of the library in use, and will automatically pull in
+ * dependencies for the modules requested.  It supports rollup files and will
+ * automatically use these when appropriate in order to minimize the number of
+ * http connections required to load all of the dependencies.  It can load the
+ * files from the Yahoo! CDN, and it can utilize the combo service provided on
+ * this network to reduce the number of http connections required to download 
+ * YUI files.
+ * @class Loader
+ * @constructor
+ * @param o an optional set of configuration options.  Valid options:
+ * <ul>
+ *  <li>base:
+ *  The base dir</li>
+ *  <li>secureBase:
+ *  The secure base dir (not implemented)</li>
+ *  <li>comboBase:
+ *  The YUI combo service base dir. Ex: http://yui.yahooapis.com/combo?</li>
+ *  <li>root:
+ *  The root path to prepend to module names for the combo service. Ex: 2.5.2/build/</li>
+ *  <li>filter:
+ *  
+ * A filter to apply to result urls.  This filter will modify the default
+ * path for all modules.  The default path for the YUI library is the
+ * minified version of the files (e.g., event-min.js).  The filter property
+ * can be a predefined filter or a custom filter.  The valid predefined 
+ * filters are:
+ * <dl>
+ *  <dt>DEBUG</dt>
+ *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+ *      This option will automatically include the logger widget</dd>
+ *  <dt>RAW</dt>
+ *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+ * </dl>
+ * You can also define a custom filter, which must be an object literal 
+ * containing a search expression and a replace string:
+ * <pre>
+ *  myFilter: &#123; 
+ *      'searchExp': "-min\\.js", 
+ *      'replaceStr': "-debug.js"
+ *  &#125;
+ * </pre>
+ *
+ *  </li>
+ *  <li>combine:
+ *  Use the YUI combo service to reduce the number of http connections required to load your dependencies</li>
+ *  <li>ignore:
+ *  A list of modules that should never be dynamically loaded</li>
+ *  <li>force:
+ *  A list of modules that should always be loaded when required, even if already present on the page</li>
+ *  <li>insertBefore:
+ *  Node or id for a node that should be used as the insertion point for new nodes</li>
+ *  <li>charset:
+ *  charset for dynamic nodes</li>
+ *  <li>timeout:
+ *  number of milliseconds before a timeout occurs when dynamically loading nodes.  in not set, there is no timeout</li>
+ *  <li>context:
+ *  execution context for all callbacks</li>
+ *  <li>onSuccess:
+ *  callback for the 'success' event</li>
+ *  <li>onFailure:
+ *  callback for the 'failure' event</li>
+ *  <li>onTimeout:
+ *  callback for the 'timeout' event</li>
+ *  <li>onProgress:
+ *  callback executed each time a script or css file is loaded</li>
+ *  <li>modules:
+ *  A list of module definitions.  See Loader.addModule for the supported module metadata</li>
+ * </ul>
+ */
+
+// @TODO backed out the custom event changes so that the event system
+// isn't required in the seed build.  If needed, we may want to 
+// add them back if the event system is detected.
+
+/*
+ * Executed when the loader successfully completes an insert operation
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onSuccess config option.
+ * @event success
+ */
+
+/*
+ * Executed when the loader fails to complete an insert operation.
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onFailure config option.
+ *
+ * @event failure
+ */
+
+/*
+ * Executed when a Get operation times out.
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onTimeout config option.
+ *
+ * @event timeout
+ */
+
+// http://yui.yahooapis.com/combo?2.5.2/build/yahoo/yahoo-min.js&2.5.2/build/dom/dom-min.js&2.5.2/build/event/event-min.js&2.5.2/build/autocomplete/autocomplete-min.js"
+
+YUI.add("loader", function(Y) {
+
+var BASE = 'base', 
+    CSS = 'css',
+    JS = 'js',
+    CSSRESET = 'cssreset',
+    CSSFONTS = 'cssfonts',
+    CSSGRIDS = 'cssgrids',
+    CSSBASE = 'cssbase',
+    CSS_AFTER = [CSSRESET, CSSFONTS, CSSGRIDS, 'cssreset-context', 'cssfonts-context', 'cssgrids-context'],
+    YUI_CSS = ['reset', 'fonts', 'grids', 'base'],
+    VERSION = '3.0.0pr2',
+    ROOT = VERSION + '/build/',
+    CONTEXT = '-context',
+    META = {
+
+    version: VERSION,
+
+    root: ROOT,
+
+    base: 'http://yui.yahooapis.com/' + ROOT,
+
+    comboBase: 'http://yui.yahooapis.com/combo?',
+
+    skin: {
+        defaultSkin: 'sam',
+        base: 'assets/skins/',
+        path: 'skin.css',
+        after: ['reset', 'fonts', 'grids', 'base']
+        //rollup: 3
+    },
+
+    modules: {
+
+       dom: {
+            requires: ['event'],
+            submodules: {
+                'dom-base': {
+                    requires: ['event']
+                },
+                'dom-style': {
+                    requires: ['dom-base']
+
+                },
+                'dom-screen': {
+                    requires: ['dom-base', 'dom-style']
+                },
+                selector: {
+                    requires: ['dom-base']
+                }
+            }
+        },
+
+        node: {
+            requires: ['dom'],
+            submodules: {
+                'node-base': {
+                    requires: ['dom-base', 'selector']
+                },
+                'node-style': {
+                    requires: ['dom-style', 'node-base']
+                },
+                'node-screen': {
+                    requires: ['dom-screen', 'node-base']
+                },
+                'node-event-simulate': {
+                    requires: ['node-base']
+                }
+            }
+        },
+
+        anim: {
+            requires: [BASE, 'node'],
+            submodules: {
+                'anim-base': {
+                    requires: ['base', 'node-style']
+                },
+                'anim-color': {
+                    requires: ['anim-base']
+                },
+                'anim-curve': {
+                    requires: ['anim-xy']
+                },
+                'anim-easing': {
+                },
+                'anim-scroll': {
+                    requires: ['anim-base']
+                },
+                'anim-xy': {
+                    requires: ['anim-base', 'node-screen']
+                },
+                'anim-node-plugin': {
+                     requires: ['node', 'anim-base']
+                }
+            }
+        },
+
+        attribute: { 
+            requires: ['event']
+        },
+
+        base: {
+            requires: ['attribute']
+        },
+        
+        compat: { 
+            requires: ['node', 'dump', 'substitute']
+        },
+
+        classnamemanager: { },
+
+        console: {
+            requires: ['widget', 'substitute'],
+            skinnable: true
+        },
+        
+        cookie: { },
+
+        // Note: CSS attributes are modified programmatically to reduce metadata size
+        // cssbase: {
+        //     after: CSS_AFTER
+        // },
+
+        // cssgrids: {
+        //     requires: [CSSFONTS],
+        //     optional: [CSSRESET]
+        // },
+
+        dd:{
+            submodules: {
+                'dd-ddm-base': {
+                    requires: ['node', BASE]
+                }, 
+                'dd-ddm':{
+                    requires: ['dd-ddm-base']
+                }, 
+                'dd-ddm-drop':{
+                    requires: ['dd-ddm']
+                }, 
+                'dd-drag':{
+                    requires: ['dd-ddm-base']
+                }, 
+                'dd-drop':{
+                    requires: ['dd-ddm-drop']
+                }, 
+                'dd-proxy':{
+                    requires: ['dd-drag']
+                }, 
+                'dd-constrain':{
+                    requires: ['dd-drag', 'dd-proxy']
+                }, 
+                'dd-plugin':{
+                    requires: ['dd-drag'],
+                    optional: ['dd-constrain', 'dd-proxy']
+                },
+                'dd-drop-plugin':{
+                    requires: ['dd-drop']
+                }
+            }
+        },
+
+        dump: { },
+
+        event: { 
+            requires: ['oop']
+        },
+
+        get: { 
+            requires: ['yui-base']
+        },
+        
+        io:{
+            submodules: {
+
+                'io-base': {
+                    requires: ['node']
+                }, 
+
+                'io-xdr': {
+                    requires: ['io-base']
+                }, 
+
+                'io-form': {
+                    requires: ['io-base']
+                }, 
+
+                'io-upload-iframe': {
+                    requires: ['io-base']
+                },
+
+                'io-queue': {
+                    requires: ['io-base']
+                }
+            }
+        },
+
+        json: {
+            submodules: {
+                'json-parse': {
+                },
+
+                'json-stringify': {
+                }
+            }
+        },
+
+        loader: { 
+            requires: ['get']
+        },
+
+        'node-menunav': {
+            requires: ['node', 'classnamemanager'],
+            skinnable: true
+        },
+        
+        oop: { 
+            requires: ['yui-base']
+        },
+
+        overlay: {
+            requires: ['widget', 'widget-position', 'widget-position-ext', 'widget-stack', 'widget-stdmod'],
+            skinnable: true
+        },
+
+        plugin: { 
+            requires: ['base']
+        },
+
+        profiler: { },
+
+        queue: {
+            requires: ['node']
+        },
+
+        slider: {
+            requires: ['widget', 'dd-constrain'],
+            skinnable: true
+        },
+
+        stylesheet: { },
+
+        substitute: {
+            optional: ['dump']
+        },
+
+        widget: {
+            requires: ['base', 'node', 'classnamemanager'],
+            plugins: {
+                'widget-position': { },
+                'widget-position-ext': {
+                    requires: ['widget-position']
+                },
+                'widget-stack': {
+                    skinnable: true
+                },
+                'widget-stdmod': { }
+            },
+            skinnable: true
+        },
+
+        // Since YUI is required for everything else, it should not be specified as
+        // a dependency.
+        yui: {
+            supersedes: ['yui-base', 'get', 'loader']
+        },
+
+        'yui-base': { },
+
+        yuitest: {                                                                                                                                                        
+            requires: ['substitute', 'node', 'json']                                                                                                                     
+        }  
+
+    }
+};
+
+var _path = function(dir, file, type) {
+    return dir + '/' + file + '-min.' + (type || CSS);
+};
+
+var _cssmeta = function() {
+    var mods = META.modules;
+    // modify the meta info for YUI CSS
+    for (var i=0; i<YUI_CSS.length; i=i+1) {
+        var bname = YUI_CSS[i],
+            mname = CSS + bname;
+
+        mods[mname] = {
+            type: CSS,
+            path: _path(mname, bname)
+        };
+
+        // define -context module
+        var contextname = mname + CONTEXT;
+        bname = bname + CONTEXT;
+
+        mods[contextname] = {
+            type: CSS,
+            path: _path(mname, bname)
+        };
+
+        if (mname == CSSGRIDS) {
+            mods[mname].requires = [CSSFONTS];
+            mods[mname].optional = [CSSRESET];
+            mods[contextname].requires = [CSSFONTS + CONTEXT];
+            mods[contextname].optional = [CSSRESET + CONTEXT];
+        } else if (mname == CSSBASE) {
+            mods[mname].after = CSS_AFTER;
+            mods[contextname].after = CSS_AFTER;
+        }
+    }
+}();
+
+Y.Env.meta = META;
+
+
+    var L=Y.Lang, env=Y.Env,
+        PROV = "_provides", SUPER = "_supersedes",
+        REQ = "expanded";
+
+    Y.Loader = function(o) {
+
+        /**
+         * Internal callback to handle multiple internal insert() calls
+         * so that css is inserted prior to js
+         * @property _internalCallback
+         * @private
+         */
+        this._internalCallback = null;
+
+        /**
+         * Use the YUI environment listener to detect script load.  This
+         * is only switched on for Safari 2.x and below.
+         * @property _useYahooListener
+         * @private
+         */
+        this._useYahooListener = false;
+
+        /**
+         * Callback that will be executed when the loader is finished
+         * with an insert
+         * @method onSuccess
+         * @type function
+         */
+        this.onSuccess = null;
+
+        /**
+         * Callback that will be executed if there is a failure
+         * @method onFailure
+         * @type function
+         */
+        this.onFailure = null;
+
+        /**
+         * Callback executed each time a script or css file is loaded
+         * @method onProgress
+         * @type function
+         */
+        this.onProgress = null;
+
+        /**
+         * Callback that will be executed if a timeout occurs
+         * @method onTimeout
+         * @type function
+         */
+        this.onTimeout = null;
+
+        /**
+         * The execution context for all callbacks
+         * @property context
+         * @default {YUI} the YUI instance
+         */
+        this.context = Y;
+
+        /**
+         * Data that is passed to all callbacks
+         * @property data
+         */
+        this.data = null;
+
+        /**
+         * Node reference or id where new nodes should be inserted before
+         * @property insertBefore
+         * @type string|HTMLElement
+         */
+        this.insertBefore = null;
+
+        /**
+         * The charset attribute for inserted nodes
+         * @property charset
+         * @type string
+         * @default utf-8
+         */
+        this.charset = null;
+
+        /**
+         * The base directory.
+         * @property base
+         * @type string
+         * @default http://yui.yahooapis.com/[YUI VERSION]/build/
+         */
+        this.base = Y.Env.meta.base;
+
+        /**
+         * Base path for the combo service
+         * @property comboBase
+         * @type string
+         * @default http://yui.yahooapis.com/combo?
+         */
+        this.comboBase = Y.Env.meta.comboBase;
+
+        /**
+         * If configured, YUI JS resources will use the combo
+         * handler
+         * @property combine
+         * @type boolean
+         * @default true if a base dir isn't in the config
+         */
+        this.combine = (!(BASE in o));
+
+        /**
+         * Ignore modules registered on the YUI global
+         * @property ignoreRegistered
+         * @default false
+         */
+        this.ignoreRegistered = false;
+
+        /**
+         * Root path to prepend to module path for the combo
+         * service
+         * @property root
+         * @type string
+         * @default [YUI VERSION]/build/
+         */
+        this.root = Y.Env.meta.root;
+
+        /**
+         * Timeout value in milliseconds.  If set, this value will be used by
+         * the get utility.  the timeout event will fire if
+         * a timeout occurs.
+         * @property timeout
+         * @type int
+         */
+        this.timeout = 0;
+
+        /**
+         * A list of modules that should not be loaded, even if
+         * they turn up in the dependency tree
+         * @property ignore
+         * @type string[]
+         */
+        this.ignore = null;
+
+        /**
+         * A list of modules that should always be loaded, even
+         * if they have already been inserted into the page.
+         * @property force
+         * @type string[]
+         */
+        this.force = null;
+
+        /**
+         * Should we allow rollups
+         * @property allowRollup
+         * @type boolean
+         * @default true
+         */
+        this.allowRollup = true;
+
+        /**
+         * A filter to apply to result urls.  This filter will modify the default
+         * path for all modules.  The default path for the YUI library is the
+         * minified version of the files (e.g., event-min.js).  The filter property
+         * can be a predefined filter or a custom filter.  The valid predefined 
+         * filters are:
+         * <dl>
+         *  <dt>DEBUG</dt>
+         *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+         *      This option will automatically include the logger widget</dd>
+         *  <dt>RAW</dt>
+         *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+         * </dl>
+         * You can also define a custom filter, which must be an object literal 
+         * containing a search expression and a replace string:
+         * <pre>
+         *  myFilter: &#123; 
+         *      'searchExp': "-min\\.js", 
+         *      'replaceStr': "-debug.js"
+         *  &#125;
+         * </pre>
+         * @property filter
+         * @type string|{searchExp: string, replaceStr: string}
+         */
+        this.filter = null;
+
+        /**
+         * The list of requested modules
+         * @property required
+         * @type {string: boolean}
+         */
+        this.required = {};
+
+        /**
+         * The library metadata
+         * @property moduleInfo
+         */
+        // this.moduleInfo = Y.merge(Y.Env.meta.moduleInfo);
+        this.moduleInfo = {};
+
+        /**
+         * Provides the information used to skin the skinnable components.
+         * The following skin definition would result in 'skin1' and 'skin2'
+         * being loaded for calendar (if calendar was requested), and
+         * 'sam' for all other skinnable components:
+         *
+         *   <code>
+         *   skin: {
+         *
+         *      // The default skin, which is automatically applied if not
+         *      // overriden by a component-specific skin definition.
+         *      // Change this in to apply a different skin globally
+         *      defaultSkin: 'sam', 
+         *
+         *      // This is combined with the loader base property to get
+         *      // the default root directory for a skin. ex:
+         *      // http://yui.yahooapis.com/2.3.0/build/assets/skins/sam/
+         *      base: 'assets/skins/',
+         *
+         *      // The name of the rollup css file for the skin
+         *      path: 'skin.css',
+         *
+         *      // The number of skinnable components requested that are
+         *      // required before using the rollup file rather than the
+         *      // individual component css files
+         *      rollup: 3,
+         *
+         *      // Any component-specific overrides can be specified here,
+         *      // making it possible to load different skins for different
+         *      // components.  It is possible to load more than one skin
+         *      // for a given component as well.
+         *      overrides: {
+         *          calendar: ['skin1', 'skin2']
+         *      }
+         *   }
+         *   </code>
+         *   @property skin
+         */
+         this.skin = Y.merge(Y.Env.meta.skin);
+        
+        var defaults = Y.Env.meta.modules;
+
+        for (var i in defaults) {
+            if (defaults.hasOwnProperty(i)) {
+                this._internal = true;
+                this.addModule(defaults[i], i);
+                this._internal = false;
+            }
+        }
+
+        /**
+         * List of rollup files found in the library metadata
+         * @property rollups
+         */
+        this.rollups = null;
+
+        /**
+         * Whether or not to load optional dependencies for 
+         * the requested modules
+         * @property loadOptional
+         * @type boolean
+         * @default false
+         */
+        this.loadOptional = false;
+
+        /**
+         * All of the derived dependencies in sorted order, which
+         * will be populated when either calculate() or insert()
+         * is called
+         * @property sorted
+         * @type string[]
+         */
+        this.sorted = [];
+
+        /**
+         * Set when beginning to compute the dependency tree. 
+         * Composed of what YUI reports to be loaded combined
+         * with what has been loaded by the tool
+         * @propery loaded
+         * @type {string: boolean}
+         */
+        this.loaded = {};
+
+        /**
+         * A list of modules to attach to the YUI instance when complete.
+         * If not supplied, the sorted list of dependencies are applied.
+         * @property attaching
+         */
+        this.attaching = null;
+
+        /**
+         * Flag to indicate the dependency tree needs to be recomputed
+         * if insert is called again.
+         * @property dirty
+         * @type boolean
+         * @default true
+         */
+        this.dirty = true;
+
+        /**
+         * List of modules inserted by the utility
+         * @property inserted
+         * @type {string: boolean}
+         */
+        this.inserted = {};
+
+        this.skipped = {};
+
+
+        // Y.on('yui:load', this.loadNext, this);
+
+        this._config(o);
+
+    };
+
+    Y.Loader.prototype = {
+
+        FILTERS: {
+            RAW: { 
+                'searchExp': "-min\\.js", 
+                'replaceStr': ".js"
+            },
+            DEBUG: { 
+                'searchExp': "-min\\.js", 
+                'replaceStr': "-debug.js"
+            }
+        },
+
+        SKIN_PREFIX: "skin-",
+
+        _config: function(o) {
+
+            // apply config values
+            if (o) {
+                for (var i in o) {
+                    if (o.hasOwnProperty(i)) {
+                        var val = o[i];
+                        if (i == 'require') {
+                            this.require(val);
+                        } else if (i == 'modules') {
+
+                            // add a hash of module definitions
+                            for (var j in val) {
+                                if (val.hasOwnProperty(j)) {
+                                    this.addModule(val[j], j);
+                                }
+                            }
+
+                        } else {
+                            this[i] = val;
+                        }
+                    }
+                }
+            }
+
+            // fix filter
+            var f = this.filter;
+
+            if (L.isString(f)) {
+                f = f.toUpperCase();
+                this.filterName = f;
+                this.filter = this.FILTERS[f];
+            }
+
+        },
+
+        /**
+         * Returns the skin module name for the specified skin name.  If a
+         * module name is supplied, the returned skin module name is 
+         * specific to the module passed in.
+         * @method formatSkin
+         * @param skin {string} the name of the skin
+         * @param mod {string} optional: the name of a module to skin
+         * @return {string} the full skin module name
+         */
+        formatSkin: function(skin, mod) {
+            var s = this.SKIN_PREFIX + skin;
+            if (mod) {
+                s = s + "-" + mod;
+            }
+
+            return s;
+        },
+
+        /**
+         * Reverses <code>formatSkin</code>, providing the skin name and
+         * module name if the string matches the pattern for skins.
+         * @method parseSkin
+         * @param mod {string} the module name to parse
+         * @return {skin: string, module: string} the parsed skin name 
+         * and module name, or null if the supplied string does not match
+         * the skin pattern
+         */
+        parseSkin: function(mod) {
+            
+            if (mod.indexOf(this.SKIN_PREFIX) === 0) {
+                var a = mod.split("-");
+                return {skin: a[1], module: a[2]};
+            } 
+
+            return null;
+        },
+
+        /**
+         * Adds the skin def to the module info
+         * @method _addSkin
+         * @param skin {string} the name of the skin
+         * @param mod {string} the name of the module
+         * @param parent {string} parent module if this is a skin of a
+         * submodule or plugin
+         * @return {string} the module name for the skin
+         * @private
+         */
+        _addSkin: function(skin, mod, parent) {
+
+            var name = this.formatSkin(skin), info = this.moduleInfo,
+                sinf = this.skin, ext = info[mod] && info[mod].ext;
+
+            /*
+            // Add a module definition for the skin rollup css
+            // Y.log('ext? ' + mod + ": " + ext);
+            if (!info[name]) {
+                // Y.log('adding skin ' + name);
+                this.addModule({
+                    'name': name,
+                    'type': 'css',
+                    'path': sinf.base + skin + '/' + sinf.path,
+                    //'supersedes': '*',
+                    'after': sinf.after,
+                    'rollup': sinf.rollup,
+                    'ext': ext
+                });
+            }
+            */
+
+            // Add a module definition for the module-specific skin css
+            if (mod) {
+                name = this.formatSkin(skin, mod);
+                if (!info[name]) {
+                    var mdef = info[mod], pkg = mdef.pkg || mod;
+                    // Y.log('adding skin ' + name);
+                    this.addModule({
+                        'name': name,
+                        'type': 'css',
+                        'after': sinf.after,
+                        'path': (parent || pkg) + '/' + sinf.base + skin + '/' + mod + '.css',
+                        'ext': ext
+                    });
+                }
+            }
+
+            return name;
+        },
+
+        /** Add a new module to the component metadata.         
+         * <dl>
+         *     <dt>name:</dt>       <dd>required, the component name</dd>
+         *     <dt>type:</dt>       <dd>required, the component type (js or css)</dd>
+         *     <dt>path:</dt>       <dd>required, the path to the script from "base"</dd>
+         *     <dt>requires:</dt>   <dd>array of modules required by this component</dd>
+         *     <dt>optional:</dt>   <dd>array of optional modules for this component</dd>
+         *     <dt>supersedes:</dt> <dd>array of the modules this component replaces</dd>
+         *     <dt>after:</dt>      <dd>array of modules the components which, if present, should be sorted above this one</dd>
+         *     <dt>rollup:</dt>     <dd>the number of superseded modules required for automatic rollup</dd>
+         *     <dt>fullpath:</dt>   <dd>If fullpath is specified, this is used instead of the configured base + path</dd>
+         *     <dt>skinnable:</dt>  <dd>flag to determine if skin assets should automatically be pulled in</dd>
+         *     <dt>submodules:</dt> <dd>a has of submodules</dd>
+         * </dl>
+         * @method addModule
+         * @param o An object containing the module data
+         * @param name the module name (optional), required if not in the module data
+         * @return {boolean} true if the module was added, false if 
+         * the object passed in did not provide all required attributes
+         */
+        addModule: function(o, name) {
+
+            name = name || o.name;
+            o.name = name;
+
+            if (!o || !o.name) {
+                return false;
+            }
+
+            if (!o.type) {
+                o.type = JS;
+            }
+
+            if (!o.path && !o.fullpath) {
+                // o.path = name + "/" + name + "-min." + o.type;
+                o.path = _path(name, name, o.type);
+            }
+
+            o.ext = ('ext' in o) ? o.ext : (this._internal) ? false : true;
+            o.requires = o.requires || [];
+
+            // Y.log('New module ' + name);
+
+            this.moduleInfo[name] = o;
+
+            // Handle submodule logic
+            var subs = o.submodules, i;
+            if (subs) {
+                var sup = [], l=0;
+
+                for (i in subs) {
+                    if (subs.hasOwnProperty(i)) {
+                        var s = subs[i];
+                        s.path = _path(name, i, o.type);
+                        this.addModule(s, i);
+                        sup.push(i);
+
+                        if (o.skinnable) {
+                            var smod = this._addSkin(this.skin.defaultSkin, i, name);
+                            sup.push(smod.name);
+                        }
+
+                        l++;
+                    }
+                }
+
+                o.supersedes = sup;
+                o.rollup = Math.min(l-1, 4);
+            }
+
+            var plugins = o.plugins;
+            if (plugins) {
+                for (i in plugins) {
+                    if (plugins.hasOwnProperty(i)) {
+                        var plug = plugins[i];
+                        plug.path = _path(name, i, o.type);
+                        plug.requires = plug.requires || [];
+                        plug.requires.push(name);
+                        this.addModule(plug, i);
+                        if (o.skinnable) {
+                            this._addSkin(this.skin.defaultSkin, i, name);
+                        }
+                    }
+                }
+            }
+
+            this.dirty = true;
+
+            return o;
+        },
+
+        /**
+         * Add a requirement for one or more module
+         * @method require
+         * @param what {string[] | string*} the modules to load
+         */
+        require: function(what) {
+            var a = (typeof what === "string") ? arguments : what;
+            this.dirty = true;
+            Y.mix(this.required, Y.Array.hash(a));
+        },
+
+        /**
+         * Returns an object containing properties for all modules required
+         * in order to load the requested module
+         * @method getRequires
+         * @param mod The module definition from moduleInfo
+         */
+        getRequires: function(mod) {
+
+            if (!mod) {
+                // Y.log('getRequires, no module');
+                return [];
+            }
+
+            if (!this.dirty && mod.expanded) {
+                // Y.log('already expanded');
+                return mod.expanded;
+            }
+
+            var i, d=[], r=mod.requires, o=mod.optional, 
+                info=this.moduleInfo, m, j, add;
+
+            for (i=0; i<r.length; i=i+1) {
+                // Y.log(mod.name + ' requiring ' + r[i]);
+                d.push(r[i]);
+                m = this.getModule(r[i]);
+                add = this.getRequires(m);
+                for (j=0;j<add.length;j=j+1) {
+                    d.push(add[j]);
+                }
+            }
+
+            // get the requirements from superseded modules, if any
+            r=mod.supersedes;
+            if (r) {
+                for (i=0; i<r.length; i=i+1) {
+                    // Y.log(mod.name + ' requiring ' + r[i]);
+                    d.push(r[i]);
+                    m = this.getModule(r[i]);
+                    add = this.getRequires(m);
+                    for (j=0;j<add.length;j=j+1) {
+                        d.push(add[j]);
+                    }
+                }
+            }
+
+            if (o && this.loadOptional) {
+                for (i=0; i<o.length; i=i+1) {
+                    d.push(o[i]);
+                    add = this.getRequires(info[o[i]]);
+                    for (j=0;j<add.length;j=j+1) {
+                        d.push(add[j]);
+                    }
+                }
+            }
+
+            mod.expanded = Y.Object.keys(Y.Array.hash(d));
+
+            // Y.log(mod.expanded);
+
+            return mod.expanded;
+        },
+
+
+        /**
+         * Returns an object literal of the modules the supplied module satisfies
+         * @method getProvides
+         * @param name{string} The name of the module
+         * @param notMe {string} don't add this module name, only include superseded modules
+         * @return what this module provides
+         */
+        getProvides: function(name, notMe) {
+            var addMe = !(notMe), ckey = (addMe) ? PROV : SUPER,
+                m = this.getModule(name), o = {};
+
+            if (!m) {
+                return o;
+            }
+
+            if (m[ckey]) {
+// Y.log('cached: ' + name + ' ' + ckey + ' ' + L.dump(this.moduleInfo[name][ckey], 0));
+                return m[ckey];
+            }
+
+            var s = m.supersedes, done={}, me = this;
+
+            // use worker to break cycles
+            var add = function(mm) {
+                if (!done[mm]) {
+                    // Y.log(name + ' provides worker trying: ' + mm);
+                    done[mm] = true;
+                    // we always want the return value normal behavior 
+                    // (provides) for superseded modules.
+                    Y.mix(o, me.getProvides(mm));
+                } 
+                
+                // else {
+                // Y.log(name + ' provides worker skipping done: ' + mm);
+                // }
+            };
+
+            // calculate superseded modules
+            if (s) {
+                for (var i=0; i<s.length; i=i+1) {
+                    add(s[i]);
+                }
+            }
+
+            // supersedes cache
+            m[SUPER] = o;
+            // provides cache
+            m[PROV] = Y.merge(o);
+            m[PROV][name] = true;
+
+// Y.log(name + " supersedes " + L.dump(m[SUPER], 0));
+// Y.log(name + " provides " + L.dump(m[PROV], 0));
+
+            return m[ckey];
+        },
+
+
+        /**
+         * Calculates the dependency tree, the result is stored in the sorted 
+         * property
+         * @method calculate
+         * @param o optional options object
+         */
+        calculate: function(o) {
+            if (o || this.dirty) {
+                this._config(o);
+                this._setup();
+                this._explode();
+                if (this.allowRollup) {
+                    this._rollup();
+                }
+                this._reduce();
+                this._sort();
+
+                // Y.log("after calculate: " + this.sorted);
+
+                this.dirty = false;
+            }
+        },
+
+        /**
+         * Investigates the current YUI configuration on the page.  By default,
+         * modules already detected will not be loaded again unless a force
+         * option is encountered.  Called by calculate()
+         * @method _setup
+         * @private
+         */
+        _setup: function() {
+
+            var info = this.moduleInfo, name, i, j;
+
+            // Create skin modules
+            for (name in info) {
+                if (info.hasOwnProperty(name)) {
+                    var m = info[name];
+                    if (m && m.skinnable) {
+                        // Y.log("skinning: " + name);
+                        var o=this.skin.overrides, smod;
+                        if (o && o[name]) {
+                            for (i=0; i<o[name].length; i=i+1) {
+                                smod = this._addSkin(o[name][i], name);
+                            }
+                        } else {
+                            smod = this._addSkin(this.skin.defaultSkin, name);
+                        }
+
+                        m.requires.push(smod);
+                    }
+                }
+            }
+
+            var l = Y.merge(this.inserted); // shallow clone
+
+            // available modules
+            if (!this.ignoreRegistered) {
+                Y.mix(l, YUI.Env.mods);
+            }
+            
+            // Y.log("Already loaded stuff: " + L.dump(l, 0));
+
+            // add the ignore list to the list of loaded packages
+            if (this.ignore) {
+                // OU.appendArray(l, this.ignore);
+                Y.mix(l, Y.Array.hash(this.ignore));
+            }
+
+            // expand the list to include superseded modules
+            for (j in l) {
+                // Y.log("expanding: " + j);
+                if (l.hasOwnProperty(j)) {
+                    Y.mix(l, this.getProvides(j));
+                }
+            }
+
+            // remove modules on the force list from the loaded list
+            if (this.force) {
+                for (i=0; i<this.force.length; i=i+1) {
+                    if (this.force[i] in l) {
+                        delete l[this.force[i]];
+                    }
+                }
+            }
+
+            // Y.log("loaded expanded: " + L.dump(l, 0));
+
+            this.loaded = l;
+
+        },
+        
+
+        /**
+         * Inspects the required modules list looking for additional 
+         * dependencies.  Expands the required list to include all 
+         * required modules.  Called by calculate()
+         * @method _explode
+         * @private
+         */
+        _explode: function() {
+
+            var r=this.required, i, mod;
+
+            for (i in r) {
+                if (r.hasOwnProperty(i)) {
+                    mod = this.getModule(i);
+                    // Y.log('exploding ' + i);
+
+                    var req = this.getRequires(mod);
+
+                    if (req) {
+                        // Y.log('via explode: ' + req);
+                        Y.mix(r, Y.Array.hash(req));
+                    }
+                }
+            }
+        },
+
+        getModule: function(name) {
+
+            var m = this.moduleInfo[name];
+
+            // create the default module
+            // if (!m) {
+                // Y.log('Module does not exist: ' + name + ', creating with defaults');
+                // m = this.addModule({ext: false}, name);
+            // }
+
+            return m;
+        },
+
+        /**
+         * Look for rollup packages to determine if all of the modules a
+         * rollup supersedes are required.  If so, include the rollup to
+         * help reduce the total number of connections required.  Called
+         * by calculate()
+         * @method _rollup
+         * @private
+         */
+        _rollup: function() {
+            var i, j, m, s, rollups={}, r=this.required, roll,
+                info = this.moduleInfo;
+
+            // find and cache rollup modules
+            if (this.dirty || !this.rollups) {
+                for (i in info) {
+                    if (info.hasOwnProperty(i)) {
+                        m = this.getModule(i);
+                        // if (m && m.rollup && m.supersedes) {
+                        if (m && m.rollup) {
+                            rollups[i] = m;
+                        }
+                    }
+                }
+
+                this.rollups = rollups;
+            }
+
+            // make as many passes as needed to pick up rollup rollups
+            for (;;) {
+                var rolled = false;
+
+                // go through the rollup candidates
+                for (i in rollups) { 
+
+                    if (rollups.hasOwnProperty(i)) {
+
+                        // there can be only one
+                        if (!r[i] && !this.loaded[i]) {
+                            m =this.getModule(i); s = m.supersedes ||[]; roll=false;
+
+                            if (!m.rollup) {
+                                continue;
+                            }
+
+                            var c=0;
+
+                            // check the threshold
+                            for (j=0;j<s.length;j=j+1) {
+
+                                // if the superseded module is loaded, we can't load the rollup
+                                // if (this.loaded[s[j]] && (!_Y.dupsAllowed[s[j]])) {
+                                if (this.loaded[s[j]]) {
+                                    roll = false;
+                                    break;
+                                // increment the counter if this module is required.  if we are
+                                // beyond the rollup threshold, we will use the rollup module
+                                } else if (r[s[j]]) {
+                                    c++;
+                                    roll = (c >= m.rollup);
+                                    if (roll) {
+                                        // Y.log("over thresh " + c + ", " + L.dump(r));
+                                        break;
+                                    }
+                                }
+                            }
+
+                            if (roll) {
+                                // Y.log("rollup: " +  i + ", " + L.dump(this, 1));
+                                // add the rollup
+                                r[i] = true;
+                                rolled = true;
+
+                                // expand the rollup's dependencies
+                                this.getRequires(m);
+                            }
+                        }
+                    }
+                }
+
+                // if we made it here w/o rolling up something, we are done
+                if (!rolled) {
+                    break;
+                }
+            }
+        },
+
+        /**
+         * Remove superceded modules and loaded modules.  Called by
+         * calculate() after we have the mega list of all dependencies
+         * @method _reduce
+         * @private
+         */
+        _reduce: function() {
+
+            var i, j, s, m, r=this.required;
+            for (i in r) {
+
+                if (r.hasOwnProperty(i)) {
+
+                    // remove if already loaded
+                    if (i in this.loaded) { 
+                        delete r[i];
+
+                    // remove anything this module supersedes
+                    } else {
+
+                         m = this.getModule(i);
+                         s = m && m.supersedes;
+                         if (s) {
+                             for (j=0; j<s.length; j=j+1) {
+                                 if (s[j] in r) {
+                                     delete r[s[j]];
+                                 }
+                             }
+                         }
+                    }
+                }
+            }
+        },
+
+        _attach: function() {
+
+            // this is the full list of items the YUI needs attached,
+            // which is needed if some dependencies are already on
+            // the page without their dependencies.
+            if (this.attaching) {
+                Y.log('attaching Y supplied deps: ' + this.attaching, "info", "loader");
+                Y._attach(this.attaching);
+            } else {
+                Y.log('attaching sorted list: ' + this.sorted, "info", "loader");
+                Y._attach(this.sorted);
+            }
+
+            this._pushEvents();
+
+        },
+
+        _onSuccess: function() {
+
+            this._attach();
+
+            var skipped = this.skipped;
+
+            for (var i in skipped) {
+                if (skipped.hasOwnProperty(i)) {
+                    delete this.inserted[i];
+                }
+            }
+
+            this.skipped = {};
+
+            // this.fire('success', {
+            //     data: this.data
+            // });
+
+            var f = this.onSuccess;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'success',
+                    data: this.data,
+                    success: true
+                });
+            }
+
+        },
+
+        _onFailure: function(msg) {
+            this._attach();
+            // this.fire('failure', {
+            //     msg: 'operation failed: ' + msg,
+            //     data: this.data
+            // });
+
+            var f = this.onFailure;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'failure: ' + msg,
+                    data: this.data,
+                    success: false
+                });
+            }
+        },
+
+        _onTimeout: function() {
+            this._attach();
+
+            // this.fire('timeout', {
+            //     data: this.data
+            // });
+
+            var f = this.onTimeout;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'timeout',
+                    data: this.data,
+                    success: false
+                });
+            }
+        },
+        
+        /**
+         * Sorts the dependency tree.  The last step of calculate()
+         * @method _sort
+         * @private
+         */
+        _sort: function() {
+            // create an indexed list
+            var s=Y.Object.keys(this.required), info=this.moduleInfo, loaded=this.loaded,
+                me = this;
+
+            // returns true if b is not loaded, and is required
+            // directly or by means of modules it supersedes.
+            var requires = function(aa, bb) {
+
+                var mm=info[aa];
+
+                if (loaded[bb] || !mm) {
+                    return false;
+                }
+
+                var ii, rr = mm.expanded, 
+                    after = mm.after, other=info[bb];
+
+                // check if this module requires the other directly
+                if (rr && Y.Array.indexOf(rr, bb) > -1) {
+                    return true;
+                }
+
+                // check if this module should be sorted after the other
+                if (after && Y.Array.indexOf(after, bb) > -1) {
+                    return true;
+                }
+
+                // check if this module requires one the other supersedes
+                var ss=info[bb] && info[bb].supersedes;
+                if (ss) {
+                    for (ii=0; ii<ss.length; ii=ii+1) {
+                        if (requires(aa, ss[ii])) {
+                            return true;
+                        }
+                    }
+                }
+
+                // external css files should be sorted below yui css
+                if (mm.ext && mm.type == CSS && !other.ext && other.type == CSS) {
+                    return true;
+                }
+
+                return false;
+            };
+
+            // pointer to the first unsorted item
+            var p=0; 
+
+            // keep going until we make a pass without moving anything
+            for (;;) {
+               
+                var l=s.length, a, b, j, k, moved=false;
+
+                // start the loop after items that are already sorted
+                for (j=p; j<l; j=j+1) {
+
+                    // check the next module on the list to see if its
+                    // dependencies have been met
+                    a = s[j];
+
+                    // check everything below current item and move if we
+                    // find a requirement for the current item
+                    for (k=j+1; k<l; k=k+1) {
+                        if (requires(a, s[k])) {
+
+                            // extract the dependency so we can move it up
+                            b = s.splice(k, 1);
+
+                            // insert the dependency above the item that 
+                            // requires it
+                            s.splice(j, 0, b[0]);
+
+                            moved = true;
+                            break;
+                        }
+                    }
+
+                    // jump out of loop if we moved something
+                    if (moved) {
+                        break;
+                    // this item is sorted, move our pointer and keep going
+                    } else {
+                        p = p + 1;
+                    }
+                }
+
+                // when we make it here and moved is false, we are 
+                // finished sorting
+                if (!moved) {
+                    break;
+                }
+
+            }
+
+            this.sorted = s;
+        },
+
+        /**
+         * inserts the requested modules and their dependencies.  
+         * <code>type</code> can be "js" or "css".  Both script and 
+         * css are inserted if type is not provided.
+         * @method insert
+         * @param o optional options object
+         * @param type {string} the type of dependency to insert
+         */
+        insert: function(o, type) {
+
+            Y.log('Insert() ' + (type || ''), "info", "loader");
+
+            // build the dependency list
+            this.calculate(o);
+
+            if (!type) {
+                // Y.log("trying to load css first");
+                var self = this;
+                this._internalCallback = function() {
+                            self._internalCallback = null;
+                            self.insert(null, JS);
+                        };
+                this.insert(null, CSS);
+                return;
+            }
+
+            // set a flag to indicate the load has started
+            this._loading = true;
+
+            // flag to indicate we are done with the combo service
+            // and any additional files will need to be loaded
+            // individually
+            this._combineComplete = {};
+
+            // keep the loadType (js, css or undefined) cached
+            this.loadType = type;
+
+            // start the load
+            this.loadNext();
+
+        },
+
+        /**
+         * Executed every time a module is loaded, and if we are in a load
+         * cycle, we attempt to load the next script.  Public so that it
+         * is possible to call this if using a method other than
+         * Y.register to determine when scripts are fully loaded
+         * @method loadNext
+         * @param mname {string} optional the name of the module that has
+         * been loaded (which is usually why it is time to load the next
+         * one)
+         */
+        loadNext: function(mname) {
+
+            // It is possible that this function is executed due to something
+            // else one the page loading a YUI module.  Only react when we
+            // are actively loading something
+            if (!this._loading) {
+                return;
+            }
+
+            var s, len, i, m, url, self=this, type=this.loadType, fn;
+
+            // @TODO this will need to handle the two phase insert when
+            // CSS support is added
+            if (this.combine && (!this._combineComplete[type])) {
+
+                this._combining = []; 
+                s=this.sorted;
+                len=s.length;
+                url=this.comboBase;
+
+                for (i=0; i<len; i=i+1) {
+                    m = this.getModule(s[i]);
+// @TODO we can't combine CSS yet until we deliver files with absolute paths to the assets
+                    // Do not try to combine non-yui JS
+                    if (m && m.type === this.loadType && !m.ext) {
+                        url += this.root + m.path;
+                        if (i < len-1) {
+                            url += '&';
+                        }
+
+                        this._combining.push(s[i]);
+                    }
+                }
+
+                if (this._combining.length) {
+
+Y.log('Attempting to combine: ' + this._combining, "info", "loader");
+
+                    var callback=function(o) {
+                        Y.log('Combo complete: ' + o.data, "info", "loader");
+                        this._combineComplete[type] = true;
+
+
+                        var c=this._combining, len=c.length, i, m;
+                        for (i=0; i<len; i=i+1) {
+                            this.inserted[c[i]] = true;
+                        }
+
+                        this.loadNext(o.data);
+                    };
+
+                    fn =(type === CSS) ? Y.Get.css : Y.Get.script;
+
+                    // @TODO get rid of the redundant Get code
+                    fn(this._filter(url), {
+                        data: this._loading,
+                        onSuccess: callback,
+                        onFailure: this._onFailure,
+                        onTimeout: this._onTimeout,
+                        insertBefore: this.insertBefore,
+                        charset: this.charset,
+                        timeout: this.timeout,
+                        context: self 
+                    });
+
+                    return;
+
+                } else {
+                    this._combineComplete[type] = true;
+                }
+            }
+
+            if (mname) {
+
+                // if the module that was just loaded isn't what we were expecting,
+                // continue to wait
+                if (mname !== this._loading) {
+                    return;
+                }
+
+Y.log("loadNext executing, just loaded " + mname || "", "info", "loader");
+
+                // The global handler that is called when each module is loaded
+                // will pass that module name to this function.  Storing this
+                // data to avoid loading the same module multiple times
+                this.inserted[mname] = true;
+
+                // this.fire('progress', {
+                //     name: mname,
+                //     data: this.data
+                // });
+                if (this.onProgress) {
+                    this.onProgress.call(this.context, {
+                            name: mname,
+                            data: this.data
+                        });
+                }
+
+
+            }
+
+            s=this.sorted;
+            len=s.length;
+
+            for (i=0; i<len; i=i+1) {
+
+                // this.inserted keeps track of what the loader has loaded.
+                // move on if this item is done.
+                if (s[i] in this.inserted) {
+                    // Y.log(s[i] + " alread loaded ");
+                    continue;
+                }
+
+                // Because rollups will cause multiple load notifications
+                // from Y, loadNext may be called multiple times for
+                // the same module when loading a rollup.  We can safely
+                // skip the subsequent requests
+                if (s[i] === this._loading) {
+                    Y.log("still loading " + s[i] + ", waiting", "info", "loader");
+                    return;
+                }
+
+                // log("inserting " + s[i]);
+                m = this.getModule(s[i]);
+
+                if (!m) {
+
+                    var msg = "Undefined module " + s[i] + " skipped";
+                    Y.log(msg, 'warn', 'loader');
+                    this.inserted[s[i]] = true;
+                    this.skipped[s[i]] = true;
+                    continue;
+
+                    // this.fire('failure', {
+                        // msg: msg,
+                        // data: this.data
+                    // });
+                }
+
+
+                // The load type is stored to offer the possibility to load
+                // the css separately from the script.
+                if (!type || type === m.type) {
+                    this._loading = s[i];
+                    Y.log("attempting to load " + s[i] + ", " + this.base, "info", "loader");
+
+                    fn = (m.type === CSS) ? Y.Get.css : Y.Get.script;
+
+                    var onsuccess=function(o) {
+                            // Y.log('loading next, just loaded' + o.data);
+                            self.loadNext(o.data);
+                        };
+                        
+                    url = (m.fullpath) ? this._filter(m.fullpath) : this._url(m.path, s[i]);
+
+                    self = this; 
+
+                    fn(url, {
+                        data: s[i],
+                        onSuccess: onsuccess,
+                        insertBefore: this.insertBefore,
+                        charset: this.charset,
+                        onFailure: this._onFailure,
+                        onTimeout: this._onTimeout,
+                        timeout: this.timeout,
+                        context: self 
+                    });
+
+                    return;
+                }
+            }
+
+            // we are finished
+            this._loading = null;
+
+            fn = this._internalCallback;
+
+            // internal callback for loading css first
+            if (fn) {
+                // Y.log('loader internal');
+                this._internalCallback = null;
+                fn.call(this);
+
+            // } else if (this.onSuccess) {
+            } else {
+                // Y.log('loader complete');
+                // call Y.use passing this instance. Y will use the sorted
+                // dependency list.
+                this._onSuccess();
+            }
+
+        },
+
+        /**
+         * In IE, the onAvailable/onDOMReady events need help when Event is
+         * loaded dynamically
+         * @method _pushEvents
+         * @param {Function} optional function reference
+         * @private
+         */
+        _pushEvents: function() {
+            if (Y.Event) {
+                Y.Event._load();
+            }
+        },
+
+        /**
+         * Apply filter defined for this instance to a url/path
+         * method _filter
+         * @param u {string} the string to filter
+         * @return {string} the filtered string
+         * @private
+         */
+        _filter: function(u) {
+
+            Y.log('filter ' + u);
+
+            var f = this.filter;
+
+            if (u && f) {
+                var useFilter = true;
+
+                if (this.filterName == "DEBUG") {
+                
+                    var exc = this.logExclude,
+                        inc = this.logInclude;
+                    if (inc && !(name in inc)) {
+                        useFilter = false;
+                    } else if (exc && (name in exc)) {
+                        useFilter = false;
+                    }
+
+                }
+                
+                if (useFilter) {
+                    u = u.replace(new RegExp(f.searchExp, 'g'), f.replaceStr);
+                }
+            }
+
+            return u;
+
+        },
+
+        /**
+         * Generates the full url for a module
+         * method _url
+         * @param path {string} the path fragment
+         * @return {string} the full url
+         * @private
+         */
+        _url: function(path, name) {
+            return this._filter((this.base || "") + path);
+        }
+
+    };
+
+    // Y.augment(Y.Loader, Y.Event.Target);
+
+}, "3.0.0pr2");

=== added file 'loggerhead/static/javascript/yui/build/loader/loader-min.js'
--- loggerhead/static/javascript/yui/build/loader/loader-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/loader/loader-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,9 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("loader",function(C){var P="base",O="css",M="js",G="cssreset",Q="cssfonts",N="cssgrids",B="cssbase",E=[G,Q,N,"cssreset-context","cssfonts-context","cssgrids-context"],J=["reset","fonts","grids","base"],T="3.0.0pr2",A=T+"/build/",R="-context",U={version:T,root:A,base:"http://yui.yahooapis.com/"+A,comboBase:"http://yui.yahooapis.com/combo?",skin:{defaultSkin:"sam",base:"assets/skins/",path:"skin.css",after:["reset","fonts","grids","base"]},modules:{dom:{requires:["event"],submodules:{"dom-base":{requires:["event"]},"dom-style":{requires:["dom-base"]},"dom-screen":{requires:["dom-base","dom-style"]},selector:{requires:["dom-base"]}}},node:{requires:["dom"],submodules:{"node-base":{requires:["dom-base","selector"]},"node-style":{requires:["dom-style","node-base"]},"node-screen":{requires:["dom-screen","node-base"]},"node-event-simulate":{requires:["node-base"]}}},anim:{requires:[P,"node"],submodules:{"anim-base":{requires:["base","node-style"]},"anim-color":{requires:["anim-base"]},"anim-curve":{requires:["anim-xy"]},"anim-easing":{},"anim-scroll":{requires:["anim-base"]},"anim-xy":{requires:["anim-base","node-screen"]},"anim-node-plugin":{requires:["node","anim-base"]}}},attribute:{requires:["event"]},base:{requires:["attribute"]},compat:{requires:["node","dump","substitute"]},classnamemanager:{},console:{requires:["widget","substitute"],skinnable:true},cookie:{},dd:{submodules:{"dd-ddm-base":{requires:["node",P]},"dd-ddm":{requires:["dd-ddm-base"]},"dd-ddm-drop":{requires:["dd-ddm"]},"dd-drag":{requires:["dd-ddm-base"]},"dd-drop":{requires:["dd-ddm-drop"]},"dd-proxy":{requires:["dd-drag"]},"dd-constrain":{requires:["dd-drag","dd-proxy"]},"dd-plugin":{requires:["dd-drag"],optional:["dd-constrain","dd-proxy"]},"dd-drop-plugin":{requires:["dd-drop"]}}},dump:{},event:{requires:["oop"]},get:{requires:["yui-base"]},io:{submodules:{"io-base":{requires:["node"]},"io-xdr":{requires:["io-base"]},"io-form":{requires:["io-base"]},"io-upload-iframe":{requires:["io-base"]},"io-queue":{requires:["io-base"]}}},json:{submodules:{"json-parse":{},"json-stringify":{}}},loader:{requires:["get"]},"node-menunav":{requires:["node","classnamemanager"],skinnable:true},oop:{requires:["yui-base"]},overlay:{requires:["widget","widget-position","widget-position-ext","widget-stack","widget-stdmod"],skinnable:true},plugin:{requires:["base"]},profiler:{},queue:{requires:["node"]},slider:{requires:["widget","dd-constrain"],skinnable:true},stylesheet:{},substitute:{optional:["dump"]},widget:{requires:["base","node","classnamemanager"],plugins:{"widget-position":{},"widget-position-ext":{requires:["widget-position"]},"widget-stack":{skinnable:true},"widget-stdmod":{}},skinnable:true},yui:{supersedes:["yui-base","get","loader"]},"yui-base":{},yuitest:{requires:["substitute","node","json"]}}};var H=function(L,W,X){return L+"/"+W+"-min."+(X||O);};var F=function(){var X=U.modules;for(var W=0;W<J.length;W=W+1){var Z=J[W],Y=O+Z;X[Y]={type:O,path:H(Y,Z)};var L=Y+R;Z=Z+R;X[L]={type:O,path:H(Y,Z)};if(Y==N){X[Y].requires=[Q];X[Y].optional=[G];X[L].requires=[Q+R];X[L].optional=[G+R];}else{if(Y==B){X[Y].after=E;X[L].after=E;}}}}();C.Env.meta=U;var K=C.Lang,S=C.Env,I="_provides",V="_supersedes",D="expanded";C.Loader=function(X){this._internalCallback=null;this._useYahooListener=false;this.onSuccess=null;this.onFailure=null;this.onProgress=null;this.onTimeout=null;this.context=C;this.data=null;this.insertBefore=null;this.charset=null;this.base=C.Env.meta.base;this.comboBase=C.Env.meta.comboBase;this.combine=(!(P in X));this.ignoreRegistered=false;this.root=C.Env.meta.root;this.timeout=0;this.ignore=null;this.force=null;this.allowRollup=true;this.filter=null;this.required={};this.moduleInfo={};this.skin=C.merge(C.Env.meta.skin);var W=C.Env.meta.modules;for(var L in W){if(W.hasOwnProperty(L)){this._internal=true;this.addModule(W[L],L);this._internal=false;}}this.rollups=null;this.loadOptional=false;this.sorted=[];this.loaded={};this.attaching=null;this.dirty=true;this.inserted={};this.skipped={};this._config(X);};C.Loader.prototype={FILTERS:{RAW:{"searchExp":"-min\\.js","replaceStr":".js"},DEBUG:{"searchExp":"-min\\.js","replaceStr":"-debug.js"}},SKIN_PREFIX:"skin-",_config:function(Z){if(Z){for(var W in Z){if(Z.hasOwnProperty(W)){var Y=Z[W];if(W=="require"){this.require(Y);}else{if(W=="modules"){for(var L in Y){if(Y.hasOwnProperty(L)){this.addModule(Y[L],L);}}}else{this[W]=Y;}}}}}var X=this.filter;if(K.isString(X)){X=X.toUpperCase();this.filterName=X;this.filter=this.FILTERS[X];}},formatSkin:function(X,L){var W=this.SKIN_PREFIX+X;if(L){W=W+"-"+L;}return W;},parseSkin:function(W){if(W.indexOf(this.SKIN_PREFIX)===0){var L=W.split("-");return{skin:L[1],module:L[2]};}return null;},_addSkin:function(d,b,c){var L=this.formatSkin(d),Y=this.moduleInfo,W=this.skin,X=Y[b]&&Y[b].ext;if(b){L=this.formatSkin(d,b);if(!Y[L]){var a=Y[b],Z=a.pkg||b;this.addModule({"name":L,"type":"css","after":W.after,"path":(c||Z)+"/"+W.base+d+"/"+b+".css","ext":X});}}return L;},addModule:function(X,W){W=W||X.name;X.name=W;if(!X||!X.name){return false;}if(!X.type){X.type=M;}if(!X.path&&!X.fullpath){X.path=H(W,W,X.type);}X.ext=("ext" in X)?X.ext:(this._internal)?false:true;X.requires=X.requires||[];this.moduleInfo[W]=X;var a=X.submodules,b;if(a){var c=[],Y=0;for(b in a){if(a.hasOwnProperty(b)){var e=a[b];e.path=H(W,b,X.type);this.addModule(e,b);c.push(b);if(X.skinnable){var d=this._addSkin(this.skin.defaultSkin,b,W);c.push(d.name);}Y++;}}X.supersedes=c;X.rollup=Math.min(Y-1,4);}var Z=X.plugins;if(Z){for(b in Z){if(Z.hasOwnProperty(b)){var L=Z[b];L.path=H(W,b,X.type);L.requires=L.requires||[];L.requires.push(W);this.addModule(L,b);if(X.skinnable){this._addSkin(this.skin.defaultSkin,b,W);}}}}this.dirty=true;return X;},require:function(W){var L=(typeof W==="string")?arguments:W;this.dirty=true;C.mix(this.required,C.Array.hash(L));},getRequires:function(c){if(!c){return[];}if(!this.dirty&&c.expanded){return c.expanded;}var a,b=[],L=c.requires,W=c.optional,X=this.moduleInfo,Y,Z,e;
+for(a=0;a<L.length;a=a+1){b.push(L[a]);Y=this.getModule(L[a]);e=this.getRequires(Y);for(Z=0;Z<e.length;Z=Z+1){b.push(e[Z]);}}L=c.supersedes;if(L){for(a=0;a<L.length;a=a+1){b.push(L[a]);Y=this.getModule(L[a]);e=this.getRequires(Y);for(Z=0;Z<e.length;Z=Z+1){b.push(e[Z]);}}}if(W&&this.loadOptional){for(a=0;a<W.length;a=a+1){b.push(W[a]);e=this.getRequires(X[W[a]]);for(Z=0;Z<e.length;Z=Z+1){b.push(e[Z]);}}}c.expanded=C.Object.keys(C.Array.hash(b));return c.expanded;},getProvides:function(X,c){var W=!(c),L=(W)?I:V,Z=this.getModule(X),Y={};if(!Z){return Y;}if(Z[L]){return Z[L];}var f=Z.supersedes,a={},d=this;var e=function(g){if(!a[g]){a[g]=true;C.mix(Y,d.getProvides(g));}};if(f){for(var b=0;b<f.length;b=b+1){e(f[b]);}}Z[V]=Y;Z[I]=C.merge(Y);Z[I][X]=true;return Z[L];},calculate:function(L){if(L||this.dirty){this._config(L);this._setup();this._explode();if(this.allowRollup){this._rollup();}this._reduce();this._sort();this.dirty=false;}},_setup:function(){var b=this.moduleInfo,Z,a,Y;for(Z in b){if(b.hasOwnProperty(Z)){var W=b[Z];if(W&&W.skinnable){var c=this.skin.overrides,L;if(c&&c[Z]){for(a=0;a<c[Z].length;a=a+1){L=this._addSkin(c[Z][a],Z);}}else{L=this._addSkin(this.skin.defaultSkin,Z);}W.requires.push(L);}}}var X=C.merge(this.inserted);if(!this.ignoreRegistered){C.mix(X,YUI.Env.mods);}if(this.ignore){C.mix(X,C.Array.hash(this.ignore));}for(Y in X){if(X.hasOwnProperty(Y)){C.mix(X,this.getProvides(Y));}}if(this.force){for(a=0;a<this.force.length;a=a+1){if(this.force[a] in X){delete X[this.force[a]];}}}this.loaded=X;},_explode:function(){var Y=this.required,W,L;for(W in Y){if(Y.hasOwnProperty(W)){L=this.getModule(W);var X=this.getRequires(L);if(X){C.mix(Y,C.Array.hash(X));}}}},getModule:function(W){var L=this.moduleInfo[W];return L;},_rollup:function(){var b,a,Z,f,e={},L=this.required,X,Y=this.moduleInfo;if(this.dirty||!this.rollups){for(b in Y){if(Y.hasOwnProperty(b)){Z=this.getModule(b);if(Z&&Z.rollup){e[b]=Z;}}}this.rollups=e;}for(;;){var W=false;for(b in e){if(e.hasOwnProperty(b)){if(!L[b]&&!this.loaded[b]){Z=this.getModule(b);f=Z.supersedes||[];X=false;if(!Z.rollup){continue;}var d=0;for(a=0;a<f.length;a=a+1){if(this.loaded[f[a]]){X=false;break;}else{if(L[f[a]]){d++;X=(d>=Z.rollup);if(X){break;}}}}if(X){L[b]=true;W=true;this.getRequires(Z);}}}}if(!W){break;}}},_reduce:function(){var X,W,Y,L,Z=this.required;for(X in Z){if(Z.hasOwnProperty(X)){if(X in this.loaded){delete Z[X];}else{L=this.getModule(X);Y=L&&L.supersedes;if(Y){for(W=0;W<Y.length;W=W+1){if(Y[W] in Z){delete Z[Y[W]];}}}}}}},_attach:function(){if(this.attaching){C._attach(this.attaching);}else{C._attach(this.sorted);}this._pushEvents();},_onSuccess:function(){this._attach();var L=this.skipped;for(var W in L){if(L.hasOwnProperty(W)){delete this.inserted[W];}}this.skipped={};var X=this.onSuccess;if(X){X.call(this.context,{msg:"success",data:this.data,success:true});}},_onFailure:function(W){this._attach();var L=this.onFailure;if(L){L.call(this.context,{msg:"failure: "+W,data:this.data,success:false});}},_onTimeout:function(){this._attach();var L=this.onTimeout;if(L){L.call(this.context,{msg:"timeout",data:this.data,success:false});}},_sort:function(){var h=C.Object.keys(this.required),W=this.moduleInfo,c=this.loaded,d=this;var i=function(l,o){var n=W[l];if(c[o]||!n){return false;}var k,b=n.expanded,m=n.after,a=W[o];if(b&&C.Array.indexOf(b,o)>-1){return true;}if(m&&C.Array.indexOf(m,o)>-1){return true;}var j=W[o]&&W[o].supersedes;if(j){for(k=0;k<j.length;k=k+1){if(i(l,j[k])){return true;}}}if(n.ext&&n.type==O&&!a.ext&&a.type==O){return true;}return false;};var L=0;for(;;){var X=h.length,g,f,Z,Y,e=false;for(Z=L;Z<X;Z=Z+1){g=h[Z];for(Y=Z+1;Y<X;Y=Y+1){if(i(g,h[Y])){f=h.splice(Y,1);h.splice(Z,0,f[0]);e=true;break;}}if(e){break;}else{L=L+1;}}if(!e){break;}}this.sorted=h;},insert:function(X,W){this.calculate(X);if(!W){var L=this;this._internalCallback=function(){L._internalCallback=null;L.insert(null,M);};this.insert(null,O);return;}this._loading=true;this._combineComplete={};this.loadType=W;this.loadNext();},loadNext:function(a){if(!this._loading){return;}var g,Z,Y,X,L,f=this,b=this.loadType,c;if(this.combine&&(!this._combineComplete[b])){this._combining=[];g=this.sorted;Z=g.length;L=this.comboBase;for(Y=0;Y<Z;Y=Y+1){X=this.getModule(g[Y]);if(X&&X.type===this.loadType&&!X.ext){L+=this.root+X.path;if(Y<Z-1){L+="&";}this._combining.push(g[Y]);}}if(this._combining.length){var d=function(l){this._combineComplete[b]=true;var n=this._combining,j=n.length,k,h;for(k=0;k<j;k=k+1){this.inserted[n[k]]=true;}this.loadNext(l.data);};c=(b===O)?C.Get.css:C.Get.script;c(this._filter(L),{data:this._loading,onSuccess:d,onFailure:this._onFailure,onTimeout:this._onTimeout,insertBefore:this.insertBefore,charset:this.charset,timeout:this.timeout,context:f});return;}else{this._combineComplete[b]=true;}}if(a){if(a!==this._loading){return;}this.inserted[a]=true;if(this.onProgress){this.onProgress.call(this.context,{name:a,data:this.data});}}g=this.sorted;Z=g.length;for(Y=0;Y<Z;Y=Y+1){if(g[Y] in this.inserted){continue;}if(g[Y]===this._loading){return;}X=this.getModule(g[Y]);if(!X){var W="Undefined module "+g[Y]+" skipped";this.inserted[g[Y]]=true;this.skipped[g[Y]]=true;continue;}if(!b||b===X.type){this._loading=g[Y];c=(X.type===O)?C.Get.css:C.Get.script;var e=function(h){f.loadNext(h.data);};L=(X.fullpath)?this._filter(X.fullpath):this._url(X.path,g[Y]);f=this;c(L,{data:g[Y],onSuccess:e,insertBefore:this.insertBefore,charset:this.charset,onFailure:this._onFailure,onTimeout:this._onTimeout,timeout:this.timeout,context:f});return;}}this._loading=null;c=this._internalCallback;if(c){this._internalCallback=null;c.call(this);}else{this._onSuccess();}},_pushEvents:function(){if(C.Event){C.Event._load();}},_filter:function(X){var Y=this.filter;if(X&&Y){var W=true;if(this.filterName=="DEBUG"){var L=this.logExclude,Z=this.logInclude;if(Z&&!(name in Z)){W=false;}else{if(L&&(name in L)){W=false;}}}if(W){X=X.replace(new RegExp(Y.searchExp,"g"),Y.replaceStr);}}return X;},_url:function(W,L){return this._filter((this.base||"")+W);
+}};},"3.0.0pr2");
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/loader/loader.js'
--- loggerhead/static/javascript/yui/build/loader/loader.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/loader/loader.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1812 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * Loader dynamically loads script and css files.  It includes the dependency
+ * info for the version of the library in use, and will automatically pull in
+ * dependencies for the modules requested.  It supports rollup files and will
+ * automatically use these when appropriate in order to minimize the number of
+ * http connections required to load all of the dependencies.  It can load the
+ * files from the Yahoo! CDN, and it can utilize the combo service provided on
+ * this network to reduce the number of http connections required to download 
+ * YUI files.
+ *
+ * @module yui
+ * @submodule loader
+ */
+
+/**
+ * Loader dynamically loads script and css files.  It includes the dependency
+ * info for the version of the library in use, and will automatically pull in
+ * dependencies for the modules requested.  It supports rollup files and will
+ * automatically use these when appropriate in order to minimize the number of
+ * http connections required to load all of the dependencies.  It can load the
+ * files from the Yahoo! CDN, and it can utilize the combo service provided on
+ * this network to reduce the number of http connections required to download 
+ * YUI files.
+ * @class Loader
+ * @constructor
+ * @param o an optional set of configuration options.  Valid options:
+ * <ul>
+ *  <li>base:
+ *  The base dir</li>
+ *  <li>secureBase:
+ *  The secure base dir (not implemented)</li>
+ *  <li>comboBase:
+ *  The YUI combo service base dir. Ex: http://yui.yahooapis.com/combo?</li>
+ *  <li>root:
+ *  The root path to prepend to module names for the combo service. Ex: 2.5.2/build/</li>
+ *  <li>filter:
+ *  
+ * A filter to apply to result urls.  This filter will modify the default
+ * path for all modules.  The default path for the YUI library is the
+ * minified version of the files (e.g., event-min.js).  The filter property
+ * can be a predefined filter or a custom filter.  The valid predefined 
+ * filters are:
+ * <dl>
+ *  <dt>DEBUG</dt>
+ *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+ *      This option will automatically include the logger widget</dd>
+ *  <dt>RAW</dt>
+ *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+ * </dl>
+ * You can also define a custom filter, which must be an object literal 
+ * containing a search expression and a replace string:
+ * <pre>
+ *  myFilter: &#123; 
+ *      'searchExp': "-min\\.js", 
+ *      'replaceStr': "-debug.js"
+ *  &#125;
+ * </pre>
+ *
+ *  </li>
+ *  <li>combine:
+ *  Use the YUI combo service to reduce the number of http connections required to load your dependencies</li>
+ *  <li>ignore:
+ *  A list of modules that should never be dynamically loaded</li>
+ *  <li>force:
+ *  A list of modules that should always be loaded when required, even if already present on the page</li>
+ *  <li>insertBefore:
+ *  Node or id for a node that should be used as the insertion point for new nodes</li>
+ *  <li>charset:
+ *  charset for dynamic nodes</li>
+ *  <li>timeout:
+ *  number of milliseconds before a timeout occurs when dynamically loading nodes.  in not set, there is no timeout</li>
+ *  <li>context:
+ *  execution context for all callbacks</li>
+ *  <li>onSuccess:
+ *  callback for the 'success' event</li>
+ *  <li>onFailure:
+ *  callback for the 'failure' event</li>
+ *  <li>onTimeout:
+ *  callback for the 'timeout' event</li>
+ *  <li>onProgress:
+ *  callback executed each time a script or css file is loaded</li>
+ *  <li>modules:
+ *  A list of module definitions.  See Loader.addModule for the supported module metadata</li>
+ * </ul>
+ */
+
+// @TODO backed out the custom event changes so that the event system
+// isn't required in the seed build.  If needed, we may want to 
+// add them back if the event system is detected.
+
+/*
+ * Executed when the loader successfully completes an insert operation
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onSuccess config option.
+ * @event success
+ */
+
+/*
+ * Executed when the loader fails to complete an insert operation.
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onFailure config option.
+ *
+ * @event failure
+ */
+
+/*
+ * Executed when a Get operation times out.
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onTimeout config option.
+ *
+ * @event timeout
+ */
+
+// http://yui.yahooapis.com/combo?2.5.2/build/yahoo/yahoo-min.js&2.5.2/build/dom/dom-min.js&2.5.2/build/event/event-min.js&2.5.2/build/autocomplete/autocomplete-min.js"
+
+YUI.add("loader", function(Y) {
+
+var BASE = 'base', 
+    CSS = 'css',
+    JS = 'js',
+    CSSRESET = 'cssreset',
+    CSSFONTS = 'cssfonts',
+    CSSGRIDS = 'cssgrids',
+    CSSBASE = 'cssbase',
+    CSS_AFTER = [CSSRESET, CSSFONTS, CSSGRIDS, 'cssreset-context', 'cssfonts-context', 'cssgrids-context'],
+    YUI_CSS = ['reset', 'fonts', 'grids', 'base'],
+    VERSION = '3.0.0pr2',
+    ROOT = VERSION + '/build/',
+    CONTEXT = '-context',
+    META = {
+
+    version: VERSION,
+
+    root: ROOT,
+
+    base: 'http://yui.yahooapis.com/' + ROOT,
+
+    comboBase: 'http://yui.yahooapis.com/combo?',
+
+    skin: {
+        defaultSkin: 'sam',
+        base: 'assets/skins/',
+        path: 'skin.css',
+        after: ['reset', 'fonts', 'grids', 'base']
+        //rollup: 3
+    },
+
+    modules: {
+
+       dom: {
+            requires: ['event'],
+            submodules: {
+                'dom-base': {
+                    requires: ['event']
+                },
+                'dom-style': {
+                    requires: ['dom-base']
+
+                },
+                'dom-screen': {
+                    requires: ['dom-base', 'dom-style']
+                },
+                selector: {
+                    requires: ['dom-base']
+                }
+            }
+        },
+
+        node: {
+            requires: ['dom'],
+            submodules: {
+                'node-base': {
+                    requires: ['dom-base', 'selector']
+                },
+                'node-style': {
+                    requires: ['dom-style', 'node-base']
+                },
+                'node-screen': {
+                    requires: ['dom-screen', 'node-base']
+                },
+                'node-event-simulate': {
+                    requires: ['node-base']
+                }
+            }
+        },
+
+        anim: {
+            requires: [BASE, 'node'],
+            submodules: {
+                'anim-base': {
+                    requires: ['base', 'node-style']
+                },
+                'anim-color': {
+                    requires: ['anim-base']
+                },
+                'anim-curve': {
+                    requires: ['anim-xy']
+                },
+                'anim-easing': {
+                },
+                'anim-scroll': {
+                    requires: ['anim-base']
+                },
+                'anim-xy': {
+                    requires: ['anim-base', 'node-screen']
+                },
+                'anim-node-plugin': {
+                     requires: ['node', 'anim-base']
+                }
+            }
+        },
+
+        attribute: { 
+            requires: ['event']
+        },
+
+        base: {
+            requires: ['attribute']
+        },
+        
+        compat: { 
+            requires: ['node', 'dump', 'substitute']
+        },
+
+        classnamemanager: { },
+
+        console: {
+            requires: ['widget', 'substitute'],
+            skinnable: true
+        },
+        
+        cookie: { },
+
+        // Note: CSS attributes are modified programmatically to reduce metadata size
+        // cssbase: {
+        //     after: CSS_AFTER
+        // },
+
+        // cssgrids: {
+        //     requires: [CSSFONTS],
+        //     optional: [CSSRESET]
+        // },
+
+        dd:{
+            submodules: {
+                'dd-ddm-base': {
+                    requires: ['node', BASE]
+                }, 
+                'dd-ddm':{
+                    requires: ['dd-ddm-base']
+                }, 
+                'dd-ddm-drop':{
+                    requires: ['dd-ddm']
+                }, 
+                'dd-drag':{
+                    requires: ['dd-ddm-base']
+                }, 
+                'dd-drop':{
+                    requires: ['dd-ddm-drop']
+                }, 
+                'dd-proxy':{
+                    requires: ['dd-drag']
+                }, 
+                'dd-constrain':{
+                    requires: ['dd-drag', 'dd-proxy']
+                }, 
+                'dd-plugin':{
+                    requires: ['dd-drag'],
+                    optional: ['dd-constrain', 'dd-proxy']
+                },
+                'dd-drop-plugin':{
+                    requires: ['dd-drop']
+                }
+            }
+        },
+
+        dump: { },
+
+        event: { 
+            requires: ['oop']
+        },
+
+        get: { 
+            requires: ['yui-base']
+        },
+        
+        io:{
+            submodules: {
+
+                'io-base': {
+                    requires: ['node']
+                }, 
+
+                'io-xdr': {
+                    requires: ['io-base']
+                }, 
+
+                'io-form': {
+                    requires: ['io-base']
+                }, 
+
+                'io-upload-iframe': {
+                    requires: ['io-base']
+                },
+
+                'io-queue': {
+                    requires: ['io-base']
+                }
+            }
+        },
+
+        json: {
+            submodules: {
+                'json-parse': {
+                },
+
+                'json-stringify': {
+                }
+            }
+        },
+
+        loader: { 
+            requires: ['get']
+        },
+
+        'node-menunav': {
+            requires: ['node', 'classnamemanager'],
+            skinnable: true
+        },
+        
+        oop: { 
+            requires: ['yui-base']
+        },
+
+        overlay: {
+            requires: ['widget', 'widget-position', 'widget-position-ext', 'widget-stack', 'widget-stdmod'],
+            skinnable: true
+        },
+
+        plugin: { 
+            requires: ['base']
+        },
+
+        profiler: { },
+
+        queue: {
+            requires: ['node']
+        },
+
+        slider: {
+            requires: ['widget', 'dd-constrain'],
+            skinnable: true
+        },
+
+        stylesheet: { },
+
+        substitute: {
+            optional: ['dump']
+        },
+
+        widget: {
+            requires: ['base', 'node', 'classnamemanager'],
+            plugins: {
+                'widget-position': { },
+                'widget-position-ext': {
+                    requires: ['widget-position']
+                },
+                'widget-stack': {
+                    skinnable: true
+                },
+                'widget-stdmod': { }
+            },
+            skinnable: true
+        },
+
+        // Since YUI is required for everything else, it should not be specified as
+        // a dependency.
+        yui: {
+            supersedes: ['yui-base', 'get', 'loader']
+        },
+
+        'yui-base': { },
+
+        yuitest: {                                                                                                                                                        
+            requires: ['substitute', 'node', 'json']                                                                                                                     
+        }  
+
+    }
+};
+
+var _path = function(dir, file, type) {
+    return dir + '/' + file + '-min.' + (type || CSS);
+};
+
+var _cssmeta = function() {
+    var mods = META.modules;
+    // modify the meta info for YUI CSS
+    for (var i=0; i<YUI_CSS.length; i=i+1) {
+        var bname = YUI_CSS[i],
+            mname = CSS + bname;
+
+        mods[mname] = {
+            type: CSS,
+            path: _path(mname, bname)
+        };
+
+        // define -context module
+        var contextname = mname + CONTEXT;
+        bname = bname + CONTEXT;
+
+        mods[contextname] = {
+            type: CSS,
+            path: _path(mname, bname)
+        };
+
+        if (mname == CSSGRIDS) {
+            mods[mname].requires = [CSSFONTS];
+            mods[mname].optional = [CSSRESET];
+            mods[contextname].requires = [CSSFONTS + CONTEXT];
+            mods[contextname].optional = [CSSRESET + CONTEXT];
+        } else if (mname == CSSBASE) {
+            mods[mname].after = CSS_AFTER;
+            mods[contextname].after = CSS_AFTER;
+        }
+    }
+}();
+
+Y.Env.meta = META;
+
+
+    var L=Y.Lang, env=Y.Env,
+        PROV = "_provides", SUPER = "_supersedes",
+        REQ = "expanded";
+
+    Y.Loader = function(o) {
+
+        /**
+         * Internal callback to handle multiple internal insert() calls
+         * so that css is inserted prior to js
+         * @property _internalCallback
+         * @private
+         */
+        this._internalCallback = null;
+
+        /**
+         * Use the YUI environment listener to detect script load.  This
+         * is only switched on for Safari 2.x and below.
+         * @property _useYahooListener
+         * @private
+         */
+        this._useYahooListener = false;
+
+        /**
+         * Callback that will be executed when the loader is finished
+         * with an insert
+         * @method onSuccess
+         * @type function
+         */
+        this.onSuccess = null;
+
+        /**
+         * Callback that will be executed if there is a failure
+         * @method onFailure
+         * @type function
+         */
+        this.onFailure = null;
+
+        /**
+         * Callback executed each time a script or css file is loaded
+         * @method onProgress
+         * @type function
+         */
+        this.onProgress = null;
+
+        /**
+         * Callback that will be executed if a timeout occurs
+         * @method onTimeout
+         * @type function
+         */
+        this.onTimeout = null;
+
+        /**
+         * The execution context for all callbacks
+         * @property context
+         * @default {YUI} the YUI instance
+         */
+        this.context = Y;
+
+        /**
+         * Data that is passed to all callbacks
+         * @property data
+         */
+        this.data = null;
+
+        /**
+         * Node reference or id where new nodes should be inserted before
+         * @property insertBefore
+         * @type string|HTMLElement
+         */
+        this.insertBefore = null;
+
+        /**
+         * The charset attribute for inserted nodes
+         * @property charset
+         * @type string
+         * @default utf-8
+         */
+        this.charset = null;
+
+        /**
+         * The base directory.
+         * @property base
+         * @type string
+         * @default http://yui.yahooapis.com/[YUI VERSION]/build/
+         */
+        this.base = Y.Env.meta.base;
+
+        /**
+         * Base path for the combo service
+         * @property comboBase
+         * @type string
+         * @default http://yui.yahooapis.com/combo?
+         */
+        this.comboBase = Y.Env.meta.comboBase;
+
+        /**
+         * If configured, YUI JS resources will use the combo
+         * handler
+         * @property combine
+         * @type boolean
+         * @default true if a base dir isn't in the config
+         */
+        this.combine = (!(BASE in o));
+
+        /**
+         * Ignore modules registered on the YUI global
+         * @property ignoreRegistered
+         * @default false
+         */
+        this.ignoreRegistered = false;
+
+        /**
+         * Root path to prepend to module path for the combo
+         * service
+         * @property root
+         * @type string
+         * @default [YUI VERSION]/build/
+         */
+        this.root = Y.Env.meta.root;
+
+        /**
+         * Timeout value in milliseconds.  If set, this value will be used by
+         * the get utility.  the timeout event will fire if
+         * a timeout occurs.
+         * @property timeout
+         * @type int
+         */
+        this.timeout = 0;
+
+        /**
+         * A list of modules that should not be loaded, even if
+         * they turn up in the dependency tree
+         * @property ignore
+         * @type string[]
+         */
+        this.ignore = null;
+
+        /**
+         * A list of modules that should always be loaded, even
+         * if they have already been inserted into the page.
+         * @property force
+         * @type string[]
+         */
+        this.force = null;
+
+        /**
+         * Should we allow rollups
+         * @property allowRollup
+         * @type boolean
+         * @default true
+         */
+        this.allowRollup = true;
+
+        /**
+         * A filter to apply to result urls.  This filter will modify the default
+         * path for all modules.  The default path for the YUI library is the
+         * minified version of the files (e.g., event-min.js).  The filter property
+         * can be a predefined filter or a custom filter.  The valid predefined 
+         * filters are:
+         * <dl>
+         *  <dt>DEBUG</dt>
+         *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+         *      This option will automatically include the logger widget</dd>
+         *  <dt>RAW</dt>
+         *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+         * </dl>
+         * You can also define a custom filter, which must be an object literal 
+         * containing a search expression and a replace string:
+         * <pre>
+         *  myFilter: &#123; 
+         *      'searchExp': "-min\\.js", 
+         *      'replaceStr': "-debug.js"
+         *  &#125;
+         * </pre>
+         * @property filter
+         * @type string|{searchExp: string, replaceStr: string}
+         */
+        this.filter = null;
+
+        /**
+         * The list of requested modules
+         * @property required
+         * @type {string: boolean}
+         */
+        this.required = {};
+
+        /**
+         * The library metadata
+         * @property moduleInfo
+         */
+        // this.moduleInfo = Y.merge(Y.Env.meta.moduleInfo);
+        this.moduleInfo = {};
+
+        /**
+         * Provides the information used to skin the skinnable components.
+         * The following skin definition would result in 'skin1' and 'skin2'
+         * being loaded for calendar (if calendar was requested), and
+         * 'sam' for all other skinnable components:
+         *
+         *   <code>
+         *   skin: {
+         *
+         *      // The default skin, which is automatically applied if not
+         *      // overriden by a component-specific skin definition.
+         *      // Change this in to apply a different skin globally
+         *      defaultSkin: 'sam', 
+         *
+         *      // This is combined with the loader base property to get
+         *      // the default root directory for a skin. ex:
+         *      // http://yui.yahooapis.com/2.3.0/build/assets/skins/sam/
+         *      base: 'assets/skins/',
+         *
+         *      // The name of the rollup css file for the skin
+         *      path: 'skin.css',
+         *
+         *      // The number of skinnable components requested that are
+         *      // required before using the rollup file rather than the
+         *      // individual component css files
+         *      rollup: 3,
+         *
+         *      // Any component-specific overrides can be specified here,
+         *      // making it possible to load different skins for different
+         *      // components.  It is possible to load more than one skin
+         *      // for a given component as well.
+         *      overrides: {
+         *          calendar: ['skin1', 'skin2']
+         *      }
+         *   }
+         *   </code>
+         *   @property skin
+         */
+         this.skin = Y.merge(Y.Env.meta.skin);
+        
+        var defaults = Y.Env.meta.modules;
+
+        for (var i in defaults) {
+            if (defaults.hasOwnProperty(i)) {
+                this._internal = true;
+                this.addModule(defaults[i], i);
+                this._internal = false;
+            }
+        }
+
+        /**
+         * List of rollup files found in the library metadata
+         * @property rollups
+         */
+        this.rollups = null;
+
+        /**
+         * Whether or not to load optional dependencies for 
+         * the requested modules
+         * @property loadOptional
+         * @type boolean
+         * @default false
+         */
+        this.loadOptional = false;
+
+        /**
+         * All of the derived dependencies in sorted order, which
+         * will be populated when either calculate() or insert()
+         * is called
+         * @property sorted
+         * @type string[]
+         */
+        this.sorted = [];
+
+        /**
+         * Set when beginning to compute the dependency tree. 
+         * Composed of what YUI reports to be loaded combined
+         * with what has been loaded by the tool
+         * @propery loaded
+         * @type {string: boolean}
+         */
+        this.loaded = {};
+
+        /**
+         * A list of modules to attach to the YUI instance when complete.
+         * If not supplied, the sorted list of dependencies are applied.
+         * @property attaching
+         */
+        this.attaching = null;
+
+        /**
+         * Flag to indicate the dependency tree needs to be recomputed
+         * if insert is called again.
+         * @property dirty
+         * @type boolean
+         * @default true
+         */
+        this.dirty = true;
+
+        /**
+         * List of modules inserted by the utility
+         * @property inserted
+         * @type {string: boolean}
+         */
+        this.inserted = {};
+
+        this.skipped = {};
+
+
+        // Y.on('yui:load', this.loadNext, this);
+
+        this._config(o);
+
+    };
+
+    Y.Loader.prototype = {
+
+        FILTERS: {
+            RAW: { 
+                'searchExp': "-min\\.js", 
+                'replaceStr': ".js"
+            },
+            DEBUG: { 
+                'searchExp': "-min\\.js", 
+                'replaceStr': "-debug.js"
+            }
+        },
+
+        SKIN_PREFIX: "skin-",
+
+        _config: function(o) {
+
+            // apply config values
+            if (o) {
+                for (var i in o) {
+                    if (o.hasOwnProperty(i)) {
+                        var val = o[i];
+                        if (i == 'require') {
+                            this.require(val);
+                        } else if (i == 'modules') {
+
+                            // add a hash of module definitions
+                            for (var j in val) {
+                                if (val.hasOwnProperty(j)) {
+                                    this.addModule(val[j], j);
+                                }
+                            }
+
+                        } else {
+                            this[i] = val;
+                        }
+                    }
+                }
+            }
+
+            // fix filter
+            var f = this.filter;
+
+            if (L.isString(f)) {
+                f = f.toUpperCase();
+                this.filterName = f;
+                this.filter = this.FILTERS[f];
+            }
+
+        },
+
+        /**
+         * Returns the skin module name for the specified skin name.  If a
+         * module name is supplied, the returned skin module name is 
+         * specific to the module passed in.
+         * @method formatSkin
+         * @param skin {string} the name of the skin
+         * @param mod {string} optional: the name of a module to skin
+         * @return {string} the full skin module name
+         */
+        formatSkin: function(skin, mod) {
+            var s = this.SKIN_PREFIX + skin;
+            if (mod) {
+                s = s + "-" + mod;
+            }
+
+            return s;
+        },
+
+        /**
+         * Reverses <code>formatSkin</code>, providing the skin name and
+         * module name if the string matches the pattern for skins.
+         * @method parseSkin
+         * @param mod {string} the module name to parse
+         * @return {skin: string, module: string} the parsed skin name 
+         * and module name, or null if the supplied string does not match
+         * the skin pattern
+         */
+        parseSkin: function(mod) {
+            
+            if (mod.indexOf(this.SKIN_PREFIX) === 0) {
+                var a = mod.split("-");
+                return {skin: a[1], module: a[2]};
+            } 
+
+            return null;
+        },
+
+        /**
+         * Adds the skin def to the module info
+         * @method _addSkin
+         * @param skin {string} the name of the skin
+         * @param mod {string} the name of the module
+         * @param parent {string} parent module if this is a skin of a
+         * submodule or plugin
+         * @return {string} the module name for the skin
+         * @private
+         */
+        _addSkin: function(skin, mod, parent) {
+
+            var name = this.formatSkin(skin), info = this.moduleInfo,
+                sinf = this.skin, ext = info[mod] && info[mod].ext;
+
+            /*
+            // Add a module definition for the skin rollup css
+            if (!info[name]) {
+                this.addModule({
+                    'name': name,
+                    'type': 'css',
+                    'path': sinf.base + skin + '/' + sinf.path,
+                    //'supersedes': '*',
+                    'after': sinf.after,
+                    'rollup': sinf.rollup,
+                    'ext': ext
+                });
+            }
+            */
+
+            // Add a module definition for the module-specific skin css
+            if (mod) {
+                name = this.formatSkin(skin, mod);
+                if (!info[name]) {
+                    var mdef = info[mod], pkg = mdef.pkg || mod;
+                    this.addModule({
+                        'name': name,
+                        'type': 'css',
+                        'after': sinf.after,
+                        'path': (parent || pkg) + '/' + sinf.base + skin + '/' + mod + '.css',
+                        'ext': ext
+                    });
+                }
+            }
+
+            return name;
+        },
+
+        /** Add a new module to the component metadata.         
+         * <dl>
+         *     <dt>name:</dt>       <dd>required, the component name</dd>
+         *     <dt>type:</dt>       <dd>required, the component type (js or css)</dd>
+         *     <dt>path:</dt>       <dd>required, the path to the script from "base"</dd>
+         *     <dt>requires:</dt>   <dd>array of modules required by this component</dd>
+         *     <dt>optional:</dt>   <dd>array of optional modules for this component</dd>
+         *     <dt>supersedes:</dt> <dd>array of the modules this component replaces</dd>
+         *     <dt>after:</dt>      <dd>array of modules the components which, if present, should be sorted above this one</dd>
+         *     <dt>rollup:</dt>     <dd>the number of superseded modules required for automatic rollup</dd>
+         *     <dt>fullpath:</dt>   <dd>If fullpath is specified, this is used instead of the configured base + path</dd>
+         *     <dt>skinnable:</dt>  <dd>flag to determine if skin assets should automatically be pulled in</dd>
+         *     <dt>submodules:</dt> <dd>a has of submodules</dd>
+         * </dl>
+         * @method addModule
+         * @param o An object containing the module data
+         * @param name the module name (optional), required if not in the module data
+         * @return {boolean} true if the module was added, false if 
+         * the object passed in did not provide all required attributes
+         */
+        addModule: function(o, name) {
+
+            name = name || o.name;
+            o.name = name;
+
+            if (!o || !o.name) {
+                return false;
+            }
+
+            if (!o.type) {
+                o.type = JS;
+            }
+
+            if (!o.path && !o.fullpath) {
+                // o.path = name + "/" + name + "-min." + o.type;
+                o.path = _path(name, name, o.type);
+            }
+
+            o.ext = ('ext' in o) ? o.ext : (this._internal) ? false : true;
+            o.requires = o.requires || [];
+
+
+            this.moduleInfo[name] = o;
+
+            // Handle submodule logic
+            var subs = o.submodules, i;
+            if (subs) {
+                var sup = [], l=0;
+
+                for (i in subs) {
+                    if (subs.hasOwnProperty(i)) {
+                        var s = subs[i];
+                        s.path = _path(name, i, o.type);
+                        this.addModule(s, i);
+                        sup.push(i);
+
+                        if (o.skinnable) {
+                            var smod = this._addSkin(this.skin.defaultSkin, i, name);
+                            sup.push(smod.name);
+                        }
+
+                        l++;
+                    }
+                }
+
+                o.supersedes = sup;
+                o.rollup = Math.min(l-1, 4);
+            }
+
+            var plugins = o.plugins;
+            if (plugins) {
+                for (i in plugins) {
+                    if (plugins.hasOwnProperty(i)) {
+                        var plug = plugins[i];
+                        plug.path = _path(name, i, o.type);
+                        plug.requires = plug.requires || [];
+                        plug.requires.push(name);
+                        this.addModule(plug, i);
+                        if (o.skinnable) {
+                            this._addSkin(this.skin.defaultSkin, i, name);
+                        }
+                    }
+                }
+            }
+
+            this.dirty = true;
+
+            return o;
+        },
+
+        /**
+         * Add a requirement for one or more module
+         * @method require
+         * @param what {string[] | string*} the modules to load
+         */
+        require: function(what) {
+            var a = (typeof what === "string") ? arguments : what;
+            this.dirty = true;
+            Y.mix(this.required, Y.Array.hash(a));
+        },
+
+        /**
+         * Returns an object containing properties for all modules required
+         * in order to load the requested module
+         * @method getRequires
+         * @param mod The module definition from moduleInfo
+         */
+        getRequires: function(mod) {
+
+            if (!mod) {
+                return [];
+            }
+
+            if (!this.dirty && mod.expanded) {
+                return mod.expanded;
+            }
+
+            var i, d=[], r=mod.requires, o=mod.optional, 
+                info=this.moduleInfo, m, j, add;
+
+            for (i=0; i<r.length; i=i+1) {
+                d.push(r[i]);
+                m = this.getModule(r[i]);
+                add = this.getRequires(m);
+                for (j=0;j<add.length;j=j+1) {
+                    d.push(add[j]);
+                }
+            }
+
+            // get the requirements from superseded modules, if any
+            r=mod.supersedes;
+            if (r) {
+                for (i=0; i<r.length; i=i+1) {
+                    d.push(r[i]);
+                    m = this.getModule(r[i]);
+                    add = this.getRequires(m);
+                    for (j=0;j<add.length;j=j+1) {
+                        d.push(add[j]);
+                    }
+                }
+            }
+
+            if (o && this.loadOptional) {
+                for (i=0; i<o.length; i=i+1) {
+                    d.push(o[i]);
+                    add = this.getRequires(info[o[i]]);
+                    for (j=0;j<add.length;j=j+1) {
+                        d.push(add[j]);
+                    }
+                }
+            }
+
+            mod.expanded = Y.Object.keys(Y.Array.hash(d));
+
+
+            return mod.expanded;
+        },
+
+
+        /**
+         * Returns an object literal of the modules the supplied module satisfies
+         * @method getProvides
+         * @param name{string} The name of the module
+         * @param notMe {string} don't add this module name, only include superseded modules
+         * @return what this module provides
+         */
+        getProvides: function(name, notMe) {
+            var addMe = !(notMe), ckey = (addMe) ? PROV : SUPER,
+                m = this.getModule(name), o = {};
+
+            if (!m) {
+                return o;
+            }
+
+            if (m[ckey]) {
+                return m[ckey];
+            }
+
+            var s = m.supersedes, done={}, me = this;
+
+            // use worker to break cycles
+            var add = function(mm) {
+                if (!done[mm]) {
+                    done[mm] = true;
+                    // we always want the return value normal behavior 
+                    // (provides) for superseded modules.
+                    Y.mix(o, me.getProvides(mm));
+                } 
+                
+                // else {
+                // }
+            };
+
+            // calculate superseded modules
+            if (s) {
+                for (var i=0; i<s.length; i=i+1) {
+                    add(s[i]);
+                }
+            }
+
+            // supersedes cache
+            m[SUPER] = o;
+            // provides cache
+            m[PROV] = Y.merge(o);
+            m[PROV][name] = true;
+
+
+            return m[ckey];
+        },
+
+
+        /**
+         * Calculates the dependency tree, the result is stored in the sorted 
+         * property
+         * @method calculate
+         * @param o optional options object
+         */
+        calculate: function(o) {
+            if (o || this.dirty) {
+                this._config(o);
+                this._setup();
+                this._explode();
+                if (this.allowRollup) {
+                    this._rollup();
+                }
+                this._reduce();
+                this._sort();
+
+
+                this.dirty = false;
+            }
+        },
+
+        /**
+         * Investigates the current YUI configuration on the page.  By default,
+         * modules already detected will not be loaded again unless a force
+         * option is encountered.  Called by calculate()
+         * @method _setup
+         * @private
+         */
+        _setup: function() {
+
+            var info = this.moduleInfo, name, i, j;
+
+            // Create skin modules
+            for (name in info) {
+                if (info.hasOwnProperty(name)) {
+                    var m = info[name];
+                    if (m && m.skinnable) {
+                        var o=this.skin.overrides, smod;
+                        if (o && o[name]) {
+                            for (i=0; i<o[name].length; i=i+1) {
+                                smod = this._addSkin(o[name][i], name);
+                            }
+                        } else {
+                            smod = this._addSkin(this.skin.defaultSkin, name);
+                        }
+
+                        m.requires.push(smod);
+                    }
+                }
+            }
+
+            var l = Y.merge(this.inserted); // shallow clone
+
+            // available modules
+            if (!this.ignoreRegistered) {
+                Y.mix(l, YUI.Env.mods);
+            }
+            
+
+            // add the ignore list to the list of loaded packages
+            if (this.ignore) {
+                // OU.appendArray(l, this.ignore);
+                Y.mix(l, Y.Array.hash(this.ignore));
+            }
+
+            // expand the list to include superseded modules
+            for (j in l) {
+                if (l.hasOwnProperty(j)) {
+                    Y.mix(l, this.getProvides(j));
+                }
+            }
+
+            // remove modules on the force list from the loaded list
+            if (this.force) {
+                for (i=0; i<this.force.length; i=i+1) {
+                    if (this.force[i] in l) {
+                        delete l[this.force[i]];
+                    }
+                }
+            }
+
+
+            this.loaded = l;
+
+        },
+        
+
+        /**
+         * Inspects the required modules list looking for additional 
+         * dependencies.  Expands the required list to include all 
+         * required modules.  Called by calculate()
+         * @method _explode
+         * @private
+         */
+        _explode: function() {
+
+            var r=this.required, i, mod;
+
+            for (i in r) {
+                if (r.hasOwnProperty(i)) {
+                    mod = this.getModule(i);
+
+                    var req = this.getRequires(mod);
+
+                    if (req) {
+                        Y.mix(r, Y.Array.hash(req));
+                    }
+                }
+            }
+        },
+
+        getModule: function(name) {
+
+            var m = this.moduleInfo[name];
+
+            // create the default module
+            // if (!m) {
+                // m = this.addModule({ext: false}, name);
+            // }
+
+            return m;
+        },
+
+        /**
+         * Look for rollup packages to determine if all of the modules a
+         * rollup supersedes are required.  If so, include the rollup to
+         * help reduce the total number of connections required.  Called
+         * by calculate()
+         * @method _rollup
+         * @private
+         */
+        _rollup: function() {
+            var i, j, m, s, rollups={}, r=this.required, roll,
+                info = this.moduleInfo;
+
+            // find and cache rollup modules
+            if (this.dirty || !this.rollups) {
+                for (i in info) {
+                    if (info.hasOwnProperty(i)) {
+                        m = this.getModule(i);
+                        // if (m && m.rollup && m.supersedes) {
+                        if (m && m.rollup) {
+                            rollups[i] = m;
+                        }
+                    }
+                }
+
+                this.rollups = rollups;
+            }
+
+            // make as many passes as needed to pick up rollup rollups
+            for (;;) {
+                var rolled = false;
+
+                // go through the rollup candidates
+                for (i in rollups) { 
+
+                    if (rollups.hasOwnProperty(i)) {
+
+                        // there can be only one
+                        if (!r[i] && !this.loaded[i]) {
+                            m =this.getModule(i); s = m.supersedes ||[]; roll=false;
+
+                            if (!m.rollup) {
+                                continue;
+                            }
+
+                            var c=0;
+
+                            // check the threshold
+                            for (j=0;j<s.length;j=j+1) {
+
+                                // if the superseded module is loaded, we can't load the rollup
+                                // if (this.loaded[s[j]] && (!_Y.dupsAllowed[s[j]])) {
+                                if (this.loaded[s[j]]) {
+                                    roll = false;
+                                    break;
+                                // increment the counter if this module is required.  if we are
+                                // beyond the rollup threshold, we will use the rollup module
+                                } else if (r[s[j]]) {
+                                    c++;
+                                    roll = (c >= m.rollup);
+                                    if (roll) {
+                                        break;
+                                    }
+                                }
+                            }
+
+                            if (roll) {
+                                // add the rollup
+                                r[i] = true;
+                                rolled = true;
+
+                                // expand the rollup's dependencies
+                                this.getRequires(m);
+                            }
+                        }
+                    }
+                }
+
+                // if we made it here w/o rolling up something, we are done
+                if (!rolled) {
+                    break;
+                }
+            }
+        },
+
+        /**
+         * Remove superceded modules and loaded modules.  Called by
+         * calculate() after we have the mega list of all dependencies
+         * @method _reduce
+         * @private
+         */
+        _reduce: function() {
+
+            var i, j, s, m, r=this.required;
+            for (i in r) {
+
+                if (r.hasOwnProperty(i)) {
+
+                    // remove if already loaded
+                    if (i in this.loaded) { 
+                        delete r[i];
+
+                    // remove anything this module supersedes
+                    } else {
+
+                         m = this.getModule(i);
+                         s = m && m.supersedes;
+                         if (s) {
+                             for (j=0; j<s.length; j=j+1) {
+                                 if (s[j] in r) {
+                                     delete r[s[j]];
+                                 }
+                             }
+                         }
+                    }
+                }
+            }
+        },
+
+        _attach: function() {
+
+            // this is the full list of items the YUI needs attached,
+            // which is needed if some dependencies are already on
+            // the page without their dependencies.
+            if (this.attaching) {
+                Y._attach(this.attaching);
+            } else {
+                Y._attach(this.sorted);
+            }
+
+            this._pushEvents();
+
+        },
+
+        _onSuccess: function() {
+
+            this._attach();
+
+            var skipped = this.skipped;
+
+            for (var i in skipped) {
+                if (skipped.hasOwnProperty(i)) {
+                    delete this.inserted[i];
+                }
+            }
+
+            this.skipped = {};
+
+            // this.fire('success', {
+            //     data: this.data
+            // });
+
+            var f = this.onSuccess;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'success',
+                    data: this.data,
+                    success: true
+                });
+            }
+
+        },
+
+        _onFailure: function(msg) {
+            this._attach();
+            // this.fire('failure', {
+            //     msg: 'operation failed: ' + msg,
+            //     data: this.data
+            // });
+
+            var f = this.onFailure;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'failure: ' + msg,
+                    data: this.data,
+                    success: false
+                });
+            }
+        },
+
+        _onTimeout: function() {
+            this._attach();
+
+            // this.fire('timeout', {
+            //     data: this.data
+            // });
+
+            var f = this.onTimeout;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'timeout',
+                    data: this.data,
+                    success: false
+                });
+            }
+        },
+        
+        /**
+         * Sorts the dependency tree.  The last step of calculate()
+         * @method _sort
+         * @private
+         */
+        _sort: function() {
+            // create an indexed list
+            var s=Y.Object.keys(this.required), info=this.moduleInfo, loaded=this.loaded,
+                me = this;
+
+            // returns true if b is not loaded, and is required
+            // directly or by means of modules it supersedes.
+            var requires = function(aa, bb) {
+
+                var mm=info[aa];
+
+                if (loaded[bb] || !mm) {
+                    return false;
+                }
+
+                var ii, rr = mm.expanded, 
+                    after = mm.after, other=info[bb];
+
+                // check if this module requires the other directly
+                if (rr && Y.Array.indexOf(rr, bb) > -1) {
+                    return true;
+                }
+
+                // check if this module should be sorted after the other
+                if (after && Y.Array.indexOf(after, bb) > -1) {
+                    return true;
+                }
+
+                // check if this module requires one the other supersedes
+                var ss=info[bb] && info[bb].supersedes;
+                if (ss) {
+                    for (ii=0; ii<ss.length; ii=ii+1) {
+                        if (requires(aa, ss[ii])) {
+                            return true;
+                        }
+                    }
+                }
+
+                // external css files should be sorted below yui css
+                if (mm.ext && mm.type == CSS && !other.ext && other.type == CSS) {
+                    return true;
+                }
+
+                return false;
+            };
+
+            // pointer to the first unsorted item
+            var p=0; 
+
+            // keep going until we make a pass without moving anything
+            for (;;) {
+               
+                var l=s.length, a, b, j, k, moved=false;
+
+                // start the loop after items that are already sorted
+                for (j=p; j<l; j=j+1) {
+
+                    // check the next module on the list to see if its
+                    // dependencies have been met
+                    a = s[j];
+
+                    // check everything below current item and move if we
+                    // find a requirement for the current item
+                    for (k=j+1; k<l; k=k+1) {
+                        if (requires(a, s[k])) {
+
+                            // extract the dependency so we can move it up
+                            b = s.splice(k, 1);
+
+                            // insert the dependency above the item that 
+                            // requires it
+                            s.splice(j, 0, b[0]);
+
+                            moved = true;
+                            break;
+                        }
+                    }
+
+                    // jump out of loop if we moved something
+                    if (moved) {
+                        break;
+                    // this item is sorted, move our pointer and keep going
+                    } else {
+                        p = p + 1;
+                    }
+                }
+
+                // when we make it here and moved is false, we are 
+                // finished sorting
+                if (!moved) {
+                    break;
+                }
+
+            }
+
+            this.sorted = s;
+        },
+
+        /**
+         * inserts the requested modules and their dependencies.  
+         * <code>type</code> can be "js" or "css".  Both script and 
+         * css are inserted if type is not provided.
+         * @method insert
+         * @param o optional options object
+         * @param type {string} the type of dependency to insert
+         */
+        insert: function(o, type) {
+
+
+            // build the dependency list
+            this.calculate(o);
+
+            if (!type) {
+                var self = this;
+                this._internalCallback = function() {
+                            self._internalCallback = null;
+                            self.insert(null, JS);
+                        };
+                this.insert(null, CSS);
+                return;
+            }
+
+            // set a flag to indicate the load has started
+            this._loading = true;
+
+            // flag to indicate we are done with the combo service
+            // and any additional files will need to be loaded
+            // individually
+            this._combineComplete = {};
+
+            // keep the loadType (js, css or undefined) cached
+            this.loadType = type;
+
+            // start the load
+            this.loadNext();
+
+        },
+
+        /**
+         * Executed every time a module is loaded, and if we are in a load
+         * cycle, we attempt to load the next script.  Public so that it
+         * is possible to call this if using a method other than
+         * Y.register to determine when scripts are fully loaded
+         * @method loadNext
+         * @param mname {string} optional the name of the module that has
+         * been loaded (which is usually why it is time to load the next
+         * one)
+         */
+        loadNext: function(mname) {
+
+            // It is possible that this function is executed due to something
+            // else one the page loading a YUI module.  Only react when we
+            // are actively loading something
+            if (!this._loading) {
+                return;
+            }
+
+            var s, len, i, m, url, self=this, type=this.loadType, fn;
+
+            // @TODO this will need to handle the two phase insert when
+            // CSS support is added
+            if (this.combine && (!this._combineComplete[type])) {
+
+                this._combining = []; 
+                s=this.sorted;
+                len=s.length;
+                url=this.comboBase;
+
+                for (i=0; i<len; i=i+1) {
+                    m = this.getModule(s[i]);
+// @TODO we can't combine CSS yet until we deliver files with absolute paths to the assets
+                    // Do not try to combine non-yui JS
+                    if (m && m.type === this.loadType && !m.ext) {
+                        url += this.root + m.path;
+                        if (i < len-1) {
+                            url += '&';
+                        }
+
+                        this._combining.push(s[i]);
+                    }
+                }
+
+                if (this._combining.length) {
+
+
+                    var callback=function(o) {
+                        this._combineComplete[type] = true;
+
+
+                        var c=this._combining, len=c.length, i, m;
+                        for (i=0; i<len; i=i+1) {
+                            this.inserted[c[i]] = true;
+                        }
+
+                        this.loadNext(o.data);
+                    };
+
+                    fn =(type === CSS) ? Y.Get.css : Y.Get.script;
+
+                    // @TODO get rid of the redundant Get code
+                    fn(this._filter(url), {
+                        data: this._loading,
+                        onSuccess: callback,
+                        onFailure: this._onFailure,
+                        onTimeout: this._onTimeout,
+                        insertBefore: this.insertBefore,
+                        charset: this.charset,
+                        timeout: this.timeout,
+                        context: self 
+                    });
+
+                    return;
+
+                } else {
+                    this._combineComplete[type] = true;
+                }
+            }
+
+            if (mname) {
+
+                // if the module that was just loaded isn't what we were expecting,
+                // continue to wait
+                if (mname !== this._loading) {
+                    return;
+                }
+
+
+                // The global handler that is called when each module is loaded
+                // will pass that module name to this function.  Storing this
+                // data to avoid loading the same module multiple times
+                this.inserted[mname] = true;
+
+                // this.fire('progress', {
+                //     name: mname,
+                //     data: this.data
+                // });
+                if (this.onProgress) {
+                    this.onProgress.call(this.context, {
+                            name: mname,
+                            data: this.data
+                        });
+                }
+
+
+            }
+
+            s=this.sorted;
+            len=s.length;
+
+            for (i=0; i<len; i=i+1) {
+
+                // this.inserted keeps track of what the loader has loaded.
+                // move on if this item is done.
+                if (s[i] in this.inserted) {
+                    continue;
+                }
+
+                // Because rollups will cause multiple load notifications
+                // from Y, loadNext may be called multiple times for
+                // the same module when loading a rollup.  We can safely
+                // skip the subsequent requests
+                if (s[i] === this._loading) {
+                    return;
+                }
+
+                // log("inserting " + s[i]);
+                m = this.getModule(s[i]);
+
+                if (!m) {
+
+                    var msg = "Undefined module " + s[i] + " skipped";
+                    this.inserted[s[i]] = true;
+                    this.skipped[s[i]] = true;
+                    continue;
+
+                    // this.fire('failure', {
+                        // msg: msg,
+                        // data: this.data
+                    // });
+                }
+
+
+                // The load type is stored to offer the possibility to load
+                // the css separately from the script.
+                if (!type || type === m.type) {
+                    this._loading = s[i];
+
+                    fn = (m.type === CSS) ? Y.Get.css : Y.Get.script;
+
+                    var onsuccess=function(o) {
+                            self.loadNext(o.data);
+                        };
+                        
+                    url = (m.fullpath) ? this._filter(m.fullpath) : this._url(m.path, s[i]);
+
+                    self = this; 
+
+                    fn(url, {
+                        data: s[i],
+                        onSuccess: onsuccess,
+                        insertBefore: this.insertBefore,
+                        charset: this.charset,
+                        onFailure: this._onFailure,
+                        onTimeout: this._onTimeout,
+                        timeout: this.timeout,
+                        context: self 
+                    });
+
+                    return;
+                }
+            }
+
+            // we are finished
+            this._loading = null;
+
+            fn = this._internalCallback;
+
+            // internal callback for loading css first
+            if (fn) {
+                this._internalCallback = null;
+                fn.call(this);
+
+            // } else if (this.onSuccess) {
+            } else {
+                // call Y.use passing this instance. Y will use the sorted
+                // dependency list.
+                this._onSuccess();
+            }
+
+        },
+
+        /**
+         * In IE, the onAvailable/onDOMReady events need help when Event is
+         * loaded dynamically
+         * @method _pushEvents
+         * @param {Function} optional function reference
+         * @private
+         */
+        _pushEvents: function() {
+            if (Y.Event) {
+                Y.Event._load();
+            }
+        },
+
+        /**
+         * Apply filter defined for this instance to a url/path
+         * method _filter
+         * @param u {string} the string to filter
+         * @return {string} the filtered string
+         * @private
+         */
+        _filter: function(u) {
+
+
+            var f = this.filter;
+
+            if (u && f) {
+                var useFilter = true;
+
+                if (this.filterName == "DEBUG") {
+                
+                    var exc = this.logExclude,
+                        inc = this.logInclude;
+                    if (inc && !(name in inc)) {
+                        useFilter = false;
+                    } else if (exc && (name in exc)) {
+                        useFilter = false;
+                    }
+
+                }
+                
+                if (useFilter) {
+                    u = u.replace(new RegExp(f.searchExp, 'g'), f.replaceStr);
+                }
+            }
+
+            return u;
+
+        },
+
+        /**
+         * Generates the full url for a module
+         * method _url
+         * @param path {string} the path fragment
+         * @return {string} the full url
+         * @private
+         */
+        _url: function(path, name) {
+            return this._filter((this.base || "") + path);
+        }
+
+    };
+
+    // Y.augment(Y.Loader, Y.Event.Target);
+
+}, "3.0.0pr2");

=== added directory 'loggerhead/static/javascript/yui/build/node'
=== added directory 'loggerhead/static/javascript/yui/build/node-menunav'
=== added file 'loggerhead/static/javascript/yui/build/node-menunav/README'
--- loggerhead/static/javascript/yui/build/node-menunav/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node-menunav/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,3 @@
+**** version 3.0.0 PR2 ***
+
+* Initial 3.0 revision

=== added directory 'loggerhead/static/javascript/yui/build/node-menunav/assets'
=== added file 'loggerhead/static/javascript/yui/build/node-menunav/assets/node-menunav-core.css'
--- loggerhead/static/javascript/yui/build/node-menunav/assets/node-menunav-core.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node-menunav/assets/node-menunav-core.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,175 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-menu .yui-menu {
+
+	position: absolute;
+	z-index: 1;
+
+}
+
+
+.yui-menu .yui-shim {
+
+	/* 
+		Styles for the <iframe> shim used to prevent <select> elements from poking through 
+		submenus in IE < 7.  Note: For peformance, creation of the <iframe> shim for each submenu  
+		is deferred until it is initially made visible by the user.
+	*/
+
+    position: absolute;
+    top: 0;
+    left: 0;
+    z-index: -1;
+	opacity: 0;
+	filter: alpha(opacity=0);  /* For IE since it doesn't implement the CSS3 "opacity" property. */
+	border: none;
+	margin: 0;
+	padding: 0;
+	height: 100%;
+	width: 100%;
+
+}
+
+.yui-menu-hidden {
+
+	/*
+		Position hidden menus outside the viewport boundaries to prevent them from 
+		triggering scrollbars on the viewport.
+	*/
+
+	top: -10000px;
+	left: -10000px;
+
+	/*
+		Using "visibility:hidden" over "display" none because:
+		
+		1)	As the "position" property for submenus is set to "absolute", they are out of 
+			the document flow and take up no space.  Therefore, from that perspective use of 
+			"display:none" is redundant.
+		
+		2)	According to MSDN use of "display:none" is more expensive:
+			"Display is the more expensive of the two CSS properties, so if you are 
+			making elements appear and disappear often, visibility will be faster." 
+			(See http://msdn.microsoft.com/en-us/library/bb264005(VS.85).aspx)
+	*/
+
+	visibility: hidden;
+
+}
+
+.yui-menu li {
+
+    list-style-type: none;    
+
+}
+
+.yui-menu ul, 
+.yui-menu li { 
+
+    margin: 0;
+    padding: 0;
+
+}
+
+.yui-menu-label,
+.yui-menuitem-content {
+
+    text-align: left;
+    white-space: nowrap;
+    display: block;
+
+}
+
+.yui-menu-horizontal li {
+
+	float: left;
+	width: auto;
+
+}
+
+.yui-menu-horizontal li li {
+
+	float: none;
+
+}
+
+.yui-menu-horizontal ul {
+
+	/*
+		Use of "zoom" sets the "hasLayout" property to "true" in IE (< 8).  When "hasLayout" is 
+		set to "true", an element can clear its floated descendents.  For more:
+		http://msdn.microsoft.com/en-gb/library/ms533776(VS.85).aspx
+	*/
+
+	*zoom: 1;
+
+}
+
+.yui-menu-horizontal ul ul {
+
+	/*
+		No need to clear <ul>s of submenus of horizontal menus since <li>s of submenus
+		aren't floated.
+	*/
+
+	*zoom: normal;
+
+}			
+
+.yui-menu-horizontal>.yui-menu-content>ul:after {
+
+	/*	Self-clearing solution for Opera, Webkit, Gecko and IE > 7	*/
+
+	content: "";
+	display: block;
+	clear: both;
+	line-height: 0;
+	font-size: 0;
+	visibility: hidden;
+
+}
+
+
+/*
+	The following two rules are for IE 7.  Triggering "hasLayout" (via use of "zoom") prevents 
+	first-tier submenus from hiding when the mouse is moving from an menu label in a root menu to 
+	its corresponding submenu.
+*/
+
+.yui-menu-content {
+
+	*zoom: 1;
+    
+}
+
+
+.yui-menu-hidden .yui-menu-content {
+
+	*zoom: normal;
+
+}
+
+
+/*
+	The following two rules are for IE 6 (Standards Mode and Quirks Mode) and IE 7 (Quirks Mode 
+	only).  Triggering "hasLayout" (via use of "zoom") fixes a bug in IE where mousing mousing off 
+	the text node of menuitem or menu label will incorrectly trigger the mouseout event.
+*/
+
+.yui-menuitem-content,
+.yui-menu-label {
+
+	_zoom: 1;
+
+}
+
+.yui-menu-hiden .yui-menuitem-content,
+.yui-menu-hiden .yui-menu-label {
+
+	_zoom: normal;
+
+}
\ No newline at end of file

=== added directory 'loggerhead/static/javascript/yui/build/node-menunav/assets/skins'
=== added directory 'loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam'
=== added file 'loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/horizontal-menu-submenu-indicator.png'
Binary files loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/horizontal-menu-submenu-indicator.png and loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/horizontal-menu-submenu-indicator.png differ
=== added file 'loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/horizontal-menu-submenu-toggle.png'
Binary files loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/horizontal-menu-submenu-toggle.png and loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/horizontal-menu-submenu-toggle.png differ
=== added file 'loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/node-menunav-skin.css'
--- loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/node-menunav-skin.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/node-menunav-skin.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,269 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/* Vertical menus and submenus */
+
+.yui-skin-sam .yui-menu-content, 
+.yui-skin-sam .yui-menu .yui-menu .yui-menu-content {
+
+    font-size: 93%;  /* 12px */
+    line-height: 1.5;  /* 18px */
+    *line-height: 1.45; /* For IE */
+    border: solid 1px #808080;
+    background: #fff;
+    padding: 3px 0;
+
+}
+
+.yui-skin-sam .yui-menu .yui-menu .yui-menu-content {
+
+	font-size: 100%;
+    
+}
+
+
+/* Horizontal menus */
+
+.yui-skin-sam .yui-menu-horizontal .yui-menu-content {
+
+    line-height: 2;  /* ~24px */
+    *line-height: 1.9; /* For IE */
+    background: url(../../../../assets/skins/sam/sprite.png) repeat-x 0 0;
+    padding: 0;
+
+}
+
+
+.yui-skin-sam .yui-menu ul,
+.yui-skin-sam .yui-menu ul ul {
+
+	margin-top: 3px;
+	padding-top: 3px;
+    border-top: solid 1px #ccc;
+
+}
+
+.yui-skin-sam .yui-menu ul.first-of-type {
+
+    border: 0;
+	margin: 0;
+	padding: 0;    
+
+}
+
+.yui-skin-sam .yui-menu-horizontal ul {
+
+	padding: 0;
+	margin: 0;
+	border: 0;
+
+}
+
+
+.yui-skin-sam .yui-menu li,
+.yui-skin-sam .yui-menu .yui-menu li {
+
+    /*
+        For and IE 6 (Strict Mode and Quirks Mode) and IE 7 (Quirks Mode only): Used to collapse 
+        superfluous white space between <li> elements that is triggered by the "display" property 
+        of the <a> elements being set to "block" by node-menunav-core.css file.
+    */
+
+    _border-bottom: solid 1px #fff;
+
+}
+
+.yui-skin-sam .yui-menu-horizontal li {
+
+	_border-bottom: 0;
+
+}
+
+.yui-skin-sam .yui-menubuttonnav li {
+
+    border-right: solid 1px #ccc;
+
+}
+
+.yui-skin-sam .yui-splitbuttonnav li {
+
+    border-right: solid 1px #808080;
+
+}
+
+.yui-skin-sam .yui-menubuttonnav li li,
+.yui-skin-sam .yui-splitbuttonnav li li {
+
+	border-right: 0;
+
+}
+
+
+/* Menuitems and menu labels */
+
+
+.yui-skin-sam .yui-menu-label,
+.yui-skin-sam .yui-menu .yui-menu .yui-menu-label,
+.yui-skin-sam .yui-menuitem-content,
+.yui-skin-sam .yui-menu .yui-menu .yui-menuitem-content {
+
+    padding: 0 20px;
+    color: #000;
+    text-decoration: none;
+    cursor: default;
+
+	/*
+		Necessary specify values for border, position and margin to override values specified in 
+		the selectors that follow. 
+	*/
+
+	float: none;
+	border: 0;
+	margin: 0;
+
+}
+
+.yui-skin-sam .yui-menu-horizontal .yui-menu-label,
+.yui-skin-sam .yui-menu-horizontal .yui-menuitem-content {
+
+    padding: 0 10px;
+    border-style: solid;
+    border-color: #808080;
+    border-width: 1px 0;
+    margin: -1px 0;
+
+    float: left; 	/*	Ensures that menu labels clear floated descendents. Also gets negative 
+    					margins working in IE 7 (Strict Mode). */
+    width: auto;
+
+}
+
+.yui-skin-sam .yui-menu-label,
+.yui-skin-sam .yui-menu .yui-menu .yui-menu-label {
+
+	background: url(vertical-menu-submenu-indicator.png) right center no-repeat;
+
+}
+
+.yui-skin-sam .yui-menu-horizontal .yui-menu-label {
+
+    background: url(../../../../assets/skins/sam/sprite.png) repeat-x 0 0;
+
+}
+
+.yui-skin-sam .yui-menubuttonnav .yui-menu-label,
+.yui-skin-sam .yui-splitbuttonnav .yui-menu-label {
+
+	background-image: none;
+
+}
+
+.yui-skin-sam .yui-menubuttonnav .yui-menu-label {
+
+    padding-right: 0;
+
+}
+
+.yui-skin-sam .yui-menubuttonnav .yui-menu-label em {
+
+	font-style: normal;
+	padding-right: 20px;
+    display: block;
+    background: url(horizontal-menu-submenu-indicator.png) right center no-repeat;
+
+}
+
+
+.yui-skin-sam .yui-splitbuttonnav .yui-menu-label {
+
+	padding: 0;
+
+}
+
+.yui-skin-sam .yui-splitbuttonnav .yui-menu-label a {
+
+	float: left;
+	width: auto;
+    color: #000;
+    text-decoration: none;
+    cursor: default;
+	padding: 0 5px 0 10px;
+
+}
+
+.yui-skin-sam .yui-splitbuttonnav .yui-menu-label .yui-menu-toggle {
+	
+	padding: 0;	/* Overide padding applied by the preceeding rule. */
+	border-left: solid 1px #ccc; 
+	width: 15px;
+	overflow: hidden;
+	text-indent: -1000px;
+    background: url(horizontal-menu-submenu-indicator.png) 3px center no-repeat;	
+	
+}
+
+
+/* Selected menuitem */
+
+.yui-skin-sam .yui-menu-label-active,
+.yui-skin-sam .yui-menu-label-menuvisible,
+.yui-skin-sam .yui-menu .yui-menu .yui-menu-label-active,
+.yui-skin-sam .yui-menu .yui-menu .yui-menu-label-menuvisible {
+
+	background-color: #B3D4FF;
+
+}
+
+.yui-skin-sam .yui-menuitem-active .yui-menuitem-content,
+.yui-skin-sam .yui-menu .yui-menu .yui-menuitem-active .yui-menuitem-content {
+
+	background-image: none;
+    background-color: #B3D4FF;
+    
+    /*
+    	Undo values set for "border-left-width" and "margin-left" when the root menu has a class of
+    	"yui-menubuttonnav" or "yui-splitbuttonnav" applied.
+    */
+
+	border-left-width: 0;
+    margin-left: 0;
+
+}
+
+.yui-skin-sam .yui-menu-horizontal .yui-menu-label-active,
+.yui-skin-sam .yui-menu-horizontal .yui-menuitem-active .yui-menuitem-content,
+.yui-skin-sam .yui-menu-horizontal .yui-menu-label-menuvisible {
+
+    border-color: #7D98B8;
+    background: url(../../../../assets/skins/sam/sprite.png) repeat-x 0 -1700px;
+
+}
+
+.yui-skin-sam .yui-menubuttonnav .yui-menu-label-active,
+.yui-skin-sam .yui-menubuttonnav .yui-menuitem-active .yui-menuitem-content,
+.yui-skin-sam .yui-menubuttonnav .yui-menu-label-menuvisible,
+.yui-skin-sam .yui-splitbuttonnav .yui-menu-label-active,
+.yui-skin-sam .yui-splitbuttonnav .yui-menuitem-active .yui-menuitem-content,
+.yui-skin-sam .yui-splitbuttonnav .yui-menu-label-menuvisible {
+
+    border-left-width: 1px;
+    margin-left: -1px;
+
+}
+
+.yui-skin-sam .yui-splitbuttonnav .yui-menu-label-menuvisible {
+
+    border-color: #808080;
+    background: transparent;
+
+}
+
+.yui-skin-sam .yui-splitbuttonnav .yui-menu-label-menuvisible .yui-menu-toggle {
+
+    border-color: #7D98B8;
+    background: url(horizontal-menu-submenu-toggle.png) left center no-repeat;
+
+}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/node-menunav.css'
--- loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/node-menunav.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/node-menunav.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-menu .yui-menu{position:absolute;z-index:1;}.yui-menu .yui-shim{position:absolute;top:0;left:0;z-index:-1;opacity:0;filter:alpha(opacity=0);border:none;margin:0;padding:0;height:100%;width:100%;}.yui-menu-hidden{top:-10000px;left:-10000px;visibility:hidden;}.yui-menu li{list-style-type:none;}.yui-menu ul,.yui-menu li{margin:0;padding:0;}.yui-menu-label,.yui-menuitem-content{text-align:left;white-space:nowrap;display:block;}.yui-menu-horizontal li{float:left;width:auto;}.yui-menu-horizontal li li{float:none;}.yui-menu-horizontal ul{*zoom:1;}.yui-menu-horizontal ul ul{*zoom:normal;}.yui-menu-horizontal>.yui-menu-content>ul:after{content:"";display:block;clear:both;line-height:0;font-size:0;visibility:hidden;}.yui-menu-content{*zoom:1;}.yui-menu-hidden .yui-menu-content{*zoom:normal;}.yui-menuitem-content,.yui-menu-label{_zoom:1;}.yui-menu-hiden .yui-menuitem-content,.yui-menu-hiden .yui-menu-label{_zoom:normal;}.yui-skin-sam .yui-menu-content,.yui-skin-sam .yui-menu .yui-menu .yui-menu-content{font-size:93%;line-height:1.5;*line-height:1.45;border:solid 1px #808080;background:#fff;padding:3px 0;}.yui-skin-sam .yui-menu .yui-menu .yui-menu-content{font-size:100%;}.yui-skin-sam .yui-menu-horizontal .yui-menu-content{line-height:2;*line-height:1.9;background:url(../../../../assets/skins/sam/sprite.png) repeat-x 0 0;padding:0;}.yui-skin-sam .yui-menu ul,.yui-skin-sam .yui-menu ul ul{margin-top:3px;padding-top:3px;border-top:solid 1px #ccc;}.yui-skin-sam .yui-menu ul.first-of-type{border:0;margin:0;padding:0;}.yui-skin-sam .yui-menu-horizontal ul{padding:0;margin:0;border:0;}.yui-skin-sam .yui-menu li,.yui-skin-sam .yui-menu .yui-menu li{_border-bottom:solid 1px #fff;}.yui-skin-sam .yui-menu-horizontal li{_border-bottom:0;}.yui-skin-sam .yui-menubuttonnav li{border-right:solid 1px #ccc;}.yui-skin-sam .yui-splitbuttonnav li{border-right:solid 1px #808080;}.yui-skin-sam .yui-menubuttonnav li li,.yui-skin-sam .yui-splitbuttonnav li li{border-right:0;}.yui-skin-sam .yui-menu-label,.yui-skin-sam .yui-menu .yui-menu .yui-menu-label,.yui-skin-sam .yui-menuitem-content,.yui-skin-sam .yui-menu .yui-menu .yui-menuitem-content{padding:0 20px;color:#000;text-decoration:none;cursor:default;float:none;border:0;margin:0;}.yui-skin-sam .yui-menu-horizontal .yui-menu-label,.yui-skin-sam .yui-menu-horizontal .yui-menuitem-content{padding:0 10px;border-style:solid;border-color:#808080;border-width:1px 0;margin:-1px 0;float:left;width:auto;}.yui-skin-sam .yui-menu-label,.yui-skin-sam .yui-menu .yui-menu .yui-menu-label{background:url(vertical-menu-submenu-indicator.png) right center no-repeat;}.yui-skin-sam .yui-menu-horizontal .yui-menu-label{background:url(../../../../assets/skins/sam/sprite.png) repeat-x 0 0;}.yui-skin-sam .yui-menubuttonnav .yui-menu-label,.yui-skin-sam .yui-splitbuttonnav .yui-menu-label{background-image:none;}.yui-skin-sam .yui-menubuttonnav .yui-menu-label{padding-right:0;}.yui-skin-sam .yui-menubuttonnav .yui-menu-label em{font-style:normal;padding-right:20px;display:block;background:url(horizontal-menu-submenu-indicator.png) right center no-repeat;}.yui-skin-sam .yui-splitbuttonnav .yui-menu-label{padding:0;}.yui-skin-sam .yui-splitbuttonnav .yui-menu-label a{float:left;width:auto;color:#000;text-decoration:none;cursor:default;padding:0 5px 0 10px;}.yui-skin-sam .yui-splitbuttonnav .yui-menu-label .yui-menu-toggle{padding:0;border-left:solid 1px #ccc;width:15px;overflow:hidden;text-indent:-1000px;background:url(horizontal-menu-submenu-indicator.png) 3px center no-repeat;}.yui-skin-sam .yui-menu-label-active,.yui-skin-sam .yui-menu-label-menuvisible,.yui-skin-sam .yui-menu .yui-menu .yui-menu-label-active,.yui-skin-sam .yui-menu .yui-menu .yui-menu-label-menuvisible{background-color:#B3D4FF;}.yui-skin-sam .yui-menuitem-active .yui-menuitem-content,.yui-skin-sam .yui-menu .yui-menu .yui-menuitem-active .yui-menuitem-content{background-image:none;background-color:#B3D4FF;border-left-width:0;margin-left:0;}.yui-skin-sam .yui-menu-horizontal .yui-menu-label-active,.yui-skin-sam .yui-menu-horizontal .yui-menuitem-active .yui-menuitem-content,.yui-skin-sam .yui-menu-horizontal .yui-menu-label-menuvisible{border-color:#7D98B8;background:url(../../../../assets/skins/sam/sprite.png) repeat-x 0 -1700px;}.yui-skin-sam .yui-menubuttonnav .yui-menu-label-active,.yui-skin-sam .yui-menubuttonnav .yui-menuitem-active .yui-menuitem-content,.yui-skin-sam .yui-menubuttonnav .yui-menu-label-menuvisible,.yui-skin-sam .yui-splitbuttonnav .yui-menu-label-active,.yui-skin-sam .yui-splitbuttonnav .yui-menuitem-active .yui-menuitem-content,.yui-skin-sam .yui-splitbuttonnav .yui-menu-label-menuvisible{border-left-width:1px;margin-left:-1px;}.yui-skin-sam .yui-splitbuttonnav .yui-menu-label-menuvisible{border-color:#808080;background:transparent;}.yui-skin-sam .yui-splitbuttonnav .yui-menu-label-menuvisible .yui-menu-toggle{border-color:#7D98B8;background:url(horizontal-menu-submenu-toggle.png) left center no-repeat;}

=== added file 'loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/vertical-menu-submenu-indicator.png'
Binary files loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/vertical-menu-submenu-indicator.png and loggerhead/static/javascript/yui/build/node-menunav/assets/skins/sam/vertical-menu-submenu-indicator.png differ
=== added file 'loggerhead/static/javascript/yui/build/node-menunav/node-menunav-debug.js'
--- loggerhead/static/javascript/yui/build/node-menunav/node-menunav-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node-menunav/node-menunav-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,2078 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node-menunav', function(Y) {
+
+/**
+* <p>The MenuNav Node Plugin makes it easy to transform existing list-based markup into traditional, 
+* drop down navigational menus that are both accessible and easy to customize, and only require 
+* a small set of dependencies.</p>
+* <p>To use the MenuNav Node Plugin, simply pass a reference to the plugin to a Node instance's 
+* <code>plug</code> method.</p>
+* 
+* <p>
+* <code>
+* &#60;script type="text/javascript"&#62;<br>
+* <br>
+* 		//	Call the "use" method, passing in "node-menunav".  This will load the <br>
+* 		//	script and CSS for the MenuNav Node Plugin and all of the required <br>
+* 		//	dependencies.<br>
+* <br>
+* 		YUI().use("node-menunav", function(Y) {<br>
+* <br>
+* 			//	Use the "contentready" event to initialize the menu when the subtree of <br>
+* 			//	element representing the root menu (&#60;div id="menu-1"&#62;) is ready to <br>
+* 			//	be scripted.<br>
+* <br>
+* 			Y.on("contentready", function () {<br>
+* <br>
+* 				//	The scope of the callback will be a Node instance representing <br>
+* 				//	the root menu (&#60;div id="menu-1"&#62;).  Therefore, since "this"<br>
+* 				//	represents a Node instance, it is possible to just call "this.plug"<br>
+* 				//	passing in a reference to the MenuNav Node Plugin.<br>
+* <br>
+* 				this.plug(Y.plugin.NodeMenuNav);<br>
+* <br>
+* 			}, "#menu-1");<br>
+* <br>		
+* 		}); <br>
+* <br>	
+* 	&#60;/script&#62;<br>
+* </code>
+* </p>
+*
+* <p>The MenuNav Node Plugin has several configuration properties that can be set via an 
+* object literal that is passed as a second argument to a Node instance's <code>plug</code> method.
+* </p>
+*
+* <p>
+* <code>
+* &#60;script type="text/javascript"&#62;<br>
+* <br>
+* 		//	Call the "use" method, passing in "node-menunav".  This will load the <br>
+* 		//	script and CSS for the MenuNav Node Plugin and all of the required <br>
+* 		//	dependencies.<br>
+* <br>
+* 		YUI().use("node-menunav", function(Y) {<br>
+* <br>
+* 			//	Use the "contentready" event to initialize the menu when the subtree of <br>
+* 			//	element representing the root menu (&#60;div id="menu-1"&#62;) is ready to <br>
+* 			//	be scripted.<br>
+* <br>
+* 			Y.on("contentready", function () {<br>
+* <br>
+* 				//	The scope of the callback will be a Node instance representing <br>
+* 				//	the root menu (&#60;div id="menu-1"&#62;).  Therefore, since "this"<br>
+* 				//	represents a Node instance, it is possible to just call "this.plug"<br>
+* 				//	passing in a reference to the MenuNav Node Plugin.<br>
+* <br>
+* 				this.plug(Y.plugin.NodeMenuNav, { mouseOutHideDelay: 1000 });<br>
+* <br>
+* 			}, "#menu-1");<br>
+* <br>		
+* 		}); <br>
+* <br>	
+* 	&#60;/script&#62;<br>
+* </code>
+* </p>
+* 
+* <p> The complete list of the MenuNav Node Plugin configuration properties are:</p>
+* <dl>
+* 	<dt>useARIA</dt>
+* 		<dd>Boolean indicating if use of the WAI-ARIA Roles and States should be enabled for the 
+* 		MenuNav.  Set to true by default for Firefox 3 and Internet Explorer 8 as currently only 
+* 		these browsers have support for ARIA, and are supported by several screen readers for 
+* 		Windows that also offer support for ARIA.</dd>
+* 
+* 	<dt>autoSubmenuDisplay</dt>
+* 		<dd>Boolean indicating if submenus are automatically made visible when the user mouses over 
+* 		the menu's items.  Set to true by default.</dd>
+* 
+* 	<dt>submenuShowDelay</dt>
+* 		<dd>Number indicating the time (in milliseconds) that should expire before a submenu is 
+* 		made visible when the user mouses over the menu's label.  Set to 250 by default.</dd>
+* 
+* 	<dt>submenuHideDelay</dt>
+* 		<dd>Number indicating the time (in milliseconds) that should expire before a submenu is 
+* 		hidden when the user mouses out of a menu label heading in the direction of a submenu.  
+* 		Set to 250 by default.</dd>
+* 
+* 	<dt>mouseOutHideDelay</dt>
+* 		<dd>Number indicating the time (in milliseconds) that should expire before a submenu is 
+* 		hidden when the user mouses out of it.  Set to 750 by default.</dd>
+* </dl>
+* 
+* @module node-menunav
+*/
+
+	//	Util shortcuts
+
+var UA = Y.UA,
+	Lang = Y.Lang,
+	later = Y.later,
+	getClassName = Y.ClassNameManager.getClassName,
+
+
+	//	Native types
+
+	TRUE = true,
+	FALSE = false,
+	NULL = null,
+
+
+
+	//	Frequently used strings
+
+	MENU = "menu",
+	MENUITEM = "menuitem",
+	HIDDEN = "hidden",
+	TAB_INDEX = "tabIndex",		
+	PARENT_NODE = "parentNode",
+	CHILDREN = "children",
+	OFFSET_HEIGHT = "offsetHeight",
+	OFFSET_WIDTH = "offsetWidth",
+	PX = "px",
+	ID = "id",
+	PERIOD = ".",
+	HANDLED_MOUSEOUT = "handledMouseOut",
+	HANDLED_MOUSEOVER = "handledMouseOver",
+	ACTIVE = "active",
+	LABEL = "label",
+	LOWERCASE_A = "a",
+	MOUSEDOWN = "mousedown",
+	KEYDOWN = "keydown",
+	CLICK = "click",
+	EMPTY_STRING = "",
+	FIRST_OF_TYPE = "first-of-type",
+
+
+	//	CSS class names
+
+	CSS_MENU = getClassName(MENU),
+	CSS_MENU_HIDDEN = getClassName(MENU, HIDDEN),
+	CSS_MENU_HORIZONTAL = getClassName(MENU, "horizontal"),
+	CSS_MENU_LABEL = getClassName(MENU, LABEL),
+	CSS_MENU_LABEL_ACTIVE = getClassName(MENU, LABEL, ACTIVE),
+	CSS_MENU_LABEL_MENUVISIBLE = getClassName(MENU, LABEL, (MENU + "visible")),
+	CSS_MENUITEM = getClassName(MENUITEM),
+	CSS_MENUITEM_ACTIVE = getClassName(MENUITEM, ACTIVE),
+
+
+	//	CSS selectors
+	
+	MENU_SELECTOR = PERIOD + CSS_MENU;
+
+
+//	Utility functions
+
+
+//	TO DO: Remove once Node implements circular functionality
+var getPreviousSibling = function (node) {
+
+	var oPrevious = node.previous(),
+		oParentNode,
+		oChildren,
+		oULs,
+		oUL;
+	
+
+	if (!oPrevious) {
+	
+		oParentNode = node.get(PARENT_NODE);
+		oULs = oParentNode.get(PARENT_NODE).get(CHILDREN);
+
+		if (oULs.size() > 1) {
+			
+			oUL = oParentNode.previous();
+			
+			if (oUL) {
+				oChildren = oUL.get(CHILDREN);
+			}
+			else {
+				oChildren = oULs.item(oULs.size() - 1).get(CHILDREN);
+			}
+			
+		}
+		else {
+			oChildren = oParentNode.get(CHILDREN);
+		}
+
+		oPrevious = oChildren.item(oChildren.size() - 1);
+		
+	}
+	
+	return oPrevious;
+
+};
+
+
+//	TO DO: Remove once Node implements circular functionality
+var getNextSibling = function (node) {
+
+	var oNext = node.next(),
+		oParentNode,
+		oChildren,
+		oULs,
+		oUL;
+	
+
+	if (!oNext) {
+
+		oParentNode = node.get(PARENT_NODE);
+		oULs = oParentNode.get(PARENT_NODE).get(CHILDREN);
+
+		if (oULs.size() > 1) {
+			
+			oUL = oParentNode.next();
+			
+			if (oUL) {
+				oChildren = oUL.get(CHILDREN);
+			}
+			else {
+				oChildren = oULs.item(0).get(CHILDREN);
+			}
+			
+		}		
+		else {
+			oChildren = node.get(PARENT_NODE).get(CHILDREN);
+		}
+
+		oNext = oChildren.item(0);		
+
+	}
+	
+	return oNext;
+
+};
+
+
+var setARIARole = function (node, role) {
+
+	node.setAttribute("role", role);
+
+};
+
+
+var setARIAProperty = function (node, property, value) {
+
+	node.setAttribute(("aria-" + property), value);
+
+};
+
+
+var setARIAPresentation = function (node) {
+
+	setARIARole(node, "presentation");
+
+};
+
+
+var removeFromTabIndex = function (node) {
+
+	node.set(TAB_INDEX, -1);
+
+};
+
+
+var placeInDefaultTabIndex = function (node) {
+
+	node.set(TAB_INDEX, 0);
+
+};
+
+
+var isAnchor = function (node) {
+	
+	var bReturnVal = FALSE;
+	
+	if (node) {
+		bReturnVal = node.get("nodeName").toLowerCase() === LOWERCASE_A;
+	}
+	
+	return bReturnVal;
+	
+};
+
+
+var isMenuItem = function (node) {
+
+	return node.hasClass(CSS_MENUITEM);
+
+};
+
+
+var isMenuLabel = function (node) {
+
+	return node.hasClass(CSS_MENU_LABEL);
+
+};
+
+
+var isHorizontalMenu = function (menu) {
+
+	return menu.hasClass(CSS_MENU_HORIZONTAL);
+
+};
+
+
+var hasVisibleSubmenu = function (menuLabel) {
+
+	return menuLabel.hasClass(CSS_MENU_LABEL_MENUVISIBLE);
+
+};
+
+
+var getItemAnchor = function (node) {
+
+	return isAnchor(node) ? node : node.query(LOWERCASE_A);
+
+};
+
+
+var getNodeWithClass = function (node, className, searchAncestors) {
+
+	var oItem;
+	
+	if (node) {
+		
+		if (node.hasClass(className)) {
+			oItem = node;
+		}
+		
+		if (!oItem && searchAncestors) {
+			oItem = node.ancestor((PERIOD + className));
+		}
+	
+	}
+	
+	return oItem;
+
+};
+
+
+var getParentMenu = function (node) {
+
+	return node.ancestor(MENU_SELECTOR);
+	
+};
+
+
+var getMenu = function (node, searchAncestors) {
+
+	return getNodeWithClass(node, CSS_MENU, searchAncestors);
+
+};
+
+
+var getMenuItem = function (node, searchAncestors) {
+
+	var oItem;
+	
+	if (node) {
+		oItem = getNodeWithClass(node, CSS_MENUITEM, searchAncestors);
+	}
+	
+	return oItem;
+
+};
+
+
+var getMenuLabel = function (node, searchAncestors) {
+
+	var oItem;
+	
+	if (node) {
+	
+		if (searchAncestors) {
+			oItem = getNodeWithClass(node, CSS_MENU_LABEL, searchAncestors);
+		}
+		else {
+			oItem = getNodeWithClass(node, CSS_MENU_LABEL) || node.query((PERIOD + CSS_MENU_LABEL));
+		}
+		
+	}
+	
+	return oItem;
+
+};
+
+
+var getItem = function (node, searchAncestors) {
+
+	var oItem;
+	
+	if (node) {
+		oItem = getMenuItem(node, searchAncestors) || getMenuLabel(node, searchAncestors);
+	}
+	
+	return oItem;	
+
+};
+
+
+var getNextItem = function (item, previous) {
+
+	var oItemLI,
+		oNextLI,
+		oNextItem;
+	
+
+	if (item) {
+
+		oItemLI = isMenuItem(item) ? item : item.get(PARENT_NODE);
+
+		oNextLI = previous ? getPreviousSibling(oItemLI) : getNextSibling(oItemLI);
+
+		oNextItem = getItem(oNextLI);
+	
+	}
+	
+	return oNextItem;
+	
+};
+
+
+var getPreviousItem = function (item) {
+
+	return getNextItem(item, true);
+
+};
+
+
+var getFirstItem = function (menu) {
+	
+	return getItem(menu.query("li"));
+
+};
+
+
+var getActiveClass = function (node) {
+
+	return isMenuItem(node) ? CSS_MENUITEM_ACTIVE : CSS_MENU_LABEL_ACTIVE;
+
+};
+
+
+var blurItem = function (item) {
+
+	var oAnchor;
+
+	if (item) {
+
+		oAnchor = getItemAnchor(item);
+
+		//	TO DO:  Remove once implemented in Node
+		try {
+			oAnchor.blur();
+		}
+		catch (ex) { }
+
+	}
+
+};
+	
+
+var focusItem = function (item) {
+
+	var oAnchor;
+
+	if (item) {
+
+		oAnchor = getItemAnchor(item);
+	
+		//	TO DO:  Remove once implemented in Node
+		try {
+			oAnchor.focus();
+		}
+		catch (ex) { }
+	
+	}
+
+};
+
+
+var handleMouseOverForNode = function (node, target) {
+
+	return node && !node[HANDLED_MOUSEOVER] && (node === target || node.contains(target));
+
+};
+
+
+var handleMouseOutForNode = function (node, relatedTarget) {
+
+	return node && !node[HANDLED_MOUSEOUT] && 
+		(node !== relatedTarget && !node.contains(relatedTarget));
+
+};
+
+
+/**
+* The NodeMenuNav class is a plugin for a Node instance.  The class is used via the 
+* <a href="Node.html#method_plug"><code>plug</code></a> method of Node and should not be 
+* instantiated directly.
+* @namespace plugin
+* @class NodeMenuNav
+*/
+var MenuNav = function (config) {
+
+	var menuNav = this,
+		oRootMenu = config.owner,
+		oDocument,
+		bUseARIA,
+		bAutoSubmenuDisplay,
+		nMouseOutHideDelay,
+		oMenuNodes,
+		oFirstItem,
+		oULs;
+		
+
+	if (oRootMenu) {
+
+		bUseARIA = config.useARIA;
+		bAutoSubmenuDisplay = config.autoSubmenuDisplay;
+		nMouseOutHideDelay = config.mouseOutHideDelay;
+		
+
+		//	Enable ARIA for Firefox 3 and IE 8 by default since those are the two browsers 
+		//	that current support ARIA
+
+		menuNav._useARIA = Lang.isBoolean(bUseARIA) ? 
+						bUseARIA : ((UA.gecko && UA.gecko >= 1.9) || (UA.ie && UA.ie >= 8));
+
+
+		menuNav._autoSubmenuDisplay = 
+					Lang.isBoolean(bAutoSubmenuDisplay) ? bAutoSubmenuDisplay : TRUE;
+
+		menuNav._submenuShowDelay = config.submenuShowDelay || 250;
+		menuNav._submenuHideDelay = config.submenuHideDelay || 250;
+
+		menuNav._mouseOutHideDelay = Lang.isNumber(nMouseOutHideDelay) ? nMouseOutHideDelay : 750;
+
+
+		//	Hide all visible submenus
+
+		oMenuNodes = oRootMenu.queryAll(MENU_SELECTOR);
+
+		if (oMenuNodes) {
+			oMenuNodes.addClass(CSS_MENU_HIDDEN);
+		}
+
+
+		oULs = oRootMenu.queryAll("ul:" + FIRST_OF_TYPE);
+
+		if (oULs) {
+			oULs.addClass(FIRST_OF_TYPE);
+		}
+
+
+		//	Wire up all event handlers
+
+
+		oRootMenu.on("mouseover", menuNav._onMouseOver, menuNav);
+		oRootMenu.on("mouseout", menuNav._onMouseOut, menuNav);
+		oRootMenu.on("mousemove", menuNav._onMouseMove, menuNav);
+		oRootMenu.on(MOUSEDOWN, menuNav._toggleSubmenuDisplay, menuNav);
+		oRootMenu.on(KEYDOWN, menuNav._toggleSubmenuDisplay, menuNav);
+		oRootMenu.on(CLICK, menuNav._toggleSubmenuDisplay, menuNav);
+		oRootMenu.on("keypress", menuNav._onKeyPress, menuNav);
+		oRootMenu.on(KEYDOWN, menuNav._onKeyDown, menuNav);
+
+		oDocument = oRootMenu.get("ownerDocument");
+
+		oDocument.on(MOUSEDOWN, menuNav._onDocMouseDown, menuNav);
+
+		Y.on("focus", Y.bind(menuNav._onDocFocus, menuNav), oDocument);
+
+		menuNav._rootMenu = oRootMenu;
+
+
+		if (menuNav._useARIA) {
+
+			menuNav._applyARIA(oRootMenu);
+
+			oFirstItem = getFirstItem(oRootMenu);
+	
+			if (oFirstItem) {
+	
+				placeInDefaultTabIndex(getItemAnchor(oFirstItem));
+	
+				menuNav._firstItem = oFirstItem;
+	
+			}		
+		
+		}
+
+	}
+
+};
+
+
+MenuNav.NS = "MenuNav";
+
+
+/** 
+* @property NodeMenuNav.SHIM_TEMPLATE_TITLE
+* @description String representing the value for the <code>title</code> attribute for the shim used
+* to prevent <code>&#60;select&#62;</code> elements from poking through menus in IE 6.
+* @default "Menu Stacking Shim"
+* @type String
+*/
+MenuNav.SHIM_TEMPLATE_TITLE = "Menu Stacking Shim";
+
+
+/** 
+* @property NodeMenuNav.SHIM_TEMPLATE
+* @description String representing the HTML used to create the <code>&#60;iframe&#62;</code> shim 
+* used to prevent <code>&#60;select&#62;</code> elements from poking through menus in IE 6.
+* @default &#34;&#60;iframe frameborder=&#34;0&#34; tabindex=&#34;-1&#34; 
+* class=&#34;yui-shim&#34; title=&#34;Menu Stacking Shim&#34; 
+* src=&#34;javascript:false;&#34;&#62;&#60;/iframe&#62;&#34;
+* @type String
+*/
+
+//	<iframe> shim notes:
+//
+//	1) Need to set the "frameBorder" property to 0 to suppress the default <iframe> border in IE.  
+//	(Setting the CSS "border" property alone doesn't suppress it.)  
+//
+//	2) The "src" attribute of the <iframe> is set to "javascript:false;" so that it won't load a 
+//	page inside it, preventing the secure/nonsecure warning in IE when using HTTPS.
+//
+//	3) Since the role of the <iframe> shim is completely presentational, its "tabindex" attribute
+//	is set to "-1" and its title attribute is set to "Menu Stacking Shim".  Both strategies help
+//	users of screen readers to avoid mistakenly interacting with the <iframe> shim.
+
+MenuNav.SHIM_TEMPLATE	=	'<iframe frameborder="0" tabindex="-1" class="' + 
+							getClassName("shim") + 
+							'" title="' + MenuNav.SHIM_TEMPLATE_TITLE + 
+							'" src="javascript:false;"></iframe>';
+
+
+MenuNav.prototype = {
+
+	//	Protected properties
+
+	/** 
+	* @property _rootMenu
+	* @description Node instance representing the root menu in the MenuNav.
+	* @default null
+	* @protected
+	* @type Node
+	*/
+	_rootMenu: NULL,	
+
+
+	/** 
+	* @property _activeItem
+	* @description Node instance representing the MenuNav's active descendent - the menuitem or 
+	* menu label the user is currently interacting with.
+	* @default null
+	* @protected
+	* @type Node
+	*/
+	_activeItem: NULL, 
+
+
+	/** 
+	* @property _activeMenu
+	* @description Node instance representing the menu that is the parent of the MenuNav's 
+	* active descendent.
+	* @default null
+	* @protected
+	* @type Node
+	*/
+	_activeMenu: NULL,
+
+
+	/** 
+	* @property _hasFocus
+	* @description Boolean indicating if the MenuNav has focus.
+	* @default false
+	* @protected
+	* @type Boolean
+	*/
+	_hasFocus: FALSE,
+
+
+	//	In gecko-based browsers a mouseover and mouseout event will fire even 
+	//	if a DOM element moves out from under the mouse without the user actually
+	//	moving the mouse.  This bug affects MenuNav because the user can hit the 
+	//	Esc key to hide a menu, and if the mouse is over the menu when the 
+	//	user presses Esc, the _onMenuMouseOut handler will be called.  To fix this 
+	//	bug the following flag (_blockMouseEvent) is used to block the code in the 
+	//	_onMenuMouseOut handler from executing.
+
+	/** 
+	* @property _blockMouseEvent
+	* @description Boolean indicating whether or not to handle the "mouseover" event.
+	* @default false
+	* @protected
+	* @type Boolean
+	*/
+	_blockMouseEvent: FALSE,
+
+
+	/** 
+	* @property _currentMouseX
+	* @description Number representing the current x coordinate of the mouse inside the MenuNav.
+	* @default 0
+	* @protected
+	* @type Number
+	*/
+	_currentMouseX: 0,
+
+
+	/** 
+	* @property _movingToSubmenu
+	* @description Boolean indicating if the mouse is moving from a menu label to its 
+	* corresponding submenu.
+	* @default false
+	* @protected
+	* @type Boolean
+	*/
+	_movingToSubmenu: FALSE,
+
+
+	/** 
+	* @property _showSubmenuTimer
+	* @description Timer used to show a submenu.
+	* @default null
+	* @protected
+	* @type Object
+	*/
+	_showSubmenuTimer: NULL,
+
+
+	/** 
+	* @property _hideSubmenuTimer
+	* @description Timer used to hide a submenu.
+	* @default null
+	* @protected
+	* @type Object
+	*/
+	_hideSubmenuTimer: NULL,
+
+
+	/** 
+	* @property _hideAllSubmenusTimer
+	* @description Timer used to hide a all submenus.
+	* @default null
+	* @protected
+	* @type Object
+	*/
+	_hideAllSubmenusTimer: NULL,
+
+
+	/** 
+	* @property _firstItem
+	* @description Node instance representing the first item (menuitem or menu label) in the root 
+	* menu of a MenuNav.
+	* @default null
+	* @protected
+	* @type Node
+	*/
+	_firstItem: NULL,
+
+
+	/** 
+	* @property _autoSubmenuDisplay
+    * @description Boolean indicating if submenus are automatically made visible when the user 
+    * mouses over the menu's items.
+    * @default true
+	* @protected
+    * @type Boolean
+	*/
+	_autoSubmenuDisplay: TRUE,
+
+
+
+	//	Protected methods
+
+	/**
+	* @method _isRoot
+	* @description Returns a boolean indicating if the specified menu is the root menu in 
+	* the MenuNav.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	* @return {Boolean} Boolean indicating if the specified menu is the root menu in the MenuNav.	
+	*/
+	_isRoot: function (menu) {
+
+		return this._rootMenu.compareTo(menu);
+
+	},
+
+
+	/**
+	* @method _getTopmostSubmenu
+	* @description Returns the topmost submenu of a submenu hierarchy.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	* @return {Node} Node instance representing a menu.
+	*/
+	_getTopmostSubmenu: function (menu) {
+	
+		var menuNav = this,
+			oMenu = getParentMenu(menu),
+			returnVal;
+
+
+		if (!oMenu) {
+			returnVal = menu;
+		}
+		else if (menuNav._isRoot(oMenu)) {
+			returnVal = menu;
+		}
+		else {
+			returnVal = menuNav._getTopmostSubmenu(oMenu);
+		}
+	
+		return returnVal;
+	
+	},
+
+
+	/**
+	* @method _clearActiveItem
+	* @description Clears the MenuNav's active descendent.
+	* @protected
+	*/
+	_clearActiveItem: function () {
+
+		var menuNav = this,
+			oActiveItem = menuNav._activeItem;
+		
+		if (oActiveItem) {
+
+			oActiveItem.removeClass(getActiveClass(oActiveItem));
+
+			if (menuNav._useARIA) {
+				removeFromTabIndex(getItemAnchor(oActiveItem));
+			}
+
+		}
+
+		menuNav._activeItem = NULL;
+	
+	},
+
+
+	/**
+	* @method _setActiveItem
+	* @description Sets the specified menuitem or menu label as the MenuNav's active descendent.
+	* @protected
+	* @param {Node} item Node instance representing a menuitem or menu label.
+	*/
+	_setActiveItem: function (item) {
+
+		var menuNav = this;
+	
+		if (item) {
+			
+			menuNav._clearActiveItem();
+	
+			item.addClass(getActiveClass(item));
+	
+			if (menuNav._useARIA) {
+				placeInDefaultTabIndex(getItemAnchor(item));
+			}
+			
+			menuNav._activeItem = item;
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _focusItem
+	* @description Focuses the specified menuitem or menu label.
+	* @protected
+	* @param {Node} item Node instance representing a menuitem or menu label.
+	*/
+	_focusItem: function (item) {
+	
+		if (item && this._hasFocus) {
+		
+			//	Need to focus using a zero-second timeout to get Apple's VoiceOver to 
+			//	recognize that the focused item has changed
+
+			later(0, null, focusItem, item);
+
+		}
+	
+	},
+
+
+	/**
+	* @method _applyARIA
+	* @description Applies the ARIA Roles, States and Properties to the supplied menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	*/
+	_applyARIA: function (menu) {
+
+		var menuNav = this,
+			bIsRoot = menuNav._isRoot(menu),
+			oMenuLabel,
+			oMenuToggle,
+			oListNodes,
+			oMenuItemContentNodes,
+			oMenuLabelNodes,
+			oSubmenu,
+			sID;
+
+
+		setARIARole(menu, (bIsRoot ? "menubar" : MENU));
+
+		if (!bIsRoot) {
+
+			oMenuLabel = menu.previous();
+			oMenuToggle = oMenuLabel.query(PERIOD + getClassName(MENU, "toggle"));
+			
+			if (oMenuToggle) {
+				oMenuLabel = oMenuToggle;
+			}
+			
+			sID = oMenuLabel.get(ID);
+			
+			if (!sID) {
+				sID = Y.guid();
+				oMenuLabel.set(ID, sID);
+			}
+
+			setARIAProperty(menu, "labelledby", sID);
+			setARIAProperty(menu, HIDDEN, TRUE);
+		
+		}
+
+
+		oListNodes = menu.queryAll("ul,li");
+		
+		if (oListNodes) {
+
+			oListNodes.each(function (node) {
+			
+				setARIAPresentation(node);
+			
+			});
+
+		}
+		
+
+		oMenuItemContentNodes = menu.queryAll((PERIOD + getClassName(MENUITEM, "content")));
+
+		if (oMenuItemContentNodes) {
+
+			oMenuItemContentNodes.each(function (node) {
+
+				removeFromTabIndex(node);
+				setARIARole(node, MENUITEM);
+
+			});
+
+		}
+		
+
+		oMenuLabelNodes = menu.queryAll((PERIOD + CSS_MENU_LABEL));
+
+		if (oMenuLabelNodes) {
+
+			oMenuLabelNodes.each(function (node) {
+
+				oMenuLabel = node;
+				oMenuToggle = node.query((PERIOD + getClassName(MENU, "toggle")));
+				
+				if (oMenuToggle) {
+
+					setARIAPresentation(oMenuToggle);
+					removeFromTabIndex(oMenuToggle);
+					
+					oMenuLabel = oMenuToggle.previous();
+				
+				}
+
+				setARIARole(oMenuLabel, MENUITEM);
+				setARIAProperty(oMenuLabel, "haspopup", TRUE);
+				removeFromTabIndex(oMenuLabel);
+				
+				oSubmenu = node.next();
+				
+				if (oSubmenu) {
+					menuNav._applyARIA(oSubmenu);
+				}
+				
+			});
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _showMenu
+	* @description Shows the specified menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	*/
+	_showMenu: function (menu) {
+
+		var menuNav = this,
+			oParentMenu = getParentMenu(menu),
+			oLI = menu.get(PARENT_NODE),
+			aXY = oLI.getXY(),
+			oItem;
+
+		if (menuNav._useARIA) {
+			setARIAProperty(menu, HIDDEN, FALSE);
+		}
+
+		if (isHorizontalMenu(oParentMenu)) {
+			aXY[1] = aXY[1] + oLI.get(OFFSET_HEIGHT);
+		}
+		else {
+			aXY[0] = aXY[0] + oLI.get(OFFSET_WIDTH);
+		}
+		
+		menu.setXY(aXY);
+
+		if (UA.ie < 8) {
+
+			if (UA.ie === 6 && !menu.hasIFrameShim) {
+	
+				menu.appendChild(Y.Node.create(MenuNav.SHIM_TEMPLATE));
+				menu.hasIFrameShim = TRUE;
+
+			}
+
+			//	Clear previous values for height and width
+
+			menu.setStyles({ height: EMPTY_STRING, width: EMPTY_STRING });
+
+			//	Set the width and height of the menu's bounding box - this is necessary for IE 6
+			//	so that the CSS for the <iframe> shim can simply set the <iframe>'s width and height 
+			//	to 100% to ensure that dimensions of an <iframe> shim are always sync'd to the 
+			//	that of its parent menu.  Specifying a width and height also helps when positioning
+			//	decorator elements (for creating effects like rounded corners) inside a menu's 
+			//	bounding box in IE 7.
+			
+			menu.setStyles({ 
+				height: (menu.get(OFFSET_HEIGHT) + PX), 
+				width: (menu.get(OFFSET_WIDTH) + PX) });
+
+		}
+
+		menu.previous().addClass(CSS_MENU_LABEL_MENUVISIBLE);
+		menu.removeClass(CSS_MENU_HIDDEN);
+
+		oItem = getFirstItem(menu);
+
+		menuNav._focusItem(oItem);
+
+	},
+	
+
+	/**
+	* @method _hideMenu 
+	* @description Hides the specified menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	* @param {Boolean} activateAndFocusLabel Boolean indicating if the label for the specified 
+	* menu should be focused and set as active.
+	*/
+	_hideMenu: function (menu, activateAndFocusLabel) {
+
+		var menuNav = this,
+			oLabel = menu.previous(),
+			oActiveItem;
+
+		oLabel.removeClass(CSS_MENU_LABEL_MENUVISIBLE);
+
+
+		if (activateAndFocusLabel) {
+			menuNav._setActiveItem(oLabel);
+			menuNav._focusItem(oLabel);
+		}
+
+		oActiveItem = menu.query((PERIOD + CSS_MENUITEM_ACTIVE));
+
+		if (oActiveItem) {
+			oActiveItem.removeClass(CSS_MENUITEM_ACTIVE);
+		}
+
+		//	Clear the values for top and left that were set by the call to "setXY" when the menu
+		//	was shown so that the hidden position specified in the core CSS file will take affect.
+
+		menu.setStyles({ left: EMPTY_STRING, top: EMPTY_STRING });
+		
+		menu.addClass(CSS_MENU_HIDDEN);
+		setARIAProperty(menu, HIDDEN, TRUE);
+		
+	},
+
+
+	/**
+	* @method _hideAllSubmenus
+	* @description Hides all submenus of the specified menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	*/
+	_hideAllSubmenus: function (menu) {
+
+		var menuNav = this,
+			oSubmenus = menu.queryAll(MENU_SELECTOR);
+
+		if (oSubmenus) {
+
+			oSubmenus.each(Y.bind(function (submenuNode) {
+			
+				menuNav._hideMenu(submenuNode);
+			
+			}, menuNav));
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _cancelShowSubmenuTimer
+	* @description Cancels the timer used to show a submenu.
+	* @protected
+	*/
+	_cancelShowSubmenuTimer: function () {
+
+		var menuNav = this,
+			oShowSubmenuTimer = menuNav._showSubmenuTimer;
+
+		if (oShowSubmenuTimer) {
+			oShowSubmenuTimer.cancel();
+			menuNav._showSubmenuTimer = NULL;
+		}
+	
+	},
+
+
+	/**
+	* @method _cancelHideSubmenuTimer
+	* @description Cancels the timer used to hide a submenu.
+	* @protected
+	*/
+	_cancelHideSubmenuTimer: function () {
+
+		var menuNav = this,
+			oHideSubmenuTimer = menuNav._hideSubmenuTimer;
+
+
+		if (oHideSubmenuTimer) {
+			oHideSubmenuTimer.cancel();
+			menuNav._hideSubmenuTimer = NULL;
+		}
+	
+	},
+
+
+
+	//	Event handlers for discrete pieces of pieces of the menu
+
+
+	/**
+	* @method _onMenuMouseOver
+	* @description "mouseover" event handler for a menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuMouseOver: function (menu, event) {
+
+		var menuNav = this,
+			oHideAllSubmenusTimer = menuNav._hideAllSubmenusTimer;
+
+		if (oHideAllSubmenusTimer) {
+			oHideAllSubmenusTimer.cancel();
+			menuNav._hideAllSubmenusTimer = NULL;
+		}
+
+		menuNav._cancelHideSubmenuTimer();
+
+		menuNav._activeMenu = menu;
+
+
+		if (menuNav._movingToSubmenu && isHorizontalMenu(menu)) {
+			menuNav._movingToSubmenu = FALSE;
+		}
+
+	},
+
+
+	/**
+	* @method _onMenuMouseOut
+	* @description "mouseout" event handler for a menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuMouseOut: function (menu, event) {
+
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			oRelatedTarget = event.relatedTarget,
+			oActiveItem = menuNav._activeItem,
+			oParentMenu,
+			oMenu;
+
+
+		if (oActiveMenu && !oActiveMenu.contains(oRelatedTarget)) {
+		
+			oParentMenu = getParentMenu(oActiveMenu);
+			
+
+			if (oParentMenu && !oParentMenu.contains(oRelatedTarget)) {
+
+				if (menuNav._mouseOutHideDelay > 0) {
+
+					menuNav._cancelShowSubmenuTimer();
+
+					menuNav._hideAllSubmenusTimer = 
+
+							later(menuNav._mouseOutHideDelay, menuNav, function () {
+
+								var	oSubmenu;
+
+								oActiveMenu = menuNav._activeMenu;
+							
+								menuNav._hideAllSubmenus(menuNav._rootMenu);
+						
+								if (oActiveMenu) {
+						
+									//	Focus the label element for the topmost submenu
+									oSubmenu = menuNav._getTopmostSubmenu(oActiveMenu);
+									menuNav._focusItem(oSubmenu.previous());
+						
+								}
+							
+							});
+						
+				}
+			
+			}
+			else {
+			
+				if (oActiveItem) {
+				
+					oMenu = getParentMenu(oActiveItem);
+
+					if (!menuNav._isRoot(oMenu)) { 
+						menuNav._focusItem(oMenu.previous());
+					}
+				
+				}
+			
+			}
+
+		}
+
+	},
+
+
+	/**
+	* @method _onMenuLabelMouseOver
+	* @description "mouseover" event handler for a menu label.
+	* @protected
+	* @param {Node} menuLabel Node instance representing a menu label.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuLabelMouseOver: function (menuLabel, event) {
+
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			bIsRoot = menuNav._isRoot(oActiveMenu),
+			bUseAutoSubmenuDisplay = (menuNav._autoSubmenuDisplay && bIsRoot || !bIsRoot),
+			oSubmenu;
+
+
+		menuNav._setActiveItem(menuLabel);
+		menuNav._focusItem(menuLabel);
+		
+
+		if (bUseAutoSubmenuDisplay && !menuNav._movingToSubmenu) {
+	
+			menuNav._cancelHideSubmenuTimer();
+			menuNav._cancelShowSubmenuTimer();
+
+
+			if (!hasVisibleSubmenu(menuLabel)) {
+
+				oSubmenu = menuLabel.next();
+	
+
+				if (oSubmenu) {
+					
+					menuNav._hideAllSubmenus(oActiveMenu);
+
+					menuNav._showSubmenuTimer = 
+									later(menuNav._submenuShowDelay, menuNav, 
+											menuNav._showMenu, oSubmenu);
+				
+				}
+			
+			}
+		
+		}
+
+	},
+
+
+	/**
+	* @method _onMenuLabelMouseOut
+	* @description "mouseout" event handler for a menu label.
+	* @protected
+	* @param {Node} menuLabel Node instance representing a menu label.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuLabelMouseOut: function (menuLabel, event) {
+
+		var menuNav = this,
+			bIsRoot = menuNav._isRoot(menuNav._activeMenu),
+			bUseAutoSubmenuDisplay = (menuNav._autoSubmenuDisplay && bIsRoot || !bIsRoot),
+			oRelatedTarget = event.relatedTarget,
+			oSubmenu = menuLabel.next();
+
+		menuNav._clearActiveItem();
+
+		if (bUseAutoSubmenuDisplay) {
+
+			if (menuNav._movingToSubmenu && !menuNav._showSubmenuTimer && oSubmenu) {
+
+				//	If the mouse is moving diagonally toward the submenu and another submenu 
+				//	isn't in the process of being displayed (via a timer), then hide the submenu 
+				//	via a timer to give the user some time to reach the submenu.
+			
+				menuNav._hideSubmenuTimer = later(menuNav._submenuHideDelay, menuNav, 
+															menuNav._hideMenu, oSubmenu);
+			
+			}
+			else if (!menuNav._movingToSubmenu && oSubmenu && 
+				!oSubmenu.contains(oRelatedTarget) && oRelatedTarget !== oSubmenu) {
+
+				//	If the mouse is not moving toward the submenu, cancel any submenus that 
+				//	might be in the process of being displayed (via a timer) and hide this 
+				//	submenu immediately.
+
+				menuNav._cancelShowSubmenuTimer();
+
+				menuNav._hideMenu(oSubmenu);
+
+			}
+
+		}
+
+	},
+	
+
+	/**
+	* @method _onMenuItemMouseOver
+	* @description "mouseover" event handler for a menuitem.
+	* @protected
+	* @param {Node} menuItem Node instance representing a menuitem.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuItemMouseOver: function (menuItem, event) {
+
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			bIsRoot = menuNav._isRoot(oActiveMenu),
+			bUseAutoSubmenuDisplay = (menuNav._autoSubmenuDisplay && bIsRoot || !bIsRoot);
+
+
+		menuNav._setActiveItem(menuItem);
+		menuNav._focusItem(menuItem);
+
+
+		if (bUseAutoSubmenuDisplay && !menuNav._movingToSubmenu) {
+
+			menuNav._hideAllSubmenus(oActiveMenu);
+
+		}
+
+	},
+	
+
+	/**
+	* @method _onMenuItemMouseOut
+	* @description "mouseout" event handler for a menuitem.
+	* @protected
+	* @param {Node} menuItem Node instance representing a menuitem.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuItemMouseOut: function (menuItem, event) {
+
+		this._clearActiveItem();
+
+	},
+
+
+	/**
+	* @method _onVerticalMenuKeyDown
+	* @description "keydown" event handler for vertical menus of a MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onVerticalMenuKeyDown: function (event) {
+
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			oRootMenu = menuNav._rootMenu,
+			oTarget = event.target,
+			oFocusedItem = getItem(oTarget, TRUE),
+			bPreventDefault = FALSE,
+			nKeyCode = event.keyCode,
+			oSubmenu,
+			oParentMenu,
+			oLI,
+			oNextItem,
+			oItem;
+
+
+		switch (nKeyCode) {
+
+			case 37:	//	left arrow
+
+				oParentMenu = getParentMenu(oActiveMenu);
+
+				if (oParentMenu && isHorizontalMenu(oParentMenu)) {
+				
+					menuNav._hideMenu(oActiveMenu);
+					oLI = getPreviousSibling(oActiveMenu.get(PARENT_NODE));
+					oItem = getItem(oLI);
+					
+					if (oItem) {
+
+						if (isMenuLabel(oItem)) {	//	Menu label
+						
+							oSubmenu = oItem.next();
+						
+
+							if (oSubmenu) {
+
+								menuNav._showMenu(oSubmenu);
+								menuNav._setActiveItem(getFirstItem(oSubmenu));
+
+							}
+							else {
+	
+								menuNav._setActiveItem(oItem);
+								focusItem(oItem);
+	
+							}
+						
+						}
+						else {	//	MenuItem
+
+							menuNav._setActiveItem(oItem);
+							focusItem(oItem);
+
+						}
+					
+					}
+
+				}
+				else if (!menuNav._isRoot(oActiveMenu)) {
+					menuNav._hideMenu(oActiveMenu, TRUE);
+				}
+
+
+				bPreventDefault = TRUE;
+
+			break;
+
+			case 39:	//	right arrow
+
+				if (isMenuLabel(oTarget)) {
+					
+					oSubmenu = oTarget.next();
+
+					if (oSubmenu) {
+						menuNav._showMenu(oSubmenu);
+						menuNav._setActiveItem(getFirstItem(oSubmenu));
+					}
+				
+				}
+				else if (isHorizontalMenu(oRootMenu)) {
+
+					oSubmenu = menuNav._getTopmostSubmenu(oActiveMenu);
+					oLI = getNextSibling(oSubmenu.get(PARENT_NODE));
+					oItem = getItem(oLI);
+
+					menuNav._hideAllSubmenus(oRootMenu);
+
+					if (oItem) {
+
+						if (isMenuLabel(oItem)) {	//	Menu label
+
+							oSubmenu = oItem.next();
+
+							if (oSubmenu) {
+
+								menuNav._showMenu(oSubmenu);
+								menuNav._setActiveItem(getFirstItem(oSubmenu));
+
+							}
+							else {
+	
+								menuNav._setActiveItem(oItem);
+								focusItem(oItem);
+	
+							}
+						
+						}
+						else {	//	MenuItem
+
+							menuNav._setActiveItem(oItem);
+							focusItem(oItem);
+
+						}							
+
+					}
+				
+				}
+
+				bPreventDefault = TRUE;
+
+			break;
+
+			case 38:	//	up arrow
+			case 40:	//	down arrow
+
+				menuNav._hideAllSubmenus(oActiveMenu);
+
+				oNextItem = nKeyCode === 38 ? 
+								getPreviousItem(oFocusedItem) : getNextItem(oFocusedItem);
+
+				menuNav._setActiveItem(oNextItem);
+				focusItem(oNextItem);
+
+				bPreventDefault = TRUE;
+
+			break;
+
+		}	
+
+
+		if (bPreventDefault) {
+
+			//	Prevent the browser from scrolling the window
+
+			event.preventDefault();			
+
+		}
+	
+	},
+	
+
+	/**
+	* @method _onHorizontalMenuKeyDown
+	* @description "keydown" event handler for horizontal menus of a MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onHorizontalMenuKeyDown: function (event) {
+
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			oTarget = event.target,
+			oFocusedItem = getItem(oTarget, TRUE),
+			bPreventDefault = FALSE,
+			nKeyCode = event.keyCode,
+			oNextItem,
+			oSubmenu;
+
+		switch (nKeyCode) {
+
+			case 37:	//	left arrow
+			case 39:	//	right arrow
+
+				menuNav._hideAllSubmenus(oActiveMenu);
+
+				oNextItem = nKeyCode === 37 ? 
+								getPreviousItem(oFocusedItem) : getNextItem(oFocusedItem);
+
+				menuNav._setActiveItem(oNextItem);
+				focusItem(oNextItem);
+
+				bPreventDefault = TRUE;
+
+			break;
+
+			case 40:	//	down arrow
+
+				menuNav._hideAllSubmenus(oActiveMenu);
+
+				if (isMenuLabel(oFocusedItem)) {
+				
+					oSubmenu = oFocusedItem.next();
+
+					if (oSubmenu) {
+						menuNav._showMenu(oSubmenu);
+						menuNav._setActiveItem(getFirstItem(oSubmenu));
+					}
+
+					bPreventDefault = TRUE;
+				
+				}
+
+			break;
+
+		}		
+
+
+		if (bPreventDefault) {
+
+			//	Prevent the browser from scrolling the window
+
+			event.preventDefault();			
+
+		}
+	
+	},
+
+
+	//	Generic DOM Event handlers
+
+
+	/**
+	* @method _onMouseMove
+	* @description "mousemove" event handler for the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMouseMove: function (event) {
+
+		var menuNav = this;
+
+		//	Using a timer to set the value of the "_currentMouseX" property helps improve the 
+		//	reliability of the calculation used to set the value of the "_movingToSubmenu"
+		//	property - especially in Opera.
+
+		later(10, menuNav, function () {
+
+			menuNav._currentMouseX = event.pageX;
+		
+		});
+	
+	},
+
+
+	/**
+	* @method _onMouseOver
+	* @description "mouseover" event handler for the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMouseOver: function (event) {
+
+		var menuNav = this,
+			oTarget,
+			oMenu,
+			oMenuLabel,
+			oParentMenu,
+			oMenuItem;
+
+
+		if (menuNav._blockMouseEvent) {
+			menuNav._blockMouseEvent = FALSE;
+		}
+		else {
+
+			oTarget = event.target;
+			oMenu = getMenu(oTarget, TRUE);
+			oMenuLabel = getMenuLabel(oTarget, TRUE);
+			oMenuItem = getMenuItem(oTarget, TRUE);
+
+
+			if (handleMouseOverForNode(oMenu, oTarget)) {
+
+				menuNav._onMenuMouseOver(oMenu, event);
+
+				oMenu[HANDLED_MOUSEOVER] = TRUE;
+				oMenu[HANDLED_MOUSEOUT] = FALSE;
+
+				oParentMenu = getParentMenu(oMenu);
+
+				if (oParentMenu) {
+
+					oParentMenu[HANDLED_MOUSEOUT] = TRUE;
+					oParentMenu[HANDLED_MOUSEOVER] = FALSE;
+		
+				}
+			
+			}
+
+			if (handleMouseOverForNode(oMenuLabel, oTarget)) {
+
+				menuNav._onMenuLabelMouseOver(oMenuLabel, event);
+
+				oMenuLabel[HANDLED_MOUSEOVER] = TRUE;
+				oMenuLabel[HANDLED_MOUSEOUT] = FALSE;
+	
+			}
+
+			if (handleMouseOverForNode(oMenuItem, oTarget)) {
+	
+				menuNav._onMenuItemMouseOver(oMenuItem, event);
+
+				oMenuItem[HANDLED_MOUSEOVER] = TRUE;
+				oMenuItem[HANDLED_MOUSEOUT] = FALSE;
+				
+			}
+
+		}
+
+	},
+
+
+	/**
+	* @method _onMouseOut
+	* @description "mouseout" event handler for the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMouseOut: function (event) {
+			
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			bMovingToSubmenu = FALSE,
+			oTarget,
+			oRelatedTarget,
+			oMenu,
+			oMenuLabel,
+			oSubmenu,
+			oMenuItem;
+
+
+		menuNav._movingToSubmenu = (oActiveMenu && !isHorizontalMenu(oActiveMenu) && 
+											((event.pageX - 5) > menuNav._currentMouseX));
+		
+		oTarget = event.target;
+		oRelatedTarget = event.relatedTarget;
+		oMenu = getMenu(oTarget, TRUE);
+		oMenuLabel = getMenuLabel(oTarget, TRUE);
+		oMenuItem = getMenuItem(oTarget, TRUE);
+
+
+		if (handleMouseOutForNode(oMenuLabel, oRelatedTarget)) {
+
+			menuNav._onMenuLabelMouseOut(oMenuLabel, event);
+
+			oMenuLabel[HANDLED_MOUSEOUT] = TRUE;
+			oMenuLabel[HANDLED_MOUSEOVER] = FALSE;
+
+		}
+
+		if (handleMouseOutForNode(oMenuItem, oRelatedTarget)) {
+
+			menuNav._onMenuItemMouseOut(oMenuItem, event);
+
+			oMenuItem[HANDLED_MOUSEOUT] = TRUE;
+			oMenuItem[HANDLED_MOUSEOVER] = FALSE;
+			
+		}
+
+
+		if (oMenuLabel) {
+
+			oSubmenu = oMenuLabel.next();
+
+			if (oSubmenu && (oRelatedTarget === oSubmenu || oSubmenu.contains(oRelatedTarget))) {
+
+				bMovingToSubmenu = TRUE;
+
+			}
+		
+		}
+		
+
+		if (handleMouseOutForNode(oMenu, oRelatedTarget) || bMovingToSubmenu) {
+
+			menuNav._onMenuMouseOut(oMenu, event);				
+
+			oMenu[HANDLED_MOUSEOUT] = TRUE;
+			oMenu[HANDLED_MOUSEOVER] = FALSE;
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _toggleSubmenuDisplay
+	* @description "mousedown," "keydown," and "click" event handler for the MenuNav used to 
+	* toggle the display of a submenu.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_toggleSubmenuDisplay: function (event) {
+
+		var menuNav = this,
+			oTarget = event.target,
+			oMenuLabel = getMenuLabel(oTarget, TRUE),
+			sType = event.type,
+			oAnchor,
+			oSubmenu,
+			sHref,
+			nHashPos,
+			nLen,
+			sId;
+
+
+		if (oMenuLabel) {
+
+			oAnchor = isAnchor(oTarget) ? oTarget : oTarget.ancestor(isAnchor);
+			
+
+			if (oAnchor) {
+
+				//	Need to pass "2" as a second argument to "getAttribute" for IE otherwise IE 
+				//	will return a fully qualified URL for the value of the "href" attribute.
+				//	http://msdn.microsoft.com/en-us/library/ms536429(VS.85).aspx
+
+				sHref = oAnchor.getAttribute("href", 2);
+				nHashPos = sHref.indexOf("#");
+				nLen = sHref.length;
+
+				if (nHashPos === 0 && nLen > 1) {
+
+					sId = sHref.substr(1, nLen);
+					oSubmenu = oMenuLabel.next();
+
+					if (oSubmenu && (oSubmenu.get(ID) === sId)) {
+
+
+						if (sType === MOUSEDOWN || (sType === KEYDOWN && event.keyCode === 13)) {
+
+							//	The call to "preventDefault" below results in the element 
+							//	serving as the menu's label to not receive focus in Webkit, 
+							//	therefore the "_hasFocus" flag never gets set to true, meaning the 
+							//	first item in the submenu isn't focused when the submenu is 
+							//	displayed.  To fix this issue, it is necessary to set the 
+							//	"_hasFocus" flag to true.
+	
+							if (UA.webkit && !menuNav._hasFocus) {
+								menuNav._hasFocus = TRUE;
+							}
+
+
+							if (hasVisibleSubmenu(oMenuLabel)) {
+								menuNav._hideMenu(oSubmenu);
+								focusItem(oMenuLabel);
+							}
+							else {
+								menuNav._hideAllSubmenus(menuNav._rootMenu);
+								menuNav._showMenu(oSubmenu);
+							}
+						
+						}
+
+
+						if (sType === CLICK) {
+
+							//	Prevent the browser from following the URL of the anchor element
+							
+							event.preventDefault();
+						
+						}
+					
+					}
+				
+				}				
+
+
+			}
+		
+		}
+	
+	},
+	
+
+	/**
+	* @method _onKeyPress
+	* @description "keypress" event handler for the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onKeyPress: function (event) {
+	
+		switch (event.keyCode) {
+
+			case 37:	//	left arrow
+			case 38:	//	up arrow
+			case 39:	//	right arrow
+			case 40:	//	down arrow
+
+				//	Prevent the browser from scrolling the window
+
+				event.preventDefault();
+
+			break;
+
+		}						
+
+	},	
+
+
+	/**
+	* @method _onKeyDown
+	* @description "keydown" event handler for the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onKeyDown: function (event) {
+
+		var menuNav = this,
+			oActiveItem = menuNav._activeItem,
+			oTarget = event.target,
+			oActiveMenu = getParentMenu(oTarget),
+			oSubmenu;
+
+		if (oActiveMenu) {
+
+			menuNav._activeMenu = oActiveMenu;
+
+			if (isHorizontalMenu(oActiveMenu)) {
+				menuNav._onHorizontalMenuKeyDown(event);
+			}
+			else {
+				menuNav._onVerticalMenuKeyDown(event);
+			}
+
+
+			if (event.keyCode === 27) {
+
+				if (!menuNav._isRoot(oActiveMenu)) {
+
+					menuNav._hideMenu(oActiveMenu, TRUE);
+					event.stopPropagation();
+					menuNav._blockMouseEvent = UA.gecko ? TRUE : FALSE;
+
+				}
+				else if (oActiveItem) {
+
+					if (isMenuLabel(oActiveItem) && hasVisibleSubmenu(oActiveItem)) {
+					
+						oSubmenu = oActiveItem.next();
+
+						if (oSubmenu) {
+							menuNav._hideMenu(oSubmenu);
+						}
+
+					}
+					else {
+
+						blurItem(oTarget);
+						menuNav._clearActiveItem();
+					
+					}
+
+				}
+			
+			}
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _onDocMouseDown
+	* @description "mousedown" event handler for the owner document of the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onDocMouseDown: function (event) {
+	
+		var menuNav = this,
+			oRoot = menuNav._rootMenu,
+			oTarget = event.target;
+
+
+		if (!oRoot.compareTo(oTarget) && !oRoot.contains(oTarget)) {
+		
+			menuNav._hideAllSubmenus(oRoot);
+
+
+			//	Document doesn't receive focus in Webkit when the user mouses down on it, 
+			//	so the "_hasFocus" property won't get set to the correct value.  The 
+			//	following line corrects the problem.
+
+			if (UA.webkit) {
+				menuNav._hasFocus = FALSE;
+				menuNav._clearActiveItem();
+			}
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _onDocFocus
+	* @description "focus" event handler for the owner document of the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onDocFocus: function (event) {
+	
+		var menuNav = this,
+			bUseARIA = menuNav._useARIA,
+			oFirstItem = menuNav._firstItem,
+			oActiveItem = menuNav._activeItem,
+			oTarget = event.target;
+
+		
+		if (menuNav._rootMenu.contains(oTarget)) {	//	The menu has focus
+
+			if (!menuNav._hasFocus) {	//	Initial focus
+
+				//	First time the menu has been focused, need to setup focused state and  
+				//	established active active descendant
+	
+				menuNav._hasFocus = TRUE;
+	
+				oActiveItem = getItem(oTarget, TRUE);
+	
+				if (oActiveItem) {	
+					menuNav._setActiveItem(oActiveItem);
+				}
+			
+			}
+		
+		}
+		else {	//	The menu has lost focus
+
+			menuNav._clearActiveItem();
+			
+			menuNav._hasFocus = FALSE;
+
+
+			if (oFirstItem && bUseARIA) {
+			
+				placeInDefaultTabIndex(getItemAnchor(oFirstItem));
+
+			}
+
+		}
+	
+	}
+
+};
+
+
+Y.namespace('plugin');
+
+Y.plugin.NodeMenuNav = MenuNav;
+
+
+}, '3.0.0pr2' ,{requires:['node', 'classnamemanager']});

=== added file 'loggerhead/static/javascript/yui/build/node-menunav/node-menunav-min.js'
--- loggerhead/static/javascript/yui/build/node-menunav/node-menunav-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node-menunav/node-menunav-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("node-menunav",function(D){var n=D.UA,AO=D.Lang,u=D.later,AK=D.ClassNameManager.getClassName,j=true,AI=false,m=null,P="menu",G="menuitem",AF="hidden",AB="tabIndex",Q="parentNode",W="children",x="offsetHeight",AA="offsetWidth",AM="px",g="id",I=".",E="handledMouseOut",s="handledMouseOver",b="active",AJ="label",d="a",v="mousedown",AN="keydown",z="click",O="",U="first-of-type",l=AK(P),AE=AK(P,AF),a=AK(P,"horizontal"),AG=AK(P,AJ),i=AK(P,AJ,b),Z=AK(P,AJ,(P+"visible")),J=AK(G),A=AK(G,b),h=I+l;var K=function(AR){var AT=AR.previous(),AQ,AS,AP,Y;if(!AT){AQ=AR.get(Q);AP=AQ.get(Q).get(W);if(AP.size()>1){Y=AQ.previous();if(Y){AS=Y.get(W);}else{AS=AP.item(AP.size()-1).get(W);}}else{AS=AQ.get(W);}AT=AS.item(AS.size()-1);}return AT;};var c=function(AR){var AT=AR.next(),AQ,AS,AP,Y;if(!AT){AQ=AR.get(Q);AP=AQ.get(Q).get(W);if(AP.size()>1){Y=AQ.next();if(Y){AS=Y.get(W);}else{AS=AP.item(0).get(W);}}else{AS=AR.get(Q).get(W);}AT=AS.item(0);}return AT;};var R=function(Y,AP){Y.setAttribute("role",AP);};var S=function(Y,AQ,AP){Y.setAttribute(("aria-"+AQ),AP);};var AH=function(Y){R(Y,"presentation");};var AC=function(Y){Y.set(AB,-1);};var M=function(Y){Y.set(AB,0);};var F=function(Y){var AP=AI;if(Y){AP=Y.get("nodeName").toLowerCase()===d;}return AP;};var N=function(Y){return Y.hasClass(J);};var t=function(Y){return Y.hasClass(AG);};var r=function(Y){return Y.hasClass(a);};var o=function(Y){return Y.hasClass(Z);};var q=function(Y){return F(Y)?Y:Y.query(d);};var y=function(AQ,AP,Y){var AR;if(AQ){if(AQ.hasClass(AP)){AR=AQ;}if(!AR&&Y){AR=AQ.ancestor((I+AP));}}return AR;};var L=function(Y){return Y.ancestor(h);};var X=function(AP,Y){return y(AP,l,Y);};var AD=function(AP,Y){var AQ;if(AP){AQ=y(AP,J,Y);}return AQ;};var p=function(AP,Y){var AQ;if(AP){if(Y){AQ=y(AP,AG,Y);}else{AQ=y(AP,AG)||AP.query((I+AG));}}return AQ;};var B=function(AP,Y){var AQ;if(AP){AQ=AD(AP,Y)||p(AP,Y);}return AQ;};var V=function(AR,AQ){var Y,AS,AP;if(AR){Y=N(AR)?AR:AR.get(Q);AS=AQ?K(Y):c(Y);AP=B(AS);}return AP;};var AL=function(Y){return V(Y,true);};var C=function(Y){return B(Y.query("li"));};var f=function(Y){return N(Y)?A:i;};var k=function(AQ){var AP;if(AQ){AP=q(AQ);try{AP.blur();}catch(Y){}}};var w=function(AQ){var AP;if(AQ){AP=q(AQ);try{AP.focus();}catch(Y){}}};var e=function(Y,AP){return Y&&!Y[s]&&(Y===AP||Y.contains(AP));};var H=function(AP,Y){return AP&&!AP[E]&&(AP!==Y&&!AP.contains(Y));};var T=function(AQ){var AP=this,AX=AQ.owner,AV,AW,AU,AR,AT,AS,Y;if(AX){AW=AQ.useARIA;AU=AQ.autoSubmenuDisplay;AR=AQ.mouseOutHideDelay;AP._useARIA=AO.isBoolean(AW)?AW:((n.gecko&&n.gecko>=1.9)||(n.ie&&n.ie>=8));AP._autoSubmenuDisplay=AO.isBoolean(AU)?AU:j;AP._submenuShowDelay=AQ.submenuShowDelay||250;AP._submenuHideDelay=AQ.submenuHideDelay||250;AP._mouseOutHideDelay=AO.isNumber(AR)?AR:750;AT=AX.queryAll(h);if(AT){AT.addClass(AE);}Y=AX.queryAll("ul:"+U);if(Y){Y.addClass(U);}AX.on("mouseover",AP._onMouseOver,AP);AX.on("mouseout",AP._onMouseOut,AP);AX.on("mousemove",AP._onMouseMove,AP);AX.on(v,AP._toggleSubmenuDisplay,AP);AX.on(AN,AP._toggleSubmenuDisplay,AP);AX.on(z,AP._toggleSubmenuDisplay,AP);AX.on("keypress",AP._onKeyPress,AP);AX.on(AN,AP._onKeyDown,AP);AV=AX.get("ownerDocument");AV.on(v,AP._onDocMouseDown,AP);D.on("focus",D.bind(AP._onDocFocus,AP),AV);AP._rootMenu=AX;if(AP._useARIA){AP._applyARIA(AX);AS=C(AX);if(AS){M(q(AS));AP._firstItem=AS;}}}};T.NS="MenuNav";T.SHIM_TEMPLATE_TITLE="Menu Stacking Shim";T.SHIM_TEMPLATE='<iframe frameborder="0" tabindex="-1" class="'+AK("shim")+'" title="'+T.SHIM_TEMPLATE_TITLE+'" src="javascript:false;"></iframe>';T.prototype={_rootMenu:m,_activeItem:m,_activeMenu:m,_hasFocus:AI,_blockMouseEvent:AI,_currentMouseX:0,_movingToSubmenu:AI,_showSubmenuTimer:m,_hideSubmenuTimer:m,_hideAllSubmenusTimer:m,_firstItem:m,_autoSubmenuDisplay:j,_isRoot:function(Y){return this._rootMenu.compareTo(Y);},_getTopmostSubmenu:function(AR){var AQ=this,Y=L(AR),AP;if(!Y){AP=AR;}else{if(AQ._isRoot(Y)){AP=AR;}else{AP=AQ._getTopmostSubmenu(Y);}}return AP;},_clearActiveItem:function(){var AP=this,Y=AP._activeItem;if(Y){Y.removeClass(f(Y));if(AP._useARIA){AC(q(Y));}}AP._activeItem=m;},_setActiveItem:function(AP){var Y=this;if(AP){Y._clearActiveItem();AP.addClass(f(AP));if(Y._useARIA){M(q(AP));}Y._activeItem=AP;}},_focusItem:function(Y){if(Y&&this._hasFocus){u(0,null,w,Y);}},_applyARIA:function(AR){var AQ=this,AV=AQ._isRoot(AR),Y,AU,AT,AP,AX,AS,AW;R(AR,(AV?"menubar":P));if(!AV){Y=AR.previous();AU=Y.query(I+AK(P,"toggle"));if(AU){Y=AU;}AW=Y.get(g);if(!AW){AW=D.guid();Y.set(g,AW);}S(AR,"labelledby",AW);S(AR,AF,j);}AT=AR.queryAll("ul,li");if(AT){AT.each(function(AY){AH(AY);});}AP=AR.queryAll((I+AK(G,"content")));if(AP){AP.each(function(AY){AC(AY);R(AY,G);});}AX=AR.queryAll((I+AG));if(AX){AX.each(function(AY){Y=AY;AU=AY.query((I+AK(P,"toggle")));if(AU){AH(AU);AC(AU);Y=AU.previous();}R(Y,G);S(Y,"haspopup",j);AC(Y);AS=AY.next();if(AS){AQ._applyARIA(AS);}});}},_showMenu:function(AT){var AQ=this,Y=L(AT),AR=AT.get(Q),AP=AR.getXY(),AS;if(AQ._useARIA){S(AT,AF,AI);}if(r(Y)){AP[1]=AP[1]+AR.get(x);}else{AP[0]=AP[0]+AR.get(AA);}AT.setXY(AP);if(n.ie<8){if(n.ie===6&&!AT.hasIFrameShim){AT.appendChild(D.Node.create(T.SHIM_TEMPLATE));AT.hasIFrameShim=j;}AT.setStyles({height:O,width:O});AT.setStyles({height:(AT.get(x)+AM),width:(AT.get(AA)+AM)});}AT.previous().addClass(Z);AT.removeClass(AE);AS=C(AT);AQ._focusItem(AS);},_hideMenu:function(AR,AP){var AQ=this,AS=AR.previous(),Y;AS.removeClass(Z);if(AP){AQ._setActiveItem(AS);AQ._focusItem(AS);}Y=AR.query((I+A));if(Y){Y.removeClass(A);}AR.setStyles({left:O,top:O});AR.addClass(AE);S(AR,AF,j);},_hideAllSubmenus:function(AQ){var AP=this,Y=AQ.queryAll(h);if(Y){Y.each(D.bind(function(AR){AP._hideMenu(AR);},AP));}},_cancelShowSubmenuTimer:function(){var AP=this,Y=AP._showSubmenuTimer;if(Y){Y.cancel();AP._showSubmenuTimer=m;}},_cancelHideSubmenuTimer:function(){var Y=this,AP=Y._hideSubmenuTimer;if(AP){AP.cancel();Y._hideSubmenuTimer=m;}},_onMenuMouseOver:function(AR,AQ){var AP=this,Y=AP._hideAllSubmenusTimer;if(Y){Y.cancel();AP._hideAllSubmenusTimer=m;
+}AP._cancelHideSubmenuTimer();AP._activeMenu=AR;if(AP._movingToSubmenu&&r(AR)){AP._movingToSubmenu=AI;}},_onMenuMouseOut:function(AV,AT){var AS=this,AQ=AS._activeMenu,AU=AT.relatedTarget,Y=AS._activeItem,AR,AP;if(AQ&&!AQ.contains(AU)){AR=L(AQ);if(AR&&!AR.contains(AU)){if(AS._mouseOutHideDelay>0){AS._cancelShowSubmenuTimer();AS._hideAllSubmenusTimer=u(AS._mouseOutHideDelay,AS,function(){var AW;AQ=AS._activeMenu;AS._hideAllSubmenus(AS._rootMenu);if(AQ){AW=AS._getTopmostSubmenu(AQ);AS._focusItem(AW.previous());}});}}else{if(Y){AP=L(Y);if(!AS._isRoot(AP)){AS._focusItem(AP.previous());}}}}},_onMenuLabelMouseOver:function(AS,AU){var AT=this,AR=AT._activeMenu,Y=AT._isRoot(AR),AQ=(AT._autoSubmenuDisplay&&Y||!Y),AP;AT._setActiveItem(AS);AT._focusItem(AS);if(AQ&&!AT._movingToSubmenu){AT._cancelHideSubmenuTimer();AT._cancelShowSubmenuTimer();if(!o(AS)){AP=AS.next();if(AP){AT._hideAllSubmenus(AR);AT._showSubmenuTimer=u(AT._submenuShowDelay,AT,AT._showMenu,AP);}}}},_onMenuLabelMouseOut:function(AR,AT){var AS=this,Y=AS._isRoot(AS._activeMenu),AQ=(AS._autoSubmenuDisplay&&Y||!Y),AU=AT.relatedTarget,AP=AR.next();AS._clearActiveItem();if(AQ){if(AS._movingToSubmenu&&!AS._showSubmenuTimer&&AP){AS._hideSubmenuTimer=u(AS._submenuHideDelay,AS,AS._hideMenu,AP);}else{if(!AS._movingToSubmenu&&AP&&!AP.contains(AU)&&AU!==AP){AS._cancelShowSubmenuTimer();AS._hideMenu(AP);}}}},_onMenuItemMouseOver:function(AR,AT){var AS=this,AQ=AS._activeMenu,Y=AS._isRoot(AQ),AP=(AS._autoSubmenuDisplay&&Y||!Y);AS._setActiveItem(AR);AS._focusItem(AR);if(AP&&!AS._movingToSubmenu){AS._hideAllSubmenus(AQ);}},_onMenuItemMouseOut:function(Y,AP){this._clearActiveItem();},_onVerticalMenuKeyDown:function(Y){var AP=this,AU=AP._activeMenu,Aa=AP._rootMenu,AQ=Y.target,AS=B(AQ,j),AT=AI,AY=Y.keyCode,AW,AR,AV,AZ,AX;switch(AY){case 37:AR=L(AU);if(AR&&r(AR)){AP._hideMenu(AU);AV=K(AU.get(Q));AX=B(AV);if(AX){if(t(AX)){AW=AX.next();if(AW){AP._showMenu(AW);AP._setActiveItem(C(AW));}else{AP._setActiveItem(AX);w(AX);}}else{AP._setActiveItem(AX);w(AX);}}}else{if(!AP._isRoot(AU)){AP._hideMenu(AU,j);}}AT=j;break;case 39:if(t(AQ)){AW=AQ.next();if(AW){AP._showMenu(AW);AP._setActiveItem(C(AW));}}else{if(r(Aa)){AW=AP._getTopmostSubmenu(AU);AV=c(AW.get(Q));AX=B(AV);AP._hideAllSubmenus(Aa);if(AX){if(t(AX)){AW=AX.next();if(AW){AP._showMenu(AW);AP._setActiveItem(C(AW));}else{AP._setActiveItem(AX);w(AX);}}else{AP._setActiveItem(AX);w(AX);}}}}AT=j;break;case 38:case 40:AP._hideAllSubmenus(AU);AZ=AY===38?AL(AS):V(AS);AP._setActiveItem(AZ);w(AZ);AT=j;break;}if(AT){Y.preventDefault();}},_onHorizontalMenuKeyDown:function(Y){var AP=this,AT=AP._activeMenu,AQ=Y.target,AR=B(AQ,j),AS=AI,AV=Y.keyCode,AW,AU;switch(AV){case 37:case 39:AP._hideAllSubmenus(AT);AW=AV===37?AL(AR):V(AR);AP._setActiveItem(AW);w(AW);AS=j;break;case 40:AP._hideAllSubmenus(AT);if(t(AR)){AU=AR.next();if(AU){AP._showMenu(AU);AP._setActiveItem(C(AU));}AS=j;}break;}if(AS){Y.preventDefault();}},_onMouseMove:function(AP){var Y=this;u(10,Y,function(){Y._currentMouseX=AP.pageX;});},_onMouseOver:function(AS){var AR=this,AP,Y,AU,AQ,AT;if(AR._blockMouseEvent){AR._blockMouseEvent=AI;}else{AP=AS.target;Y=X(AP,j);AU=p(AP,j);AT=AD(AP,j);if(e(Y,AP)){AR._onMenuMouseOver(Y,AS);Y[s]=j;Y[E]=AI;AQ=L(Y);if(AQ){AQ[E]=j;AQ[s]=AI;}}if(e(AU,AP)){AR._onMenuLabelMouseOver(AU,AS);AU[s]=j;AU[E]=AI;}if(e(AT,AP)){AR._onMenuItemMouseOver(AT,AS);AT[s]=j;AT[E]=AI;}}},_onMouseOut:function(AP){var AQ=this,AS=AQ._activeMenu,AX=AI,AR,AT,AV,Y,AU,AW;AQ._movingToSubmenu=(AS&&!r(AS)&&((AP.pageX-5)>AQ._currentMouseX));AR=AP.target;AT=AP.relatedTarget;AV=X(AR,j);Y=p(AR,j);AW=AD(AR,j);if(H(Y,AT)){AQ._onMenuLabelMouseOut(Y,AP);Y[E]=j;Y[s]=AI;}if(H(AW,AT)){AQ._onMenuItemMouseOut(AW,AP);AW[E]=j;AW[s]=AI;}if(Y){AU=Y.next();if(AU&&(AT===AU||AU.contains(AT))){AX=j;}}if(H(AV,AT)||AX){AQ._onMenuMouseOut(AV,AP);AV[E]=j;AV[s]=AI;}},_toggleSubmenuDisplay:function(AQ){var AR=this,AS=AQ.target,AP=p(AS,j),Y=AQ.type,AW,AV,AU,AX,AY,AT;if(AP){AW=F(AS)?AS:AS.ancestor(F);if(AW){AU=AW.getAttribute("href",2);AX=AU.indexOf("#");AY=AU.length;if(AX===0&&AY>1){AT=AU.substr(1,AY);AV=AP.next();if(AV&&(AV.get(g)===AT)){if(Y===v||(Y===AN&&AQ.keyCode===13)){if(n.webkit&&!AR._hasFocus){AR._hasFocus=j;}if(o(AP)){AR._hideMenu(AV);w(AP);}else{AR._hideAllSubmenus(AR._rootMenu);AR._showMenu(AV);}}if(Y===z){AQ.preventDefault();}}}}}},_onKeyPress:function(Y){switch(Y.keyCode){case 37:case 38:case 39:case 40:Y.preventDefault();break;}},_onKeyDown:function(AT){var AS=this,Y=AS._activeItem,AP=AT.target,AR=L(AP),AQ;if(AR){AS._activeMenu=AR;if(r(AR)){AS._onHorizontalMenuKeyDown(AT);}else{AS._onVerticalMenuKeyDown(AT);}if(AT.keyCode===27){if(!AS._isRoot(AR)){AS._hideMenu(AR,j);AT.stopPropagation();AS._blockMouseEvent=n.gecko?j:AI;}else{if(Y){if(t(Y)&&o(Y)){AQ=Y.next();if(AQ){AS._hideMenu(AQ);}}else{k(AP);AS._clearActiveItem();}}}}}},_onDocMouseDown:function(AR){var AQ=this,AP=AQ._rootMenu,Y=AR.target;if(!AP.compareTo(Y)&&!AP.contains(Y)){AQ._hideAllSubmenus(AP);if(n.webkit){AQ._hasFocus=AI;AQ._clearActiveItem();}}},_onDocFocus:function(AS){var AR=this,AP=AR._useARIA,AT=AR._firstItem,Y=AR._activeItem,AQ=AS.target;if(AR._rootMenu.contains(AQ)){if(!AR._hasFocus){AR._hasFocus=j;Y=B(AQ,j);if(Y){AR._setActiveItem(Y);}}}else{AR._clearActiveItem();AR._hasFocus=AI;if(AT&&AP){M(q(AT));}}}};D.namespace("plugin");D.plugin.NodeMenuNav=T;},"3.0.0pr2",{requires:["node","classnamemanager"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/node-menunav/node-menunav.js'
--- loggerhead/static/javascript/yui/build/node-menunav/node-menunav.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node-menunav/node-menunav.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,2078 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node-menunav', function(Y) {
+
+/**
+* <p>The MenuNav Node Plugin makes it easy to transform existing list-based markup into traditional, 
+* drop down navigational menus that are both accessible and easy to customize, and only require 
+* a small set of dependencies.</p>
+* <p>To use the MenuNav Node Plugin, simply pass a reference to the plugin to a Node instance's 
+* <code>plug</code> method.</p>
+* 
+* <p>
+* <code>
+* &#60;script type="text/javascript"&#62;<br>
+* <br>
+* 		//	Call the "use" method, passing in "node-menunav".  This will load the <br>
+* 		//	script and CSS for the MenuNav Node Plugin and all of the required <br>
+* 		//	dependencies.<br>
+* <br>
+* 		YUI().use("node-menunav", function(Y) {<br>
+* <br>
+* 			//	Use the "contentready" event to initialize the menu when the subtree of <br>
+* 			//	element representing the root menu (&#60;div id="menu-1"&#62;) is ready to <br>
+* 			//	be scripted.<br>
+* <br>
+* 			Y.on("contentready", function () {<br>
+* <br>
+* 				//	The scope of the callback will be a Node instance representing <br>
+* 				//	the root menu (&#60;div id="menu-1"&#62;).  Therefore, since "this"<br>
+* 				//	represents a Node instance, it is possible to just call "this.plug"<br>
+* 				//	passing in a reference to the MenuNav Node Plugin.<br>
+* <br>
+* 				this.plug(Y.plugin.NodeMenuNav);<br>
+* <br>
+* 			}, "#menu-1");<br>
+* <br>		
+* 		}); <br>
+* <br>	
+* 	&#60;/script&#62;<br>
+* </code>
+* </p>
+*
+* <p>The MenuNav Node Plugin has several configuration properties that can be set via an 
+* object literal that is passed as a second argument to a Node instance's <code>plug</code> method.
+* </p>
+*
+* <p>
+* <code>
+* &#60;script type="text/javascript"&#62;<br>
+* <br>
+* 		//	Call the "use" method, passing in "node-menunav".  This will load the <br>
+* 		//	script and CSS for the MenuNav Node Plugin and all of the required <br>
+* 		//	dependencies.<br>
+* <br>
+* 		YUI().use("node-menunav", function(Y) {<br>
+* <br>
+* 			//	Use the "contentready" event to initialize the menu when the subtree of <br>
+* 			//	element representing the root menu (&#60;div id="menu-1"&#62;) is ready to <br>
+* 			//	be scripted.<br>
+* <br>
+* 			Y.on("contentready", function () {<br>
+* <br>
+* 				//	The scope of the callback will be a Node instance representing <br>
+* 				//	the root menu (&#60;div id="menu-1"&#62;).  Therefore, since "this"<br>
+* 				//	represents a Node instance, it is possible to just call "this.plug"<br>
+* 				//	passing in a reference to the MenuNav Node Plugin.<br>
+* <br>
+* 				this.plug(Y.plugin.NodeMenuNav, { mouseOutHideDelay: 1000 });<br>
+* <br>
+* 			}, "#menu-1");<br>
+* <br>		
+* 		}); <br>
+* <br>	
+* 	&#60;/script&#62;<br>
+* </code>
+* </p>
+* 
+* <p> The complete list of the MenuNav Node Plugin configuration properties are:</p>
+* <dl>
+* 	<dt>useARIA</dt>
+* 		<dd>Boolean indicating if use of the WAI-ARIA Roles and States should be enabled for the 
+* 		MenuNav.  Set to true by default for Firefox 3 and Internet Explorer 8 as currently only 
+* 		these browsers have support for ARIA, and are supported by several screen readers for 
+* 		Windows that also offer support for ARIA.</dd>
+* 
+* 	<dt>autoSubmenuDisplay</dt>
+* 		<dd>Boolean indicating if submenus are automatically made visible when the user mouses over 
+* 		the menu's items.  Set to true by default.</dd>
+* 
+* 	<dt>submenuShowDelay</dt>
+* 		<dd>Number indicating the time (in milliseconds) that should expire before a submenu is 
+* 		made visible when the user mouses over the menu's label.  Set to 250 by default.</dd>
+* 
+* 	<dt>submenuHideDelay</dt>
+* 		<dd>Number indicating the time (in milliseconds) that should expire before a submenu is 
+* 		hidden when the user mouses out of a menu label heading in the direction of a submenu.  
+* 		Set to 250 by default.</dd>
+* 
+* 	<dt>mouseOutHideDelay</dt>
+* 		<dd>Number indicating the time (in milliseconds) that should expire before a submenu is 
+* 		hidden when the user mouses out of it.  Set to 750 by default.</dd>
+* </dl>
+* 
+* @module node-menunav
+*/
+
+	//	Util shortcuts
+
+var UA = Y.UA,
+	Lang = Y.Lang,
+	later = Y.later,
+	getClassName = Y.ClassNameManager.getClassName,
+
+
+	//	Native types
+
+	TRUE = true,
+	FALSE = false,
+	NULL = null,
+
+
+
+	//	Frequently used strings
+
+	MENU = "menu",
+	MENUITEM = "menuitem",
+	HIDDEN = "hidden",
+	TAB_INDEX = "tabIndex",		
+	PARENT_NODE = "parentNode",
+	CHILDREN = "children",
+	OFFSET_HEIGHT = "offsetHeight",
+	OFFSET_WIDTH = "offsetWidth",
+	PX = "px",
+	ID = "id",
+	PERIOD = ".",
+	HANDLED_MOUSEOUT = "handledMouseOut",
+	HANDLED_MOUSEOVER = "handledMouseOver",
+	ACTIVE = "active",
+	LABEL = "label",
+	LOWERCASE_A = "a",
+	MOUSEDOWN = "mousedown",
+	KEYDOWN = "keydown",
+	CLICK = "click",
+	EMPTY_STRING = "",
+	FIRST_OF_TYPE = "first-of-type",
+
+
+	//	CSS class names
+
+	CSS_MENU = getClassName(MENU),
+	CSS_MENU_HIDDEN = getClassName(MENU, HIDDEN),
+	CSS_MENU_HORIZONTAL = getClassName(MENU, "horizontal"),
+	CSS_MENU_LABEL = getClassName(MENU, LABEL),
+	CSS_MENU_LABEL_ACTIVE = getClassName(MENU, LABEL, ACTIVE),
+	CSS_MENU_LABEL_MENUVISIBLE = getClassName(MENU, LABEL, (MENU + "visible")),
+	CSS_MENUITEM = getClassName(MENUITEM),
+	CSS_MENUITEM_ACTIVE = getClassName(MENUITEM, ACTIVE),
+
+
+	//	CSS selectors
+	
+	MENU_SELECTOR = PERIOD + CSS_MENU;
+
+
+//	Utility functions
+
+
+//	TO DO: Remove once Node implements circular functionality
+var getPreviousSibling = function (node) {
+
+	var oPrevious = node.previous(),
+		oParentNode,
+		oChildren,
+		oULs,
+		oUL;
+	
+
+	if (!oPrevious) {
+	
+		oParentNode = node.get(PARENT_NODE);
+		oULs = oParentNode.get(PARENT_NODE).get(CHILDREN);
+
+		if (oULs.size() > 1) {
+			
+			oUL = oParentNode.previous();
+			
+			if (oUL) {
+				oChildren = oUL.get(CHILDREN);
+			}
+			else {
+				oChildren = oULs.item(oULs.size() - 1).get(CHILDREN);
+			}
+			
+		}
+		else {
+			oChildren = oParentNode.get(CHILDREN);
+		}
+
+		oPrevious = oChildren.item(oChildren.size() - 1);
+		
+	}
+	
+	return oPrevious;
+
+};
+
+
+//	TO DO: Remove once Node implements circular functionality
+var getNextSibling = function (node) {
+
+	var oNext = node.next(),
+		oParentNode,
+		oChildren,
+		oULs,
+		oUL;
+	
+
+	if (!oNext) {
+
+		oParentNode = node.get(PARENT_NODE);
+		oULs = oParentNode.get(PARENT_NODE).get(CHILDREN);
+
+		if (oULs.size() > 1) {
+			
+			oUL = oParentNode.next();
+			
+			if (oUL) {
+				oChildren = oUL.get(CHILDREN);
+			}
+			else {
+				oChildren = oULs.item(0).get(CHILDREN);
+			}
+			
+		}		
+		else {
+			oChildren = node.get(PARENT_NODE).get(CHILDREN);
+		}
+
+		oNext = oChildren.item(0);		
+
+	}
+	
+	return oNext;
+
+};
+
+
+var setARIARole = function (node, role) {
+
+	node.setAttribute("role", role);
+
+};
+
+
+var setARIAProperty = function (node, property, value) {
+
+	node.setAttribute(("aria-" + property), value);
+
+};
+
+
+var setARIAPresentation = function (node) {
+
+	setARIARole(node, "presentation");
+
+};
+
+
+var removeFromTabIndex = function (node) {
+
+	node.set(TAB_INDEX, -1);
+
+};
+
+
+var placeInDefaultTabIndex = function (node) {
+
+	node.set(TAB_INDEX, 0);
+
+};
+
+
+var isAnchor = function (node) {
+	
+	var bReturnVal = FALSE;
+	
+	if (node) {
+		bReturnVal = node.get("nodeName").toLowerCase() === LOWERCASE_A;
+	}
+	
+	return bReturnVal;
+	
+};
+
+
+var isMenuItem = function (node) {
+
+	return node.hasClass(CSS_MENUITEM);
+
+};
+
+
+var isMenuLabel = function (node) {
+
+	return node.hasClass(CSS_MENU_LABEL);
+
+};
+
+
+var isHorizontalMenu = function (menu) {
+
+	return menu.hasClass(CSS_MENU_HORIZONTAL);
+
+};
+
+
+var hasVisibleSubmenu = function (menuLabel) {
+
+	return menuLabel.hasClass(CSS_MENU_LABEL_MENUVISIBLE);
+
+};
+
+
+var getItemAnchor = function (node) {
+
+	return isAnchor(node) ? node : node.query(LOWERCASE_A);
+
+};
+
+
+var getNodeWithClass = function (node, className, searchAncestors) {
+
+	var oItem;
+	
+	if (node) {
+		
+		if (node.hasClass(className)) {
+			oItem = node;
+		}
+		
+		if (!oItem && searchAncestors) {
+			oItem = node.ancestor((PERIOD + className));
+		}
+	
+	}
+	
+	return oItem;
+
+};
+
+
+var getParentMenu = function (node) {
+
+	return node.ancestor(MENU_SELECTOR);
+	
+};
+
+
+var getMenu = function (node, searchAncestors) {
+
+	return getNodeWithClass(node, CSS_MENU, searchAncestors);
+
+};
+
+
+var getMenuItem = function (node, searchAncestors) {
+
+	var oItem;
+	
+	if (node) {
+		oItem = getNodeWithClass(node, CSS_MENUITEM, searchAncestors);
+	}
+	
+	return oItem;
+
+};
+
+
+var getMenuLabel = function (node, searchAncestors) {
+
+	var oItem;
+	
+	if (node) {
+	
+		if (searchAncestors) {
+			oItem = getNodeWithClass(node, CSS_MENU_LABEL, searchAncestors);
+		}
+		else {
+			oItem = getNodeWithClass(node, CSS_MENU_LABEL) || node.query((PERIOD + CSS_MENU_LABEL));
+		}
+		
+	}
+	
+	return oItem;
+
+};
+
+
+var getItem = function (node, searchAncestors) {
+
+	var oItem;
+	
+	if (node) {
+		oItem = getMenuItem(node, searchAncestors) || getMenuLabel(node, searchAncestors);
+	}
+	
+	return oItem;	
+
+};
+
+
+var getNextItem = function (item, previous) {
+
+	var oItemLI,
+		oNextLI,
+		oNextItem;
+	
+
+	if (item) {
+
+		oItemLI = isMenuItem(item) ? item : item.get(PARENT_NODE);
+
+		oNextLI = previous ? getPreviousSibling(oItemLI) : getNextSibling(oItemLI);
+
+		oNextItem = getItem(oNextLI);
+	
+	}
+	
+	return oNextItem;
+	
+};
+
+
+var getPreviousItem = function (item) {
+
+	return getNextItem(item, true);
+
+};
+
+
+var getFirstItem = function (menu) {
+	
+	return getItem(menu.query("li"));
+
+};
+
+
+var getActiveClass = function (node) {
+
+	return isMenuItem(node) ? CSS_MENUITEM_ACTIVE : CSS_MENU_LABEL_ACTIVE;
+
+};
+
+
+var blurItem = function (item) {
+
+	var oAnchor;
+
+	if (item) {
+
+		oAnchor = getItemAnchor(item);
+
+		//	TO DO:  Remove once implemented in Node
+		try {
+			oAnchor.blur();
+		}
+		catch (ex) { }
+
+	}
+
+};
+	
+
+var focusItem = function (item) {
+
+	var oAnchor;
+
+	if (item) {
+
+		oAnchor = getItemAnchor(item);
+	
+		//	TO DO:  Remove once implemented in Node
+		try {
+			oAnchor.focus();
+		}
+		catch (ex) { }
+	
+	}
+
+};
+
+
+var handleMouseOverForNode = function (node, target) {
+
+	return node && !node[HANDLED_MOUSEOVER] && (node === target || node.contains(target));
+
+};
+
+
+var handleMouseOutForNode = function (node, relatedTarget) {
+
+	return node && !node[HANDLED_MOUSEOUT] && 
+		(node !== relatedTarget && !node.contains(relatedTarget));
+
+};
+
+
+/**
+* The NodeMenuNav class is a plugin for a Node instance.  The class is used via the 
+* <a href="Node.html#method_plug"><code>plug</code></a> method of Node and should not be 
+* instantiated directly.
+* @namespace plugin
+* @class NodeMenuNav
+*/
+var MenuNav = function (config) {
+
+	var menuNav = this,
+		oRootMenu = config.owner,
+		oDocument,
+		bUseARIA,
+		bAutoSubmenuDisplay,
+		nMouseOutHideDelay,
+		oMenuNodes,
+		oFirstItem,
+		oULs;
+		
+
+	if (oRootMenu) {
+
+		bUseARIA = config.useARIA;
+		bAutoSubmenuDisplay = config.autoSubmenuDisplay;
+		nMouseOutHideDelay = config.mouseOutHideDelay;
+		
+
+		//	Enable ARIA for Firefox 3 and IE 8 by default since those are the two browsers 
+		//	that current support ARIA
+
+		menuNav._useARIA = Lang.isBoolean(bUseARIA) ? 
+						bUseARIA : ((UA.gecko && UA.gecko >= 1.9) || (UA.ie && UA.ie >= 8));
+
+
+		menuNav._autoSubmenuDisplay = 
+					Lang.isBoolean(bAutoSubmenuDisplay) ? bAutoSubmenuDisplay : TRUE;
+
+		menuNav._submenuShowDelay = config.submenuShowDelay || 250;
+		menuNav._submenuHideDelay = config.submenuHideDelay || 250;
+
+		menuNav._mouseOutHideDelay = Lang.isNumber(nMouseOutHideDelay) ? nMouseOutHideDelay : 750;
+
+
+		//	Hide all visible submenus
+
+		oMenuNodes = oRootMenu.queryAll(MENU_SELECTOR);
+
+		if (oMenuNodes) {
+			oMenuNodes.addClass(CSS_MENU_HIDDEN);
+		}
+
+
+		oULs = oRootMenu.queryAll("ul:" + FIRST_OF_TYPE);
+
+		if (oULs) {
+			oULs.addClass(FIRST_OF_TYPE);
+		}
+
+
+		//	Wire up all event handlers
+
+
+		oRootMenu.on("mouseover", menuNav._onMouseOver, menuNav);
+		oRootMenu.on("mouseout", menuNav._onMouseOut, menuNav);
+		oRootMenu.on("mousemove", menuNav._onMouseMove, menuNav);
+		oRootMenu.on(MOUSEDOWN, menuNav._toggleSubmenuDisplay, menuNav);
+		oRootMenu.on(KEYDOWN, menuNav._toggleSubmenuDisplay, menuNav);
+		oRootMenu.on(CLICK, menuNav._toggleSubmenuDisplay, menuNav);
+		oRootMenu.on("keypress", menuNav._onKeyPress, menuNav);
+		oRootMenu.on(KEYDOWN, menuNav._onKeyDown, menuNav);
+
+		oDocument = oRootMenu.get("ownerDocument");
+
+		oDocument.on(MOUSEDOWN, menuNav._onDocMouseDown, menuNav);
+
+		Y.on("focus", Y.bind(menuNav._onDocFocus, menuNav), oDocument);
+
+		menuNav._rootMenu = oRootMenu;
+
+
+		if (menuNav._useARIA) {
+
+			menuNav._applyARIA(oRootMenu);
+
+			oFirstItem = getFirstItem(oRootMenu);
+	
+			if (oFirstItem) {
+	
+				placeInDefaultTabIndex(getItemAnchor(oFirstItem));
+	
+				menuNav._firstItem = oFirstItem;
+	
+			}		
+		
+		}
+
+	}
+
+};
+
+
+MenuNav.NS = "MenuNav";
+
+
+/** 
+* @property NodeMenuNav.SHIM_TEMPLATE_TITLE
+* @description String representing the value for the <code>title</code> attribute for the shim used
+* to prevent <code>&#60;select&#62;</code> elements from poking through menus in IE 6.
+* @default "Menu Stacking Shim"
+* @type String
+*/
+MenuNav.SHIM_TEMPLATE_TITLE = "Menu Stacking Shim";
+
+
+/** 
+* @property NodeMenuNav.SHIM_TEMPLATE
+* @description String representing the HTML used to create the <code>&#60;iframe&#62;</code> shim 
+* used to prevent <code>&#60;select&#62;</code> elements from poking through menus in IE 6.
+* @default &#34;&#60;iframe frameborder=&#34;0&#34; tabindex=&#34;-1&#34; 
+* class=&#34;yui-shim&#34; title=&#34;Menu Stacking Shim&#34; 
+* src=&#34;javascript:false;&#34;&#62;&#60;/iframe&#62;&#34;
+* @type String
+*/
+
+//	<iframe> shim notes:
+//
+//	1) Need to set the "frameBorder" property to 0 to suppress the default <iframe> border in IE.  
+//	(Setting the CSS "border" property alone doesn't suppress it.)  
+//
+//	2) The "src" attribute of the <iframe> is set to "javascript:false;" so that it won't load a 
+//	page inside it, preventing the secure/nonsecure warning in IE when using HTTPS.
+//
+//	3) Since the role of the <iframe> shim is completely presentational, its "tabindex" attribute
+//	is set to "-1" and its title attribute is set to "Menu Stacking Shim".  Both strategies help
+//	users of screen readers to avoid mistakenly interacting with the <iframe> shim.
+
+MenuNav.SHIM_TEMPLATE	=	'<iframe frameborder="0" tabindex="-1" class="' + 
+							getClassName("shim") + 
+							'" title="' + MenuNav.SHIM_TEMPLATE_TITLE + 
+							'" src="javascript:false;"></iframe>';
+
+
+MenuNav.prototype = {
+
+	//	Protected properties
+
+	/** 
+	* @property _rootMenu
+	* @description Node instance representing the root menu in the MenuNav.
+	* @default null
+	* @protected
+	* @type Node
+	*/
+	_rootMenu: NULL,	
+
+
+	/** 
+	* @property _activeItem
+	* @description Node instance representing the MenuNav's active descendent - the menuitem or 
+	* menu label the user is currently interacting with.
+	* @default null
+	* @protected
+	* @type Node
+	*/
+	_activeItem: NULL, 
+
+
+	/** 
+	* @property _activeMenu
+	* @description Node instance representing the menu that is the parent of the MenuNav's 
+	* active descendent.
+	* @default null
+	* @protected
+	* @type Node
+	*/
+	_activeMenu: NULL,
+
+
+	/** 
+	* @property _hasFocus
+	* @description Boolean indicating if the MenuNav has focus.
+	* @default false
+	* @protected
+	* @type Boolean
+	*/
+	_hasFocus: FALSE,
+
+
+	//	In gecko-based browsers a mouseover and mouseout event will fire even 
+	//	if a DOM element moves out from under the mouse without the user actually
+	//	moving the mouse.  This bug affects MenuNav because the user can hit the 
+	//	Esc key to hide a menu, and if the mouse is over the menu when the 
+	//	user presses Esc, the _onMenuMouseOut handler will be called.  To fix this 
+	//	bug the following flag (_blockMouseEvent) is used to block the code in the 
+	//	_onMenuMouseOut handler from executing.
+
+	/** 
+	* @property _blockMouseEvent
+	* @description Boolean indicating whether or not to handle the "mouseover" event.
+	* @default false
+	* @protected
+	* @type Boolean
+	*/
+	_blockMouseEvent: FALSE,
+
+
+	/** 
+	* @property _currentMouseX
+	* @description Number representing the current x coordinate of the mouse inside the MenuNav.
+	* @default 0
+	* @protected
+	* @type Number
+	*/
+	_currentMouseX: 0,
+
+
+	/** 
+	* @property _movingToSubmenu
+	* @description Boolean indicating if the mouse is moving from a menu label to its 
+	* corresponding submenu.
+	* @default false
+	* @protected
+	* @type Boolean
+	*/
+	_movingToSubmenu: FALSE,
+
+
+	/** 
+	* @property _showSubmenuTimer
+	* @description Timer used to show a submenu.
+	* @default null
+	* @protected
+	* @type Object
+	*/
+	_showSubmenuTimer: NULL,
+
+
+	/** 
+	* @property _hideSubmenuTimer
+	* @description Timer used to hide a submenu.
+	* @default null
+	* @protected
+	* @type Object
+	*/
+	_hideSubmenuTimer: NULL,
+
+
+	/** 
+	* @property _hideAllSubmenusTimer
+	* @description Timer used to hide a all submenus.
+	* @default null
+	* @protected
+	* @type Object
+	*/
+	_hideAllSubmenusTimer: NULL,
+
+
+	/** 
+	* @property _firstItem
+	* @description Node instance representing the first item (menuitem or menu label) in the root 
+	* menu of a MenuNav.
+	* @default null
+	* @protected
+	* @type Node
+	*/
+	_firstItem: NULL,
+
+
+	/** 
+	* @property _autoSubmenuDisplay
+    * @description Boolean indicating if submenus are automatically made visible when the user 
+    * mouses over the menu's items.
+    * @default true
+	* @protected
+    * @type Boolean
+	*/
+	_autoSubmenuDisplay: TRUE,
+
+
+
+	//	Protected methods
+
+	/**
+	* @method _isRoot
+	* @description Returns a boolean indicating if the specified menu is the root menu in 
+	* the MenuNav.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	* @return {Boolean} Boolean indicating if the specified menu is the root menu in the MenuNav.	
+	*/
+	_isRoot: function (menu) {
+
+		return this._rootMenu.compareTo(menu);
+
+	},
+
+
+	/**
+	* @method _getTopmostSubmenu
+	* @description Returns the topmost submenu of a submenu hierarchy.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	* @return {Node} Node instance representing a menu.
+	*/
+	_getTopmostSubmenu: function (menu) {
+	
+		var menuNav = this,
+			oMenu = getParentMenu(menu),
+			returnVal;
+
+
+		if (!oMenu) {
+			returnVal = menu;
+		}
+		else if (menuNav._isRoot(oMenu)) {
+			returnVal = menu;
+		}
+		else {
+			returnVal = menuNav._getTopmostSubmenu(oMenu);
+		}
+	
+		return returnVal;
+	
+	},
+
+
+	/**
+	* @method _clearActiveItem
+	* @description Clears the MenuNav's active descendent.
+	* @protected
+	*/
+	_clearActiveItem: function () {
+
+		var menuNav = this,
+			oActiveItem = menuNav._activeItem;
+		
+		if (oActiveItem) {
+
+			oActiveItem.removeClass(getActiveClass(oActiveItem));
+
+			if (menuNav._useARIA) {
+				removeFromTabIndex(getItemAnchor(oActiveItem));
+			}
+
+		}
+
+		menuNav._activeItem = NULL;
+	
+	},
+
+
+	/**
+	* @method _setActiveItem
+	* @description Sets the specified menuitem or menu label as the MenuNav's active descendent.
+	* @protected
+	* @param {Node} item Node instance representing a menuitem or menu label.
+	*/
+	_setActiveItem: function (item) {
+
+		var menuNav = this;
+	
+		if (item) {
+			
+			menuNav._clearActiveItem();
+	
+			item.addClass(getActiveClass(item));
+	
+			if (menuNav._useARIA) {
+				placeInDefaultTabIndex(getItemAnchor(item));
+			}
+			
+			menuNav._activeItem = item;
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _focusItem
+	* @description Focuses the specified menuitem or menu label.
+	* @protected
+	* @param {Node} item Node instance representing a menuitem or menu label.
+	*/
+	_focusItem: function (item) {
+	
+		if (item && this._hasFocus) {
+		
+			//	Need to focus using a zero-second timeout to get Apple's VoiceOver to 
+			//	recognize that the focused item has changed
+
+			later(0, null, focusItem, item);
+
+		}
+	
+	},
+
+
+	/**
+	* @method _applyARIA
+	* @description Applies the ARIA Roles, States and Properties to the supplied menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	*/
+	_applyARIA: function (menu) {
+
+		var menuNav = this,
+			bIsRoot = menuNav._isRoot(menu),
+			oMenuLabel,
+			oMenuToggle,
+			oListNodes,
+			oMenuItemContentNodes,
+			oMenuLabelNodes,
+			oSubmenu,
+			sID;
+
+
+		setARIARole(menu, (bIsRoot ? "menubar" : MENU));
+
+		if (!bIsRoot) {
+
+			oMenuLabel = menu.previous();
+			oMenuToggle = oMenuLabel.query(PERIOD + getClassName(MENU, "toggle"));
+			
+			if (oMenuToggle) {
+				oMenuLabel = oMenuToggle;
+			}
+			
+			sID = oMenuLabel.get(ID);
+			
+			if (!sID) {
+				sID = Y.guid();
+				oMenuLabel.set(ID, sID);
+			}
+
+			setARIAProperty(menu, "labelledby", sID);
+			setARIAProperty(menu, HIDDEN, TRUE);
+		
+		}
+
+
+		oListNodes = menu.queryAll("ul,li");
+		
+		if (oListNodes) {
+
+			oListNodes.each(function (node) {
+			
+				setARIAPresentation(node);
+			
+			});
+
+		}
+		
+
+		oMenuItemContentNodes = menu.queryAll((PERIOD + getClassName(MENUITEM, "content")));
+
+		if (oMenuItemContentNodes) {
+
+			oMenuItemContentNodes.each(function (node) {
+
+				removeFromTabIndex(node);
+				setARIARole(node, MENUITEM);
+
+			});
+
+		}
+		
+
+		oMenuLabelNodes = menu.queryAll((PERIOD + CSS_MENU_LABEL));
+
+		if (oMenuLabelNodes) {
+
+			oMenuLabelNodes.each(function (node) {
+
+				oMenuLabel = node;
+				oMenuToggle = node.query((PERIOD + getClassName(MENU, "toggle")));
+				
+				if (oMenuToggle) {
+
+					setARIAPresentation(oMenuToggle);
+					removeFromTabIndex(oMenuToggle);
+					
+					oMenuLabel = oMenuToggle.previous();
+				
+				}
+
+				setARIARole(oMenuLabel, MENUITEM);
+				setARIAProperty(oMenuLabel, "haspopup", TRUE);
+				removeFromTabIndex(oMenuLabel);
+				
+				oSubmenu = node.next();
+				
+				if (oSubmenu) {
+					menuNav._applyARIA(oSubmenu);
+				}
+				
+			});
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _showMenu
+	* @description Shows the specified menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	*/
+	_showMenu: function (menu) {
+
+		var menuNav = this,
+			oParentMenu = getParentMenu(menu),
+			oLI = menu.get(PARENT_NODE),
+			aXY = oLI.getXY(),
+			oItem;
+
+		if (menuNav._useARIA) {
+			setARIAProperty(menu, HIDDEN, FALSE);
+		}
+
+		if (isHorizontalMenu(oParentMenu)) {
+			aXY[1] = aXY[1] + oLI.get(OFFSET_HEIGHT);
+		}
+		else {
+			aXY[0] = aXY[0] + oLI.get(OFFSET_WIDTH);
+		}
+		
+		menu.setXY(aXY);
+
+		if (UA.ie < 8) {
+
+			if (UA.ie === 6 && !menu.hasIFrameShim) {
+	
+				menu.appendChild(Y.Node.create(MenuNav.SHIM_TEMPLATE));
+				menu.hasIFrameShim = TRUE;
+
+			}
+
+			//	Clear previous values for height and width
+
+			menu.setStyles({ height: EMPTY_STRING, width: EMPTY_STRING });
+
+			//	Set the width and height of the menu's bounding box - this is necessary for IE 6
+			//	so that the CSS for the <iframe> shim can simply set the <iframe>'s width and height 
+			//	to 100% to ensure that dimensions of an <iframe> shim are always sync'd to the 
+			//	that of its parent menu.  Specifying a width and height also helps when positioning
+			//	decorator elements (for creating effects like rounded corners) inside a menu's 
+			//	bounding box in IE 7.
+			
+			menu.setStyles({ 
+				height: (menu.get(OFFSET_HEIGHT) + PX), 
+				width: (menu.get(OFFSET_WIDTH) + PX) });
+
+		}
+
+		menu.previous().addClass(CSS_MENU_LABEL_MENUVISIBLE);
+		menu.removeClass(CSS_MENU_HIDDEN);
+
+		oItem = getFirstItem(menu);
+
+		menuNav._focusItem(oItem);
+
+	},
+	
+
+	/**
+	* @method _hideMenu 
+	* @description Hides the specified menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	* @param {Boolean} activateAndFocusLabel Boolean indicating if the label for the specified 
+	* menu should be focused and set as active.
+	*/
+	_hideMenu: function (menu, activateAndFocusLabel) {
+
+		var menuNav = this,
+			oLabel = menu.previous(),
+			oActiveItem;
+
+		oLabel.removeClass(CSS_MENU_LABEL_MENUVISIBLE);
+
+
+		if (activateAndFocusLabel) {
+			menuNav._setActiveItem(oLabel);
+			menuNav._focusItem(oLabel);
+		}
+
+		oActiveItem = menu.query((PERIOD + CSS_MENUITEM_ACTIVE));
+
+		if (oActiveItem) {
+			oActiveItem.removeClass(CSS_MENUITEM_ACTIVE);
+		}
+
+		//	Clear the values for top and left that were set by the call to "setXY" when the menu
+		//	was shown so that the hidden position specified in the core CSS file will take affect.
+
+		menu.setStyles({ left: EMPTY_STRING, top: EMPTY_STRING });
+		
+		menu.addClass(CSS_MENU_HIDDEN);
+		setARIAProperty(menu, HIDDEN, TRUE);
+		
+	},
+
+
+	/**
+	* @method _hideAllSubmenus
+	* @description Hides all submenus of the specified menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	*/
+	_hideAllSubmenus: function (menu) {
+
+		var menuNav = this,
+			oSubmenus = menu.queryAll(MENU_SELECTOR);
+
+		if (oSubmenus) {
+
+			oSubmenus.each(Y.bind(function (submenuNode) {
+			
+				menuNav._hideMenu(submenuNode);
+			
+			}, menuNav));
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _cancelShowSubmenuTimer
+	* @description Cancels the timer used to show a submenu.
+	* @protected
+	*/
+	_cancelShowSubmenuTimer: function () {
+
+		var menuNav = this,
+			oShowSubmenuTimer = menuNav._showSubmenuTimer;
+
+		if (oShowSubmenuTimer) {
+			oShowSubmenuTimer.cancel();
+			menuNav._showSubmenuTimer = NULL;
+		}
+	
+	},
+
+
+	/**
+	* @method _cancelHideSubmenuTimer
+	* @description Cancels the timer used to hide a submenu.
+	* @protected
+	*/
+	_cancelHideSubmenuTimer: function () {
+
+		var menuNav = this,
+			oHideSubmenuTimer = menuNav._hideSubmenuTimer;
+
+
+		if (oHideSubmenuTimer) {
+			oHideSubmenuTimer.cancel();
+			menuNav._hideSubmenuTimer = NULL;
+		}
+	
+	},
+
+
+
+	//	Event handlers for discrete pieces of pieces of the menu
+
+
+	/**
+	* @method _onMenuMouseOver
+	* @description "mouseover" event handler for a menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuMouseOver: function (menu, event) {
+
+		var menuNav = this,
+			oHideAllSubmenusTimer = menuNav._hideAllSubmenusTimer;
+
+		if (oHideAllSubmenusTimer) {
+			oHideAllSubmenusTimer.cancel();
+			menuNav._hideAllSubmenusTimer = NULL;
+		}
+
+		menuNav._cancelHideSubmenuTimer();
+
+		menuNav._activeMenu = menu;
+
+
+		if (menuNav._movingToSubmenu && isHorizontalMenu(menu)) {
+			menuNav._movingToSubmenu = FALSE;
+		}
+
+	},
+
+
+	/**
+	* @method _onMenuMouseOut
+	* @description "mouseout" event handler for a menu.
+	* @protected
+	* @param {Node} menu Node instance representing a menu.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuMouseOut: function (menu, event) {
+
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			oRelatedTarget = event.relatedTarget,
+			oActiveItem = menuNav._activeItem,
+			oParentMenu,
+			oMenu;
+
+
+		if (oActiveMenu && !oActiveMenu.contains(oRelatedTarget)) {
+		
+			oParentMenu = getParentMenu(oActiveMenu);
+			
+
+			if (oParentMenu && !oParentMenu.contains(oRelatedTarget)) {
+
+				if (menuNav._mouseOutHideDelay > 0) {
+
+					menuNav._cancelShowSubmenuTimer();
+
+					menuNav._hideAllSubmenusTimer = 
+
+							later(menuNav._mouseOutHideDelay, menuNav, function () {
+
+								var	oSubmenu;
+
+								oActiveMenu = menuNav._activeMenu;
+							
+								menuNav._hideAllSubmenus(menuNav._rootMenu);
+						
+								if (oActiveMenu) {
+						
+									//	Focus the label element for the topmost submenu
+									oSubmenu = menuNav._getTopmostSubmenu(oActiveMenu);
+									menuNav._focusItem(oSubmenu.previous());
+						
+								}
+							
+							});
+						
+				}
+			
+			}
+			else {
+			
+				if (oActiveItem) {
+				
+					oMenu = getParentMenu(oActiveItem);
+
+					if (!menuNav._isRoot(oMenu)) { 
+						menuNav._focusItem(oMenu.previous());
+					}
+				
+				}
+			
+			}
+
+		}
+
+	},
+
+
+	/**
+	* @method _onMenuLabelMouseOver
+	* @description "mouseover" event handler for a menu label.
+	* @protected
+	* @param {Node} menuLabel Node instance representing a menu label.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuLabelMouseOver: function (menuLabel, event) {
+
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			bIsRoot = menuNav._isRoot(oActiveMenu),
+			bUseAutoSubmenuDisplay = (menuNav._autoSubmenuDisplay && bIsRoot || !bIsRoot),
+			oSubmenu;
+
+
+		menuNav._setActiveItem(menuLabel);
+		menuNav._focusItem(menuLabel);
+		
+
+		if (bUseAutoSubmenuDisplay && !menuNav._movingToSubmenu) {
+	
+			menuNav._cancelHideSubmenuTimer();
+			menuNav._cancelShowSubmenuTimer();
+
+
+			if (!hasVisibleSubmenu(menuLabel)) {
+
+				oSubmenu = menuLabel.next();
+	
+
+				if (oSubmenu) {
+					
+					menuNav._hideAllSubmenus(oActiveMenu);
+
+					menuNav._showSubmenuTimer = 
+									later(menuNav._submenuShowDelay, menuNav, 
+											menuNav._showMenu, oSubmenu);
+				
+				}
+			
+			}
+		
+		}
+
+	},
+
+
+	/**
+	* @method _onMenuLabelMouseOut
+	* @description "mouseout" event handler for a menu label.
+	* @protected
+	* @param {Node} menuLabel Node instance representing a menu label.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuLabelMouseOut: function (menuLabel, event) {
+
+		var menuNav = this,
+			bIsRoot = menuNav._isRoot(menuNav._activeMenu),
+			bUseAutoSubmenuDisplay = (menuNav._autoSubmenuDisplay && bIsRoot || !bIsRoot),
+			oRelatedTarget = event.relatedTarget,
+			oSubmenu = menuLabel.next();
+
+		menuNav._clearActiveItem();
+
+		if (bUseAutoSubmenuDisplay) {
+
+			if (menuNav._movingToSubmenu && !menuNav._showSubmenuTimer && oSubmenu) {
+
+				//	If the mouse is moving diagonally toward the submenu and another submenu 
+				//	isn't in the process of being displayed (via a timer), then hide the submenu 
+				//	via a timer to give the user some time to reach the submenu.
+			
+				menuNav._hideSubmenuTimer = later(menuNav._submenuHideDelay, menuNav, 
+															menuNav._hideMenu, oSubmenu);
+			
+			}
+			else if (!menuNav._movingToSubmenu && oSubmenu && 
+				!oSubmenu.contains(oRelatedTarget) && oRelatedTarget !== oSubmenu) {
+
+				//	If the mouse is not moving toward the submenu, cancel any submenus that 
+				//	might be in the process of being displayed (via a timer) and hide this 
+				//	submenu immediately.
+
+				menuNav._cancelShowSubmenuTimer();
+
+				menuNav._hideMenu(oSubmenu);
+
+			}
+
+		}
+
+	},
+	
+
+	/**
+	* @method _onMenuItemMouseOver
+	* @description "mouseover" event handler for a menuitem.
+	* @protected
+	* @param {Node} menuItem Node instance representing a menuitem.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuItemMouseOver: function (menuItem, event) {
+
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			bIsRoot = menuNav._isRoot(oActiveMenu),
+			bUseAutoSubmenuDisplay = (menuNav._autoSubmenuDisplay && bIsRoot || !bIsRoot);
+
+
+		menuNav._setActiveItem(menuItem);
+		menuNav._focusItem(menuItem);
+
+
+		if (bUseAutoSubmenuDisplay && !menuNav._movingToSubmenu) {
+
+			menuNav._hideAllSubmenus(oActiveMenu);
+
+		}
+
+	},
+	
+
+	/**
+	* @method _onMenuItemMouseOut
+	* @description "mouseout" event handler for a menuitem.
+	* @protected
+	* @param {Node} menuItem Node instance representing a menuitem.
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMenuItemMouseOut: function (menuItem, event) {
+
+		this._clearActiveItem();
+
+	},
+
+
+	/**
+	* @method _onVerticalMenuKeyDown
+	* @description "keydown" event handler for vertical menus of a MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onVerticalMenuKeyDown: function (event) {
+
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			oRootMenu = menuNav._rootMenu,
+			oTarget = event.target,
+			oFocusedItem = getItem(oTarget, TRUE),
+			bPreventDefault = FALSE,
+			nKeyCode = event.keyCode,
+			oSubmenu,
+			oParentMenu,
+			oLI,
+			oNextItem,
+			oItem;
+
+
+		switch (nKeyCode) {
+
+			case 37:	//	left arrow
+
+				oParentMenu = getParentMenu(oActiveMenu);
+
+				if (oParentMenu && isHorizontalMenu(oParentMenu)) {
+				
+					menuNav._hideMenu(oActiveMenu);
+					oLI = getPreviousSibling(oActiveMenu.get(PARENT_NODE));
+					oItem = getItem(oLI);
+					
+					if (oItem) {
+
+						if (isMenuLabel(oItem)) {	//	Menu label
+						
+							oSubmenu = oItem.next();
+						
+
+							if (oSubmenu) {
+
+								menuNav._showMenu(oSubmenu);
+								menuNav._setActiveItem(getFirstItem(oSubmenu));
+
+							}
+							else {
+	
+								menuNav._setActiveItem(oItem);
+								focusItem(oItem);
+	
+							}
+						
+						}
+						else {	//	MenuItem
+
+							menuNav._setActiveItem(oItem);
+							focusItem(oItem);
+
+						}
+					
+					}
+
+				}
+				else if (!menuNav._isRoot(oActiveMenu)) {
+					menuNav._hideMenu(oActiveMenu, TRUE);
+				}
+
+
+				bPreventDefault = TRUE;
+
+			break;
+
+			case 39:	//	right arrow
+
+				if (isMenuLabel(oTarget)) {
+					
+					oSubmenu = oTarget.next();
+
+					if (oSubmenu) {
+						menuNav._showMenu(oSubmenu);
+						menuNav._setActiveItem(getFirstItem(oSubmenu));
+					}
+				
+				}
+				else if (isHorizontalMenu(oRootMenu)) {
+
+					oSubmenu = menuNav._getTopmostSubmenu(oActiveMenu);
+					oLI = getNextSibling(oSubmenu.get(PARENT_NODE));
+					oItem = getItem(oLI);
+
+					menuNav._hideAllSubmenus(oRootMenu);
+
+					if (oItem) {
+
+						if (isMenuLabel(oItem)) {	//	Menu label
+
+							oSubmenu = oItem.next();
+
+							if (oSubmenu) {
+
+								menuNav._showMenu(oSubmenu);
+								menuNav._setActiveItem(getFirstItem(oSubmenu));
+
+							}
+							else {
+	
+								menuNav._setActiveItem(oItem);
+								focusItem(oItem);
+	
+							}
+						
+						}
+						else {	//	MenuItem
+
+							menuNav._setActiveItem(oItem);
+							focusItem(oItem);
+
+						}							
+
+					}
+				
+				}
+
+				bPreventDefault = TRUE;
+
+			break;
+
+			case 38:	//	up arrow
+			case 40:	//	down arrow
+
+				menuNav._hideAllSubmenus(oActiveMenu);
+
+				oNextItem = nKeyCode === 38 ? 
+								getPreviousItem(oFocusedItem) : getNextItem(oFocusedItem);
+
+				menuNav._setActiveItem(oNextItem);
+				focusItem(oNextItem);
+
+				bPreventDefault = TRUE;
+
+			break;
+
+		}	
+
+
+		if (bPreventDefault) {
+
+			//	Prevent the browser from scrolling the window
+
+			event.preventDefault();			
+
+		}
+	
+	},
+	
+
+	/**
+	* @method _onHorizontalMenuKeyDown
+	* @description "keydown" event handler for horizontal menus of a MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onHorizontalMenuKeyDown: function (event) {
+
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			oTarget = event.target,
+			oFocusedItem = getItem(oTarget, TRUE),
+			bPreventDefault = FALSE,
+			nKeyCode = event.keyCode,
+			oNextItem,
+			oSubmenu;
+
+		switch (nKeyCode) {
+
+			case 37:	//	left arrow
+			case 39:	//	right arrow
+
+				menuNav._hideAllSubmenus(oActiveMenu);
+
+				oNextItem = nKeyCode === 37 ? 
+								getPreviousItem(oFocusedItem) : getNextItem(oFocusedItem);
+
+				menuNav._setActiveItem(oNextItem);
+				focusItem(oNextItem);
+
+				bPreventDefault = TRUE;
+
+			break;
+
+			case 40:	//	down arrow
+
+				menuNav._hideAllSubmenus(oActiveMenu);
+
+				if (isMenuLabel(oFocusedItem)) {
+				
+					oSubmenu = oFocusedItem.next();
+
+					if (oSubmenu) {
+						menuNav._showMenu(oSubmenu);
+						menuNav._setActiveItem(getFirstItem(oSubmenu));
+					}
+
+					bPreventDefault = TRUE;
+				
+				}
+
+			break;
+
+		}		
+
+
+		if (bPreventDefault) {
+
+			//	Prevent the browser from scrolling the window
+
+			event.preventDefault();			
+
+		}
+	
+	},
+
+
+	//	Generic DOM Event handlers
+
+
+	/**
+	* @method _onMouseMove
+	* @description "mousemove" event handler for the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMouseMove: function (event) {
+
+		var menuNav = this;
+
+		//	Using a timer to set the value of the "_currentMouseX" property helps improve the 
+		//	reliability of the calculation used to set the value of the "_movingToSubmenu"
+		//	property - especially in Opera.
+
+		later(10, menuNav, function () {
+
+			menuNav._currentMouseX = event.pageX;
+		
+		});
+	
+	},
+
+
+	/**
+	* @method _onMouseOver
+	* @description "mouseover" event handler for the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMouseOver: function (event) {
+
+		var menuNav = this,
+			oTarget,
+			oMenu,
+			oMenuLabel,
+			oParentMenu,
+			oMenuItem;
+
+
+		if (menuNav._blockMouseEvent) {
+			menuNav._blockMouseEvent = FALSE;
+		}
+		else {
+
+			oTarget = event.target;
+			oMenu = getMenu(oTarget, TRUE);
+			oMenuLabel = getMenuLabel(oTarget, TRUE);
+			oMenuItem = getMenuItem(oTarget, TRUE);
+
+
+			if (handleMouseOverForNode(oMenu, oTarget)) {
+
+				menuNav._onMenuMouseOver(oMenu, event);
+
+				oMenu[HANDLED_MOUSEOVER] = TRUE;
+				oMenu[HANDLED_MOUSEOUT] = FALSE;
+
+				oParentMenu = getParentMenu(oMenu);
+
+				if (oParentMenu) {
+
+					oParentMenu[HANDLED_MOUSEOUT] = TRUE;
+					oParentMenu[HANDLED_MOUSEOVER] = FALSE;
+		
+				}
+			
+			}
+
+			if (handleMouseOverForNode(oMenuLabel, oTarget)) {
+
+				menuNav._onMenuLabelMouseOver(oMenuLabel, event);
+
+				oMenuLabel[HANDLED_MOUSEOVER] = TRUE;
+				oMenuLabel[HANDLED_MOUSEOUT] = FALSE;
+	
+			}
+
+			if (handleMouseOverForNode(oMenuItem, oTarget)) {
+	
+				menuNav._onMenuItemMouseOver(oMenuItem, event);
+
+				oMenuItem[HANDLED_MOUSEOVER] = TRUE;
+				oMenuItem[HANDLED_MOUSEOUT] = FALSE;
+				
+			}
+
+		}
+
+	},
+
+
+	/**
+	* @method _onMouseOut
+	* @description "mouseout" event handler for the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onMouseOut: function (event) {
+			
+		var menuNav = this,
+			oActiveMenu = menuNav._activeMenu,
+			bMovingToSubmenu = FALSE,
+			oTarget,
+			oRelatedTarget,
+			oMenu,
+			oMenuLabel,
+			oSubmenu,
+			oMenuItem;
+
+
+		menuNav._movingToSubmenu = (oActiveMenu && !isHorizontalMenu(oActiveMenu) && 
+											((event.pageX - 5) > menuNav._currentMouseX));
+		
+		oTarget = event.target;
+		oRelatedTarget = event.relatedTarget;
+		oMenu = getMenu(oTarget, TRUE);
+		oMenuLabel = getMenuLabel(oTarget, TRUE);
+		oMenuItem = getMenuItem(oTarget, TRUE);
+
+
+		if (handleMouseOutForNode(oMenuLabel, oRelatedTarget)) {
+
+			menuNav._onMenuLabelMouseOut(oMenuLabel, event);
+
+			oMenuLabel[HANDLED_MOUSEOUT] = TRUE;
+			oMenuLabel[HANDLED_MOUSEOVER] = FALSE;
+
+		}
+
+		if (handleMouseOutForNode(oMenuItem, oRelatedTarget)) {
+
+			menuNav._onMenuItemMouseOut(oMenuItem, event);
+
+			oMenuItem[HANDLED_MOUSEOUT] = TRUE;
+			oMenuItem[HANDLED_MOUSEOVER] = FALSE;
+			
+		}
+
+
+		if (oMenuLabel) {
+
+			oSubmenu = oMenuLabel.next();
+
+			if (oSubmenu && (oRelatedTarget === oSubmenu || oSubmenu.contains(oRelatedTarget))) {
+
+				bMovingToSubmenu = TRUE;
+
+			}
+		
+		}
+		
+
+		if (handleMouseOutForNode(oMenu, oRelatedTarget) || bMovingToSubmenu) {
+
+			menuNav._onMenuMouseOut(oMenu, event);				
+
+			oMenu[HANDLED_MOUSEOUT] = TRUE;
+			oMenu[HANDLED_MOUSEOVER] = FALSE;
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _toggleSubmenuDisplay
+	* @description "mousedown," "keydown," and "click" event handler for the MenuNav used to 
+	* toggle the display of a submenu.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_toggleSubmenuDisplay: function (event) {
+
+		var menuNav = this,
+			oTarget = event.target,
+			oMenuLabel = getMenuLabel(oTarget, TRUE),
+			sType = event.type,
+			oAnchor,
+			oSubmenu,
+			sHref,
+			nHashPos,
+			nLen,
+			sId;
+
+
+		if (oMenuLabel) {
+
+			oAnchor = isAnchor(oTarget) ? oTarget : oTarget.ancestor(isAnchor);
+			
+
+			if (oAnchor) {
+
+				//	Need to pass "2" as a second argument to "getAttribute" for IE otherwise IE 
+				//	will return a fully qualified URL for the value of the "href" attribute.
+				//	http://msdn.microsoft.com/en-us/library/ms536429(VS.85).aspx
+
+				sHref = oAnchor.getAttribute("href", 2);
+				nHashPos = sHref.indexOf("#");
+				nLen = sHref.length;
+
+				if (nHashPos === 0 && nLen > 1) {
+
+					sId = sHref.substr(1, nLen);
+					oSubmenu = oMenuLabel.next();
+
+					if (oSubmenu && (oSubmenu.get(ID) === sId)) {
+
+
+						if (sType === MOUSEDOWN || (sType === KEYDOWN && event.keyCode === 13)) {
+
+							//	The call to "preventDefault" below results in the element 
+							//	serving as the menu's label to not receive focus in Webkit, 
+							//	therefore the "_hasFocus" flag never gets set to true, meaning the 
+							//	first item in the submenu isn't focused when the submenu is 
+							//	displayed.  To fix this issue, it is necessary to set the 
+							//	"_hasFocus" flag to true.
+	
+							if (UA.webkit && !menuNav._hasFocus) {
+								menuNav._hasFocus = TRUE;
+							}
+
+
+							if (hasVisibleSubmenu(oMenuLabel)) {
+								menuNav._hideMenu(oSubmenu);
+								focusItem(oMenuLabel);
+							}
+							else {
+								menuNav._hideAllSubmenus(menuNav._rootMenu);
+								menuNav._showMenu(oSubmenu);
+							}
+						
+						}
+
+
+						if (sType === CLICK) {
+
+							//	Prevent the browser from following the URL of the anchor element
+							
+							event.preventDefault();
+						
+						}
+					
+					}
+				
+				}				
+
+
+			}
+		
+		}
+	
+	},
+	
+
+	/**
+	* @method _onKeyPress
+	* @description "keypress" event handler for the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onKeyPress: function (event) {
+	
+		switch (event.keyCode) {
+
+			case 37:	//	left arrow
+			case 38:	//	up arrow
+			case 39:	//	right arrow
+			case 40:	//	down arrow
+
+				//	Prevent the browser from scrolling the window
+
+				event.preventDefault();
+
+			break;
+
+		}						
+
+	},	
+
+
+	/**
+	* @method _onKeyDown
+	* @description "keydown" event handler for the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onKeyDown: function (event) {
+
+		var menuNav = this,
+			oActiveItem = menuNav._activeItem,
+			oTarget = event.target,
+			oActiveMenu = getParentMenu(oTarget),
+			oSubmenu;
+
+		if (oActiveMenu) {
+
+			menuNav._activeMenu = oActiveMenu;
+
+			if (isHorizontalMenu(oActiveMenu)) {
+				menuNav._onHorizontalMenuKeyDown(event);
+			}
+			else {
+				menuNav._onVerticalMenuKeyDown(event);
+			}
+
+
+			if (event.keyCode === 27) {
+
+				if (!menuNav._isRoot(oActiveMenu)) {
+
+					menuNav._hideMenu(oActiveMenu, TRUE);
+					event.stopPropagation();
+					menuNav._blockMouseEvent = UA.gecko ? TRUE : FALSE;
+
+				}
+				else if (oActiveItem) {
+
+					if (isMenuLabel(oActiveItem) && hasVisibleSubmenu(oActiveItem)) {
+					
+						oSubmenu = oActiveItem.next();
+
+						if (oSubmenu) {
+							menuNav._hideMenu(oSubmenu);
+						}
+
+					}
+					else {
+
+						blurItem(oTarget);
+						menuNav._clearActiveItem();
+					
+					}
+
+				}
+			
+			}
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _onDocMouseDown
+	* @description "mousedown" event handler for the owner document of the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onDocMouseDown: function (event) {
+	
+		var menuNav = this,
+			oRoot = menuNav._rootMenu,
+			oTarget = event.target;
+
+
+		if (!oRoot.compareTo(oTarget) && !oRoot.contains(oTarget)) {
+		
+			menuNav._hideAllSubmenus(oRoot);
+
+
+			//	Document doesn't receive focus in Webkit when the user mouses down on it, 
+			//	so the "_hasFocus" property won't get set to the correct value.  The 
+			//	following line corrects the problem.
+
+			if (UA.webkit) {
+				menuNav._hasFocus = FALSE;
+				menuNav._clearActiveItem();
+			}
+		
+		}
+	
+	},
+
+
+	/**
+	* @method _onDocFocus
+	* @description "focus" event handler for the owner document of the MenuNav.
+	* @protected
+	* @param {Object} event Object representing the DOM event.
+	*/
+	_onDocFocus: function (event) {
+	
+		var menuNav = this,
+			bUseARIA = menuNav._useARIA,
+			oFirstItem = menuNav._firstItem,
+			oActiveItem = menuNav._activeItem,
+			oTarget = event.target;
+
+		
+		if (menuNav._rootMenu.contains(oTarget)) {	//	The menu has focus
+
+			if (!menuNav._hasFocus) {	//	Initial focus
+
+				//	First time the menu has been focused, need to setup focused state and  
+				//	established active active descendant
+	
+				menuNav._hasFocus = TRUE;
+	
+				oActiveItem = getItem(oTarget, TRUE);
+	
+				if (oActiveItem) {	
+					menuNav._setActiveItem(oActiveItem);
+				}
+			
+			}
+		
+		}
+		else {	//	The menu has lost focus
+
+			menuNav._clearActiveItem();
+			
+			menuNav._hasFocus = FALSE;
+
+
+			if (oFirstItem && bUseARIA) {
+			
+				placeInDefaultTabIndex(getItemAnchor(oFirstItem));
+
+			}
+
+		}
+	
+	}
+
+};
+
+
+Y.namespace('plugin');
+
+Y.plugin.NodeMenuNav = MenuNav;
+
+
+}, '3.0.0pr2' ,{requires:['node', 'classnamemanager']});

=== added file 'loggerhead/static/javascript/yui/build/node/README'
--- loggerhead/static/javascript/yui/build/node/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,13 @@
+**** version 3.0.0 PR2 ***
+
+* Node instances now have NodeList api
+
+* Y.all now returns null for non-matching queries (symmetry with "Y.get")
+
+* deep setters/getters now supported (Y.get('#foo').get('firstSibling.innerHTML'))
+
+* window can now be a Node instance 
+
+**** version 3.0.0 PR1 ***
+
+* initial 3.0 revision

=== added file 'loggerhead/static/javascript/yui/build/node/node-base-debug.js'
--- loggerhead/static/javascript/yui/build/node/node-base-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-base-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,914 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node-base', function(Y) {
+
+    /**
+     * The Node Utility provides a DOM-like interface for interacting with DOM nodes.
+     * @module node
+     * @submodule node-base
+     */    
+
+    /**
+     * The Node class provides a wrapper for manipulating DOM Nodes.
+     * Node properties can be accessed via the set/get methods.
+     * Use Y.get() to retrieve Node instances.
+     *
+     * <strong>NOTE:</strong> Node properties are accessed using
+     * the <code>set</code> and <code>get</code> methods.
+     *
+     * @class Node
+     * @constructor
+     */
+
+    var OWNER_DOCUMENT = 'ownerDocument',
+        TAG_NAME = 'tagName',
+        NODE_NAME = 'nodeName',
+        NODE_TYPE = 'nodeType',
+
+        Selector = Y.Selector,
+        _instances = {},
+        _restrict = {},
+        _slice = [].slice;
+
+    // used with previous/next/ancestor tests
+    var _wrapFn = function(fn) {
+        var ret = null;
+        if (fn) {
+            ret = (typeof fn === 'string') ?
+            function(n) {
+                return Y.Selector.test(n, fn);
+            } : 
+            function(n) {
+                return fn(Y.get(n));
+            };
+        }
+
+        return ret;
+    };
+
+    var _getDoc = function(node) {
+        var doc = Y.config.doc;
+
+        if (node) {
+            if (node[NODE_TYPE]) {
+                if (node[NODE_TYPE] === 9) { // already a document node
+                    doc = node;
+                } else {
+                    doc = node[OWNER_DOCUMENT];
+                }
+            } else if (Node[node._yuid]) { // Node instance document
+                doc = Node[node._yuid]()[0];
+            }
+        }
+
+        return doc;
+    };
+
+    var _getDOMNode = function(node) {
+        if (node && !node[NODE_TYPE] && node._yuid) {
+            node = Node[node._yuid]()[0];
+        }
+
+        return  node || null;
+    };
+
+    var Node = function() {
+        this.init.apply(this, arguments);
+    };
+
+    Node.PLUGINS = {};
+
+    Node._deepGet = function (path, val) {
+        var pl = path.length,
+            i;
+
+        if (pl > 0) {
+            for (i = 0; val !== undefined && i < pl; ++i) {
+                val = val[path[i]];
+            }
+        }
+
+        return val;
+    };
+
+    Node._deepSet = function(path, val, subval) {
+        var leafIdx = path.length-1,
+            i,
+            o;
+
+        if (leafIdx >= 0) {
+            o = val;
+
+            for (i = 0; o !== undefined && i < leafIdx; ++i) {
+                o = o[path[i]];
+            }
+
+            if (o !== undefined && o[path[i]] !== undefined) {
+                o[path[i]] = subval;
+            }
+        }
+    };
+
+    Node.scrubVal = function(val, node, depth) {
+        if (val !== undefined) {
+            if (typeof val === 'object' || typeof val === 'function') { // safari nodeList === function
+                if (val !== null && (
+                        NODE_TYPE in val || // dom node
+                        val.item || // dom collection or Node instance
+                        (val[0] && val[0][NODE_TYPE]) || // assume array of nodes
+                        val.document) // window TODO: restrict?
+                    ) { 
+                    if (node && _restrict && _restrict[node._yuid] && !node.contains(val)) {
+                        val = null; // not allowed to go outside of root node
+                    } else {
+                        if (val[NODE_TYPE] || val.document) { // node or window
+                            val = Node.get(val);
+                        } else {
+                            val = Node.all(val);
+                        }
+                    }
+                } else {
+                    depth = (depth === undefined) ? 4 : depth;
+                    if (depth > 0) {
+                        for (var i in val) {
+                            if (val.hasOwnProperty && val.hasOwnProperty(i)) {
+                                val[i] = Node.scrubVal(val[i], node, --depth);
+                            }
+                        }
+                    }
+                    
+                }
+            }
+        } else {
+            val = node; // for chaining
+        }
+
+        return val;
+    };
+
+    Node.setters = {};
+    Node.getters = {
+        /**
+         * Normalizes nodeInnerText and textContent. 
+         * @property text
+         * @type String
+         */
+        'text': function(node) {
+            return Y.DOM.getText(node);
+        },
+
+        'options': function(node) {
+            return (node) ? node.getElementsByTagName('option') : [];
+        },
+
+        /**
+         * Returns a NodeList instance. 
+         * @property children
+         * @type NodeList
+         */
+        'children': function(node) {
+            var children = node.children;
+
+            if (children === undefined) {
+                var childNodes = node.childNodes;
+                children = [];
+
+                for (var i = 0, len = childNodes.length; i < len; ++i) {
+                    if (childNodes[i][TAG_NAME]) {
+                        children[children.length] = childNodes[i];
+                    }
+                }
+            }
+            return children;
+        }
+    };
+
+    Node.methods = function(name, fn) {
+        if (typeof name == 'string') {
+            Node.prototype[name] = function() {
+                var args = _slice.call(arguments, 0),
+                    instance = this,
+                    getAll =  (_instances[this._yuid]) ? false : true, // return array of vals for lists
+                    ret = (getAll) ? [] : null,
+                    val;
+
+                var getValue = function(node) {
+                    args[0] = node;
+                    val = Node.scrubVal(fn.apply(instance, args), instance);
+                    if (getAll) {
+                        ret[ret.length] = val;
+                    } else {
+                        ret = val;
+                    }
+                };
+
+                args.unshift('');
+                Node[instance._yuid](getValue);
+                return ret;
+            };
+        } else { // assume object
+            Y.each(name, function(fn, name) {
+                Node.methods(name, fn);
+            });
+        }
+
+    };
+
+    Node.getDOMNode = _getDOMNode;
+    
+    Node.wrapDOMMethod = function(name) {
+        return function() {
+            return Y.DOM[name].apply(Y.DOM, arguments);
+        };
+
+    };
+
+    Node.addDOMMethods = function(methods) {
+        var add = {}; 
+        Y.each(methods, function(v, n) {
+            add[v] = Y.Node.wrapDOMMethod(v);
+        });
+
+        Y.Node.methods(add);
+    };
+
+    Node.prototype = {
+        init: function(nodes, doc, isRoot, getAll) {
+            var uid;
+
+            doc = _getDoc(doc);
+
+            this.getId = function() {
+                return uid;
+            };
+
+            var _all = function(fn, i) {
+                if (fn) {
+                    i = i || 0;
+                    for (var node; node = nodes[i++];) {
+                        fn(node);
+                    }
+                }
+                return nodes;
+            };
+
+            // uid = selector || Y.guid(); // to cache queryAll results
+            uid = Y.guid();
+
+            if (nodes) { // zero length collection returns null
+                if (nodes[NODE_TYPE] || nodes.document) { // node or window
+                    nodes = [nodes];
+                }
+            } else {
+                nodes = [];
+            }
+
+            if (!getAll && nodes.length) { // stamp the dom node
+                try { // IE only allows ID on Element
+                    if (nodes[0].uniqueID) {
+                        uid = nodes[0].uniqueID;
+                    }
+                    nodes[0]._yuid = uid;
+                } catch(e) { // not cacheable
+                    Y.log(nodes[0] + ' is not cacheable', 'warn', 'Node'); 
+                }
+            }
+
+            this._yuid = uid;
+            Node[uid] = _all; // for applying/returning dom nodes
+
+            if (!getAll) {
+                _instances[uid] = this;
+            }
+
+            this.initPlugins();
+        },
+
+        initPlugins: function() {
+            Y.each(Node.PLUGINS, function(config, fn) {
+                this.plug(fn, config);
+            });
+        },
+
+        /**
+         * Filters the NodeList instance down to only nodes matching the given selector.
+         * @method filter
+         * @param {String} selector The selector to filter against
+         * @return {NodeList} NodeList containing the updated collection 
+         * @see Selector
+         */
+        filter: function(selector) {
+            return Node.scrubVal(Selector.filter(Node[this._yuid](), selector), this);
+        },
+
+        /**
+         * Applies the given function to each Node in the NodeList.
+         * @method each
+         * @param {Function} fn The function to apply 
+         * @param {Object} context optional An optional context to apply the function with
+         * Default context is the NodeList instance
+         * @return {NodeList} NodeList containing the updated collection 
+         * @chainable
+         */
+        each: function(fn, context) {
+            context = context || this;
+            Node[this._yuid](function(node) {
+                fn.call(context, Node.get(node));
+            });
+        },
+
+        /**
+         * Returns the current number of items in the NodeList.
+         * @method size
+         * @return {Int} The number of items in the NodeList. 
+         */
+        size: function() {
+            return Node[this._yuid]().length;
+        },
+
+        /**
+         * Retrieves the Node instance at the given index. 
+         * @method item
+         *
+         * @param {Number} index The index of the target Node.
+         * @return {Node} The Node instance at the given index.
+         */
+        item: function(index) {
+            var node = Node[this._yuid]()[index];
+            return Node.get(node);
+        },
+
+       /**
+         * Attaches a DOM event handler.
+         * @method attach
+         * @param {String} type The type of DOM Event to listen for 
+         * @param {Function} fn The handler to call when the event fires 
+         * @param {Object} arg An argument object to pass to the handler 
+         */
+
+        attach: function(type, fn, arg) {
+            var args = _slice.call(arguments, 0);
+            args.splice(2, 0, Node[this._yuid]());
+            return Y.Event.attach.apply(Y.Event, args);
+        },
+
+       /**
+         * Alias for attach.
+         * @method on
+         * @param {String} type The type of DOM Event to listen for 
+         * @param {Function} fn The handler to call when the event fires 
+         * @param {Object} arg An argument object to pass to the handler 
+         * @see attach
+         */
+        on: function(type, fn, arg) {
+            return this.attach.apply(this, arguments);
+        },
+
+       /**
+         * Detaches a DOM event handler. 
+         * @method detach
+         * @param {String} type The type of DOM Event
+         * @param {Function} fn The handler to call when the event fires 
+         */
+        detach: function(type, fn) {
+            var args = _slice.call(arguments, 0);
+            args.splice(2, 0, Node[this._yuid]());
+            return Y.Event.detach.apply(Y.Event, args);
+        },
+
+       /**
+         * Creates a Node instance from HTML string
+         * @method create
+         * @param {String|Array} html The string of html to create
+         * @return {Node} A new Node instance 
+         */
+        create: function(html) {
+            return Y.Node.create(html);
+        },
+
+        /**
+         * Applies the supplied plugin to the node.
+         * @method plug
+         * @param {Function} The plugin Class to apply
+         * @param {Object} config An optional config to pass to the constructor
+         * @chainable
+         */
+        plug: function(PluginClass, config) {
+            config = config || {};
+            config.owner = this;
+            if (PluginClass && PluginClass.NS) {
+                this[PluginClass.NS] = new PluginClass(config);
+            }
+            return this;
+        },
+
+        //normalize: function() {},
+        //isSupported: function(feature, version) {},
+        toString: function() {
+            var str = '', 
+            node = Node[this._yuid]()[0] || {};
+
+            if (node) {
+                str += node[NODE_NAME];
+                if (node.id) {
+                    str += '#' + node.id; 
+                }
+
+                if (node.className) {
+                    str += '.' + node.className.replace(' ', '.'); 
+                }
+            } else {
+                'no nodes for ' + this._yuid;
+            }
+            return str;
+        }
+    };
+
+    Node.methods({
+        addEventListener: function() {
+            return Y.Event.nativeAdd.apply(Y.Event, arguments);
+        },
+        
+        removeEventListener: function() {
+            return Y.Event.nativeRemove.apply(Y.Event, arguments);
+        },
+
+        /**
+         * Set the value of the property/attribute on the HTMLElement bound to this Node.
+         * Only strings/numbers/booleans are passed through unless a SETTER exists.
+         * @method set
+         * @param {String} prop Property to set 
+         * @param {any} val Value to apply to the given property
+         * @chainable
+         */
+        // TODO: document.location.href
+        set: function(node, prop, val) {
+            if (prop.indexOf('.') < 0) {
+                if (prop in Node.setters) { // use custom setter
+                    Node.setters[prop](this, prop, val);  // passing Node instance
+                } else if (node[prop] !== undefined) { // no expandos 
+                    node[prop] = val;
+                } else {
+                    Y.log(prop + ' not in ' + node, 'warn', 'Node');
+                }
+            } else {
+                Node._deepSet(prop.split('.'), node, val);
+            }
+        },
+
+        /**
+         * Get the value of the property/attribute on the HTMLElement bound to this Node.
+         * Only strings/numbers/booleans are passed through unless a GETTER exists.
+         * @method get
+         * @param {String} prop Property to get 
+         * @return {any} Current value of the property
+         */
+        get: function(node, prop) {
+            var val;
+            if (prop.indexOf('.') < 0) {
+                if (prop in Node.getters) { // use custom getter
+                    val = Node.getters[prop].call(this, node, prop);
+                } else {
+                    val = node[prop];
+                }
+
+                // method wrapper uses undefined in chaining test
+                if (val === undefined) {
+                    val = null;
+                }
+            } else {
+                val = Node._deepGet(prop.split('.'), node);
+            }
+
+            return val;
+        },
+
+        invoke: function(node, method, a, b, c, d, e) {
+            var ret;
+
+            if (a) { // first 2 may be Node instances
+                a = (a[NODE_TYPE]) ? a : _getDOMNode(a);
+                if (b) {
+                    b = (b[NODE_TYPE]) ? b : _getDOMNode(b);
+                }
+            }
+
+            ret = node[method](a, b, c, d, e);    
+            return ret;
+        },
+
+        hasMethod: function(node, method) {
+            return !! node[method];
+        },
+
+        /**
+         * Retrieves a Node instance of nodes based on the given CSS selector. 
+         * @method query
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {Node} A Node instance for the matching HTMLElement.
+         */
+        query: function(node, selector) {
+            var ret = Selector.query(selector, node, true);
+            if (!ret) {
+                ret = null;
+            }
+
+            return ret;
+        },
+
+        /**
+         * Retrieves a nodeList based on the given CSS selector. 
+         * @method queryAll
+         * @deprecated Use query() which returns all matches
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {NodeList} A NodeList instance for the matching HTMLCollection/Array.
+         */
+        queryAll: function(node, selector) {
+            var ret = Selector.query(selector, node);
+            if (!ret.length) {
+                ret = null;
+            }
+
+            return ret;
+        },
+
+        /**
+         * Test if the supplied node matches the supplied selector.
+         * @method test
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {boolean} Whether or not the node matches the selector.
+         */
+        test: function(node, selector) {
+            return Selector.test(node, selector);
+        },
+
+        /**
+         * Compares nodes to determine if they match.
+         * Node instances can be compared to each other and/or HTMLElements.
+         * @method compareTo
+         * @param {HTMLElement | Node} refNode The reference node to compare to the node.
+         * @return {Boolean} True if the nodes match, false if they do not. 
+         */
+        compareTo: function(node, refNode) {
+            refNode = _getDOMNode(refNode) || node;
+            return node === refNode;
+        },
+
+       /**
+         * Returns the nearest ancestor that passes the test applied by supplied boolean method.
+         * @method ancestor
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @return {Node} The matching Node instance or null if not found
+         */
+        ancestor: function(node, fn) {
+            return Y.DOM.elementByAxis(node, 'parentNode', _wrapFn(fn));
+        },
+
+        /**
+         * Returns the previous matching sibling. 
+         * Returns the nearest element node sibling if no method provided.
+         * @method previous
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+         * @return {Node} Node instance or null if not found
+         */
+        previous: function(node, fn, all) {
+            return Y.DOM.elementByAxis(node, 'previousSibling', _wrapFn(fn), all);
+        }, 
+
+        /**
+         * Returns the next matching sibling. 
+         * Returns the nearest element node sibling if no method provided.
+         * @method next
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+         * @return {Node} Node instance or null if not found
+         */
+        next: function(node, fn, all) {
+            return Y.DOM.elementByAxis(node, 'nextSibling', _wrapFn(fn), all);
+        },
+        
+        /**
+         * Determines whether the ndoe is an ancestor of another HTML element in the DOM hierarchy.
+         * @method contains
+         * @param {Node | HTMLElement} needle The possible node or descendent
+         * @return {Boolean} Whether or not this node is the needle its ancestor
+         */
+        contains: function(node, needle) {
+            return Y.DOM.contains(node, _getDOMNode(needle));
+        },
+
+        /**
+         * Determines whether the node is appended to the document.
+         * @method inDoc
+         * @param {Node|HTMLElement} doc optional An optional document to check against.
+         * Defaults to current document. 
+         * @return {Boolean} Whether or not this node is appended to the document. 
+         */
+        inDoc: function(node, doc) {
+            doc = (doc) ? _getDoc(doc) : node.ownerDocument;
+            if (doc.documentElement) {
+                return Y.DOM.contains(doc.documentElement, node);
+            }
+        },
+
+        byId: function(node, id) {
+            var ret = node[OWNER_DOCUMENT].getElementById(id);
+            if (!ret || !Y.DOM.contains(node, ret)) {
+                ret = null;
+            }
+            return ret;
+        }
+
+    });
+
+    /** 
+     * Creates a Node instance from an HTML string
+     * @method create
+     * @param {String} html HTML string
+     */
+    Node.create = function(html) {
+        return Node.get(Y.DOM.create(html));
+    };
+
+    Node.getById = function(id, doc) {
+        doc = (doc && doc[NODE_TYPE]) ? doc : Y.config.doc;
+        return Node.get(doc.getElementById(id));
+    };
+
+    /**
+     * Retrieves a Node instance for the given query or nodes. 
+     * Note: Use 'document' string to retrieve document Node instance from string
+     * @method Y.get
+     * @static
+     * @param {document|HTMLElement|HTMLCollection|Array|String} node The object to wrap.
+     * @param {document|Node} doc optional The document containing the node. Defaults to current document.
+     * @param {boolean} isRoot optional Whether or not this node should be treated as a root node. Root nodes
+     * aren't allowed to traverse outside their DOM tree.
+     * @return {Node} A Node instance bound to the supplied node(s).
+     */
+    Node.get = function(node, doc, isRoot, getAll) {
+        var instance;
+
+        if (node) {
+            if (typeof node === 'string') {
+                if (node === 'document') { // TODO: allow 'doc'? 'window'?
+                    node = [Y.config.doc];
+                } else {
+                    node = Selector.query(node, doc, !getAll); // Selector arg is getFirst
+                }
+            }
+
+            if (node) {
+                if (!getAll) { // reuse single element node instances
+                    if (node._yuid) {
+                        // verify IE's uniqueID in case the node was cloned
+                        if (!node.uniqueID || (node.uniqueID === node._yuid)) {
+                            instance = _instances[node._yuid];
+                        }
+                    }
+                }
+
+                if (!instance) {
+                    instance = new Node(node, doc, isRoot, getAll);
+                }
+
+                if (instance && isRoot && !getAll) {
+                    _restrict[instance._yuid] = true;
+                }
+            }
+        }
+
+        // zero length collection returns null
+        return (instance && instance.size()) ? instance : null;
+    };
+
+    /**
+     * Retrieves a NodeList instance for the given object/string. 
+     * @method Y.all
+     * @static
+     * @param {HTMLCollection|Array|String} node The object to wrap.
+     * @param {document|Node} doc optional The document containing the node. Defaults to current document.
+     * @param {boolean} isRoot optional Whether or not this node should be treated as a root node. Root nodes
+     * @return {NodeList} A NodeList instance for the supplied nodes.
+     */
+    Node.all = function(node, doc, isRoot) {
+        return Node.get.call(Node, node, doc, isRoot, true);
+    };
+
+    Y.Array.each([
+        /**
+         * Passes through to DOM method.
+         * @method replaceChild
+         * @param {HTMLElement | Node} node Node to be inserted 
+         * @param {HTMLElement | Node} refNode Node to be replaced 
+         * @return {Node} The replaced node 
+         */
+        'replaceChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method appendChild
+         * @param {HTMLElement | Node} node Node to be appended 
+         * @return {Node} The appended node 
+         */
+        'appendChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method insertBefore
+         * @param {HTMLElement | Node} newNode Node to be appended 
+         * @param {HTMLElement | Node} refNode Node to be inserted before 
+         * @return {Node} The inserted node 
+         */
+        'insertBefore',
+
+        /**
+         * Passes through to DOM method.
+         * @method removeChild
+         * @param {HTMLElement | Node} node Node to be removed 
+         * @return {Node} The removed node 
+         */
+        'removeChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method hasChildNodes
+         * @return {Boolean} Whether or not the node has any childNodes 
+         */
+        'hasChildNodes',
+
+        /**
+         * Passes through to DOM method.
+         * @method cloneNode
+         * @param {HTMLElement | Node} node Node to be cloned 
+         * @return {Node} The clone 
+         */
+        'cloneNode',
+
+        /**
+         * Passes through to DOM method.
+         * @method getAttribute
+         * @param {String} attribute The attribute to retrieve 
+         * @return {String} The current value of the attribute 
+         */
+        'getAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method setAttribute
+         * @param {String} attribute The attribute to set 
+         * @param {String} The value to apply to the attribute 
+         * @chainable
+         */
+        'setAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method hasAttribute
+         * @param {String} attribute The attribute to test for 
+         * @return {Boolean} Whether or not the attribute is present 
+         */
+        'hasAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method removeAttribute
+         * @param {String} attribute The attribute to be removed 
+         * @chainable
+         */
+        'removeAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method scrollIntoView
+         * @chainable
+         */
+        'scrollIntoView',
+
+        /**
+         * Passes through to DOM method.
+         * @method getElementsByTagName
+         * @param {String} tagName The tagName to collect 
+         * @return {NodeList} A NodeList representing the HTMLCollection
+         */
+        'getElementsByTagName',
+
+        /**
+         * Passes through to DOM method.
+         * @method focus
+         * @chainable
+         */
+        'focus',
+
+        /**
+         * Passes through to DOM method.
+         * @method blur
+         * @chainable
+         */
+        'blur',
+
+        /**
+         * Passes through to DOM method.
+         * Only valid on FORM elements
+         * @method submit
+         * @chainable
+         */
+        'submit',
+
+        /**
+         * Passes through to DOM method.
+         * Only valid on FORM elements
+         * @method reset
+         * @chainable
+         */
+        'reset',
+
+        /**
+         * Passes through to DOM method.
+         * @method select
+         * @chainable
+         */
+         'select'
+    ], function(method) {
+        Node.prototype[method] = function(arg1, arg2, arg3) {
+            var ret = this.invoke(method, arg1, arg2, arg3);
+            return ret;
+        };
+    });
+
+    if (!document.documentElement.hasAttribute) {
+        Node.methods({
+            'hasAttribute': function(node, att) {
+                return !! node.getAttribute(att);
+            }
+        });
+    }
+
+    // used to call Node methods against NodeList nodes
+    Y.Node = Node;
+    Y.all = Y.Node.all;
+    Y.get = Y.Node.get;
+/**
+ * Extended Node interface for managing classNames.
+ * @module node
+ * @submodule node
+ * @for Node
+ */
+
+    Y.Node.addDOMMethods([
+        /**
+         * Determines whether the node has the given className.
+         * @method hasClass
+         * @param {String} className the class name to search for
+         * @return {Boolean} Whether or not the node has the given class. 
+         */
+        'hasClass',
+
+        /**
+         * Adds a class name to the node.
+         * @method addClass         
+         * @param {String} className the class name to add to the node's class attribute
+         * @chainable
+         */
+        'addClass',
+
+        /**
+         * Removes a class name from the node.
+         * @method removeClass         
+         * @param {String} className the class name to remove from the node's class attribute
+         * @chainable
+         */
+        'removeClass',
+
+        /**
+         * Replace a class with another class.
+         * If no oldClassName is present, the newClassName is simply added.
+         * @method replaceClass  
+         * @param {String} oldClassName the class name to be replaced
+         * @param {String} newClassName the class name that will be replacing the old class name
+         * @chainable
+         */
+        'replaceClass',
+
+        /**
+         * If the className exists on the node it is removed, if it doesn't exist it is added.
+         * @method toggleClass  
+         * @param {String} className the class name to be toggled
+         * @chainable
+         */
+        'toggleClass'
+    ]);
+
+
+}, '3.0.0pr2' ,{requires:['dom-base', 'selector']});

=== added file 'loggerhead/static/javascript/yui/build/node/node-base-min.js'
--- loggerhead/static/javascript/yui/build/node/node-base-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-base-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("node-base",function(C){var B="ownerDocument",H="tagName",E="nodeName",J="nodeType",A=C.Selector,M={},D={},L=[].slice;var K=function(O){var N=null;if(O){N=(typeof O==="string")?function(P){return C.Selector.test(P,O);}:function(P){return O(C.get(P));};}return N;};var I=function(N){var O=C.config.doc;if(N){if(N[J]){if(N[J]===9){O=N;}else{O=N[B];}}else{if(G[N._yuid]){O=G[N._yuid]()[0];}}}return O;};var F=function(N){if(N&&!N[J]&&N._yuid){N=G[N._yuid]()[0];}return N||null;};var G=function(){this.init.apply(this,arguments);};G.PLUGINS={};G._deepGet=function(P,Q){var O=P.length,N;if(O>0){for(N=0;Q!==undefined&&N<O;++N){Q=Q[P[N]];}}return Q;};G._deepSet=function(Q,S,P){var O=Q.length-1,N,R;if(O>=0){R=S;for(N=0;R!==undefined&&N<O;++N){R=R[Q[N]];}if(R!==undefined&&R[Q[N]]!==undefined){R[Q[N]]=P;}}};G.scrubVal=function(Q,O,P){if(Q!==undefined){if(typeof Q==="object"||typeof Q==="function"){if(Q!==null&&(J in Q||Q.item||(Q[0]&&Q[0][J])||Q.document)){if(O&&D&&D[O._yuid]&&!O.contains(Q)){Q=null;}else{if(Q[J]||Q.document){Q=G.get(Q);}else{Q=G.all(Q);}}}else{P=(P===undefined)?4:P;if(P>0){for(var N in Q){if(Q.hasOwnProperty&&Q.hasOwnProperty(N)){Q[N]=G.scrubVal(Q[N],O,--P);}}}}}}else{Q=O;}return Q;};G.setters={};G.getters={"text":function(N){return C.DOM.getText(N);},"options":function(N){return(N)?N.getElementsByTagName("option"):[];},"children":function(Q){var P=Q.children;if(P===undefined){var R=Q.childNodes;P=[];for(var O=0,N=R.length;O<N;++O){if(R[O][H]){P[P.length]=R[O];}}}return P;}};G.methods=function(N,O){if(typeof N=="string"){G.prototype[N]=function(){var S=L.call(arguments,0),P=this,T=(M[this._yuid])?false:true,R=(T)?[]:null,U;var Q=function(V){S[0]=V;U=G.scrubVal(O.apply(P,S),P);if(T){R[R.length]=U;}else{R=U;}};S.unshift("");G[P._yuid](Q);return R;};}else{C.each(N,function(Q,P){G.methods(P,Q);});}};G.getDOMNode=F;G.wrapDOMMethod=function(N){return function(){return C.DOM[N].apply(C.DOM,arguments);};};G.addDOMMethods=function(N){var O={};C.each(N,function(P,Q){O[P]=C.Node.wrapDOMMethod(P);});C.Node.methods(O);};G.prototype={init:function(O,T,N,Q){var P;T=I(T);this.getId=function(){return P;};var R=function(V,U){if(V){U=U||0;for(var W;W=O[U++];){V(W);}}return O;};P=C.guid();if(O){if(O[J]||O.document){O=[O];}}else{O=[];}if(!Q&&O.length){try{if(O[0].uniqueID){P=O[0].uniqueID;}O[0]._yuid=P;}catch(S){}}this._yuid=P;G[P]=R;if(!Q){M[P]=this;}this.initPlugins();},initPlugins:function(){C.each(G.PLUGINS,function(N,O){this.plug(O,N);});},filter:function(N){return G.scrubVal(A.filter(G[this._yuid](),N),this);},each:function(O,N){N=N||this;G[this._yuid](function(P){O.call(N,G.get(P));});},size:function(){return G[this._yuid]().length;},item:function(N){var O=G[this._yuid]()[N];return G.get(O);},attach:function(Q,P,N){var O=L.call(arguments,0);O.splice(2,0,G[this._yuid]());return C.Event.attach.apply(C.Event,O);},on:function(P,O,N){return this.attach.apply(this,arguments);},detach:function(P,O){var N=L.call(arguments,0);N.splice(2,0,G[this._yuid]());return C.Event.detach.apply(C.Event,N);},create:function(N){return C.Node.create(N);},plug:function(O,N){N=N||{};N.owner=this;if(O&&O.NS){this[O.NS]=new O(N);}return this;},toString:function(){var O="",N=G[this._yuid]()[0]||{};if(N){O+=N[E];if(N.id){O+="#"+N.id;}if(N.className){O+="."+N.className.replace(" ",".");}}else{"no nodes for "+this._yuid;}return O;}};G.methods({addEventListener:function(){return C.Event.nativeAdd.apply(C.Event,arguments);},removeEventListener:function(){return C.Event.nativeRemove.apply(C.Event,arguments);},set:function(N,P,O){if(P.indexOf(".")<0){if(P in G.setters){G.setters[P](this,P,O);}else{if(N[P]!==undefined){N[P]=O;}else{}}}else{G._deepSet(P.split("."),N,O);}},get:function(N,P){var O;if(P.indexOf(".")<0){if(P in G.getters){O=G.getters[P].call(this,N,P);}else{O=N[P];}if(O===undefined){O=null;}}else{O=G._deepGet(P.split("."),N);}return O;},invoke:function(Q,U,O,N,T,S,R){var P;if(O){O=(O[J])?O:F(O);if(N){N=(N[J])?N:F(N);}}P=Q[U](O,N,T,S,R);return P;},hasMethod:function(N,O){return !!N[O];},query:function(P,N){var O=A.query(N,P,true);if(!O){O=null;}return O;},queryAll:function(P,N){var O=A.query(N,P);if(!O.length){O=null;}return O;},test:function(O,N){return A.test(O,N);},compareTo:function(O,N){N=F(N)||O;return O===N;},ancestor:function(O,N){return C.DOM.elementByAxis(O,"parentNode",K(N));},previous:function(P,O,N){return C.DOM.elementByAxis(P,"previousSibling",K(O),N);},next:function(P,O,N){return C.DOM.elementByAxis(P,"nextSibling",K(O),N);},contains:function(N,O){return C.DOM.contains(N,F(O));},inDoc:function(N,O){O=(O)?I(O):N.ownerDocument;if(O.documentElement){return C.DOM.contains(O.documentElement,N);}},byId:function(O,P){var N=O[B].getElementById(P);if(!N||!C.DOM.contains(O,N)){N=null;}return N;}});G.create=function(N){return G.get(C.DOM.create(N));};G.getById=function(O,N){N=(N&&N[J])?N:C.config.doc;return G.get(N.getElementById(O));};G.get=function(Q,R,O,P){var N;if(Q){if(typeof Q==="string"){if(Q==="document"){Q=[C.config.doc];}else{Q=A.query(Q,R,!P);}}if(Q){if(!P){if(Q._yuid){if(!Q.uniqueID||(Q.uniqueID===Q._yuid)){N=M[Q._yuid];}}}if(!N){N=new G(Q,R,O,P);}if(N&&O&&!P){D[N._yuid]=true;}}}return(N&&N.size())?N:null;};G.all=function(O,P,N){return G.get.call(G,O,P,N,true);};C.Array.each(["replaceChild","appendChild","insertBefore","removeChild","hasChildNodes","cloneNode","getAttribute","setAttribute","hasAttribute","removeAttribute","scrollIntoView","getElementsByTagName","focus","blur","submit","reset","select"],function(N){G.prototype[N]=function(R,P,O){var Q=this.invoke(N,R,P,O);return Q;};});if(!document.documentElement.hasAttribute){G.methods({"hasAttribute":function(O,N){return !!O.getAttribute(N);}});}C.Node=G;C.all=C.Node.all;C.get=C.Node.get;C.Node.addDOMMethods(["hasClass","addClass","removeClass","replaceClass","toggleClass"]);},"3.0.0pr2",{requires:["dom-base","selector"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/node/node-base.js'
--- loggerhead/static/javascript/yui/build/node/node-base.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-base.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,912 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node-base', function(Y) {
+
+    /**
+     * The Node Utility provides a DOM-like interface for interacting with DOM nodes.
+     * @module node
+     * @submodule node-base
+     */    
+
+    /**
+     * The Node class provides a wrapper for manipulating DOM Nodes.
+     * Node properties can be accessed via the set/get methods.
+     * Use Y.get() to retrieve Node instances.
+     *
+     * <strong>NOTE:</strong> Node properties are accessed using
+     * the <code>set</code> and <code>get</code> methods.
+     *
+     * @class Node
+     * @constructor
+     */
+
+    var OWNER_DOCUMENT = 'ownerDocument',
+        TAG_NAME = 'tagName',
+        NODE_NAME = 'nodeName',
+        NODE_TYPE = 'nodeType',
+
+        Selector = Y.Selector,
+        _instances = {},
+        _restrict = {},
+        _slice = [].slice;
+
+    // used with previous/next/ancestor tests
+    var _wrapFn = function(fn) {
+        var ret = null;
+        if (fn) {
+            ret = (typeof fn === 'string') ?
+            function(n) {
+                return Y.Selector.test(n, fn);
+            } : 
+            function(n) {
+                return fn(Y.get(n));
+            };
+        }
+
+        return ret;
+    };
+
+    var _getDoc = function(node) {
+        var doc = Y.config.doc;
+
+        if (node) {
+            if (node[NODE_TYPE]) {
+                if (node[NODE_TYPE] === 9) { // already a document node
+                    doc = node;
+                } else {
+                    doc = node[OWNER_DOCUMENT];
+                }
+            } else if (Node[node._yuid]) { // Node instance document
+                doc = Node[node._yuid]()[0];
+            }
+        }
+
+        return doc;
+    };
+
+    var _getDOMNode = function(node) {
+        if (node && !node[NODE_TYPE] && node._yuid) {
+            node = Node[node._yuid]()[0];
+        }
+
+        return  node || null;
+    };
+
+    var Node = function() {
+        this.init.apply(this, arguments);
+    };
+
+    Node.PLUGINS = {};
+
+    Node._deepGet = function (path, val) {
+        var pl = path.length,
+            i;
+
+        if (pl > 0) {
+            for (i = 0; val !== undefined && i < pl; ++i) {
+                val = val[path[i]];
+            }
+        }
+
+        return val;
+    };
+
+    Node._deepSet = function(path, val, subval) {
+        var leafIdx = path.length-1,
+            i,
+            o;
+
+        if (leafIdx >= 0) {
+            o = val;
+
+            for (i = 0; o !== undefined && i < leafIdx; ++i) {
+                o = o[path[i]];
+            }
+
+            if (o !== undefined && o[path[i]] !== undefined) {
+                o[path[i]] = subval;
+            }
+        }
+    };
+
+    Node.scrubVal = function(val, node, depth) {
+        if (val !== undefined) {
+            if (typeof val === 'object' || typeof val === 'function') { // safari nodeList === function
+                if (val !== null && (
+                        NODE_TYPE in val || // dom node
+                        val.item || // dom collection or Node instance
+                        (val[0] && val[0][NODE_TYPE]) || // assume array of nodes
+                        val.document) // window TODO: restrict?
+                    ) { 
+                    if (node && _restrict && _restrict[node._yuid] && !node.contains(val)) {
+                        val = null; // not allowed to go outside of root node
+                    } else {
+                        if (val[NODE_TYPE] || val.document) { // node or window
+                            val = Node.get(val);
+                        } else {
+                            val = Node.all(val);
+                        }
+                    }
+                } else {
+                    depth = (depth === undefined) ? 4 : depth;
+                    if (depth > 0) {
+                        for (var i in val) {
+                            if (val.hasOwnProperty && val.hasOwnProperty(i)) {
+                                val[i] = Node.scrubVal(val[i], node, --depth);
+                            }
+                        }
+                    }
+                    
+                }
+            }
+        } else {
+            val = node; // for chaining
+        }
+
+        return val;
+    };
+
+    Node.setters = {};
+    Node.getters = {
+        /**
+         * Normalizes nodeInnerText and textContent. 
+         * @property text
+         * @type String
+         */
+        'text': function(node) {
+            return Y.DOM.getText(node);
+        },
+
+        'options': function(node) {
+            return (node) ? node.getElementsByTagName('option') : [];
+        },
+
+        /**
+         * Returns a NodeList instance. 
+         * @property children
+         * @type NodeList
+         */
+        'children': function(node) {
+            var children = node.children;
+
+            if (children === undefined) {
+                var childNodes = node.childNodes;
+                children = [];
+
+                for (var i = 0, len = childNodes.length; i < len; ++i) {
+                    if (childNodes[i][TAG_NAME]) {
+                        children[children.length] = childNodes[i];
+                    }
+                }
+            }
+            return children;
+        }
+    };
+
+    Node.methods = function(name, fn) {
+        if (typeof name == 'string') {
+            Node.prototype[name] = function() {
+                var args = _slice.call(arguments, 0),
+                    instance = this,
+                    getAll =  (_instances[this._yuid]) ? false : true, // return array of vals for lists
+                    ret = (getAll) ? [] : null,
+                    val;
+
+                var getValue = function(node) {
+                    args[0] = node;
+                    val = Node.scrubVal(fn.apply(instance, args), instance);
+                    if (getAll) {
+                        ret[ret.length] = val;
+                    } else {
+                        ret = val;
+                    }
+                };
+
+                args.unshift('');
+                Node[instance._yuid](getValue);
+                return ret;
+            };
+        } else { // assume object
+            Y.each(name, function(fn, name) {
+                Node.methods(name, fn);
+            });
+        }
+
+    };
+
+    Node.getDOMNode = _getDOMNode;
+    
+    Node.wrapDOMMethod = function(name) {
+        return function() {
+            return Y.DOM[name].apply(Y.DOM, arguments);
+        };
+
+    };
+
+    Node.addDOMMethods = function(methods) {
+        var add = {}; 
+        Y.each(methods, function(v, n) {
+            add[v] = Y.Node.wrapDOMMethod(v);
+        });
+
+        Y.Node.methods(add);
+    };
+
+    Node.prototype = {
+        init: function(nodes, doc, isRoot, getAll) {
+            var uid;
+
+            doc = _getDoc(doc);
+
+            this.getId = function() {
+                return uid;
+            };
+
+            var _all = function(fn, i) {
+                if (fn) {
+                    i = i || 0;
+                    for (var node; node = nodes[i++];) {
+                        fn(node);
+                    }
+                }
+                return nodes;
+            };
+
+            // uid = selector || Y.guid(); // to cache queryAll results
+            uid = Y.guid();
+
+            if (nodes) { // zero length collection returns null
+                if (nodes[NODE_TYPE] || nodes.document) { // node or window
+                    nodes = [nodes];
+                }
+            } else {
+                nodes = [];
+            }
+
+            if (!getAll && nodes.length) { // stamp the dom node
+                try { // IE only allows ID on Element
+                    if (nodes[0].uniqueID) {
+                        uid = nodes[0].uniqueID;
+                    }
+                    nodes[0]._yuid = uid;
+                } catch(e) { // not cacheable
+                }
+            }
+
+            this._yuid = uid;
+            Node[uid] = _all; // for applying/returning dom nodes
+
+            if (!getAll) {
+                _instances[uid] = this;
+            }
+
+            this.initPlugins();
+        },
+
+        initPlugins: function() {
+            Y.each(Node.PLUGINS, function(config, fn) {
+                this.plug(fn, config);
+            });
+        },
+
+        /**
+         * Filters the NodeList instance down to only nodes matching the given selector.
+         * @method filter
+         * @param {String} selector The selector to filter against
+         * @return {NodeList} NodeList containing the updated collection 
+         * @see Selector
+         */
+        filter: function(selector) {
+            return Node.scrubVal(Selector.filter(Node[this._yuid](), selector), this);
+        },
+
+        /**
+         * Applies the given function to each Node in the NodeList.
+         * @method each
+         * @param {Function} fn The function to apply 
+         * @param {Object} context optional An optional context to apply the function with
+         * Default context is the NodeList instance
+         * @return {NodeList} NodeList containing the updated collection 
+         * @chainable
+         */
+        each: function(fn, context) {
+            context = context || this;
+            Node[this._yuid](function(node) {
+                fn.call(context, Node.get(node));
+            });
+        },
+
+        /**
+         * Returns the current number of items in the NodeList.
+         * @method size
+         * @return {Int} The number of items in the NodeList. 
+         */
+        size: function() {
+            return Node[this._yuid]().length;
+        },
+
+        /**
+         * Retrieves the Node instance at the given index. 
+         * @method item
+         *
+         * @param {Number} index The index of the target Node.
+         * @return {Node} The Node instance at the given index.
+         */
+        item: function(index) {
+            var node = Node[this._yuid]()[index];
+            return Node.get(node);
+        },
+
+       /**
+         * Attaches a DOM event handler.
+         * @method attach
+         * @param {String} type The type of DOM Event to listen for 
+         * @param {Function} fn The handler to call when the event fires 
+         * @param {Object} arg An argument object to pass to the handler 
+         */
+
+        attach: function(type, fn, arg) {
+            var args = _slice.call(arguments, 0);
+            args.splice(2, 0, Node[this._yuid]());
+            return Y.Event.attach.apply(Y.Event, args);
+        },
+
+       /**
+         * Alias for attach.
+         * @method on
+         * @param {String} type The type of DOM Event to listen for 
+         * @param {Function} fn The handler to call when the event fires 
+         * @param {Object} arg An argument object to pass to the handler 
+         * @see attach
+         */
+        on: function(type, fn, arg) {
+            return this.attach.apply(this, arguments);
+        },
+
+       /**
+         * Detaches a DOM event handler. 
+         * @method detach
+         * @param {String} type The type of DOM Event
+         * @param {Function} fn The handler to call when the event fires 
+         */
+        detach: function(type, fn) {
+            var args = _slice.call(arguments, 0);
+            args.splice(2, 0, Node[this._yuid]());
+            return Y.Event.detach.apply(Y.Event, args);
+        },
+
+       /**
+         * Creates a Node instance from HTML string
+         * @method create
+         * @param {String|Array} html The string of html to create
+         * @return {Node} A new Node instance 
+         */
+        create: function(html) {
+            return Y.Node.create(html);
+        },
+
+        /**
+         * Applies the supplied plugin to the node.
+         * @method plug
+         * @param {Function} The plugin Class to apply
+         * @param {Object} config An optional config to pass to the constructor
+         * @chainable
+         */
+        plug: function(PluginClass, config) {
+            config = config || {};
+            config.owner = this;
+            if (PluginClass && PluginClass.NS) {
+                this[PluginClass.NS] = new PluginClass(config);
+            }
+            return this;
+        },
+
+        //normalize: function() {},
+        //isSupported: function(feature, version) {},
+        toString: function() {
+            var str = '', 
+            node = Node[this._yuid]()[0] || {};
+
+            if (node) {
+                str += node[NODE_NAME];
+                if (node.id) {
+                    str += '#' + node.id; 
+                }
+
+                if (node.className) {
+                    str += '.' + node.className.replace(' ', '.'); 
+                }
+            } else {
+                'no nodes for ' + this._yuid;
+            }
+            return str;
+        }
+    };
+
+    Node.methods({
+        addEventListener: function() {
+            return Y.Event.nativeAdd.apply(Y.Event, arguments);
+        },
+        
+        removeEventListener: function() {
+            return Y.Event.nativeRemove.apply(Y.Event, arguments);
+        },
+
+        /**
+         * Set the value of the property/attribute on the HTMLElement bound to this Node.
+         * Only strings/numbers/booleans are passed through unless a SETTER exists.
+         * @method set
+         * @param {String} prop Property to set 
+         * @param {any} val Value to apply to the given property
+         * @chainable
+         */
+        // TODO: document.location.href
+        set: function(node, prop, val) {
+            if (prop.indexOf('.') < 0) {
+                if (prop in Node.setters) { // use custom setter
+                    Node.setters[prop](this, prop, val);  // passing Node instance
+                } else if (node[prop] !== undefined) { // no expandos 
+                    node[prop] = val;
+                } else {
+                }
+            } else {
+                Node._deepSet(prop.split('.'), node, val);
+            }
+        },
+
+        /**
+         * Get the value of the property/attribute on the HTMLElement bound to this Node.
+         * Only strings/numbers/booleans are passed through unless a GETTER exists.
+         * @method get
+         * @param {String} prop Property to get 
+         * @return {any} Current value of the property
+         */
+        get: function(node, prop) {
+            var val;
+            if (prop.indexOf('.') < 0) {
+                if (prop in Node.getters) { // use custom getter
+                    val = Node.getters[prop].call(this, node, prop);
+                } else {
+                    val = node[prop];
+                }
+
+                // method wrapper uses undefined in chaining test
+                if (val === undefined) {
+                    val = null;
+                }
+            } else {
+                val = Node._deepGet(prop.split('.'), node);
+            }
+
+            return val;
+        },
+
+        invoke: function(node, method, a, b, c, d, e) {
+            var ret;
+
+            if (a) { // first 2 may be Node instances
+                a = (a[NODE_TYPE]) ? a : _getDOMNode(a);
+                if (b) {
+                    b = (b[NODE_TYPE]) ? b : _getDOMNode(b);
+                }
+            }
+
+            ret = node[method](a, b, c, d, e);    
+            return ret;
+        },
+
+        hasMethod: function(node, method) {
+            return !! node[method];
+        },
+
+        /**
+         * Retrieves a Node instance of nodes based on the given CSS selector. 
+         * @method query
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {Node} A Node instance for the matching HTMLElement.
+         */
+        query: function(node, selector) {
+            var ret = Selector.query(selector, node, true);
+            if (!ret) {
+                ret = null;
+            }
+
+            return ret;
+        },
+
+        /**
+         * Retrieves a nodeList based on the given CSS selector. 
+         * @method queryAll
+         * @deprecated Use query() which returns all matches
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {NodeList} A NodeList instance for the matching HTMLCollection/Array.
+         */
+        queryAll: function(node, selector) {
+            var ret = Selector.query(selector, node);
+            if (!ret.length) {
+                ret = null;
+            }
+
+            return ret;
+        },
+
+        /**
+         * Test if the supplied node matches the supplied selector.
+         * @method test
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {boolean} Whether or not the node matches the selector.
+         */
+        test: function(node, selector) {
+            return Selector.test(node, selector);
+        },
+
+        /**
+         * Compares nodes to determine if they match.
+         * Node instances can be compared to each other and/or HTMLElements.
+         * @method compareTo
+         * @param {HTMLElement | Node} refNode The reference node to compare to the node.
+         * @return {Boolean} True if the nodes match, false if they do not. 
+         */
+        compareTo: function(node, refNode) {
+            refNode = _getDOMNode(refNode) || node;
+            return node === refNode;
+        },
+
+       /**
+         * Returns the nearest ancestor that passes the test applied by supplied boolean method.
+         * @method ancestor
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @return {Node} The matching Node instance or null if not found
+         */
+        ancestor: function(node, fn) {
+            return Y.DOM.elementByAxis(node, 'parentNode', _wrapFn(fn));
+        },
+
+        /**
+         * Returns the previous matching sibling. 
+         * Returns the nearest element node sibling if no method provided.
+         * @method previous
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+         * @return {Node} Node instance or null if not found
+         */
+        previous: function(node, fn, all) {
+            return Y.DOM.elementByAxis(node, 'previousSibling', _wrapFn(fn), all);
+        }, 
+
+        /**
+         * Returns the next matching sibling. 
+         * Returns the nearest element node sibling if no method provided.
+         * @method next
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+         * @return {Node} Node instance or null if not found
+         */
+        next: function(node, fn, all) {
+            return Y.DOM.elementByAxis(node, 'nextSibling', _wrapFn(fn), all);
+        },
+        
+        /**
+         * Determines whether the ndoe is an ancestor of another HTML element in the DOM hierarchy.
+         * @method contains
+         * @param {Node | HTMLElement} needle The possible node or descendent
+         * @return {Boolean} Whether or not this node is the needle its ancestor
+         */
+        contains: function(node, needle) {
+            return Y.DOM.contains(node, _getDOMNode(needle));
+        },
+
+        /**
+         * Determines whether the node is appended to the document.
+         * @method inDoc
+         * @param {Node|HTMLElement} doc optional An optional document to check against.
+         * Defaults to current document. 
+         * @return {Boolean} Whether or not this node is appended to the document. 
+         */
+        inDoc: function(node, doc) {
+            doc = (doc) ? _getDoc(doc) : node.ownerDocument;
+            if (doc.documentElement) {
+                return Y.DOM.contains(doc.documentElement, node);
+            }
+        },
+
+        byId: function(node, id) {
+            var ret = node[OWNER_DOCUMENT].getElementById(id);
+            if (!ret || !Y.DOM.contains(node, ret)) {
+                ret = null;
+            }
+            return ret;
+        }
+
+    });
+
+    /** 
+     * Creates a Node instance from an HTML string
+     * @method create
+     * @param {String} html HTML string
+     */
+    Node.create = function(html) {
+        return Node.get(Y.DOM.create(html));
+    };
+
+    Node.getById = function(id, doc) {
+        doc = (doc && doc[NODE_TYPE]) ? doc : Y.config.doc;
+        return Node.get(doc.getElementById(id));
+    };
+
+    /**
+     * Retrieves a Node instance for the given query or nodes. 
+     * Note: Use 'document' string to retrieve document Node instance from string
+     * @method Y.get
+     * @static
+     * @param {document|HTMLElement|HTMLCollection|Array|String} node The object to wrap.
+     * @param {document|Node} doc optional The document containing the node. Defaults to current document.
+     * @param {boolean} isRoot optional Whether or not this node should be treated as a root node. Root nodes
+     * aren't allowed to traverse outside their DOM tree.
+     * @return {Node} A Node instance bound to the supplied node(s).
+     */
+    Node.get = function(node, doc, isRoot, getAll) {
+        var instance;
+
+        if (node) {
+            if (typeof node === 'string') {
+                if (node === 'document') { // TODO: allow 'doc'? 'window'?
+                    node = [Y.config.doc];
+                } else {
+                    node = Selector.query(node, doc, !getAll); // Selector arg is getFirst
+                }
+            }
+
+            if (node) {
+                if (!getAll) { // reuse single element node instances
+                    if (node._yuid) {
+                        // verify IE's uniqueID in case the node was cloned
+                        if (!node.uniqueID || (node.uniqueID === node._yuid)) {
+                            instance = _instances[node._yuid];
+                        }
+                    }
+                }
+
+                if (!instance) {
+                    instance = new Node(node, doc, isRoot, getAll);
+                }
+
+                if (instance && isRoot && !getAll) {
+                    _restrict[instance._yuid] = true;
+                }
+            }
+        }
+
+        // zero length collection returns null
+        return (instance && instance.size()) ? instance : null;
+    };
+
+    /**
+     * Retrieves a NodeList instance for the given object/string. 
+     * @method Y.all
+     * @static
+     * @param {HTMLCollection|Array|String} node The object to wrap.
+     * @param {document|Node} doc optional The document containing the node. Defaults to current document.
+     * @param {boolean} isRoot optional Whether or not this node should be treated as a root node. Root nodes
+     * @return {NodeList} A NodeList instance for the supplied nodes.
+     */
+    Node.all = function(node, doc, isRoot) {
+        return Node.get.call(Node, node, doc, isRoot, true);
+    };
+
+    Y.Array.each([
+        /**
+         * Passes through to DOM method.
+         * @method replaceChild
+         * @param {HTMLElement | Node} node Node to be inserted 
+         * @param {HTMLElement | Node} refNode Node to be replaced 
+         * @return {Node} The replaced node 
+         */
+        'replaceChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method appendChild
+         * @param {HTMLElement | Node} node Node to be appended 
+         * @return {Node} The appended node 
+         */
+        'appendChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method insertBefore
+         * @param {HTMLElement | Node} newNode Node to be appended 
+         * @param {HTMLElement | Node} refNode Node to be inserted before 
+         * @return {Node} The inserted node 
+         */
+        'insertBefore',
+
+        /**
+         * Passes through to DOM method.
+         * @method removeChild
+         * @param {HTMLElement | Node} node Node to be removed 
+         * @return {Node} The removed node 
+         */
+        'removeChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method hasChildNodes
+         * @return {Boolean} Whether or not the node has any childNodes 
+         */
+        'hasChildNodes',
+
+        /**
+         * Passes through to DOM method.
+         * @method cloneNode
+         * @param {HTMLElement | Node} node Node to be cloned 
+         * @return {Node} The clone 
+         */
+        'cloneNode',
+
+        /**
+         * Passes through to DOM method.
+         * @method getAttribute
+         * @param {String} attribute The attribute to retrieve 
+         * @return {String} The current value of the attribute 
+         */
+        'getAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method setAttribute
+         * @param {String} attribute The attribute to set 
+         * @param {String} The value to apply to the attribute 
+         * @chainable
+         */
+        'setAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method hasAttribute
+         * @param {String} attribute The attribute to test for 
+         * @return {Boolean} Whether or not the attribute is present 
+         */
+        'hasAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method removeAttribute
+         * @param {String} attribute The attribute to be removed 
+         * @chainable
+         */
+        'removeAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method scrollIntoView
+         * @chainable
+         */
+        'scrollIntoView',
+
+        /**
+         * Passes through to DOM method.
+         * @method getElementsByTagName
+         * @param {String} tagName The tagName to collect 
+         * @return {NodeList} A NodeList representing the HTMLCollection
+         */
+        'getElementsByTagName',
+
+        /**
+         * Passes through to DOM method.
+         * @method focus
+         * @chainable
+         */
+        'focus',
+
+        /**
+         * Passes through to DOM method.
+         * @method blur
+         * @chainable
+         */
+        'blur',
+
+        /**
+         * Passes through to DOM method.
+         * Only valid on FORM elements
+         * @method submit
+         * @chainable
+         */
+        'submit',
+
+        /**
+         * Passes through to DOM method.
+         * Only valid on FORM elements
+         * @method reset
+         * @chainable
+         */
+        'reset',
+
+        /**
+         * Passes through to DOM method.
+         * @method select
+         * @chainable
+         */
+         'select'
+    ], function(method) {
+        Node.prototype[method] = function(arg1, arg2, arg3) {
+            var ret = this.invoke(method, arg1, arg2, arg3);
+            return ret;
+        };
+    });
+
+    if (!document.documentElement.hasAttribute) {
+        Node.methods({
+            'hasAttribute': function(node, att) {
+                return !! node.getAttribute(att);
+            }
+        });
+    }
+
+    // used to call Node methods against NodeList nodes
+    Y.Node = Node;
+    Y.all = Y.Node.all;
+    Y.get = Y.Node.get;
+/**
+ * Extended Node interface for managing classNames.
+ * @module node
+ * @submodule node
+ * @for Node
+ */
+
+    Y.Node.addDOMMethods([
+        /**
+         * Determines whether the node has the given className.
+         * @method hasClass
+         * @param {String} className the class name to search for
+         * @return {Boolean} Whether or not the node has the given class. 
+         */
+        'hasClass',
+
+        /**
+         * Adds a class name to the node.
+         * @method addClass         
+         * @param {String} className the class name to add to the node's class attribute
+         * @chainable
+         */
+        'addClass',
+
+        /**
+         * Removes a class name from the node.
+         * @method removeClass         
+         * @param {String} className the class name to remove from the node's class attribute
+         * @chainable
+         */
+        'removeClass',
+
+        /**
+         * Replace a class with another class.
+         * If no oldClassName is present, the newClassName is simply added.
+         * @method replaceClass  
+         * @param {String} oldClassName the class name to be replaced
+         * @param {String} newClassName the class name that will be replacing the old class name
+         * @chainable
+         */
+        'replaceClass',
+
+        /**
+         * If the className exists on the node it is removed, if it doesn't exist it is added.
+         * @method toggleClass  
+         * @param {String} className the class name to be toggled
+         * @chainable
+         */
+        'toggleClass'
+    ]);
+
+
+}, '3.0.0pr2' ,{requires:['dom-base', 'selector']});

=== added file 'loggerhead/static/javascript/yui/build/node/node-debug.js'
--- loggerhead/static/javascript/yui/build/node/node-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1136 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node', function(Y) {
+
+    /**
+     * The Node Utility provides a DOM-like interface for interacting with DOM nodes.
+     * @module node
+     * @submodule node-base
+     */    
+
+    /**
+     * The Node class provides a wrapper for manipulating DOM Nodes.
+     * Node properties can be accessed via the set/get methods.
+     * Use Y.get() to retrieve Node instances.
+     *
+     * <strong>NOTE:</strong> Node properties are accessed using
+     * the <code>set</code> and <code>get</code> methods.
+     *
+     * @class Node
+     * @constructor
+     */
+
+    var OWNER_DOCUMENT = 'ownerDocument',
+        TAG_NAME = 'tagName',
+        NODE_NAME = 'nodeName',
+        NODE_TYPE = 'nodeType',
+
+        Selector = Y.Selector,
+        _instances = {},
+        _restrict = {},
+        _slice = [].slice;
+
+    // used with previous/next/ancestor tests
+    var _wrapFn = function(fn) {
+        var ret = null;
+        if (fn) {
+            ret = (typeof fn === 'string') ?
+            function(n) {
+                return Y.Selector.test(n, fn);
+            } : 
+            function(n) {
+                return fn(Y.get(n));
+            };
+        }
+
+        return ret;
+    };
+
+    var _getDoc = function(node) {
+        var doc = Y.config.doc;
+
+        if (node) {
+            if (node[NODE_TYPE]) {
+                if (node[NODE_TYPE] === 9) { // already a document node
+                    doc = node;
+                } else {
+                    doc = node[OWNER_DOCUMENT];
+                }
+            } else if (Node[node._yuid]) { // Node instance document
+                doc = Node[node._yuid]()[0];
+            }
+        }
+
+        return doc;
+    };
+
+    var _getDOMNode = function(node) {
+        if (node && !node[NODE_TYPE] && node._yuid) {
+            node = Node[node._yuid]()[0];
+        }
+
+        return  node || null;
+    };
+
+    var Node = function() {
+        this.init.apply(this, arguments);
+    };
+
+    Node.PLUGINS = {};
+
+    Node._deepGet = function (path, val) {
+        var pl = path.length,
+            i;
+
+        if (pl > 0) {
+            for (i = 0; val !== undefined && i < pl; ++i) {
+                val = val[path[i]];
+            }
+        }
+
+        return val;
+    };
+
+    Node._deepSet = function(path, val, subval) {
+        var leafIdx = path.length-1,
+            i,
+            o;
+
+        if (leafIdx >= 0) {
+            o = val;
+
+            for (i = 0; o !== undefined && i < leafIdx; ++i) {
+                o = o[path[i]];
+            }
+
+            if (o !== undefined && o[path[i]] !== undefined) {
+                o[path[i]] = subval;
+            }
+        }
+    };
+
+    Node.scrubVal = function(val, node, depth) {
+        if (val !== undefined) {
+            if (typeof val === 'object' || typeof val === 'function') { // safari nodeList === function
+                if (val !== null && (
+                        NODE_TYPE in val || // dom node
+                        val.item || // dom collection or Node instance
+                        (val[0] && val[0][NODE_TYPE]) || // assume array of nodes
+                        val.document) // window TODO: restrict?
+                    ) { 
+                    if (node && _restrict && _restrict[node._yuid] && !node.contains(val)) {
+                        val = null; // not allowed to go outside of root node
+                    } else {
+                        if (val[NODE_TYPE] || val.document) { // node or window
+                            val = Node.get(val);
+                        } else {
+                            val = Node.all(val);
+                        }
+                    }
+                } else {
+                    depth = (depth === undefined) ? 4 : depth;
+                    if (depth > 0) {
+                        for (var i in val) {
+                            if (val.hasOwnProperty && val.hasOwnProperty(i)) {
+                                val[i] = Node.scrubVal(val[i], node, --depth);
+                            }
+                        }
+                    }
+                    
+                }
+            }
+        } else {
+            val = node; // for chaining
+        }
+
+        return val;
+    };
+
+    Node.setters = {};
+    Node.getters = {
+        /**
+         * Normalizes nodeInnerText and textContent. 
+         * @property text
+         * @type String
+         */
+        'text': function(node) {
+            return Y.DOM.getText(node);
+        },
+
+        'options': function(node) {
+            return (node) ? node.getElementsByTagName('option') : [];
+        },
+
+        /**
+         * Returns a NodeList instance. 
+         * @property children
+         * @type NodeList
+         */
+        'children': function(node) {
+            var children = node.children;
+
+            if (children === undefined) {
+                var childNodes = node.childNodes;
+                children = [];
+
+                for (var i = 0, len = childNodes.length; i < len; ++i) {
+                    if (childNodes[i][TAG_NAME]) {
+                        children[children.length] = childNodes[i];
+                    }
+                }
+            }
+            return children;
+        }
+    };
+
+    Node.methods = function(name, fn) {
+        if (typeof name == 'string') {
+            Node.prototype[name] = function() {
+                var args = _slice.call(arguments, 0),
+                    instance = this,
+                    getAll =  (_instances[this._yuid]) ? false : true, // return array of vals for lists
+                    ret = (getAll) ? [] : null,
+                    val;
+
+                var getValue = function(node) {
+                    args[0] = node;
+                    val = Node.scrubVal(fn.apply(instance, args), instance);
+                    if (getAll) {
+                        ret[ret.length] = val;
+                    } else {
+                        ret = val;
+                    }
+                };
+
+                args.unshift('');
+                Node[instance._yuid](getValue);
+                return ret;
+            };
+        } else { // assume object
+            Y.each(name, function(fn, name) {
+                Node.methods(name, fn);
+            });
+        }
+
+    };
+
+    Node.getDOMNode = _getDOMNode;
+    
+    Node.wrapDOMMethod = function(name) {
+        return function() {
+            return Y.DOM[name].apply(Y.DOM, arguments);
+        };
+
+    };
+
+    Node.addDOMMethods = function(methods) {
+        var add = {}; 
+        Y.each(methods, function(v, n) {
+            add[v] = Y.Node.wrapDOMMethod(v);
+        });
+
+        Y.Node.methods(add);
+    };
+
+    Node.prototype = {
+        init: function(nodes, doc, isRoot, getAll) {
+            var uid;
+
+            doc = _getDoc(doc);
+
+            this.getId = function() {
+                return uid;
+            };
+
+            var _all = function(fn, i) {
+                if (fn) {
+                    i = i || 0;
+                    for (var node; node = nodes[i++];) {
+                        fn(node);
+                    }
+                }
+                return nodes;
+            };
+
+            // uid = selector || Y.guid(); // to cache queryAll results
+            uid = Y.guid();
+
+            if (nodes) { // zero length collection returns null
+                if (nodes[NODE_TYPE] || nodes.document) { // node or window
+                    nodes = [nodes];
+                }
+            } else {
+                nodes = [];
+            }
+
+            if (!getAll && nodes.length) { // stamp the dom node
+                try { // IE only allows ID on Element
+                    if (nodes[0].uniqueID) {
+                        uid = nodes[0].uniqueID;
+                    }
+                    nodes[0]._yuid = uid;
+                } catch(e) { // not cacheable
+                    Y.log(nodes[0] + ' is not cacheable', 'warn', 'Node'); 
+                }
+            }
+
+            this._yuid = uid;
+            Node[uid] = _all; // for applying/returning dom nodes
+
+            if (!getAll) {
+                _instances[uid] = this;
+            }
+
+            this.initPlugins();
+        },
+
+        initPlugins: function() {
+            Y.each(Node.PLUGINS, function(config, fn) {
+                this.plug(fn, config);
+            });
+        },
+
+        /**
+         * Filters the NodeList instance down to only nodes matching the given selector.
+         * @method filter
+         * @param {String} selector The selector to filter against
+         * @return {NodeList} NodeList containing the updated collection 
+         * @see Selector
+         */
+        filter: function(selector) {
+            return Node.scrubVal(Selector.filter(Node[this._yuid](), selector), this);
+        },
+
+        /**
+         * Applies the given function to each Node in the NodeList.
+         * @method each
+         * @param {Function} fn The function to apply 
+         * @param {Object} context optional An optional context to apply the function with
+         * Default context is the NodeList instance
+         * @return {NodeList} NodeList containing the updated collection 
+         * @chainable
+         */
+        each: function(fn, context) {
+            context = context || this;
+            Node[this._yuid](function(node) {
+                fn.call(context, Node.get(node));
+            });
+        },
+
+        /**
+         * Returns the current number of items in the NodeList.
+         * @method size
+         * @return {Int} The number of items in the NodeList. 
+         */
+        size: function() {
+            return Node[this._yuid]().length;
+        },
+
+        /**
+         * Retrieves the Node instance at the given index. 
+         * @method item
+         *
+         * @param {Number} index The index of the target Node.
+         * @return {Node} The Node instance at the given index.
+         */
+        item: function(index) {
+            var node = Node[this._yuid]()[index];
+            return Node.get(node);
+        },
+
+       /**
+         * Attaches a DOM event handler.
+         * @method attach
+         * @param {String} type The type of DOM Event to listen for 
+         * @param {Function} fn The handler to call when the event fires 
+         * @param {Object} arg An argument object to pass to the handler 
+         */
+
+        attach: function(type, fn, arg) {
+            var args = _slice.call(arguments, 0);
+            args.splice(2, 0, Node[this._yuid]());
+            return Y.Event.attach.apply(Y.Event, args);
+        },
+
+       /**
+         * Alias for attach.
+         * @method on
+         * @param {String} type The type of DOM Event to listen for 
+         * @param {Function} fn The handler to call when the event fires 
+         * @param {Object} arg An argument object to pass to the handler 
+         * @see attach
+         */
+        on: function(type, fn, arg) {
+            return this.attach.apply(this, arguments);
+        },
+
+       /**
+         * Detaches a DOM event handler. 
+         * @method detach
+         * @param {String} type The type of DOM Event
+         * @param {Function} fn The handler to call when the event fires 
+         */
+        detach: function(type, fn) {
+            var args = _slice.call(arguments, 0);
+            args.splice(2, 0, Node[this._yuid]());
+            return Y.Event.detach.apply(Y.Event, args);
+        },
+
+       /**
+         * Creates a Node instance from HTML string
+         * @method create
+         * @param {String|Array} html The string of html to create
+         * @return {Node} A new Node instance 
+         */
+        create: function(html) {
+            return Y.Node.create(html);
+        },
+
+        /**
+         * Applies the supplied plugin to the node.
+         * @method plug
+         * @param {Function} The plugin Class to apply
+         * @param {Object} config An optional config to pass to the constructor
+         * @chainable
+         */
+        plug: function(PluginClass, config) {
+            config = config || {};
+            config.owner = this;
+            if (PluginClass && PluginClass.NS) {
+                this[PluginClass.NS] = new PluginClass(config);
+            }
+            return this;
+        },
+
+        //normalize: function() {},
+        //isSupported: function(feature, version) {},
+        toString: function() {
+            var str = '', 
+            node = Node[this._yuid]()[0] || {};
+
+            if (node) {
+                str += node[NODE_NAME];
+                if (node.id) {
+                    str += '#' + node.id; 
+                }
+
+                if (node.className) {
+                    str += '.' + node.className.replace(' ', '.'); 
+                }
+            } else {
+                'no nodes for ' + this._yuid;
+            }
+            return str;
+        }
+    };
+
+    Node.methods({
+        addEventListener: function() {
+            return Y.Event.nativeAdd.apply(Y.Event, arguments);
+        },
+        
+        removeEventListener: function() {
+            return Y.Event.nativeRemove.apply(Y.Event, arguments);
+        },
+
+        /**
+         * Set the value of the property/attribute on the HTMLElement bound to this Node.
+         * Only strings/numbers/booleans are passed through unless a SETTER exists.
+         * @method set
+         * @param {String} prop Property to set 
+         * @param {any} val Value to apply to the given property
+         * @chainable
+         */
+        // TODO: document.location.href
+        set: function(node, prop, val) {
+            if (prop.indexOf('.') < 0) {
+                if (prop in Node.setters) { // use custom setter
+                    Node.setters[prop](this, prop, val);  // passing Node instance
+                } else if (node[prop] !== undefined) { // no expandos 
+                    node[prop] = val;
+                } else {
+                    Y.log(prop + ' not in ' + node, 'warn', 'Node');
+                }
+            } else {
+                Node._deepSet(prop.split('.'), node, val);
+            }
+        },
+
+        /**
+         * Get the value of the property/attribute on the HTMLElement bound to this Node.
+         * Only strings/numbers/booleans are passed through unless a GETTER exists.
+         * @method get
+         * @param {String} prop Property to get 
+         * @return {any} Current value of the property
+         */
+        get: function(node, prop) {
+            var val;
+            if (prop.indexOf('.') < 0) {
+                if (prop in Node.getters) { // use custom getter
+                    val = Node.getters[prop].call(this, node, prop);
+                } else {
+                    val = node[prop];
+                }
+
+                // method wrapper uses undefined in chaining test
+                if (val === undefined) {
+                    val = null;
+                }
+            } else {
+                val = Node._deepGet(prop.split('.'), node);
+            }
+
+            return val;
+        },
+
+        invoke: function(node, method, a, b, c, d, e) {
+            var ret;
+
+            if (a) { // first 2 may be Node instances
+                a = (a[NODE_TYPE]) ? a : _getDOMNode(a);
+                if (b) {
+                    b = (b[NODE_TYPE]) ? b : _getDOMNode(b);
+                }
+            }
+
+            ret = node[method](a, b, c, d, e);    
+            return ret;
+        },
+
+        hasMethod: function(node, method) {
+            return !! node[method];
+        },
+
+        /**
+         * Retrieves a Node instance of nodes based on the given CSS selector. 
+         * @method query
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {Node} A Node instance for the matching HTMLElement.
+         */
+        query: function(node, selector) {
+            var ret = Selector.query(selector, node, true);
+            if (!ret) {
+                ret = null;
+            }
+
+            return ret;
+        },
+
+        /**
+         * Retrieves a nodeList based on the given CSS selector. 
+         * @method queryAll
+         * @deprecated Use query() which returns all matches
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {NodeList} A NodeList instance for the matching HTMLCollection/Array.
+         */
+        queryAll: function(node, selector) {
+            var ret = Selector.query(selector, node);
+            if (!ret.length) {
+                ret = null;
+            }
+
+            return ret;
+        },
+
+        /**
+         * Test if the supplied node matches the supplied selector.
+         * @method test
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {boolean} Whether or not the node matches the selector.
+         */
+        test: function(node, selector) {
+            return Selector.test(node, selector);
+        },
+
+        /**
+         * Compares nodes to determine if they match.
+         * Node instances can be compared to each other and/or HTMLElements.
+         * @method compareTo
+         * @param {HTMLElement | Node} refNode The reference node to compare to the node.
+         * @return {Boolean} True if the nodes match, false if they do not. 
+         */
+        compareTo: function(node, refNode) {
+            refNode = _getDOMNode(refNode) || node;
+            return node === refNode;
+        },
+
+       /**
+         * Returns the nearest ancestor that passes the test applied by supplied boolean method.
+         * @method ancestor
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @return {Node} The matching Node instance or null if not found
+         */
+        ancestor: function(node, fn) {
+            return Y.DOM.elementByAxis(node, 'parentNode', _wrapFn(fn));
+        },
+
+        /**
+         * Returns the previous matching sibling. 
+         * Returns the nearest element node sibling if no method provided.
+         * @method previous
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+         * @return {Node} Node instance or null if not found
+         */
+        previous: function(node, fn, all) {
+            return Y.DOM.elementByAxis(node, 'previousSibling', _wrapFn(fn), all);
+        }, 
+
+        /**
+         * Returns the next matching sibling. 
+         * Returns the nearest element node sibling if no method provided.
+         * @method next
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+         * @return {Node} Node instance or null if not found
+         */
+        next: function(node, fn, all) {
+            return Y.DOM.elementByAxis(node, 'nextSibling', _wrapFn(fn), all);
+        },
+        
+        /**
+         * Determines whether the ndoe is an ancestor of another HTML element in the DOM hierarchy.
+         * @method contains
+         * @param {Node | HTMLElement} needle The possible node or descendent
+         * @return {Boolean} Whether or not this node is the needle its ancestor
+         */
+        contains: function(node, needle) {
+            return Y.DOM.contains(node, _getDOMNode(needle));
+        },
+
+        /**
+         * Determines whether the node is appended to the document.
+         * @method inDoc
+         * @param {Node|HTMLElement} doc optional An optional document to check against.
+         * Defaults to current document. 
+         * @return {Boolean} Whether or not this node is appended to the document. 
+         */
+        inDoc: function(node, doc) {
+            doc = (doc) ? _getDoc(doc) : node.ownerDocument;
+            if (doc.documentElement) {
+                return Y.DOM.contains(doc.documentElement, node);
+            }
+        },
+
+        byId: function(node, id) {
+            var ret = node[OWNER_DOCUMENT].getElementById(id);
+            if (!ret || !Y.DOM.contains(node, ret)) {
+                ret = null;
+            }
+            return ret;
+        }
+
+    });
+
+    /** 
+     * Creates a Node instance from an HTML string
+     * @method create
+     * @param {String} html HTML string
+     */
+    Node.create = function(html) {
+        return Node.get(Y.DOM.create(html));
+    };
+
+    Node.getById = function(id, doc) {
+        doc = (doc && doc[NODE_TYPE]) ? doc : Y.config.doc;
+        return Node.get(doc.getElementById(id));
+    };
+
+    /**
+     * Retrieves a Node instance for the given query or nodes. 
+     * Note: Use 'document' string to retrieve document Node instance from string
+     * @method Y.get
+     * @static
+     * @param {document|HTMLElement|HTMLCollection|Array|String} node The object to wrap.
+     * @param {document|Node} doc optional The document containing the node. Defaults to current document.
+     * @param {boolean} isRoot optional Whether or not this node should be treated as a root node. Root nodes
+     * aren't allowed to traverse outside their DOM tree.
+     * @return {Node} A Node instance bound to the supplied node(s).
+     */
+    Node.get = function(node, doc, isRoot, getAll) {
+        var instance;
+
+        if (node) {
+            if (typeof node === 'string') {
+                if (node === 'document') { // TODO: allow 'doc'? 'window'?
+                    node = [Y.config.doc];
+                } else {
+                    node = Selector.query(node, doc, !getAll); // Selector arg is getFirst
+                }
+            }
+
+            if (node) {
+                if (!getAll) { // reuse single element node instances
+                    if (node._yuid) {
+                        // verify IE's uniqueID in case the node was cloned
+                        if (!node.uniqueID || (node.uniqueID === node._yuid)) {
+                            instance = _instances[node._yuid];
+                        }
+                    }
+                }
+
+                if (!instance) {
+                    instance = new Node(node, doc, isRoot, getAll);
+                }
+
+                if (instance && isRoot && !getAll) {
+                    _restrict[instance._yuid] = true;
+                }
+            }
+        }
+
+        // zero length collection returns null
+        return (instance && instance.size()) ? instance : null;
+    };
+
+    /**
+     * Retrieves a NodeList instance for the given object/string. 
+     * @method Y.all
+     * @static
+     * @param {HTMLCollection|Array|String} node The object to wrap.
+     * @param {document|Node} doc optional The document containing the node. Defaults to current document.
+     * @param {boolean} isRoot optional Whether or not this node should be treated as a root node. Root nodes
+     * @return {NodeList} A NodeList instance for the supplied nodes.
+     */
+    Node.all = function(node, doc, isRoot) {
+        return Node.get.call(Node, node, doc, isRoot, true);
+    };
+
+    Y.Array.each([
+        /**
+         * Passes through to DOM method.
+         * @method replaceChild
+         * @param {HTMLElement | Node} node Node to be inserted 
+         * @param {HTMLElement | Node} refNode Node to be replaced 
+         * @return {Node} The replaced node 
+         */
+        'replaceChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method appendChild
+         * @param {HTMLElement | Node} node Node to be appended 
+         * @return {Node} The appended node 
+         */
+        'appendChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method insertBefore
+         * @param {HTMLElement | Node} newNode Node to be appended 
+         * @param {HTMLElement | Node} refNode Node to be inserted before 
+         * @return {Node} The inserted node 
+         */
+        'insertBefore',
+
+        /**
+         * Passes through to DOM method.
+         * @method removeChild
+         * @param {HTMLElement | Node} node Node to be removed 
+         * @return {Node} The removed node 
+         */
+        'removeChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method hasChildNodes
+         * @return {Boolean} Whether or not the node has any childNodes 
+         */
+        'hasChildNodes',
+
+        /**
+         * Passes through to DOM method.
+         * @method cloneNode
+         * @param {HTMLElement | Node} node Node to be cloned 
+         * @return {Node} The clone 
+         */
+        'cloneNode',
+
+        /**
+         * Passes through to DOM method.
+         * @method getAttribute
+         * @param {String} attribute The attribute to retrieve 
+         * @return {String} The current value of the attribute 
+         */
+        'getAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method setAttribute
+         * @param {String} attribute The attribute to set 
+         * @param {String} The value to apply to the attribute 
+         * @chainable
+         */
+        'setAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method hasAttribute
+         * @param {String} attribute The attribute to test for 
+         * @return {Boolean} Whether or not the attribute is present 
+         */
+        'hasAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method removeAttribute
+         * @param {String} attribute The attribute to be removed 
+         * @chainable
+         */
+        'removeAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method scrollIntoView
+         * @chainable
+         */
+        'scrollIntoView',
+
+        /**
+         * Passes through to DOM method.
+         * @method getElementsByTagName
+         * @param {String} tagName The tagName to collect 
+         * @return {NodeList} A NodeList representing the HTMLCollection
+         */
+        'getElementsByTagName',
+
+        /**
+         * Passes through to DOM method.
+         * @method focus
+         * @chainable
+         */
+        'focus',
+
+        /**
+         * Passes through to DOM method.
+         * @method blur
+         * @chainable
+         */
+        'blur',
+
+        /**
+         * Passes through to DOM method.
+         * Only valid on FORM elements
+         * @method submit
+         * @chainable
+         */
+        'submit',
+
+        /**
+         * Passes through to DOM method.
+         * Only valid on FORM elements
+         * @method reset
+         * @chainable
+         */
+        'reset',
+
+        /**
+         * Passes through to DOM method.
+         * @method select
+         * @chainable
+         */
+         'select'
+    ], function(method) {
+        Node.prototype[method] = function(arg1, arg2, arg3) {
+            var ret = this.invoke(method, arg1, arg2, arg3);
+            return ret;
+        };
+    });
+
+    if (!document.documentElement.hasAttribute) {
+        Node.methods({
+            'hasAttribute': function(node, att) {
+                return !! node.getAttribute(att);
+            }
+        });
+    }
+
+    // used to call Node methods against NodeList nodes
+    Y.Node = Node;
+    Y.all = Y.Node.all;
+    Y.get = Y.Node.get;
+/**
+ * Extended Node interface for managing node styles.
+ * @module node
+ * @submodule node-style
+ * @for Node
+ */
+
+Y.Node.addDOMMethods([
+    /**
+     * Returns the style's current value.
+     * @method getStyle
+     * @param {String} attr The style attribute to retrieve. 
+     * @return {String} The current value of the style property for the element.
+     */
+    'getStyle',
+
+    /**
+     * Returns the computed value for the given style property.
+     * @method getComputedStyle
+     * @param {String} attr The style attribute to retrieve. 
+     * @return {String} The computed value of the style property for the element.
+     */
+    'getComputedStyle',
+
+    /**
+     * Sets a style property of the node.
+     * @method setStyle
+     * @param {String} attr The style attribute to set. 
+     * @param {String|Number} val The value. 
+     * @chainable
+     */
+    'setStyle',
+
+    /**
+     * Sets multiple style properties on the node.
+     * @method setStyles
+     * @param {Object} hash An object literal of property:value pairs. 
+     * @chainable
+     */
+    'setStyles'
+]);
+
+/**
+ * Extended Node interface for managing classNames.
+ * @module node
+ * @submodule node
+ * @for Node
+ */
+
+    Y.Node.addDOMMethods([
+        /**
+         * Determines whether the node has the given className.
+         * @method hasClass
+         * @param {String} className the class name to search for
+         * @return {Boolean} Whether or not the node has the given class. 
+         */
+        'hasClass',
+
+        /**
+         * Adds a class name to the node.
+         * @method addClass         
+         * @param {String} className the class name to add to the node's class attribute
+         * @chainable
+         */
+        'addClass',
+
+        /**
+         * Removes a class name from the node.
+         * @method removeClass         
+         * @param {String} className the class name to remove from the node's class attribute
+         * @chainable
+         */
+        'removeClass',
+
+        /**
+         * Replace a class with another class.
+         * If no oldClassName is present, the newClassName is simply added.
+         * @method replaceClass  
+         * @param {String} oldClassName the class name to be replaced
+         * @param {String} newClassName the class name that will be replacing the old class name
+         * @chainable
+         */
+        'replaceClass',
+
+        /**
+         * If the className exists on the node it is removed, if it doesn't exist it is added.
+         * @method toggleClass  
+         * @param {String} className the class name to be toggled
+         * @chainable
+         */
+        'toggleClass'
+    ]);
+/**
+ * Extended Node interface for managing regions and screen positioning.
+ * Adds support for positioning elements and normalizes window size and scroll detection. 
+ * @module node
+ * @submodule node-screen
+ * @for Node
+ */
+Y.each([
+        /**
+         * Returns a region object for the node 
+         * @property region
+         * @type Node
+         */
+        'region',
+        /**
+         * Returns a region object for the node's viewport 
+         * @property viewportRegion
+         * @type Node
+         */
+        'viewportRegion'
+    ],
+
+    function(v, n) {
+        Y.Node.getters[v] = Y.Node.wrapDOMMethod(v);
+    }
+);
+
+Y.Node.addDOMMethods([
+    /**
+     * Determines whether or not the node is currently visible in the viewport. 
+     * @method inViewportRegion         
+     * @return {Boolean} Whether or not the node is currently positioned
+     * within the viewport's region
+     */
+    'inViewportRegion'
+]);
+
+// these need special treatment to extract 2nd node arg
+Y.Node.methods({
+    /**
+     * Compares the intersection of the node with another node or region 
+     * @method intersect         
+     * @param {Node|Object} node2 The node or region to compare with.
+     * @param {Object} altRegion An alternate region to use (rather than this node's). 
+     * @return {Object} An object representing the intersection of the regions. 
+     */
+    intersect: function(node1, node2, altRegion) {
+        if (node2 instanceof Y.Node) { // might be a region object
+            node2 = Y.Node.getDOMNode(node2);
+        }
+        return Y.DOM.intersect(node1, node2, altRegion); 
+    },
+
+    /**
+     * Determines whether or not the node is within the giving region.
+     * @method inRegion         
+     * @param {Node|Object} node2 The node or region to compare with.
+     * @param {Boolean} all Whether or not all of the node must be in the region. 
+     * @param {Object} altRegion An alternate region to use (rather than this node's). 
+     * @return {Object} An object representing the intersection of the regions. 
+     */
+    inRegion: function(node1, node2, all, altRegion) {
+        if (node2 instanceof Y.Node) { // might be a region object
+            node2 = Y.Node.getDOMNode(node2);
+        }
+        return Y.DOM.inRegion(node1, node2, all, altRegion); 
+    }
+});
+
+/**
+ * Extended Node interface for managing regions and screen positioning.
+ * Adds support for positioning elements and normalizes window size and scroll detection. 
+ * @module node
+ * @submodule node-screen
+ * @for Node
+ */
+
+    Y.each([
+        /**
+         * Returns the inner width of the viewport (exludes scrollbar). 
+         * @property winWidth
+         * @type {Int}
+         */
+        'winWidth',
+
+        /**
+         * Returns the inner height of the viewport (exludes scrollbar). 
+         * @property winHeight
+         * @type {Int}
+         */
+        'winHeight',
+
+        /**
+         * Document width 
+         * @property winHeight
+         * @type {Int}
+         */
+        'docWidth',
+
+        /**
+         * Document height 
+         * @property docHeight
+         * @type {Int}
+         */
+        'docHeight',
+
+        /**
+         * Amount page has been scroll vertically 
+         * @property docScrollX
+         * @type {Int}
+         */
+        'docScrollX',
+
+        /**
+         * Amount page has been scroll horizontally 
+         * @property docScrollY
+         * @type {Int}
+         */
+        'docScrollY'
+        ],
+        function(v, n) {
+            Y.Node.getters[v] = Y.Node.wrapDOMMethod(v);
+        }
+    );
+
+    Y.Node.addDOMMethods([
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getXY
+     * @return {Array} The XY position of the node
+    */
+        'getXY',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setXY
+     * @param {Array} xy Contains X & Y values for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setXY',
+
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getX
+     * @return {Int} The X position of the node
+    */
+        'getX',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setX
+     * @param {Int} x X value for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setX',
+
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getY
+     * @return {Int} The Y position of the node
+    */
+        'getY',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setY
+     * @param {Int} y Y value for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setY'
+    ]);
+
+
+}, '3.0.0pr2' ,{requires:['dom']});

=== added file 'loggerhead/static/javascript/yui/build/node/node-event-simulate-debug.js'
--- loggerhead/static/javascript/yui/build/node/node-event-simulate-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-event-simulate-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,30 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node-event-simulate', function(Y) {
+
+/*
+ * Functionality to simulate events.
+ * @module node
+ * @for Node
+ * @submodule node-event-simulate
+ */
+
+    /**
+     * Simulates an event on the node.
+     * @param {String} type The type of event to simulate (i.e., "click").
+     * @param {Object} options (Optional) Extra options to copy onto the event object.
+     * @return {void}
+     * @method simulate
+     * @static
+     */     
+    Y.Node.prototype.simulate = function(type, options){
+        Y.Event.simulate(Y.Node.getDOMNode(this), type, options);
+    };
+
+
+
+}, '3.0.0pr2' ,{requires:['node-base']});

=== added file 'loggerhead/static/javascript/yui/build/node/node-event-simulate-min.js'
--- loggerhead/static/javascript/yui/build/node/node-event-simulate-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-event-simulate-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("node-event-simulate",function(A){A.Node.prototype.simulate=function(C,B){A.Event.simulate(A.Node.getDOMNode(this),C,B);};},"3.0.0pr2",{requires:["node-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/node/node-event-simulate.js'
--- loggerhead/static/javascript/yui/build/node/node-event-simulate.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-event-simulate.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,30 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node-event-simulate', function(Y) {
+
+/*
+ * Functionality to simulate events.
+ * @module node
+ * @for Node
+ * @submodule node-event-simulate
+ */
+
+    /**
+     * Simulates an event on the node.
+     * @param {String} type The type of event to simulate (i.e., "click").
+     * @param {Object} options (Optional) Extra options to copy onto the event object.
+     * @return {void}
+     * @method simulate
+     * @static
+     */     
+    Y.Node.prototype.simulate = function(type, options){
+        Y.Event.simulate(Y.Node.getDOMNode(this), type, options);
+    };
+
+
+
+}, '3.0.0pr2' ,{requires:['node-base']});

=== added file 'loggerhead/static/javascript/yui/build/node/node-min.js'
--- loggerhead/static/javascript/yui/build/node/node-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("node",function(C){var B="ownerDocument",H="tagName",E="nodeName",J="nodeType",A=C.Selector,M={},D={},L=[].slice;var K=function(O){var N=null;if(O){N=(typeof O==="string")?function(P){return C.Selector.test(P,O);}:function(P){return O(C.get(P));};}return N;};var I=function(N){var O=C.config.doc;if(N){if(N[J]){if(N[J]===9){O=N;}else{O=N[B];}}else{if(G[N._yuid]){O=G[N._yuid]()[0];}}}return O;};var F=function(N){if(N&&!N[J]&&N._yuid){N=G[N._yuid]()[0];}return N||null;};var G=function(){this.init.apply(this,arguments);};G.PLUGINS={};G._deepGet=function(P,Q){var O=P.length,N;if(O>0){for(N=0;Q!==undefined&&N<O;++N){Q=Q[P[N]];}}return Q;};G._deepSet=function(Q,S,P){var O=Q.length-1,N,R;if(O>=0){R=S;for(N=0;R!==undefined&&N<O;++N){R=R[Q[N]];}if(R!==undefined&&R[Q[N]]!==undefined){R[Q[N]]=P;}}};G.scrubVal=function(Q,O,P){if(Q!==undefined){if(typeof Q==="object"||typeof Q==="function"){if(Q!==null&&(J in Q||Q.item||(Q[0]&&Q[0][J])||Q.document)){if(O&&D&&D[O._yuid]&&!O.contains(Q)){Q=null;}else{if(Q[J]||Q.document){Q=G.get(Q);}else{Q=G.all(Q);}}}else{P=(P===undefined)?4:P;if(P>0){for(var N in Q){if(Q.hasOwnProperty&&Q.hasOwnProperty(N)){Q[N]=G.scrubVal(Q[N],O,--P);}}}}}}else{Q=O;}return Q;};G.setters={};G.getters={"text":function(N){return C.DOM.getText(N);},"options":function(N){return(N)?N.getElementsByTagName("option"):[];},"children":function(Q){var P=Q.children;if(P===undefined){var R=Q.childNodes;P=[];for(var O=0,N=R.length;O<N;++O){if(R[O][H]){P[P.length]=R[O];}}}return P;}};G.methods=function(N,O){if(typeof N=="string"){G.prototype[N]=function(){var S=L.call(arguments,0),P=this,T=(M[this._yuid])?false:true,R=(T)?[]:null,U;var Q=function(V){S[0]=V;U=G.scrubVal(O.apply(P,S),P);if(T){R[R.length]=U;}else{R=U;}};S.unshift("");G[P._yuid](Q);return R;};}else{C.each(N,function(Q,P){G.methods(P,Q);});}};G.getDOMNode=F;G.wrapDOMMethod=function(N){return function(){return C.DOM[N].apply(C.DOM,arguments);};};G.addDOMMethods=function(N){var O={};C.each(N,function(P,Q){O[P]=C.Node.wrapDOMMethod(P);});C.Node.methods(O);};G.prototype={init:function(O,T,N,Q){var P;T=I(T);this.getId=function(){return P;};var R=function(V,U){if(V){U=U||0;for(var W;W=O[U++];){V(W);}}return O;};P=C.guid();if(O){if(O[J]||O.document){O=[O];}}else{O=[];}if(!Q&&O.length){try{if(O[0].uniqueID){P=O[0].uniqueID;}O[0]._yuid=P;}catch(S){}}this._yuid=P;G[P]=R;if(!Q){M[P]=this;}this.initPlugins();},initPlugins:function(){C.each(G.PLUGINS,function(N,O){this.plug(O,N);});},filter:function(N){return G.scrubVal(A.filter(G[this._yuid](),N),this);},each:function(O,N){N=N||this;G[this._yuid](function(P){O.call(N,G.get(P));});},size:function(){return G[this._yuid]().length;},item:function(N){var O=G[this._yuid]()[N];return G.get(O);},attach:function(Q,P,N){var O=L.call(arguments,0);O.splice(2,0,G[this._yuid]());return C.Event.attach.apply(C.Event,O);},on:function(P,O,N){return this.attach.apply(this,arguments);},detach:function(P,O){var N=L.call(arguments,0);N.splice(2,0,G[this._yuid]());return C.Event.detach.apply(C.Event,N);},create:function(N){return C.Node.create(N);},plug:function(O,N){N=N||{};N.owner=this;if(O&&O.NS){this[O.NS]=new O(N);}return this;},toString:function(){var O="",N=G[this._yuid]()[0]||{};if(N){O+=N[E];if(N.id){O+="#"+N.id;}if(N.className){O+="."+N.className.replace(" ",".");}}else{"no nodes for "+this._yuid;}return O;}};G.methods({addEventListener:function(){return C.Event.nativeAdd.apply(C.Event,arguments);},removeEventListener:function(){return C.Event.nativeRemove.apply(C.Event,arguments);},set:function(N,P,O){if(P.indexOf(".")<0){if(P in G.setters){G.setters[P](this,P,O);}else{if(N[P]!==undefined){N[P]=O;}else{}}}else{G._deepSet(P.split("."),N,O);}},get:function(N,P){var O;if(P.indexOf(".")<0){if(P in G.getters){O=G.getters[P].call(this,N,P);}else{O=N[P];}if(O===undefined){O=null;}}else{O=G._deepGet(P.split("."),N);}return O;},invoke:function(Q,U,O,N,T,S,R){var P;if(O){O=(O[J])?O:F(O);if(N){N=(N[J])?N:F(N);}}P=Q[U](O,N,T,S,R);return P;},hasMethod:function(N,O){return !!N[O];},query:function(P,N){var O=A.query(N,P,true);if(!O){O=null;}return O;},queryAll:function(P,N){var O=A.query(N,P);if(!O.length){O=null;}return O;},test:function(O,N){return A.test(O,N);},compareTo:function(O,N){N=F(N)||O;return O===N;},ancestor:function(O,N){return C.DOM.elementByAxis(O,"parentNode",K(N));},previous:function(P,O,N){return C.DOM.elementByAxis(P,"previousSibling",K(O),N);},next:function(P,O,N){return C.DOM.elementByAxis(P,"nextSibling",K(O),N);},contains:function(N,O){return C.DOM.contains(N,F(O));},inDoc:function(N,O){O=(O)?I(O):N.ownerDocument;if(O.documentElement){return C.DOM.contains(O.documentElement,N);}},byId:function(O,P){var N=O[B].getElementById(P);if(!N||!C.DOM.contains(O,N)){N=null;}return N;}});G.create=function(N){return G.get(C.DOM.create(N));};G.getById=function(O,N){N=(N&&N[J])?N:C.config.doc;return G.get(N.getElementById(O));};G.get=function(Q,R,O,P){var N;if(Q){if(typeof Q==="string"){if(Q==="document"){Q=[C.config.doc];}else{Q=A.query(Q,R,!P);}}if(Q){if(!P){if(Q._yuid){if(!Q.uniqueID||(Q.uniqueID===Q._yuid)){N=M[Q._yuid];}}}if(!N){N=new G(Q,R,O,P);}if(N&&O&&!P){D[N._yuid]=true;}}}return(N&&N.size())?N:null;};G.all=function(O,P,N){return G.get.call(G,O,P,N,true);};C.Array.each(["replaceChild","appendChild","insertBefore","removeChild","hasChildNodes","cloneNode","getAttribute","setAttribute","hasAttribute","removeAttribute","scrollIntoView","getElementsByTagName","focus","blur","submit","reset","select"],function(N){G.prototype[N]=function(R,P,O){var Q=this.invoke(N,R,P,O);return Q;};});if(!document.documentElement.hasAttribute){G.methods({"hasAttribute":function(O,N){return !!O.getAttribute(N);}});}C.Node=G;C.all=C.Node.all;C.get=C.Node.get;C.Node.addDOMMethods(["getStyle","getComputedStyle","setStyle","setStyles"]);C.Node.addDOMMethods(["hasClass","addClass","removeClass","replaceClass","toggleClass"]);C.each(["region","viewportRegion"],function(N,O){C.Node.getters[N]=C.Node.wrapDOMMethod(N);});C.Node.addDOMMethods(["inViewportRegion"]);
+C.Node.methods({intersect:function(O,N,P){if(N instanceof C.Node){N=C.Node.getDOMNode(N);}return C.DOM.intersect(O,N,P);},inRegion:function(O,N,P,Q){if(N instanceof C.Node){N=C.Node.getDOMNode(N);}return C.DOM.inRegion(O,N,P,Q);}});C.each(["winWidth","winHeight","docWidth","docHeight","docScrollX","docScrollY"],function(N,O){C.Node.getters[N]=C.Node.wrapDOMMethod(N);});C.Node.addDOMMethods(["getXY","setXY","getX","setX","getY","setY"]);},"3.0.0pr2",{requires:["dom"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/node/node-screen-debug.js'
--- loggerhead/static/javascript/yui/build/node/node-screen-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-screen-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,191 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node-screen', function(Y) {
+
+/**
+ * Extended Node interface for managing regions and screen positioning.
+ * Adds support for positioning elements and normalizes window size and scroll detection. 
+ * @module node
+ * @submodule node-screen
+ * @for Node
+ */
+
+    Y.each([
+        /**
+         * Returns the inner width of the viewport (exludes scrollbar). 
+         * @property winWidth
+         * @type {Int}
+         */
+        'winWidth',
+
+        /**
+         * Returns the inner height of the viewport (exludes scrollbar). 
+         * @property winHeight
+         * @type {Int}
+         */
+        'winHeight',
+
+        /**
+         * Document width 
+         * @property winHeight
+         * @type {Int}
+         */
+        'docWidth',
+
+        /**
+         * Document height 
+         * @property docHeight
+         * @type {Int}
+         */
+        'docHeight',
+
+        /**
+         * Amount page has been scroll vertically 
+         * @property docScrollX
+         * @type {Int}
+         */
+        'docScrollX',
+
+        /**
+         * Amount page has been scroll horizontally 
+         * @property docScrollY
+         * @type {Int}
+         */
+        'docScrollY'
+        ],
+        function(v, n) {
+            Y.Node.getters[v] = Y.Node.wrapDOMMethod(v);
+        }
+    );
+
+    Y.Node.addDOMMethods([
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getXY
+     * @return {Array} The XY position of the node
+    */
+        'getXY',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setXY
+     * @param {Array} xy Contains X & Y values for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setXY',
+
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getX
+     * @return {Int} The X position of the node
+    */
+        'getX',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setX
+     * @param {Int} x X value for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setX',
+
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getY
+     * @return {Int} The Y position of the node
+    */
+        'getY',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setY
+     * @param {Int} y Y value for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setY'
+    ]);
+/**
+ * Extended Node interface for managing regions and screen positioning.
+ * Adds support for positioning elements and normalizes window size and scroll detection. 
+ * @module node
+ * @submodule node-screen
+ * @for Node
+ */
+Y.each([
+        /**
+         * Returns a region object for the node 
+         * @property region
+         * @type Node
+         */
+        'region',
+        /**
+         * Returns a region object for the node's viewport 
+         * @property viewportRegion
+         * @type Node
+         */
+        'viewportRegion'
+    ],
+
+    function(v, n) {
+        Y.Node.getters[v] = Y.Node.wrapDOMMethod(v);
+    }
+);
+
+Y.Node.addDOMMethods([
+    /**
+     * Determines whether or not the node is currently visible in the viewport. 
+     * @method inViewportRegion         
+     * @return {Boolean} Whether or not the node is currently positioned
+     * within the viewport's region
+     */
+    'inViewportRegion'
+]);
+
+// these need special treatment to extract 2nd node arg
+Y.Node.methods({
+    /**
+     * Compares the intersection of the node with another node or region 
+     * @method intersect         
+     * @param {Node|Object} node2 The node or region to compare with.
+     * @param {Object} altRegion An alternate region to use (rather than this node's). 
+     * @return {Object} An object representing the intersection of the regions. 
+     */
+    intersect: function(node1, node2, altRegion) {
+        if (node2 instanceof Y.Node) { // might be a region object
+            node2 = Y.Node.getDOMNode(node2);
+        }
+        return Y.DOM.intersect(node1, node2, altRegion); 
+    },
+
+    /**
+     * Determines whether or not the node is within the giving region.
+     * @method inRegion         
+     * @param {Node|Object} node2 The node or region to compare with.
+     * @param {Boolean} all Whether or not all of the node must be in the region. 
+     * @param {Object} altRegion An alternate region to use (rather than this node's). 
+     * @return {Object} An object representing the intersection of the regions. 
+     */
+    inRegion: function(node1, node2, all, altRegion) {
+        if (node2 instanceof Y.Node) { // might be a region object
+            node2 = Y.Node.getDOMNode(node2);
+        }
+        return Y.DOM.inRegion(node1, node2, all, altRegion); 
+    }
+});
+
+
+
+}, '3.0.0pr2' ,{requires:['dom-screen']});

=== added file 'loggerhead/static/javascript/yui/build/node/node-screen-min.js'
--- loggerhead/static/javascript/yui/build/node/node-screen-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-screen-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("node-screen",function(A){A.each(["winWidth","winHeight","docWidth","docHeight","docScrollX","docScrollY"],function(B,C){A.Node.getters[B]=A.Node.wrapDOMMethod(B);});A.Node.addDOMMethods(["getXY","setXY","getX","setX","getY","setY"]);A.each(["region","viewportRegion"],function(B,C){A.Node.getters[B]=A.Node.wrapDOMMethod(B);});A.Node.addDOMMethods(["inViewportRegion"]);A.Node.methods({intersect:function(C,B,D){if(B instanceof A.Node){B=A.Node.getDOMNode(B);}return A.DOM.intersect(C,B,D);},inRegion:function(C,B,D,E){if(B instanceof A.Node){B=A.Node.getDOMNode(B);}return A.DOM.inRegion(C,B,D,E);}});},"3.0.0pr2",{requires:["dom-screen"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/node/node-screen.js'
--- loggerhead/static/javascript/yui/build/node/node-screen.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-screen.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,191 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node-screen', function(Y) {
+
+/**
+ * Extended Node interface for managing regions and screen positioning.
+ * Adds support for positioning elements and normalizes window size and scroll detection. 
+ * @module node
+ * @submodule node-screen
+ * @for Node
+ */
+
+    Y.each([
+        /**
+         * Returns the inner width of the viewport (exludes scrollbar). 
+         * @property winWidth
+         * @type {Int}
+         */
+        'winWidth',
+
+        /**
+         * Returns the inner height of the viewport (exludes scrollbar). 
+         * @property winHeight
+         * @type {Int}
+         */
+        'winHeight',
+
+        /**
+         * Document width 
+         * @property winHeight
+         * @type {Int}
+         */
+        'docWidth',
+
+        /**
+         * Document height 
+         * @property docHeight
+         * @type {Int}
+         */
+        'docHeight',
+
+        /**
+         * Amount page has been scroll vertically 
+         * @property docScrollX
+         * @type {Int}
+         */
+        'docScrollX',
+
+        /**
+         * Amount page has been scroll horizontally 
+         * @property docScrollY
+         * @type {Int}
+         */
+        'docScrollY'
+        ],
+        function(v, n) {
+            Y.Node.getters[v] = Y.Node.wrapDOMMethod(v);
+        }
+    );
+
+    Y.Node.addDOMMethods([
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getXY
+     * @return {Array} The XY position of the node
+    */
+        'getXY',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setXY
+     * @param {Array} xy Contains X & Y values for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setXY',
+
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getX
+     * @return {Int} The X position of the node
+    */
+        'getX',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setX
+     * @param {Int} x X value for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setX',
+
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getY
+     * @return {Int} The Y position of the node
+    */
+        'getY',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setY
+     * @param {Int} y Y value for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setY'
+    ]);
+/**
+ * Extended Node interface for managing regions and screen positioning.
+ * Adds support for positioning elements and normalizes window size and scroll detection. 
+ * @module node
+ * @submodule node-screen
+ * @for Node
+ */
+Y.each([
+        /**
+         * Returns a region object for the node 
+         * @property region
+         * @type Node
+         */
+        'region',
+        /**
+         * Returns a region object for the node's viewport 
+         * @property viewportRegion
+         * @type Node
+         */
+        'viewportRegion'
+    ],
+
+    function(v, n) {
+        Y.Node.getters[v] = Y.Node.wrapDOMMethod(v);
+    }
+);
+
+Y.Node.addDOMMethods([
+    /**
+     * Determines whether or not the node is currently visible in the viewport. 
+     * @method inViewportRegion         
+     * @return {Boolean} Whether or not the node is currently positioned
+     * within the viewport's region
+     */
+    'inViewportRegion'
+]);
+
+// these need special treatment to extract 2nd node arg
+Y.Node.methods({
+    /**
+     * Compares the intersection of the node with another node or region 
+     * @method intersect         
+     * @param {Node|Object} node2 The node or region to compare with.
+     * @param {Object} altRegion An alternate region to use (rather than this node's). 
+     * @return {Object} An object representing the intersection of the regions. 
+     */
+    intersect: function(node1, node2, altRegion) {
+        if (node2 instanceof Y.Node) { // might be a region object
+            node2 = Y.Node.getDOMNode(node2);
+        }
+        return Y.DOM.intersect(node1, node2, altRegion); 
+    },
+
+    /**
+     * Determines whether or not the node is within the giving region.
+     * @method inRegion         
+     * @param {Node|Object} node2 The node or region to compare with.
+     * @param {Boolean} all Whether or not all of the node must be in the region. 
+     * @param {Object} altRegion An alternate region to use (rather than this node's). 
+     * @return {Object} An object representing the intersection of the regions. 
+     */
+    inRegion: function(node1, node2, all, altRegion) {
+        if (node2 instanceof Y.Node) { // might be a region object
+            node2 = Y.Node.getDOMNode(node2);
+        }
+        return Y.DOM.inRegion(node1, node2, all, altRegion); 
+    }
+});
+
+
+
+}, '3.0.0pr2' ,{requires:['dom-screen']});

=== added file 'loggerhead/static/javascript/yui/build/node/node-style-debug.js'
--- loggerhead/static/javascript/yui/build/node/node-style-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-style-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,53 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node-style', function(Y) {
+
+/**
+ * Extended Node interface for managing node styles.
+ * @module node
+ * @submodule node-style
+ * @for Node
+ */
+
+Y.Node.addDOMMethods([
+    /**
+     * Returns the style's current value.
+     * @method getStyle
+     * @param {String} attr The style attribute to retrieve. 
+     * @return {String} The current value of the style property for the element.
+     */
+    'getStyle',
+
+    /**
+     * Returns the computed value for the given style property.
+     * @method getComputedStyle
+     * @param {String} attr The style attribute to retrieve. 
+     * @return {String} The computed value of the style property for the element.
+     */
+    'getComputedStyle',
+
+    /**
+     * Sets a style property of the node.
+     * @method setStyle
+     * @param {String} attr The style attribute to set. 
+     * @param {String|Number} val The value. 
+     * @chainable
+     */
+    'setStyle',
+
+    /**
+     * Sets multiple style properties on the node.
+     * @method setStyles
+     * @param {Object} hash An object literal of property:value pairs. 
+     * @chainable
+     */
+    'setStyles'
+]);
+
+
+
+}, '3.0.0pr2' ,{requires:['dom-style', 'node-base']});

=== added file 'loggerhead/static/javascript/yui/build/node/node-style-min.js'
--- loggerhead/static/javascript/yui/build/node/node-style-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-style-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("node-style",function(A){A.Node.addDOMMethods(["getStyle","getComputedStyle","setStyle","setStyles"]);},"3.0.0pr2",{requires:["dom-style","node-base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/node/node-style.js'
--- loggerhead/static/javascript/yui/build/node/node-style.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node-style.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,53 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node-style', function(Y) {
+
+/**
+ * Extended Node interface for managing node styles.
+ * @module node
+ * @submodule node-style
+ * @for Node
+ */
+
+Y.Node.addDOMMethods([
+    /**
+     * Returns the style's current value.
+     * @method getStyle
+     * @param {String} attr The style attribute to retrieve. 
+     * @return {String} The current value of the style property for the element.
+     */
+    'getStyle',
+
+    /**
+     * Returns the computed value for the given style property.
+     * @method getComputedStyle
+     * @param {String} attr The style attribute to retrieve. 
+     * @return {String} The computed value of the style property for the element.
+     */
+    'getComputedStyle',
+
+    /**
+     * Sets a style property of the node.
+     * @method setStyle
+     * @param {String} attr The style attribute to set. 
+     * @param {String|Number} val The value. 
+     * @chainable
+     */
+    'setStyle',
+
+    /**
+     * Sets multiple style properties on the node.
+     * @method setStyles
+     * @param {Object} hash An object literal of property:value pairs. 
+     * @chainable
+     */
+    'setStyles'
+]);
+
+
+
+}, '3.0.0pr2' ,{requires:['dom-style', 'node-base']});

=== added file 'loggerhead/static/javascript/yui/build/node/node.js'
--- loggerhead/static/javascript/yui/build/node/node.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/node/node.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1134 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('node', function(Y) {
+
+    /**
+     * The Node Utility provides a DOM-like interface for interacting with DOM nodes.
+     * @module node
+     * @submodule node-base
+     */    
+
+    /**
+     * The Node class provides a wrapper for manipulating DOM Nodes.
+     * Node properties can be accessed via the set/get methods.
+     * Use Y.get() to retrieve Node instances.
+     *
+     * <strong>NOTE:</strong> Node properties are accessed using
+     * the <code>set</code> and <code>get</code> methods.
+     *
+     * @class Node
+     * @constructor
+     */
+
+    var OWNER_DOCUMENT = 'ownerDocument',
+        TAG_NAME = 'tagName',
+        NODE_NAME = 'nodeName',
+        NODE_TYPE = 'nodeType',
+
+        Selector = Y.Selector,
+        _instances = {},
+        _restrict = {},
+        _slice = [].slice;
+
+    // used with previous/next/ancestor tests
+    var _wrapFn = function(fn) {
+        var ret = null;
+        if (fn) {
+            ret = (typeof fn === 'string') ?
+            function(n) {
+                return Y.Selector.test(n, fn);
+            } : 
+            function(n) {
+                return fn(Y.get(n));
+            };
+        }
+
+        return ret;
+    };
+
+    var _getDoc = function(node) {
+        var doc = Y.config.doc;
+
+        if (node) {
+            if (node[NODE_TYPE]) {
+                if (node[NODE_TYPE] === 9) { // already a document node
+                    doc = node;
+                } else {
+                    doc = node[OWNER_DOCUMENT];
+                }
+            } else if (Node[node._yuid]) { // Node instance document
+                doc = Node[node._yuid]()[0];
+            }
+        }
+
+        return doc;
+    };
+
+    var _getDOMNode = function(node) {
+        if (node && !node[NODE_TYPE] && node._yuid) {
+            node = Node[node._yuid]()[0];
+        }
+
+        return  node || null;
+    };
+
+    var Node = function() {
+        this.init.apply(this, arguments);
+    };
+
+    Node.PLUGINS = {};
+
+    Node._deepGet = function (path, val) {
+        var pl = path.length,
+            i;
+
+        if (pl > 0) {
+            for (i = 0; val !== undefined && i < pl; ++i) {
+                val = val[path[i]];
+            }
+        }
+
+        return val;
+    };
+
+    Node._deepSet = function(path, val, subval) {
+        var leafIdx = path.length-1,
+            i,
+            o;
+
+        if (leafIdx >= 0) {
+            o = val;
+
+            for (i = 0; o !== undefined && i < leafIdx; ++i) {
+                o = o[path[i]];
+            }
+
+            if (o !== undefined && o[path[i]] !== undefined) {
+                o[path[i]] = subval;
+            }
+        }
+    };
+
+    Node.scrubVal = function(val, node, depth) {
+        if (val !== undefined) {
+            if (typeof val === 'object' || typeof val === 'function') { // safari nodeList === function
+                if (val !== null && (
+                        NODE_TYPE in val || // dom node
+                        val.item || // dom collection or Node instance
+                        (val[0] && val[0][NODE_TYPE]) || // assume array of nodes
+                        val.document) // window TODO: restrict?
+                    ) { 
+                    if (node && _restrict && _restrict[node._yuid] && !node.contains(val)) {
+                        val = null; // not allowed to go outside of root node
+                    } else {
+                        if (val[NODE_TYPE] || val.document) { // node or window
+                            val = Node.get(val);
+                        } else {
+                            val = Node.all(val);
+                        }
+                    }
+                } else {
+                    depth = (depth === undefined) ? 4 : depth;
+                    if (depth > 0) {
+                        for (var i in val) {
+                            if (val.hasOwnProperty && val.hasOwnProperty(i)) {
+                                val[i] = Node.scrubVal(val[i], node, --depth);
+                            }
+                        }
+                    }
+                    
+                }
+            }
+        } else {
+            val = node; // for chaining
+        }
+
+        return val;
+    };
+
+    Node.setters = {};
+    Node.getters = {
+        /**
+         * Normalizes nodeInnerText and textContent. 
+         * @property text
+         * @type String
+         */
+        'text': function(node) {
+            return Y.DOM.getText(node);
+        },
+
+        'options': function(node) {
+            return (node) ? node.getElementsByTagName('option') : [];
+        },
+
+        /**
+         * Returns a NodeList instance. 
+         * @property children
+         * @type NodeList
+         */
+        'children': function(node) {
+            var children = node.children;
+
+            if (children === undefined) {
+                var childNodes = node.childNodes;
+                children = [];
+
+                for (var i = 0, len = childNodes.length; i < len; ++i) {
+                    if (childNodes[i][TAG_NAME]) {
+                        children[children.length] = childNodes[i];
+                    }
+                }
+            }
+            return children;
+        }
+    };
+
+    Node.methods = function(name, fn) {
+        if (typeof name == 'string') {
+            Node.prototype[name] = function() {
+                var args = _slice.call(arguments, 0),
+                    instance = this,
+                    getAll =  (_instances[this._yuid]) ? false : true, // return array of vals for lists
+                    ret = (getAll) ? [] : null,
+                    val;
+
+                var getValue = function(node) {
+                    args[0] = node;
+                    val = Node.scrubVal(fn.apply(instance, args), instance);
+                    if (getAll) {
+                        ret[ret.length] = val;
+                    } else {
+                        ret = val;
+                    }
+                };
+
+                args.unshift('');
+                Node[instance._yuid](getValue);
+                return ret;
+            };
+        } else { // assume object
+            Y.each(name, function(fn, name) {
+                Node.methods(name, fn);
+            });
+        }
+
+    };
+
+    Node.getDOMNode = _getDOMNode;
+    
+    Node.wrapDOMMethod = function(name) {
+        return function() {
+            return Y.DOM[name].apply(Y.DOM, arguments);
+        };
+
+    };
+
+    Node.addDOMMethods = function(methods) {
+        var add = {}; 
+        Y.each(methods, function(v, n) {
+            add[v] = Y.Node.wrapDOMMethod(v);
+        });
+
+        Y.Node.methods(add);
+    };
+
+    Node.prototype = {
+        init: function(nodes, doc, isRoot, getAll) {
+            var uid;
+
+            doc = _getDoc(doc);
+
+            this.getId = function() {
+                return uid;
+            };
+
+            var _all = function(fn, i) {
+                if (fn) {
+                    i = i || 0;
+                    for (var node; node = nodes[i++];) {
+                        fn(node);
+                    }
+                }
+                return nodes;
+            };
+
+            // uid = selector || Y.guid(); // to cache queryAll results
+            uid = Y.guid();
+
+            if (nodes) { // zero length collection returns null
+                if (nodes[NODE_TYPE] || nodes.document) { // node or window
+                    nodes = [nodes];
+                }
+            } else {
+                nodes = [];
+            }
+
+            if (!getAll && nodes.length) { // stamp the dom node
+                try { // IE only allows ID on Element
+                    if (nodes[0].uniqueID) {
+                        uid = nodes[0].uniqueID;
+                    }
+                    nodes[0]._yuid = uid;
+                } catch(e) { // not cacheable
+                }
+            }
+
+            this._yuid = uid;
+            Node[uid] = _all; // for applying/returning dom nodes
+
+            if (!getAll) {
+                _instances[uid] = this;
+            }
+
+            this.initPlugins();
+        },
+
+        initPlugins: function() {
+            Y.each(Node.PLUGINS, function(config, fn) {
+                this.plug(fn, config);
+            });
+        },
+
+        /**
+         * Filters the NodeList instance down to only nodes matching the given selector.
+         * @method filter
+         * @param {String} selector The selector to filter against
+         * @return {NodeList} NodeList containing the updated collection 
+         * @see Selector
+         */
+        filter: function(selector) {
+            return Node.scrubVal(Selector.filter(Node[this._yuid](), selector), this);
+        },
+
+        /**
+         * Applies the given function to each Node in the NodeList.
+         * @method each
+         * @param {Function} fn The function to apply 
+         * @param {Object} context optional An optional context to apply the function with
+         * Default context is the NodeList instance
+         * @return {NodeList} NodeList containing the updated collection 
+         * @chainable
+         */
+        each: function(fn, context) {
+            context = context || this;
+            Node[this._yuid](function(node) {
+                fn.call(context, Node.get(node));
+            });
+        },
+
+        /**
+         * Returns the current number of items in the NodeList.
+         * @method size
+         * @return {Int} The number of items in the NodeList. 
+         */
+        size: function() {
+            return Node[this._yuid]().length;
+        },
+
+        /**
+         * Retrieves the Node instance at the given index. 
+         * @method item
+         *
+         * @param {Number} index The index of the target Node.
+         * @return {Node} The Node instance at the given index.
+         */
+        item: function(index) {
+            var node = Node[this._yuid]()[index];
+            return Node.get(node);
+        },
+
+       /**
+         * Attaches a DOM event handler.
+         * @method attach
+         * @param {String} type The type of DOM Event to listen for 
+         * @param {Function} fn The handler to call when the event fires 
+         * @param {Object} arg An argument object to pass to the handler 
+         */
+
+        attach: function(type, fn, arg) {
+            var args = _slice.call(arguments, 0);
+            args.splice(2, 0, Node[this._yuid]());
+            return Y.Event.attach.apply(Y.Event, args);
+        },
+
+       /**
+         * Alias for attach.
+         * @method on
+         * @param {String} type The type of DOM Event to listen for 
+         * @param {Function} fn The handler to call when the event fires 
+         * @param {Object} arg An argument object to pass to the handler 
+         * @see attach
+         */
+        on: function(type, fn, arg) {
+            return this.attach.apply(this, arguments);
+        },
+
+       /**
+         * Detaches a DOM event handler. 
+         * @method detach
+         * @param {String} type The type of DOM Event
+         * @param {Function} fn The handler to call when the event fires 
+         */
+        detach: function(type, fn) {
+            var args = _slice.call(arguments, 0);
+            args.splice(2, 0, Node[this._yuid]());
+            return Y.Event.detach.apply(Y.Event, args);
+        },
+
+       /**
+         * Creates a Node instance from HTML string
+         * @method create
+         * @param {String|Array} html The string of html to create
+         * @return {Node} A new Node instance 
+         */
+        create: function(html) {
+            return Y.Node.create(html);
+        },
+
+        /**
+         * Applies the supplied plugin to the node.
+         * @method plug
+         * @param {Function} The plugin Class to apply
+         * @param {Object} config An optional config to pass to the constructor
+         * @chainable
+         */
+        plug: function(PluginClass, config) {
+            config = config || {};
+            config.owner = this;
+            if (PluginClass && PluginClass.NS) {
+                this[PluginClass.NS] = new PluginClass(config);
+            }
+            return this;
+        },
+
+        //normalize: function() {},
+        //isSupported: function(feature, version) {},
+        toString: function() {
+            var str = '', 
+            node = Node[this._yuid]()[0] || {};
+
+            if (node) {
+                str += node[NODE_NAME];
+                if (node.id) {
+                    str += '#' + node.id; 
+                }
+
+                if (node.className) {
+                    str += '.' + node.className.replace(' ', '.'); 
+                }
+            } else {
+                'no nodes for ' + this._yuid;
+            }
+            return str;
+        }
+    };
+
+    Node.methods({
+        addEventListener: function() {
+            return Y.Event.nativeAdd.apply(Y.Event, arguments);
+        },
+        
+        removeEventListener: function() {
+            return Y.Event.nativeRemove.apply(Y.Event, arguments);
+        },
+
+        /**
+         * Set the value of the property/attribute on the HTMLElement bound to this Node.
+         * Only strings/numbers/booleans are passed through unless a SETTER exists.
+         * @method set
+         * @param {String} prop Property to set 
+         * @param {any} val Value to apply to the given property
+         * @chainable
+         */
+        // TODO: document.location.href
+        set: function(node, prop, val) {
+            if (prop.indexOf('.') < 0) {
+                if (prop in Node.setters) { // use custom setter
+                    Node.setters[prop](this, prop, val);  // passing Node instance
+                } else if (node[prop] !== undefined) { // no expandos 
+                    node[prop] = val;
+                } else {
+                }
+            } else {
+                Node._deepSet(prop.split('.'), node, val);
+            }
+        },
+
+        /**
+         * Get the value of the property/attribute on the HTMLElement bound to this Node.
+         * Only strings/numbers/booleans are passed through unless a GETTER exists.
+         * @method get
+         * @param {String} prop Property to get 
+         * @return {any} Current value of the property
+         */
+        get: function(node, prop) {
+            var val;
+            if (prop.indexOf('.') < 0) {
+                if (prop in Node.getters) { // use custom getter
+                    val = Node.getters[prop].call(this, node, prop);
+                } else {
+                    val = node[prop];
+                }
+
+                // method wrapper uses undefined in chaining test
+                if (val === undefined) {
+                    val = null;
+                }
+            } else {
+                val = Node._deepGet(prop.split('.'), node);
+            }
+
+            return val;
+        },
+
+        invoke: function(node, method, a, b, c, d, e) {
+            var ret;
+
+            if (a) { // first 2 may be Node instances
+                a = (a[NODE_TYPE]) ? a : _getDOMNode(a);
+                if (b) {
+                    b = (b[NODE_TYPE]) ? b : _getDOMNode(b);
+                }
+            }
+
+            ret = node[method](a, b, c, d, e);    
+            return ret;
+        },
+
+        hasMethod: function(node, method) {
+            return !! node[method];
+        },
+
+        /**
+         * Retrieves a Node instance of nodes based on the given CSS selector. 
+         * @method query
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {Node} A Node instance for the matching HTMLElement.
+         */
+        query: function(node, selector) {
+            var ret = Selector.query(selector, node, true);
+            if (!ret) {
+                ret = null;
+            }
+
+            return ret;
+        },
+
+        /**
+         * Retrieves a nodeList based on the given CSS selector. 
+         * @method queryAll
+         * @deprecated Use query() which returns all matches
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {NodeList} A NodeList instance for the matching HTMLCollection/Array.
+         */
+        queryAll: function(node, selector) {
+            var ret = Selector.query(selector, node);
+            if (!ret.length) {
+                ret = null;
+            }
+
+            return ret;
+        },
+
+        /**
+         * Test if the supplied node matches the supplied selector.
+         * @method test
+         *
+         * @param {string} selector The CSS selector to test against.
+         * @return {boolean} Whether or not the node matches the selector.
+         */
+        test: function(node, selector) {
+            return Selector.test(node, selector);
+        },
+
+        /**
+         * Compares nodes to determine if they match.
+         * Node instances can be compared to each other and/or HTMLElements.
+         * @method compareTo
+         * @param {HTMLElement | Node} refNode The reference node to compare to the node.
+         * @return {Boolean} True if the nodes match, false if they do not. 
+         */
+        compareTo: function(node, refNode) {
+            refNode = _getDOMNode(refNode) || node;
+            return node === refNode;
+        },
+
+       /**
+         * Returns the nearest ancestor that passes the test applied by supplied boolean method.
+         * @method ancestor
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @return {Node} The matching Node instance or null if not found
+         */
+        ancestor: function(node, fn) {
+            return Y.DOM.elementByAxis(node, 'parentNode', _wrapFn(fn));
+        },
+
+        /**
+         * Returns the previous matching sibling. 
+         * Returns the nearest element node sibling if no method provided.
+         * @method previous
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+         * @return {Node} Node instance or null if not found
+         */
+        previous: function(node, fn, all) {
+            return Y.DOM.elementByAxis(node, 'previousSibling', _wrapFn(fn), all);
+        }, 
+
+        /**
+         * Returns the next matching sibling. 
+         * Returns the nearest element node sibling if no method provided.
+         * @method next
+         * @param {String | Function} fn A selector or boolean method for testing elements.
+         * If a function is used, it receives the current node being tested as the only argument.
+         * @param {Boolean} all optional Whether all node types should be returned, or just element nodes.
+         * @return {Node} Node instance or null if not found
+         */
+        next: function(node, fn, all) {
+            return Y.DOM.elementByAxis(node, 'nextSibling', _wrapFn(fn), all);
+        },
+        
+        /**
+         * Determines whether the ndoe is an ancestor of another HTML element in the DOM hierarchy.
+         * @method contains
+         * @param {Node | HTMLElement} needle The possible node or descendent
+         * @return {Boolean} Whether or not this node is the needle its ancestor
+         */
+        contains: function(node, needle) {
+            return Y.DOM.contains(node, _getDOMNode(needle));
+        },
+
+        /**
+         * Determines whether the node is appended to the document.
+         * @method inDoc
+         * @param {Node|HTMLElement} doc optional An optional document to check against.
+         * Defaults to current document. 
+         * @return {Boolean} Whether or not this node is appended to the document. 
+         */
+        inDoc: function(node, doc) {
+            doc = (doc) ? _getDoc(doc) : node.ownerDocument;
+            if (doc.documentElement) {
+                return Y.DOM.contains(doc.documentElement, node);
+            }
+        },
+
+        byId: function(node, id) {
+            var ret = node[OWNER_DOCUMENT].getElementById(id);
+            if (!ret || !Y.DOM.contains(node, ret)) {
+                ret = null;
+            }
+            return ret;
+        }
+
+    });
+
+    /** 
+     * Creates a Node instance from an HTML string
+     * @method create
+     * @param {String} html HTML string
+     */
+    Node.create = function(html) {
+        return Node.get(Y.DOM.create(html));
+    };
+
+    Node.getById = function(id, doc) {
+        doc = (doc && doc[NODE_TYPE]) ? doc : Y.config.doc;
+        return Node.get(doc.getElementById(id));
+    };
+
+    /**
+     * Retrieves a Node instance for the given query or nodes. 
+     * Note: Use 'document' string to retrieve document Node instance from string
+     * @method Y.get
+     * @static
+     * @param {document|HTMLElement|HTMLCollection|Array|String} node The object to wrap.
+     * @param {document|Node} doc optional The document containing the node. Defaults to current document.
+     * @param {boolean} isRoot optional Whether or not this node should be treated as a root node. Root nodes
+     * aren't allowed to traverse outside their DOM tree.
+     * @return {Node} A Node instance bound to the supplied node(s).
+     */
+    Node.get = function(node, doc, isRoot, getAll) {
+        var instance;
+
+        if (node) {
+            if (typeof node === 'string') {
+                if (node === 'document') { // TODO: allow 'doc'? 'window'?
+                    node = [Y.config.doc];
+                } else {
+                    node = Selector.query(node, doc, !getAll); // Selector arg is getFirst
+                }
+            }
+
+            if (node) {
+                if (!getAll) { // reuse single element node instances
+                    if (node._yuid) {
+                        // verify IE's uniqueID in case the node was cloned
+                        if (!node.uniqueID || (node.uniqueID === node._yuid)) {
+                            instance = _instances[node._yuid];
+                        }
+                    }
+                }
+
+                if (!instance) {
+                    instance = new Node(node, doc, isRoot, getAll);
+                }
+
+                if (instance && isRoot && !getAll) {
+                    _restrict[instance._yuid] = true;
+                }
+            }
+        }
+
+        // zero length collection returns null
+        return (instance && instance.size()) ? instance : null;
+    };
+
+    /**
+     * Retrieves a NodeList instance for the given object/string. 
+     * @method Y.all
+     * @static
+     * @param {HTMLCollection|Array|String} node The object to wrap.
+     * @param {document|Node} doc optional The document containing the node. Defaults to current document.
+     * @param {boolean} isRoot optional Whether or not this node should be treated as a root node. Root nodes
+     * @return {NodeList} A NodeList instance for the supplied nodes.
+     */
+    Node.all = function(node, doc, isRoot) {
+        return Node.get.call(Node, node, doc, isRoot, true);
+    };
+
+    Y.Array.each([
+        /**
+         * Passes through to DOM method.
+         * @method replaceChild
+         * @param {HTMLElement | Node} node Node to be inserted 
+         * @param {HTMLElement | Node} refNode Node to be replaced 
+         * @return {Node} The replaced node 
+         */
+        'replaceChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method appendChild
+         * @param {HTMLElement | Node} node Node to be appended 
+         * @return {Node} The appended node 
+         */
+        'appendChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method insertBefore
+         * @param {HTMLElement | Node} newNode Node to be appended 
+         * @param {HTMLElement | Node} refNode Node to be inserted before 
+         * @return {Node} The inserted node 
+         */
+        'insertBefore',
+
+        /**
+         * Passes through to DOM method.
+         * @method removeChild
+         * @param {HTMLElement | Node} node Node to be removed 
+         * @return {Node} The removed node 
+         */
+        'removeChild',
+
+        /**
+         * Passes through to DOM method.
+         * @method hasChildNodes
+         * @return {Boolean} Whether or not the node has any childNodes 
+         */
+        'hasChildNodes',
+
+        /**
+         * Passes through to DOM method.
+         * @method cloneNode
+         * @param {HTMLElement | Node} node Node to be cloned 
+         * @return {Node} The clone 
+         */
+        'cloneNode',
+
+        /**
+         * Passes through to DOM method.
+         * @method getAttribute
+         * @param {String} attribute The attribute to retrieve 
+         * @return {String} The current value of the attribute 
+         */
+        'getAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method setAttribute
+         * @param {String} attribute The attribute to set 
+         * @param {String} The value to apply to the attribute 
+         * @chainable
+         */
+        'setAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method hasAttribute
+         * @param {String} attribute The attribute to test for 
+         * @return {Boolean} Whether or not the attribute is present 
+         */
+        'hasAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method removeAttribute
+         * @param {String} attribute The attribute to be removed 
+         * @chainable
+         */
+        'removeAttribute',
+
+        /**
+         * Passes through to DOM method.
+         * @method scrollIntoView
+         * @chainable
+         */
+        'scrollIntoView',
+
+        /**
+         * Passes through to DOM method.
+         * @method getElementsByTagName
+         * @param {String} tagName The tagName to collect 
+         * @return {NodeList} A NodeList representing the HTMLCollection
+         */
+        'getElementsByTagName',
+
+        /**
+         * Passes through to DOM method.
+         * @method focus
+         * @chainable
+         */
+        'focus',
+
+        /**
+         * Passes through to DOM method.
+         * @method blur
+         * @chainable
+         */
+        'blur',
+
+        /**
+         * Passes through to DOM method.
+         * Only valid on FORM elements
+         * @method submit
+         * @chainable
+         */
+        'submit',
+
+        /**
+         * Passes through to DOM method.
+         * Only valid on FORM elements
+         * @method reset
+         * @chainable
+         */
+        'reset',
+
+        /**
+         * Passes through to DOM method.
+         * @method select
+         * @chainable
+         */
+         'select'
+    ], function(method) {
+        Node.prototype[method] = function(arg1, arg2, arg3) {
+            var ret = this.invoke(method, arg1, arg2, arg3);
+            return ret;
+        };
+    });
+
+    if (!document.documentElement.hasAttribute) {
+        Node.methods({
+            'hasAttribute': function(node, att) {
+                return !! node.getAttribute(att);
+            }
+        });
+    }
+
+    // used to call Node methods against NodeList nodes
+    Y.Node = Node;
+    Y.all = Y.Node.all;
+    Y.get = Y.Node.get;
+/**
+ * Extended Node interface for managing node styles.
+ * @module node
+ * @submodule node-style
+ * @for Node
+ */
+
+Y.Node.addDOMMethods([
+    /**
+     * Returns the style's current value.
+     * @method getStyle
+     * @param {String} attr The style attribute to retrieve. 
+     * @return {String} The current value of the style property for the element.
+     */
+    'getStyle',
+
+    /**
+     * Returns the computed value for the given style property.
+     * @method getComputedStyle
+     * @param {String} attr The style attribute to retrieve. 
+     * @return {String} The computed value of the style property for the element.
+     */
+    'getComputedStyle',
+
+    /**
+     * Sets a style property of the node.
+     * @method setStyle
+     * @param {String} attr The style attribute to set. 
+     * @param {String|Number} val The value. 
+     * @chainable
+     */
+    'setStyle',
+
+    /**
+     * Sets multiple style properties on the node.
+     * @method setStyles
+     * @param {Object} hash An object literal of property:value pairs. 
+     * @chainable
+     */
+    'setStyles'
+]);
+
+/**
+ * Extended Node interface for managing classNames.
+ * @module node
+ * @submodule node
+ * @for Node
+ */
+
+    Y.Node.addDOMMethods([
+        /**
+         * Determines whether the node has the given className.
+         * @method hasClass
+         * @param {String} className the class name to search for
+         * @return {Boolean} Whether or not the node has the given class. 
+         */
+        'hasClass',
+
+        /**
+         * Adds a class name to the node.
+         * @method addClass         
+         * @param {String} className the class name to add to the node's class attribute
+         * @chainable
+         */
+        'addClass',
+
+        /**
+         * Removes a class name from the node.
+         * @method removeClass         
+         * @param {String} className the class name to remove from the node's class attribute
+         * @chainable
+         */
+        'removeClass',
+
+        /**
+         * Replace a class with another class.
+         * If no oldClassName is present, the newClassName is simply added.
+         * @method replaceClass  
+         * @param {String} oldClassName the class name to be replaced
+         * @param {String} newClassName the class name that will be replacing the old class name
+         * @chainable
+         */
+        'replaceClass',
+
+        /**
+         * If the className exists on the node it is removed, if it doesn't exist it is added.
+         * @method toggleClass  
+         * @param {String} className the class name to be toggled
+         * @chainable
+         */
+        'toggleClass'
+    ]);
+/**
+ * Extended Node interface for managing regions and screen positioning.
+ * Adds support for positioning elements and normalizes window size and scroll detection. 
+ * @module node
+ * @submodule node-screen
+ * @for Node
+ */
+Y.each([
+        /**
+         * Returns a region object for the node 
+         * @property region
+         * @type Node
+         */
+        'region',
+        /**
+         * Returns a region object for the node's viewport 
+         * @property viewportRegion
+         * @type Node
+         */
+        'viewportRegion'
+    ],
+
+    function(v, n) {
+        Y.Node.getters[v] = Y.Node.wrapDOMMethod(v);
+    }
+);
+
+Y.Node.addDOMMethods([
+    /**
+     * Determines whether or not the node is currently visible in the viewport. 
+     * @method inViewportRegion         
+     * @return {Boolean} Whether or not the node is currently positioned
+     * within the viewport's region
+     */
+    'inViewportRegion'
+]);
+
+// these need special treatment to extract 2nd node arg
+Y.Node.methods({
+    /**
+     * Compares the intersection of the node with another node or region 
+     * @method intersect         
+     * @param {Node|Object} node2 The node or region to compare with.
+     * @param {Object} altRegion An alternate region to use (rather than this node's). 
+     * @return {Object} An object representing the intersection of the regions. 
+     */
+    intersect: function(node1, node2, altRegion) {
+        if (node2 instanceof Y.Node) { // might be a region object
+            node2 = Y.Node.getDOMNode(node2);
+        }
+        return Y.DOM.intersect(node1, node2, altRegion); 
+    },
+
+    /**
+     * Determines whether or not the node is within the giving region.
+     * @method inRegion         
+     * @param {Node|Object} node2 The node or region to compare with.
+     * @param {Boolean} all Whether or not all of the node must be in the region. 
+     * @param {Object} altRegion An alternate region to use (rather than this node's). 
+     * @return {Object} An object representing the intersection of the regions. 
+     */
+    inRegion: function(node1, node2, all, altRegion) {
+        if (node2 instanceof Y.Node) { // might be a region object
+            node2 = Y.Node.getDOMNode(node2);
+        }
+        return Y.DOM.inRegion(node1, node2, all, altRegion); 
+    }
+});
+
+/**
+ * Extended Node interface for managing regions and screen positioning.
+ * Adds support for positioning elements and normalizes window size and scroll detection. 
+ * @module node
+ * @submodule node-screen
+ * @for Node
+ */
+
+    Y.each([
+        /**
+         * Returns the inner width of the viewport (exludes scrollbar). 
+         * @property winWidth
+         * @type {Int}
+         */
+        'winWidth',
+
+        /**
+         * Returns the inner height of the viewport (exludes scrollbar). 
+         * @property winHeight
+         * @type {Int}
+         */
+        'winHeight',
+
+        /**
+         * Document width 
+         * @property winHeight
+         * @type {Int}
+         */
+        'docWidth',
+
+        /**
+         * Document height 
+         * @property docHeight
+         * @type {Int}
+         */
+        'docHeight',
+
+        /**
+         * Amount page has been scroll vertically 
+         * @property docScrollX
+         * @type {Int}
+         */
+        'docScrollX',
+
+        /**
+         * Amount page has been scroll horizontally 
+         * @property docScrollY
+         * @type {Int}
+         */
+        'docScrollY'
+        ],
+        function(v, n) {
+            Y.Node.getters[v] = Y.Node.wrapDOMMethod(v);
+        }
+    );
+
+    Y.Node.addDOMMethods([
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getXY
+     * @return {Array} The XY position of the node
+    */
+        'getXY',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setXY
+     * @param {Array} xy Contains X & Y values for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setXY',
+
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getX
+     * @return {Int} The X position of the node
+    */
+        'getX',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setX
+     * @param {Int} x X value for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setX',
+
+    /**
+     * Gets the current position of the node in page coordinates. 
+     * Nodes must be part of the DOM tree to have page coordinates
+     * (display:none or nodes not appended return false).
+     * @method getY
+     * @return {Int} The Y position of the node
+    */
+        'getY',
+
+    /**
+     * Set the position of the node in page coordinates, regardless of how the node is positioned.
+     * The node must be part of the DOM tree to have page coordinates (display:none or elements not appended return false).
+     * @method setY
+     * @param {Int} y Y value for new position (coordinates are page-based)
+     * @chainable
+     */
+        'setY'
+    ]);
+
+
+}, '3.0.0pr2' ,{requires:['dom']});

=== added directory 'loggerhead/static/javascript/yui/build/oop'
=== added file 'loggerhead/static/javascript/yui/build/oop/README'
--- loggerhead/static/javascript/yui/build/oop/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/oop/README	2008-10-20 07:34:21 +0000
@@ -0,0 +1,5 @@
+YUI OOP Utilities
+    Provides inheritance and object modification utilities
+
+3.0.0pr1
+    Initial release

=== added file 'loggerhead/static/javascript/yui/build/oop/oop-debug.js'
--- loggerhead/static/javascript/yui/build/oop/oop-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/oop/oop-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,339 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * OOP utils.  If included, the OOP methods are added to the YUI instance
+ * @module oop
+ */
+YUI.add("oop", function(Y) {
+
+    var L = Y.Lang, 
+    A = Y.Array,
+    OP = Object.prototype,
+    O;
+
+    /**
+     * The following methods are added to the YUI instance
+     * @class YUI~oop
+     */
+
+    /**
+     * Applies prototype properties from the supplier to the receiver.
+     * The receiver can be a constructor or an instance.
+     * @method augment
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param ov {boolean} if true, properties already on the receiver
+     * will be overwritten if found on the supplier.
+     * @param wl {string[]} a whitelist.  If supplied, only properties in 
+     * this list will be applied to the receiver.
+     * @param args {Array | Any} arg or arguments to apply to the supplier
+     * constructor when initializing.
+     * @return {object} the augmented object
+     *
+     * @todo constructor optional?
+     * @todo understanding what an instance is augmented with
+     * @TODO evaluate if we can do this in a way that doesn't interfere
+     * with normal inheritance
+     */
+    Y.augment = function(r, s, ov, wl, args) {
+
+        var sProto = s.prototype, newProto = null, construct = s, 
+            a = (args) ? Y.Array(args) : [], rProto = r.prototype, 
+            target =  rProto || r, applyConstructor = false;
+
+        // working on a class, so apply constructor infrastructure
+        if (rProto && construct) {
+
+            // Y.log('augment will call constructor:');
+
+            // Y.Do.before(r, construct);
+
+            var sequestered = {}, replacements = {};
+            newProto = {};
+
+            // sequester all of the functions in the supplier and replace with
+            // one that will restore all of them.
+            Y.each(sProto, function(v, k) {
+
+
+                // var initialized = false;
+
+                replacements[k] = function() {
+
+                    var me = this;
+
+// Y.log('sequestered function "' + k + '" executed.  Initializing Event.Target');
+
+                    // overwrite the prototype with all of the sequestered functions,
+                    // but only if it hasn't been overridden
+                    for (var i in sequestered) {
+                        if (Y.Object.owns(sequestered, i) && (me[i] === replacements[i])) {
+                            // Y.log('... restoring ' + k);
+                            me[i] = sequestered[i];
+                        }
+                    }
+
+                    // apply the constructor
+                    construct.apply(me, a);
+
+                    // apply the original sequestered function
+                    return sequestered[k].apply(me, arguments);
+
+                };
+
+                if ((!wl || (k in wl)) && (ov || !(k in this))) {
+
+                    // Y.log('augment: ' + k);
+
+                    if (L.isFunction(v)) {
+
+                        // sequester the function
+                        sequestered[k] = v;
+
+                        // replace the sequestered function with a function that will
+                        // restore all sequestered functions and exectue the constructor.
+                        this[k] = replacements[k];
+
+                    } else {
+
+                        // Y.log('augment() applying non-function: ' + k);
+
+                        this[k] = v;
+                    }
+
+                }
+
+            }, newProto, true);
+
+        // augmenting an instance, so apply the constructor immediately
+        } else {
+            applyConstructor = true;
+        }
+
+        Y.mix(target, newProto || sProto, ov, wl);
+
+        if (applyConstructor) {
+            s.apply(target, a);
+        }
+
+        return r;
+    };
+
+    /**
+     * Applies object properties from the supplier to the receiver.  If
+     * the target has the property, and the property is an object, the target
+     * object will be augmented with the supplier's value.  If the property
+     * is an array, the suppliers value will be appended to the target.
+     * @method aggregate
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param ov {boolean} if true, properties already on the receiver
+     * will be overwritten if found on the supplier.
+     * @param wl {string[]} a whitelist.  If supplied, only properties in 
+     * this list will be applied to the receiver.
+     * @return {object} the extended object
+     */
+    Y.aggregate = function(r, s, ov, wl) {
+        return Y.mix(r, s, ov, wl, 0, true);
+    };
+
+    /**
+     * Utility to set up the prototype, constructor and superclass properties to
+     * support an inheritance strategy that can chain constructors and methods.
+     * Static members will not be inherited.
+     *
+     * @method extend
+     * @param {Function} r   the object to modify
+     * @param {Function} s the object to inherit
+     * @param {Object} px prototype properties to add/override
+     * @param {Object} sx static properties to add/override
+     * @return {YUI} the YUI instance
+     */
+    Y.extend = function(r, s, px, sx) {
+        if (!s||!r) {
+            Y.fail("extend failed, verify dependencies");
+        }
+
+        var sp = s.prototype, rp=Y.Object(sp), i;
+        r.prototype=rp;
+
+        rp.constructor=r;
+        r.superclass=sp;
+
+        // If the superclass doesn't have a standard constructor,
+        // define one so that Super() works
+        if (s != Object && sp.constructor == OP.constructor) {
+            sp.constructor=s;
+        }
+    
+        // Add object properties too
+        // @TODO removed for now because it isn't that useful and
+        // has caused a few issues overwriting things that should
+        // not be.  You can do this manually if needed.  Revisit
+        // if this is something that really is needed for some
+        // reason.
+        // Y.mix(r, s);
+
+        // Add superclass convienience functions 
+        // @TODO revisit when we have something that works
+        // Y.augment(r, Ext);
+
+        // Add prototype overrides
+        if (px) {
+            Y.mix(rp, px, true);
+        }
+
+        // Add object overrides
+        if (sx) {
+            Y.mix(r, sx, true);
+        }
+
+        return r;
+    };
+
+    /**
+     * Executes the supplied function for each item in
+     * a collection.  Supports arrays, objects, and
+     * Y.NodeLists
+     * @method each
+     * @param o the object to iterate
+     * @param f the function to execute.  This function
+     * receives the value, key, and object as parameters
+     * @param proto if true, prototype properties are
+     * iterated on objects
+     * @return {YUI} the YUI instance
+     */
+    Y.each = function(o, f, c, proto) {
+
+        if (o.each && o.item) {
+            return o.each.call(o, f, c);
+        } else {
+            switch (A.test(o)) {
+                case 1:
+                    return A.each(o, f, c);
+                case 2:
+                    return A.each(Y.Array(o, 0, true), f, c);
+                default:
+                    return Y.Object.each(o, f, c, proto);
+            }
+        }
+
+        // return Y.Object.each(o, f, c);
+    };
+
+    /**
+     * Deep obj/array copy.  Functions will are cloned with Y.bind.
+     * Array-like objects are treated as arrays.
+     * primitives are returned untouched.  Optionally a
+     * function can be provided to handle other data types,
+     * filter keys, validate values, etc.
+     *
+     * @method clone
+     * @param o what to clone
+     * @param safe {boolean} if true, objects will not have prototype
+     * items from the source.  If false, it does.  In this case, the
+     * original is initally protected, but the clone is not completely immune
+     * from changes to the source object prototype.  Also, cloned prototype
+     * items that are deleted from the clone will result in the value
+     * of the source prototype to be exposed.  If operating on a non-safe
+     * clone, items should be nulled out rather than deleted.
+     * @TODO review
+     * @param f optional function to apply to each item in a collection
+     *          it will be executed prior to applying the value to
+     *          the new object.  Return false to prevent the copy.
+     * @param c optional execution context for f
+     * @param owner Owner object passed when clone is iterating an
+     * object.  Used to set up context for cloned functions.
+     * @return {Array|Object} the cloned object
+     */
+    Y.clone = function(o, safe, f, c, owner) {
+
+        if (!L.isObject(o)) {
+            return o;
+        }
+        
+        if (L.isDate(o)) {
+            return new Date(o);
+        }
+
+        var func = L.isFunction(o), o2;
+
+        if (func) {
+            if (o instanceof RegExp) {
+                return new RegExp(o.source);
+            }
+            o2 = Y.bind(o, owner);
+        } else {
+            o2 = (safe) ? {} : Y.Object(o);
+        }
+
+        Y.each(o, function(v, k) {
+            if (!f || (f.call(c || this, v, k, this, o) !== false)) {
+                this[k] =  Y.clone(v, safe, f, c, this);
+            }
+        }, o2);
+
+        return o2;
+    };
+    
+    /**
+     * Returns a function that will execute the supplied function in the
+     * supplied object's context, optionally adding any additional
+     * supplied parameters to the end of the arguments the function
+     * is executed with.
+     *
+     * In some cases it is preferable to have the additional arguments
+     * applied to the beginning of the function signature.  For instance,
+     * FireFox setTimeout/setInterval supplies a parameter that other
+     * browsers do not.  
+     * Note: YUI provides a later() function which wraps setTimeout/setInterval,
+     * providing context adjustment and parameter addition.  This can be 
+     * used instead of setTimeout/setInterval, avoiding the arguments
+     * collection issue when using bind() in FireFox.
+     *
+     * @TODO review param order for PR2
+     * @method bind
+     * @param f {Function} the function to bind
+     * @param c the execution context
+     * @param args* 0..n arguments to append to the end of arguments collection
+     * supplied to the function
+     * @return {function} the wrapped function
+     */
+    Y.bind = function(f, c) {
+        var a = Y.Array(arguments, 2, true);
+        return function () {
+            return f.apply(c || f, Y.Array(arguments, 0, true).concat(a));
+        };
+    };
+
+    /*
+     * Returns a function that will execute the supplied function in the
+     * supplied object's context, optionally adding any additional
+     * supplied parameters to the beginning of the arguments collection the 
+     * supplied to the function.
+     *
+     * In some cases it is preferable to have the additional arguments
+     * applied to the end of the function signature.  @see bind for a version 
+     * that does this.
+     *
+     * @TODO consider adding this in PR2
+     *
+     * @method rbind
+     * @param f {Function} the function to bind
+     * @param c the execution context
+     * @param args* 0..n arguments to append to the arguments collection for the function
+     * @return {function} the wrapped function
+     */
+    // Y.rbind = function(f, c) {
+    //     var a = Y.Array(arguments, 2, true);
+    //     return function () {
+    //         return f.apply(c || f, a.concat(Y.Array(arguments, 0, true)));
+    //     };
+    // };
+
+
+}, "3.0.0pr2");

=== added file 'loggerhead/static/javascript/yui/build/oop/oop-min.js'
--- loggerhead/static/javascript/yui/build/oop/oop-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/oop/oop-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("oop",function(F){var D=F.Lang,C=F.Array,B=Object.prototype,E;F.augment=function(A,S,I,Q,M){var K=S.prototype,O=null,R=S,N=(M)?F.Array(M):[],H=A.prototype,L=H||A,P=false;if(H&&R){var G={},J={};O={};F.each(K,function(U,T){J[T]=function(){var W=this;for(var V in G){if(F.Object.owns(G,V)&&(W[V]===J[V])){W[V]=G[V];}}R.apply(W,N);return G[T].apply(W,arguments);};if((!Q||(T in Q))&&(I||!(T in this))){if(D.isFunction(U)){G[T]=U;this[T]=J[T];}else{this[T]=U;}}},O,true);}else{P=true;}F.mix(L,O||K,I,Q);if(P){S.apply(L,N);}return A;};F.aggregate=function(H,G,A,I){return F.mix(H,G,A,I,0,true);};F.extend=function(J,I,G,L){if(!I||!J){F.fail("extend failed, verify dependencies");}var K=I.prototype,H=F.Object(K),A;J.prototype=H;H.constructor=J;J.superclass=K;if(I!=Object&&K.constructor==B.constructor){K.constructor=I;}if(G){F.mix(H,G,true);}if(L){F.mix(J,L,true);}return J;};F.each=function(H,G,I,A){if(H.each&&H.item){return H.each.call(H,G,I);}else{switch(C.test(H)){case 1:return C.each(H,G,I);case 2:return C.each(F.Array(H,0,true),G,I);default:return F.Object.each(H,G,I,A);}}};F.clone=function(K,J,I,L,A){if(!D.isObject(K)){return K;}if(D.isDate(K)){return new Date(K);}var H=D.isFunction(K),G;if(H){if(K instanceof RegExp){return new RegExp(K.source);}G=F.bind(K,A);}else{G=(J)?{}:F.Object(K);}F.each(K,function(N,M){if(!I||(I.call(L||this,N,M,this,K)!==false)){this[M]=F.clone(N,J,I,L,this);}},G);return G;};F.bind=function(G,H){var A=F.Array(arguments,2,true);return function(){return G.apply(H||G,F.Array(arguments,0,true).concat(A));};};},"3.0.0pr2");
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/oop/oop.js'
--- loggerhead/static/javascript/yui/build/oop/oop.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/oop/oop.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,334 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * OOP utils.  If included, the OOP methods are added to the YUI instance
+ * @module oop
+ */
+YUI.add("oop", function(Y) {
+
+    var L = Y.Lang, 
+    A = Y.Array,
+    OP = Object.prototype,
+    O;
+
+    /**
+     * The following methods are added to the YUI instance
+     * @class YUI~oop
+     */
+
+    /**
+     * Applies prototype properties from the supplier to the receiver.
+     * The receiver can be a constructor or an instance.
+     * @method augment
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param ov {boolean} if true, properties already on the receiver
+     * will be overwritten if found on the supplier.
+     * @param wl {string[]} a whitelist.  If supplied, only properties in 
+     * this list will be applied to the receiver.
+     * @param args {Array | Any} arg or arguments to apply to the supplier
+     * constructor when initializing.
+     * @return {object} the augmented object
+     *
+     * @todo constructor optional?
+     * @todo understanding what an instance is augmented with
+     * @TODO evaluate if we can do this in a way that doesn't interfere
+     * with normal inheritance
+     */
+    Y.augment = function(r, s, ov, wl, args) {
+
+        var sProto = s.prototype, newProto = null, construct = s, 
+            a = (args) ? Y.Array(args) : [], rProto = r.prototype, 
+            target =  rProto || r, applyConstructor = false;
+
+        // working on a class, so apply constructor infrastructure
+        if (rProto && construct) {
+
+
+            // Y.Do.before(r, construct);
+
+            var sequestered = {}, replacements = {};
+            newProto = {};
+
+            // sequester all of the functions in the supplier and replace with
+            // one that will restore all of them.
+            Y.each(sProto, function(v, k) {
+
+
+                // var initialized = false;
+
+                replacements[k] = function() {
+
+                    var me = this;
+
+
+                    // overwrite the prototype with all of the sequestered functions,
+                    // but only if it hasn't been overridden
+                    for (var i in sequestered) {
+                        if (Y.Object.owns(sequestered, i) && (me[i] === replacements[i])) {
+                            me[i] = sequestered[i];
+                        }
+                    }
+
+                    // apply the constructor
+                    construct.apply(me, a);
+
+                    // apply the original sequestered function
+                    return sequestered[k].apply(me, arguments);
+
+                };
+
+                if ((!wl || (k in wl)) && (ov || !(k in this))) {
+
+
+                    if (L.isFunction(v)) {
+
+                        // sequester the function
+                        sequestered[k] = v;
+
+                        // replace the sequestered function with a function that will
+                        // restore all sequestered functions and exectue the constructor.
+                        this[k] = replacements[k];
+
+                    } else {
+
+
+                        this[k] = v;
+                    }
+
+                }
+
+            }, newProto, true);
+
+        // augmenting an instance, so apply the constructor immediately
+        } else {
+            applyConstructor = true;
+        }
+
+        Y.mix(target, newProto || sProto, ov, wl);
+
+        if (applyConstructor) {
+            s.apply(target, a);
+        }
+
+        return r;
+    };
+
+    /**
+     * Applies object properties from the supplier to the receiver.  If
+     * the target has the property, and the property is an object, the target
+     * object will be augmented with the supplier's value.  If the property
+     * is an array, the suppliers value will be appended to the target.
+     * @method aggregate
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param ov {boolean} if true, properties already on the receiver
+     * will be overwritten if found on the supplier.
+     * @param wl {string[]} a whitelist.  If supplied, only properties in 
+     * this list will be applied to the receiver.
+     * @return {object} the extended object
+     */
+    Y.aggregate = function(r, s, ov, wl) {
+        return Y.mix(r, s, ov, wl, 0, true);
+    };
+
+    /**
+     * Utility to set up the prototype, constructor and superclass properties to
+     * support an inheritance strategy that can chain constructors and methods.
+     * Static members will not be inherited.
+     *
+     * @method extend
+     * @param {Function} r   the object to modify
+     * @param {Function} s the object to inherit
+     * @param {Object} px prototype properties to add/override
+     * @param {Object} sx static properties to add/override
+     * @return {YUI} the YUI instance
+     */
+    Y.extend = function(r, s, px, sx) {
+        if (!s||!r) {
+            Y.fail("extend failed, verify dependencies");
+        }
+
+        var sp = s.prototype, rp=Y.Object(sp), i;
+        r.prototype=rp;
+
+        rp.constructor=r;
+        r.superclass=sp;
+
+        // If the superclass doesn't have a standard constructor,
+        // define one so that Super() works
+        if (s != Object && sp.constructor == OP.constructor) {
+            sp.constructor=s;
+        }
+    
+        // Add object properties too
+        // @TODO removed for now because it isn't that useful and
+        // has caused a few issues overwriting things that should
+        // not be.  You can do this manually if needed.  Revisit
+        // if this is something that really is needed for some
+        // reason.
+        // Y.mix(r, s);
+
+        // Add superclass convienience functions 
+        // @TODO revisit when we have something that works
+        // Y.augment(r, Ext);
+
+        // Add prototype overrides
+        if (px) {
+            Y.mix(rp, px, true);
+        }
+
+        // Add object overrides
+        if (sx) {
+            Y.mix(r, sx, true);
+        }
+
+        return r;
+    };
+
+    /**
+     * Executes the supplied function for each item in
+     * a collection.  Supports arrays, objects, and
+     * Y.NodeLists
+     * @method each
+     * @param o the object to iterate
+     * @param f the function to execute.  This function
+     * receives the value, key, and object as parameters
+     * @param proto if true, prototype properties are
+     * iterated on objects
+     * @return {YUI} the YUI instance
+     */
+    Y.each = function(o, f, c, proto) {
+
+        if (o.each && o.item) {
+            return o.each.call(o, f, c);
+        } else {
+            switch (A.test(o)) {
+                case 1:
+                    return A.each(o, f, c);
+                case 2:
+                    return A.each(Y.Array(o, 0, true), f, c);
+                default:
+                    return Y.Object.each(o, f, c, proto);
+            }
+        }
+
+        // return Y.Object.each(o, f, c);
+    };
+
+    /**
+     * Deep obj/array copy.  Functions will are cloned with Y.bind.
+     * Array-like objects are treated as arrays.
+     * primitives are returned untouched.  Optionally a
+     * function can be provided to handle other data types,
+     * filter keys, validate values, etc.
+     *
+     * @method clone
+     * @param o what to clone
+     * @param safe {boolean} if true, objects will not have prototype
+     * items from the source.  If false, it does.  In this case, the
+     * original is initally protected, but the clone is not completely immune
+     * from changes to the source object prototype.  Also, cloned prototype
+     * items that are deleted from the clone will result in the value
+     * of the source prototype to be exposed.  If operating on a non-safe
+     * clone, items should be nulled out rather than deleted.
+     * @TODO review
+     * @param f optional function to apply to each item in a collection
+     *          it will be executed prior to applying the value to
+     *          the new object.  Return false to prevent the copy.
+     * @param c optional execution context for f
+     * @param owner Owner object passed when clone is iterating an
+     * object.  Used to set up context for cloned functions.
+     * @return {Array|Object} the cloned object
+     */
+    Y.clone = function(o, safe, f, c, owner) {
+
+        if (!L.isObject(o)) {
+            return o;
+        }
+        
+        if (L.isDate(o)) {
+            return new Date(o);
+        }
+
+        var func = L.isFunction(o), o2;
+
+        if (func) {
+            if (o instanceof RegExp) {
+                return new RegExp(o.source);
+            }
+            o2 = Y.bind(o, owner);
+        } else {
+            o2 = (safe) ? {} : Y.Object(o);
+        }
+
+        Y.each(o, function(v, k) {
+            if (!f || (f.call(c || this, v, k, this, o) !== false)) {
+                this[k] =  Y.clone(v, safe, f, c, this);
+            }
+        }, o2);
+
+        return o2;
+    };
+    
+    /**
+     * Returns a function that will execute the supplied function in the
+     * supplied object's context, optionally adding any additional
+     * supplied parameters to the end of the arguments the function
+     * is executed with.
+     *
+     * In some cases it is preferable to have the additional arguments
+     * applied to the beginning of the function signature.  For instance,
+     * FireFox setTimeout/setInterval supplies a parameter that other
+     * browsers do not.  
+     * Note: YUI provides a later() function which wraps setTimeout/setInterval,
+     * providing context adjustment and parameter addition.  This can be 
+     * used instead of setTimeout/setInterval, avoiding the arguments
+     * collection issue when using bind() in FireFox.
+     *
+     * @TODO review param order for PR2
+     * @method bind
+     * @param f {Function} the function to bind
+     * @param c the execution context
+     * @param args* 0..n arguments to append to the end of arguments collection
+     * supplied to the function
+     * @return {function} the wrapped function
+     */
+    Y.bind = function(f, c) {
+        var a = Y.Array(arguments, 2, true);
+        return function () {
+            return f.apply(c || f, Y.Array(arguments, 0, true).concat(a));
+        };
+    };
+
+    /*
+     * Returns a function that will execute the supplied function in the
+     * supplied object's context, optionally adding any additional
+     * supplied parameters to the beginning of the arguments collection the 
+     * supplied to the function.
+     *
+     * In some cases it is preferable to have the additional arguments
+     * applied to the end of the function signature.  @see bind for a version 
+     * that does this.
+     *
+     * @TODO consider adding this in PR2
+     *
+     * @method rbind
+     * @param f {Function} the function to bind
+     * @param c the execution context
+     * @param args* 0..n arguments to append to the arguments collection for the function
+     * @return {function} the wrapped function
+     */
+    // Y.rbind = function(f, c) {
+    //     var a = Y.Array(arguments, 2, true);
+    //     return function () {
+    //         return f.apply(c || f, a.concat(Y.Array(arguments, 0, true)));
+    //     };
+    // };
+
+
+}, "3.0.0pr2");

=== added directory 'loggerhead/static/javascript/yui/build/overlay'
=== added file 'loggerhead/static/javascript/yui/build/overlay/README'
--- loggerhead/static/javascript/yui/build/overlay/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/overlay/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,12 @@
+3.0.0PR2 - Initial release
+
+Module Name: "overlay"
+Documentation: http://developer.yahoo.com/yui/3/overlay
+
+Overlay is a positionable and stackable widget, which also 
+provides support for the standard module format layout, 
+with a header, body and footer section. 
+
+The overlay is built by extending Widget and adding the 
+WidgetPosition, WidgetStack, WidgetPositionExt and 
+WidgetStdMod extensions.
\ No newline at end of file

=== added directory 'loggerhead/static/javascript/yui/build/overlay/assets'
=== added file 'loggerhead/static/javascript/yui/build/overlay/assets/overlay-core.css'
--- loggerhead/static/javascript/yui/build/overlay/assets/overlay-core.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/overlay/assets/overlay-core.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,13 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-overlay {
+    position:absolute;
+}
+
+.yui-overlay-hidden {
+    visibility:hidden
+}

=== added directory 'loggerhead/static/javascript/yui/build/overlay/assets/skins'
=== added directory 'loggerhead/static/javascript/yui/build/overlay/assets/skins/sam'
=== added file 'loggerhead/static/javascript/yui/build/overlay/assets/skins/sam/overlay-skin.css'
--- loggerhead/static/javascript/yui/build/overlay/assets/skins/sam/overlay-skin.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/overlay/assets/skins/sam/overlay-skin.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,6 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/

=== added file 'loggerhead/static/javascript/yui/build/overlay/assets/skins/sam/overlay.css'
--- loggerhead/static/javascript/yui/build/overlay/assets/skins/sam/overlay.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/overlay/assets/skins/sam/overlay.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-overlay{position:absolute;}.yui-overlay-hidden{visibility:hidden}

=== added file 'loggerhead/static/javascript/yui/build/overlay/overlay-debug.js'
--- loggerhead/static/javascript/yui/build/overlay/overlay-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/overlay/overlay-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,36 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('overlay', function(Y) {
+
+/**
+ * Provides a basic Overlay widget, with Standard Module content support. The Overlay widget
+ * provides Page XY positioning support, alignment and centering support along with basic 
+ * stackable support (z-index and shimming).
+ *
+ * @module overlay
+ */
+
+/**
+ * A basic Overlay Widget, which can be positioned based on Page XY co-ordinates and is stackable (z-index support).
+ * It also provides alignment and centering support and uses a standard module format for it's content, with header,
+ * body and footer section support.
+ * 
+ * @class Overlay
+ * @constructor
+ * @extends Widget
+ * @uses WidgetPosition
+ * @uses WidgetStack
+ * @uses WidgetPositionExt
+ * @uses WidgetStdMod
+ * @param {Object} object The user configuration for the instance.
+ */
+Y.Overlay = Y.Base.build(Y.Widget, [Y.WidgetPosition, Y.WidgetStack, Y.WidgetPositionExt, Y.WidgetStdMod]);
+Y.Overlay.NAME = "overlay";
+
+
+
+}, '3.0.0pr2' ,{requires:['widget', 'widget-position', 'widget-stack', 'widget-position-ext', 'widget-stdmod']});

=== added file 'loggerhead/static/javascript/yui/build/overlay/overlay-min.js'
--- loggerhead/static/javascript/yui/build/overlay/overlay-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/overlay/overlay-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("overlay",function(A){A.Overlay=A.Base.build(A.Widget,[A.WidgetPosition,A.WidgetStack,A.WidgetPositionExt,A.WidgetStdMod]);A.Overlay.NAME="overlay";},"3.0.0pr2",{requires:["widget","widget-position","widget-stack","widget-position-ext","widget-stdmod"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/overlay/overlay.js'
--- loggerhead/static/javascript/yui/build/overlay/overlay.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/overlay/overlay.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,36 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('overlay', function(Y) {
+
+/**
+ * Provides a basic Overlay widget, with Standard Module content support. The Overlay widget
+ * provides Page XY positioning support, alignment and centering support along with basic 
+ * stackable support (z-index and shimming).
+ *
+ * @module overlay
+ */
+
+/**
+ * A basic Overlay Widget, which can be positioned based on Page XY co-ordinates and is stackable (z-index support).
+ * It also provides alignment and centering support and uses a standard module format for it's content, with header,
+ * body and footer section support.
+ * 
+ * @class Overlay
+ * @constructor
+ * @extends Widget
+ * @uses WidgetPosition
+ * @uses WidgetStack
+ * @uses WidgetPositionExt
+ * @uses WidgetStdMod
+ * @param {Object} object The user configuration for the instance.
+ */
+Y.Overlay = Y.Base.build(Y.Widget, [Y.WidgetPosition, Y.WidgetStack, Y.WidgetPositionExt, Y.WidgetStdMod]);
+Y.Overlay.NAME = "overlay";
+
+
+
+}, '3.0.0pr2' ,{requires:['widget', 'widget-position', 'widget-stack', 'widget-position-ext', 'widget-stdmod']});

=== added directory 'loggerhead/static/javascript/yui/build/plugin'
=== added file 'loggerhead/static/javascript/yui/build/plugin/README'
--- loggerhead/static/javascript/yui/build/plugin/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/plugin/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,3 @@
+**** version 3.0.0 PR2 ***
+
+* Plugin component added

=== added file 'loggerhead/static/javascript/yui/build/plugin/plugin-debug.js'
--- loggerhead/static/javascript/yui/build/plugin/plugin-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/plugin/plugin-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,147 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('plugin', function(Y) {
+
+/**
+ * Provides the base Plugin class for building widget plugins. 
+ *
+ * @module plugin
+ */
+
+        /**
+         * Plugin provides a base class for all Plugin classes.
+         * 
+         * @class Plugin 
+         * @extends Base
+         * @param {Object} config The configuration object for the
+         * plugin.
+         */
+        function Plugin(config) {
+            Plugin.superclass.constructor.apply(this, arguments);
+        }
+
+
+        /**
+         * Static property provides a string to identify the class.
+         *
+         * @property Plugin.NAME
+         * @type {String}
+         * @static
+         */
+        Plugin.NAME = 'plugin';
+
+        /**
+         * Static property provides the namespace the plugin will be
+         * registered under.
+         *
+         * @property Plugin.NS
+         * @type {String}
+         * @static
+         */
+        Plugin.NS = 'plugin';
+
+        var proto = {
+            _handles: null,
+
+            /**
+             * Initializer lifecycle implementation.
+             * 
+             * @method initializer
+             * @param {Object} config Configuration object literal for the plugin
+             */
+            initializer : function(config) {
+
+                if (config.owner) {
+                    this._owner = config.owner;
+                } else {
+                    Y.log('no owner defined for plugin ' + this, 'error', 'Plugin');
+                }
+
+                this._handles = [];
+
+                Y.log('Initializing: ' + this.constructor.NAME, 'info', 'Plugin');
+            },
+
+            /**
+             * desctructor lifecycle implementation.
+             * 
+             * Removes any listeners attached by the Plugin and restores
+             * and over-ridden methods.
+             * 
+             * @method destructor
+             */
+            destructor: function() {
+                // remove all handles
+                if (this._handles) {
+                    for (var i = 0, l = this._handles.length; i < l; i++) {
+                       this._handles[i].detach();
+                    }
+                }
+            },
+
+            /**
+             * Listens for events and methods fired by the owner widget.
+             * The handler is called before the event handler or method is called.
+             * @method doBefore
+             * @param sFn The event of method to listen for.
+             * @param fn The handler function to call when the listener fires.
+             * @param context An optional context to call the handler with.
+             * Default context is the plugin instance.
+             * @return Handle A handle that can be used to detach the handler (e.g. "handle.detach()").
+             */
+            doBefore: function(sFn, fn, context) {
+                var owner = this._owner,
+                    handle;
+
+                context = context || this;
+
+                if (sFn in owner) { // method
+                    handle = Y.Do.before(fn, this._owner, sFn, context);
+                } else if (owner.on) { // event
+                    handle = owner.on(sFn, fn, context);
+                }
+
+                this._handles.push(handle);
+                return handle;
+            },
+
+            /**
+             * Listens for events and methods fired by the owner widget.
+             * The handler is called after the event handler or method is called.
+             * @method doAfter
+             * @param sFn The event of method to listen for.
+             * @param fn The handler function to call when the listener fires.
+             * @param context An optional context to call the handler with.
+             * Default context is the plugin instance.
+             * @return Handle A handle that can be used to detach the handler (e.g. "handle.detach()").
+             */
+            doAfter: function(sFn, fn, context) {
+                var owner = this._owner,
+                    handle;
+
+                context = context || this;
+
+                if (sFn in owner) { // method
+                    handle = Y.Do.after(fn, this._owner, sFn, context);
+                } else if (owner.after) { // event
+                    handle = owner.after(sFn, fn, context);
+                }
+
+                this._handles.push(handle);
+                return handle;
+            },
+
+            toString: function() {
+                return this.constructor.NAME + '[' + this.constructor.NS + ']';
+            }
+        };
+
+        Y.extend(Plugin, Y.Base, proto);
+        Y.Plugin = Plugin;
+
+
+}, '3.0.0pr2' ,{requires:['base']});

=== added file 'loggerhead/static/javascript/yui/build/plugin/plugin-min.js'
--- loggerhead/static/javascript/yui/build/plugin/plugin-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/plugin/plugin-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("plugin",function(C){function A(D){A.superclass.constructor.apply(this,arguments);}A.NAME="plugin";A.NS="plugin";var B={_handles:null,initializer:function(D){if(D.owner){this._owner=D.owner;}else{}this._handles=[];},destructor:function(){if(this._handles){for(var E=0,D=this._handles.length;E<D;E++){this._handles[E].detach();}}},doBefore:function(H,F,E){var D=this._owner,G;E=E||this;if(H in D){G=C.Do.before(F,this._owner,H,E);}else{if(D.on){G=D.on(H,F,E);}}this._handles.push(G);return G;},doAfter:function(H,F,E){var D=this._owner,G;E=E||this;if(H in D){G=C.Do.after(F,this._owner,H,E);}else{if(D.after){G=D.after(H,F,E);}}this._handles.push(G);return G;},toString:function(){return this.constructor.NAME+"["+this.constructor.NS+"]";}};C.extend(A,C.Base,B);C.Plugin=A;},"3.0.0pr2",{requires:["base"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/plugin/plugin.js'
--- loggerhead/static/javascript/yui/build/plugin/plugin.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/plugin/plugin.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,145 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('plugin', function(Y) {
+
+/**
+ * Provides the base Plugin class for building widget plugins. 
+ *
+ * @module plugin
+ */
+
+        /**
+         * Plugin provides a base class for all Plugin classes.
+         * 
+         * @class Plugin 
+         * @extends Base
+         * @param {Object} config The configuration object for the
+         * plugin.
+         */
+        function Plugin(config) {
+            Plugin.superclass.constructor.apply(this, arguments);
+        }
+
+
+        /**
+         * Static property provides a string to identify the class.
+         *
+         * @property Plugin.NAME
+         * @type {String}
+         * @static
+         */
+        Plugin.NAME = 'plugin';
+
+        /**
+         * Static property provides the namespace the plugin will be
+         * registered under.
+         *
+         * @property Plugin.NS
+         * @type {String}
+         * @static
+         */
+        Plugin.NS = 'plugin';
+
+        var proto = {
+            _handles: null,
+
+            /**
+             * Initializer lifecycle implementation.
+             * 
+             * @method initializer
+             * @param {Object} config Configuration object literal for the plugin
+             */
+            initializer : function(config) {
+
+                if (config.owner) {
+                    this._owner = config.owner;
+                } else {
+                }
+
+                this._handles = [];
+
+            },
+
+            /**
+             * desctructor lifecycle implementation.
+             * 
+             * Removes any listeners attached by the Plugin and restores
+             * and over-ridden methods.
+             * 
+             * @method destructor
+             */
+            destructor: function() {
+                // remove all handles
+                if (this._handles) {
+                    for (var i = 0, l = this._handles.length; i < l; i++) {
+                       this._handles[i].detach();
+                    }
+                }
+            },
+
+            /**
+             * Listens for events and methods fired by the owner widget.
+             * The handler is called before the event handler or method is called.
+             * @method doBefore
+             * @param sFn The event of method to listen for.
+             * @param fn The handler function to call when the listener fires.
+             * @param context An optional context to call the handler with.
+             * Default context is the plugin instance.
+             * @return Handle A handle that can be used to detach the handler (e.g. "handle.detach()").
+             */
+            doBefore: function(sFn, fn, context) {
+                var owner = this._owner,
+                    handle;
+
+                context = context || this;
+
+                if (sFn in owner) { // method
+                    handle = Y.Do.before(fn, this._owner, sFn, context);
+                } else if (owner.on) { // event
+                    handle = owner.on(sFn, fn, context);
+                }
+
+                this._handles.push(handle);
+                return handle;
+            },
+
+            /**
+             * Listens for events and methods fired by the owner widget.
+             * The handler is called after the event handler or method is called.
+             * @method doAfter
+             * @param sFn The event of method to listen for.
+             * @param fn The handler function to call when the listener fires.
+             * @param context An optional context to call the handler with.
+             * Default context is the plugin instance.
+             * @return Handle A handle that can be used to detach the handler (e.g. "handle.detach()").
+             */
+            doAfter: function(sFn, fn, context) {
+                var owner = this._owner,
+                    handle;
+
+                context = context || this;
+
+                if (sFn in owner) { // method
+                    handle = Y.Do.after(fn, this._owner, sFn, context);
+                } else if (owner.after) { // event
+                    handle = owner.after(sFn, fn, context);
+                }
+
+                this._handles.push(handle);
+                return handle;
+            },
+
+            toString: function() {
+                return this.constructor.NAME + '[' + this.constructor.NS + ']';
+            }
+        };
+
+        Y.extend(Plugin, Y.Base, proto);
+        Y.Plugin = Plugin;
+
+
+}, '3.0.0pr2' ,{requires:['base']});

=== added directory 'loggerhead/static/javascript/yui/build/profiler'
=== added file 'loggerhead/static/javascript/yui/build/profiler/profiler-debug.js'
--- loggerhead/static/javascript/yui/build/profiler/profiler-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/profiler/profiler-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,383 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("profiler", function(Y){
+
+    var L = Y.Lang;
+
+    /**
+     * The YUI JavaScript profiler.
+     * @module profiler
+     * @namespace Y
+     * @requires yahoo
+     */
+    
+    /**
+     * Profiles functions in JavaScript.
+     * @namespace Y
+     * @class Profiler
+     * @static
+     */
+    Y.Profiler = {
+    
+        //-------------------------------------------------------------------------
+        // Private Properties
+        //-------------------------------------------------------------------------
+    
+        /**
+         * Container object on which to put the original unprofiled methods.
+         * @type Object
+         * @private
+         * @static
+         * @property _container
+         */
+        _container : {},
+    
+        /**
+         * Call information for functions.
+         * @type Object
+         * @private
+         * @static
+         * @property _report
+         */
+        _report : {},
+        
+        //-------------------------------------------------------------------------
+        // Private Methods
+        //-------------------------------------------------------------------------
+        
+        /**
+         * Called when a method ends execution. Marks the start and end time of the 
+         * method so it can calculate how long the function took to execute. Also 
+         * updates min/max/avg calculations for the function.
+         * @param {String} name The name of the function to mark as stopped.
+         * @param {int} duration The number of milliseconds it took the function to
+         *      execute.
+         * @return {Void}
+         * @private
+         * @static
+         */
+        _saveData : function (name /*:String*/, duration /*:int*/){
+            
+            //get the function data
+            var functionData /*:Object*/ = this._report[name];
+        
+            //increment the calls
+            functionData.calls++;
+            functionData.points.push(duration);
+    
+            //if it's already been called at least once, do more complex calculations
+            if (functionData.calls > 1) {
+                functionData.avg = ((functionData.avg*(functionData.calls-1))+duration)/functionData.calls;
+                functionData.min = Math.min(functionData.min, duration);
+                functionData.max = Math.max(functionData.max, duration);
+            } else {
+                functionData.avg = duration;
+                functionData.min = duration;
+                functionData.max = duration;
+            }                             
+        
+        },
+    
+        //-------------------------------------------------------------------------
+        // Reporting Methods
+        //-------------------------------------------------------------------------    
+        
+        /**
+         * Returns the average amount of time (in milliseconds) that the function
+         * with the given name takes to execute.
+         * @param {String} name The name of the function whose data should be returned.
+         *      If an object type method, it should be 'constructor.prototype.methodName';
+         *      a normal object method would just be 'object.methodName'.
+         * @return {float} The average time it takes the function to execute.
+         * @static
+         */
+        getAverage : function (name /*:String*/) /*:float*/ {
+            return this._report[name].avg;
+        },
+    
+        /**
+         * Returns the number of times that the given function has been called.
+         * @param {String} name The name of the function whose data should be returned.
+         * @return {int} The number of times the function was called.
+         * @static
+         */
+        getCallCount : function (name /*:String*/) /*:int*/ {
+            return this._report[name].calls;    
+        },
+        
+        /**
+         * Returns the maximum amount of time (in milliseconds) that the function
+         * with the given name takes to execute.
+         * @param {String} name The name of the function whose data should be returned.
+         *      If an object type method, it should be 'constructor.prototype.methodName';
+         *      a normal object method would just be 'object.methodName'.
+         * @return {float} The maximum time it takes the function to execute.
+         */
+        getMax : function (name /*:String*/) /*:int*/ {
+            return this._report[name].max;
+        },
+        
+        /**
+         * Returns the minimum amount of time (in milliseconds) that the function
+         * with the given name takes to execute.
+         * @param {String} name The name of the function whose data should be returned.
+         *      If an object type method, it should be 'constructor.prototype.methodName';
+         *      a normal object method would just be 'object.methodName'.
+         * @return {float} The minimum time it takes the function to execute.
+         */
+        getMin : function (name /*:String*/) /*:int*/ {
+            return this._report[name].min;
+        },
+    
+        /**
+         * Returns an object containing profiling data for a single function.
+         * The object has an entry for min, max, avg, calls, and points).
+         * @return {Object} An object containing profile data for a given function.
+         * @static
+         */
+        getFunctionReport : function (name /*:String*/) /*:Object*/ {
+            return this._report[name];
+        },
+    
+        /**
+         * Returns an object containing profiling data for all of the functions 
+         * that were profiled. The object has an entry for each function and 
+         * returns all information (min, max, average, calls, etc.) for each
+         * function.
+         * @return {Object} An object containing all profile data.
+         * @static
+         */
+        getFullReport : function (filter /*:Function*/) /*:Object*/ {
+            filter = filter || function(){return true;};
+        
+            if (typeof filter == "function") {
+                var report = {};
+                
+                for (var name in this._report){
+                    if (filter(this._report[name])){
+                        report[name] = this._report[name];    
+                    }
+                }
+                
+                return report;
+            }
+        },
+    
+        //-------------------------------------------------------------------------
+        // Profiling Methods
+        //-------------------------------------------------------------------------   
+        
+        /**
+         * Sets up a constructor for profiling, including all properties and methods on the prototype.
+         * @param {string} name The fully-qualified name of the function including namespace information.
+         * @param {Object} owner (Optional) The object that owns the function (namespace or containing object).
+         * @return {Void}
+         * @static
+         */
+        registerConstructor : function (name /*:String*/, owner /*:Object*/) /*:Void*/ {    
+            this.registerFunction(name, owner, true);
+        },
+    
+        /**
+         * Sets up a function for profiling. It essentially overwrites the function with one
+         * that has instrumentation data. This method also creates an entry for the function
+         * in the profile report. The original function is stored on the _container object.
+         * @param {String} name The full name of the function including namespacing. This
+         *      is the name of the function that is stored in the report.
+         * @param {Object} owner (Optional) The object that owns the function. If the function
+         *      isn't global then this argument is required. This could be the namespace that
+         *      the function belongs to, such as YAHOO.util.Dom, or the object on which it's
+         *      a method.
+         * @return {Void}
+         * @method registerFunction
+         */     
+        registerFunction : function(name /*:String*/, owner /*:Object*/, registerPrototype /*:Boolean*/) /*:Void*/{
+        
+            //figure out the function name without namespacing
+            var funcName /*:String*/ = (name.indexOf(".") > -1 ? name.substring(name.lastIndexOf(".")+1) : name);
+            if (!L.isObject(owner)){
+                owner = eval(name.substring(0, name.lastIndexOf(".")));
+            }
+            
+            //get the method and prototype
+            var method /*:Function*/ = owner[funcName];
+            var prototype /*:Object*/ = method.prototype;
+            
+            //see if the method has already been registered
+            if (L.isFunction(method) && !method.__yuiProfiled){
+                
+                //create a new slot for the original method
+                this._container[name] = method;
+                
+                //replace the function with the profiling one
+                owner[funcName] = function () {
+    
+                    var start = new Date();     
+                    var retval = method.apply(this, arguments);
+                    var stop = new Date();
+                    
+                    Y.Profiler._saveData(name, stop-start);
+                    
+                    return retval;                
+                
+                };
+                
+                //copy the function properties over
+                Y.mix(owner[funcName], method);
+                owner[funcName].__yuiProfiled = true;
+                owner[funcName].prototype = prototype;
+                this._container[name].__yuiOwner = owner;
+                this._container[name].__yuiFuncName = funcName;        
+            
+                //register prototype if necessary
+                if (registerPrototype) {            
+                    this.registerObject(name + ".prototype", prototype);          
+                }
+                
+                //store function information
+                this._report[name] = {
+                    calls: 0,
+                    max: 0,
+                    min: 0,
+                    avg: 0,
+                    points: []
+                };        
+            }
+                
+            return method;
+        
+        },
+            
+        
+        /**
+         * Sets up an object for profiling. It takes the object and looks for functions.
+         * When a function is found, registerMethod() is called on it. If set to recrusive
+         * mode, it will also setup objects found inside of this object for profiling, 
+         * using the same methodology.
+         * @param {String} name The name of the object to profile (shows up in report).
+         * @param {Object} owner (Optional) The object represented by the name.
+         * @param {Boolean} recurse (Optional) Determines if subobject methods are also profiled.
+         * @return {Void}
+         * @static
+         */
+        registerObject : function (name /*:String*/, object /*:Object*/, recurse /*:Boolean*/) /*:Void*/{
+        
+            //get the object
+            object = (L.isObject(object) ? object : eval(name));
+        
+            //save the object
+            this._container[name] = object;
+        
+            for (var prop in object) {
+                if (typeof object[prop] == "function"){
+                    if (prop != "constructor" && prop != "superclass"){ //don't do constructor or superclass, it's recursive
+                        this.registerFunction(name + "." + prop, object);
+                    }
+                } else if (typeof object[prop] == "object" && recurse){
+                    this.registerObject(name + "." + prop, object[prop], recurse);
+                }
+            }
+        
+        },    
+        
+        /**
+         * Removes a constructor function from profiling. Reverses the registerConstructor() method.
+         * @param {String} name The full name of the function including namespacing. This
+         *      is the name of the function that is stored in the report.
+         * @return {Void}
+         * @method unregisterFunction
+         */     
+        unregisterConstructor : function(name /*:String*/) /*:Void*/{
+                
+            //see if the method has been registered
+            if (L.isFunction(this._container[name])){
+            
+                //get original data
+                //var owner /*:Object*/ = this._container[name].__yuiOwner;
+                //var funcName /*:String*/ = this._container[name].__yuiFuncName;
+                //delete this._container[name].__yuiOwner;
+                //delete this._container[name].__yuiFuncName;
+                
+                //replace instrumented function
+                //owner[funcName] = this._container[name];
+                //delete this._container[name];
+                this.unregisterFunction(name, true);
+           
+            }
+    
+        
+        },
+        
+        /**
+         * Removes function from profiling. Reverses the registerFunction() method.
+         * @param {String} name The full name of the function including namespacing. This
+         *      is the name of the function that is stored in the report.
+         * @return {Void}
+         * @method unregisterFunction
+         */     
+        unregisterFunction : function(name /*:String*/, unregisterPrototype /*:Boolean*/) /*:Void*/{
+                
+            //see if the method has been registered
+            if (L.isFunction(this._container[name])){
+            
+                //check to see if you should unregister the prototype
+                if (unregisterPrototype){
+                    this.unregisterObject(name + ".prototype", this._container[name].prototype);
+                }
+                    
+                //get original data
+                var owner /*:Object*/ = this._container[name].__yuiOwner;
+                var funcName /*:String*/ = this._container[name].__yuiFuncName;
+                delete this._container[name].__yuiOwner;
+                delete this._container[name].__yuiFuncName;
+                
+                //replace instrumented function
+                owner[funcName] = this._container[name];
+                
+                //delete supporting information
+                delete this._container[name];
+                delete this._report[name];
+           
+            }
+                
+        
+        },
+        
+        /**
+         * Unregisters an object for profiling. It takes the object and looks for functions.
+         * When a function is found, unregisterMethod() is called on it. If set to recrusive
+         * mode, it will also unregister objects found inside of this object, 
+         * using the same methodology.
+         * @param {String} name The name of the object to unregister.
+         * @param {Boolean} recurse (Optional) Determines if subobject methods should also be
+         *      unregistered.
+         * @return {Void}
+         * @static
+         */
+        unregisterObject : function (name /*:String*/, recurse /*:Boolean*/) /*:Void*/{
+        
+            //get the object
+            if (L.isObject(this._container[name])){            
+                var object = this._container[name];    
+            
+                for (var prop in object) {
+                    if (typeof object[prop] == "function"){
+                        this.unregisterFunction(name + "." + prop);
+                    } else if (typeof object[prop] == "object" && recurse){
+                        this.unregisterObject(name + "." + prop, recurse);
+                    }
+                }
+                
+                delete this._container[name];
+            }
+        
+        }
+             
+    
+    };
+}, "3.0.0pr2");
+

=== added file 'loggerhead/static/javascript/yui/build/profiler/profiler-min.js'
--- loggerhead/static/javascript/yui/build/profiler/profiler-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/profiler/profiler-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("profiler",function(Y){var L=Y.Lang;Y.Profiler={_container:{},_report:{},_saveData:function(name,duration){var functionData=this._report[name];functionData.calls++;functionData.points.push(duration);if(functionData.calls>1){functionData.avg=((functionData.avg*(functionData.calls-1))+duration)/functionData.calls;functionData.min=Math.min(functionData.min,duration);functionData.max=Math.max(functionData.max,duration);}else{functionData.avg=duration;functionData.min=duration;functionData.max=duration;}},getAverage:function(name){return this._report[name].avg;},getCallCount:function(name){return this._report[name].calls;},getMax:function(name){return this._report[name].max;},getMin:function(name){return this._report[name].min;},getFunctionReport:function(name){return this._report[name];},getFullReport:function(filter){filter=filter||function(){return true;};if(typeof filter=="function"){var report={};for(var name in this._report){if(filter(this._report[name])){report[name]=this._report[name];}}return report;}},registerConstructor:function(name,owner){this.registerFunction(name,owner,true);},registerFunction:function(name,owner,registerPrototype){var funcName=(name.indexOf(".")>-1?name.substring(name.lastIndexOf(".")+1):name);if(!L.isObject(owner)){owner=eval(name.substring(0,name.lastIndexOf(".")));}var method=owner[funcName];var prototype=method.prototype;if(L.isFunction(method)&&!method.__yuiProfiled){this._container[name]=method;owner[funcName]=function(){var start=new Date();var retval=method.apply(this,arguments);var stop=new Date();Y.Profiler._saveData(name,stop-start);return retval;};Y.mix(owner[funcName],method);owner[funcName].__yuiProfiled=true;owner[funcName].prototype=prototype;this._container[name].__yuiOwner=owner;this._container[name].__yuiFuncName=funcName;if(registerPrototype){this.registerObject(name+".prototype",prototype);}this._report[name]={calls:0,max:0,min:0,avg:0,points:[]};}return method;},registerObject:function(name,object,recurse){object=(L.isObject(object)?object:eval(name));this._container[name]=object;for(var prop in object){if(typeof object[prop]=="function"){if(prop!="constructor"&&prop!="superclass"){this.registerFunction(name+"."+prop,object);}}else{if(typeof object[prop]=="object"&&recurse){this.registerObject(name+"."+prop,object[prop],recurse);}}}},unregisterConstructor:function(name){if(L.isFunction(this._container[name])){this.unregisterFunction(name,true);}},unregisterFunction:function(name,unregisterPrototype){if(L.isFunction(this._container[name])){if(unregisterPrototype){this.unregisterObject(name+".prototype",this._container[name].prototype);}var owner=this._container[name].__yuiOwner;var funcName=this._container[name].__yuiFuncName;delete this._container[name].__yuiOwner;delete this._container[name].__yuiFuncName;owner[funcName]=this._container[name];delete this._container[name];delete this._report[name];}},unregisterObject:function(name,recurse){if(L.isObject(this._container[name])){var object=this._container[name];for(var prop in object){if(typeof object[prop]=="function"){this.unregisterFunction(name+"."+prop);}else{if(typeof object[prop]=="object"&&recurse){this.unregisterObject(name+"."+prop,recurse);}}}delete this._container[name];}}};},"3.0.0pr2");
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/profiler/profiler.js'
--- loggerhead/static/javascript/yui/build/profiler/profiler.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/profiler/profiler.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,383 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("profiler", function(Y){
+
+    var L = Y.Lang;
+
+    /**
+     * The YUI JavaScript profiler.
+     * @module profiler
+     * @namespace Y
+     * @requires yahoo
+     */
+    
+    /**
+     * Profiles functions in JavaScript.
+     * @namespace Y
+     * @class Profiler
+     * @static
+     */
+    Y.Profiler = {
+    
+        //-------------------------------------------------------------------------
+        // Private Properties
+        //-------------------------------------------------------------------------
+    
+        /**
+         * Container object on which to put the original unprofiled methods.
+         * @type Object
+         * @private
+         * @static
+         * @property _container
+         */
+        _container : {},
+    
+        /**
+         * Call information for functions.
+         * @type Object
+         * @private
+         * @static
+         * @property _report
+         */
+        _report : {},
+        
+        //-------------------------------------------------------------------------
+        // Private Methods
+        //-------------------------------------------------------------------------
+        
+        /**
+         * Called when a method ends execution. Marks the start and end time of the 
+         * method so it can calculate how long the function took to execute. Also 
+         * updates min/max/avg calculations for the function.
+         * @param {String} name The name of the function to mark as stopped.
+         * @param {int} duration The number of milliseconds it took the function to
+         *      execute.
+         * @return {Void}
+         * @private
+         * @static
+         */
+        _saveData : function (name /*:String*/, duration /*:int*/){
+            
+            //get the function data
+            var functionData /*:Object*/ = this._report[name];
+        
+            //increment the calls
+            functionData.calls++;
+            functionData.points.push(duration);
+    
+            //if it's already been called at least once, do more complex calculations
+            if (functionData.calls > 1) {
+                functionData.avg = ((functionData.avg*(functionData.calls-1))+duration)/functionData.calls;
+                functionData.min = Math.min(functionData.min, duration);
+                functionData.max = Math.max(functionData.max, duration);
+            } else {
+                functionData.avg = duration;
+                functionData.min = duration;
+                functionData.max = duration;
+            }                             
+        
+        },
+    
+        //-------------------------------------------------------------------------
+        // Reporting Methods
+        //-------------------------------------------------------------------------    
+        
+        /**
+         * Returns the average amount of time (in milliseconds) that the function
+         * with the given name takes to execute.
+         * @param {String} name The name of the function whose data should be returned.
+         *      If an object type method, it should be 'constructor.prototype.methodName';
+         *      a normal object method would just be 'object.methodName'.
+         * @return {float} The average time it takes the function to execute.
+         * @static
+         */
+        getAverage : function (name /*:String*/) /*:float*/ {
+            return this._report[name].avg;
+        },
+    
+        /**
+         * Returns the number of times that the given function has been called.
+         * @param {String} name The name of the function whose data should be returned.
+         * @return {int} The number of times the function was called.
+         * @static
+         */
+        getCallCount : function (name /*:String*/) /*:int*/ {
+            return this._report[name].calls;    
+        },
+        
+        /**
+         * Returns the maximum amount of time (in milliseconds) that the function
+         * with the given name takes to execute.
+         * @param {String} name The name of the function whose data should be returned.
+         *      If an object type method, it should be 'constructor.prototype.methodName';
+         *      a normal object method would just be 'object.methodName'.
+         * @return {float} The maximum time it takes the function to execute.
+         */
+        getMax : function (name /*:String*/) /*:int*/ {
+            return this._report[name].max;
+        },
+        
+        /**
+         * Returns the minimum amount of time (in milliseconds) that the function
+         * with the given name takes to execute.
+         * @param {String} name The name of the function whose data should be returned.
+         *      If an object type method, it should be 'constructor.prototype.methodName';
+         *      a normal object method would just be 'object.methodName'.
+         * @return {float} The minimum time it takes the function to execute.
+         */
+        getMin : function (name /*:String*/) /*:int*/ {
+            return this._report[name].min;
+        },
+    
+        /**
+         * Returns an object containing profiling data for a single function.
+         * The object has an entry for min, max, avg, calls, and points).
+         * @return {Object} An object containing profile data for a given function.
+         * @static
+         */
+        getFunctionReport : function (name /*:String*/) /*:Object*/ {
+            return this._report[name];
+        },
+    
+        /**
+         * Returns an object containing profiling data for all of the functions 
+         * that were profiled. The object has an entry for each function and 
+         * returns all information (min, max, average, calls, etc.) for each
+         * function.
+         * @return {Object} An object containing all profile data.
+         * @static
+         */
+        getFullReport : function (filter /*:Function*/) /*:Object*/ {
+            filter = filter || function(){return true;};
+        
+            if (typeof filter == "function") {
+                var report = {};
+                
+                for (var name in this._report){
+                    if (filter(this._report[name])){
+                        report[name] = this._report[name];    
+                    }
+                }
+                
+                return report;
+            }
+        },
+    
+        //-------------------------------------------------------------------------
+        // Profiling Methods
+        //-------------------------------------------------------------------------   
+        
+        /**
+         * Sets up a constructor for profiling, including all properties and methods on the prototype.
+         * @param {string} name The fully-qualified name of the function including namespace information.
+         * @param {Object} owner (Optional) The object that owns the function (namespace or containing object).
+         * @return {Void}
+         * @static
+         */
+        registerConstructor : function (name /*:String*/, owner /*:Object*/) /*:Void*/ {    
+            this.registerFunction(name, owner, true);
+        },
+    
+        /**
+         * Sets up a function for profiling. It essentially overwrites the function with one
+         * that has instrumentation data. This method also creates an entry for the function
+         * in the profile report. The original function is stored on the _container object.
+         * @param {String} name The full name of the function including namespacing. This
+         *      is the name of the function that is stored in the report.
+         * @param {Object} owner (Optional) The object that owns the function. If the function
+         *      isn't global then this argument is required. This could be the namespace that
+         *      the function belongs to, such as YAHOO.util.Dom, or the object on which it's
+         *      a method.
+         * @return {Void}
+         * @method registerFunction
+         */     
+        registerFunction : function(name /*:String*/, owner /*:Object*/, registerPrototype /*:Boolean*/) /*:Void*/{
+        
+            //figure out the function name without namespacing
+            var funcName /*:String*/ = (name.indexOf(".") > -1 ? name.substring(name.lastIndexOf(".")+1) : name);
+            if (!L.isObject(owner)){
+                owner = eval(name.substring(0, name.lastIndexOf(".")));
+            }
+            
+            //get the method and prototype
+            var method /*:Function*/ = owner[funcName];
+            var prototype /*:Object*/ = method.prototype;
+            
+            //see if the method has already been registered
+            if (L.isFunction(method) && !method.__yuiProfiled){
+                
+                //create a new slot for the original method
+                this._container[name] = method;
+                
+                //replace the function with the profiling one
+                owner[funcName] = function () {
+    
+                    var start = new Date();     
+                    var retval = method.apply(this, arguments);
+                    var stop = new Date();
+                    
+                    Y.Profiler._saveData(name, stop-start);
+                    
+                    return retval;                
+                
+                };
+                
+                //copy the function properties over
+                Y.mix(owner[funcName], method);
+                owner[funcName].__yuiProfiled = true;
+                owner[funcName].prototype = prototype;
+                this._container[name].__yuiOwner = owner;
+                this._container[name].__yuiFuncName = funcName;        
+            
+                //register prototype if necessary
+                if (registerPrototype) {            
+                    this.registerObject(name + ".prototype", prototype);          
+                }
+                
+                //store function information
+                this._report[name] = {
+                    calls: 0,
+                    max: 0,
+                    min: 0,
+                    avg: 0,
+                    points: []
+                };        
+            }
+                
+            return method;
+        
+        },
+            
+        
+        /**
+         * Sets up an object for profiling. It takes the object and looks for functions.
+         * When a function is found, registerMethod() is called on it. If set to recrusive
+         * mode, it will also setup objects found inside of this object for profiling, 
+         * using the same methodology.
+         * @param {String} name The name of the object to profile (shows up in report).
+         * @param {Object} owner (Optional) The object represented by the name.
+         * @param {Boolean} recurse (Optional) Determines if subobject methods are also profiled.
+         * @return {Void}
+         * @static
+         */
+        registerObject : function (name /*:String*/, object /*:Object*/, recurse /*:Boolean*/) /*:Void*/{
+        
+            //get the object
+            object = (L.isObject(object) ? object : eval(name));
+        
+            //save the object
+            this._container[name] = object;
+        
+            for (var prop in object) {
+                if (typeof object[prop] == "function"){
+                    if (prop != "constructor" && prop != "superclass"){ //don't do constructor or superclass, it's recursive
+                        this.registerFunction(name + "." + prop, object);
+                    }
+                } else if (typeof object[prop] == "object" && recurse){
+                    this.registerObject(name + "." + prop, object[prop], recurse);
+                }
+            }
+        
+        },    
+        
+        /**
+         * Removes a constructor function from profiling. Reverses the registerConstructor() method.
+         * @param {String} name The full name of the function including namespacing. This
+         *      is the name of the function that is stored in the report.
+         * @return {Void}
+         * @method unregisterFunction
+         */     
+        unregisterConstructor : function(name /*:String*/) /*:Void*/{
+                
+            //see if the method has been registered
+            if (L.isFunction(this._container[name])){
+            
+                //get original data
+                //var owner /*:Object*/ = this._container[name].__yuiOwner;
+                //var funcName /*:String*/ = this._container[name].__yuiFuncName;
+                //delete this._container[name].__yuiOwner;
+                //delete this._container[name].__yuiFuncName;
+                
+                //replace instrumented function
+                //owner[funcName] = this._container[name];
+                //delete this._container[name];
+                this.unregisterFunction(name, true);
+           
+            }
+    
+        
+        },
+        
+        /**
+         * Removes function from profiling. Reverses the registerFunction() method.
+         * @param {String} name The full name of the function including namespacing. This
+         *      is the name of the function that is stored in the report.
+         * @return {Void}
+         * @method unregisterFunction
+         */     
+        unregisterFunction : function(name /*:String*/, unregisterPrototype /*:Boolean*/) /*:Void*/{
+                
+            //see if the method has been registered
+            if (L.isFunction(this._container[name])){
+            
+                //check to see if you should unregister the prototype
+                if (unregisterPrototype){
+                    this.unregisterObject(name + ".prototype", this._container[name].prototype);
+                }
+                    
+                //get original data
+                var owner /*:Object*/ = this._container[name].__yuiOwner;
+                var funcName /*:String*/ = this._container[name].__yuiFuncName;
+                delete this._container[name].__yuiOwner;
+                delete this._container[name].__yuiFuncName;
+                
+                //replace instrumented function
+                owner[funcName] = this._container[name];
+                
+                //delete supporting information
+                delete this._container[name];
+                delete this._report[name];
+           
+            }
+                
+        
+        },
+        
+        /**
+         * Unregisters an object for profiling. It takes the object and looks for functions.
+         * When a function is found, unregisterMethod() is called on it. If set to recrusive
+         * mode, it will also unregister objects found inside of this object, 
+         * using the same methodology.
+         * @param {String} name The name of the object to unregister.
+         * @param {Boolean} recurse (Optional) Determines if subobject methods should also be
+         *      unregistered.
+         * @return {Void}
+         * @static
+         */
+        unregisterObject : function (name /*:String*/, recurse /*:Boolean*/) /*:Void*/{
+        
+            //get the object
+            if (L.isObject(this._container[name])){            
+                var object = this._container[name];    
+            
+                for (var prop in object) {
+                    if (typeof object[prop] == "function"){
+                        this.unregisterFunction(name + "." + prop);
+                    } else if (typeof object[prop] == "object" && recurse){
+                        this.unregisterObject(name + "." + prop, recurse);
+                    }
+                }
+                
+                delete this._container[name];
+            }
+        
+        }
+             
+    
+    };
+}, "3.0.0pr2");
+

=== added directory 'loggerhead/static/javascript/yui/build/queue'
=== added file 'loggerhead/static/javascript/yui/build/queue/README'
--- loggerhead/static/javascript/yui/build/queue/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/queue/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+The Queue Utility
+    The Queue Utility allows you create a chain of function callbacks executed internally via setTimeout.
+
+3.0.0pr1
+    Initial release
+
+3.0.0pr2
+    No changes

=== added file 'loggerhead/static/javascript/yui/build/queue/queue-debug.js'
--- loggerhead/static/javascript/yui/build/queue/queue-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/queue/queue-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,236 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('queue', function(Y) {
+
+/**
+ * Mechanism to execute a series of callbacks in a non-blocking queue.  Each
+ * callback is executed via setTimout unless configured with a negative
+ * timeout, in which case it is run in blocking mode in the same execution
+ * thread as the previous callback.  Callbacks can be function references or
+ * object literals with the following keys:
+ * <ul>
+ *    <li><code>fn</code> - {Function} REQUIRED the callback function.</li>
+ *    <li><code>timeout</code> - {number} millisecond delay to wait after previous callback completion before executing this callback.  Negative values cause immediate blocking execution.  Default 0.</li>
+ *    <li><code>until</code> - {Function} boolean function executed before each iteration.  Return true to indicate callback completion.</li>
+ *    <li><code>iterations</code> - {Number} number of times to execute the callback before proceeding to the next callback in the queue. Incompatible with <code>until</code>.</li>
+ * </ul>
+ *
+ * @module queue
+ * @class Queue
+ * @constructor
+ * @param callback* {Function|Object} Any number of callbacks to initialize the queue
+ */
+Y.Queue = function () {
+    // Factory or Constructor
+    var me = this instanceof Y.Queue ? this : new Y.Queue();
+
+    /**
+     * The callback queue
+     * @property q
+     * @type {Array}
+     * @protected
+     */
+    me.q = [];
+
+    return me.add.apply(me,arguments);
+};
+
+Y.Queue.prototype = {
+    /**
+     * Timeout id used to pause or stop execution and indicate the execution
+     * state of the Queue.  0 indicates paused or stopped, negatives indicate
+     * blocking execution, and positives indicate non-blocking execution.
+     * @property id
+     * @type {number}
+     * @protected
+     */
+    id   : 0,
+
+    /**
+     * Execute the queue callbacks (also resumes paused Queue).
+     * @method run
+     * @return {Queue} the Queue instance
+     */
+    run : function () {
+        // Grab the first callback in the queue
+        var c  = this.q[0],
+            fn;
+
+        // If there is no callback in the queue or the Queue is currently
+        // in an execution mode, return
+        if (!c) {
+            /**
+             * Event fired after the last queued callback is executed.  Not
+             * fired if the Queue is stopped via q.stop().
+             * @event end
+             */
+            this.fire('end');
+            return this;
+        } else if (this.id) {
+            return this;
+        }
+
+        fn = c.fn || c;
+
+        if (typeof fn === 'function') {
+            var ms   = c.timeout || 0,
+                me   = this;
+
+            // Execute immediately if the callback timeout is negative.
+            if (ms < 0) {
+                this.id = ms;
+                if (c.until) { // test .until condition
+                    for (;!c.until();) {
+                        this._exec(fn,c);
+                    }
+                } else if (c.iterations) { // test .iterations
+                    for (;c.iterations-- > 0;) {
+                        this._exec(fn,c);
+                    }
+                } else { // single shot callback
+                    this._exec(fn,c);
+                }
+                this._shift();
+                this.id = 0;
+                return this.run();
+            } else {
+                if (c.until) { // test .until condition
+                    if (c.until()) {
+                        // Move to the next callback
+                        this._shift();
+                        return this.run();
+                    }
+                } else if (!c.iterations || !--c.iterations) { // .iterations
+                    this._shift();
+                }
+
+                // Set to execute after the configured timeout
+                this.id = setTimeout(function () {
+                    me._exec(fn,c);
+
+                    // Loop unless the Queue was paused from inside the callback
+                    if (me.id) {
+                        // Indicate ready to run state
+                        me.id = 0;
+                        // Start the fun all over again
+                        me.run();
+                    }
+                },ms);
+            }
+        }
+
+        return this;
+    },
+
+    /**
+     * Executes the callback function
+     * @method _exec
+     * @param fn {Function} the function to execute
+     * @param c {Object|Function} the callback as defined during add(c)
+     * @protected
+     */
+    _exec : function (fn,c) {
+        /**
+         * Fired before a callback is executed
+         * @event beforeCallback
+         * @param o {Object} Object literal with the following keys:
+         * <dl>
+         * <dt>fn</dt><dd>The function about to be executed</dd>
+         * <dt>callback</dt><dd>The callback as provided to <code>add(..)</code></dd>
+         * </dl>
+         */
+        this.fire('beforeCallback',{fn:fn,callback:c});
+
+        fn.call(this);
+
+        /**
+         * Fired before a callback is executed
+         * @event afterCallback
+         * @param o {Object} Object literal with the following keys:
+         * <dl>
+         * <dt>fn</dt><dd>The function just executed</dd>
+         * <dt>callback</dt><dd>The callback as provided to <code>add(..)</code></dd>
+         * </dl>
+         */
+        this.fire('afterCallback',{fn:fn,callback:c});
+    },
+
+    /**
+     * Shifts the first callback off the Queue
+     * @method _shift
+     * @private
+     */
+    _shift : function () {
+        /**
+         * Fired after a callback is shifted from the Queue
+         * @event shiftCallback
+         * @param callback {Function|Object} The callback passed to <code>add(..)</code>
+         */
+        this.fire('shiftCallback',this.q.shift());
+    },
+    
+    /**
+     * Add any number of callbacks to the end of the queue
+     * @method add
+     * @param callback* {Function|Object} Any number of callbacks
+     * @return {Queue} the Queue instance
+     */
+    add  : function () {
+        var callbacks = Y.Array(arguments,0,true);
+        this.q.splice.apply(this.q,[this.q.length,0].concat(callbacks));
+
+        /**
+         * Fired from within <code>add(..)</code> after callbacks are queued
+         * @event addCallback
+         * @param callbacks {Array} Array of callbacks passed to <code>add(..)</code>
+         */
+        this.fire('addCallback',callbacks);
+        return this;
+    },
+
+    /**
+     * Pause the execution of the Queue after the execution of the current
+     * callback completes.  If called from code outside of a queued callback,
+     * clears the timeout for the pending callback. Paused Queue can be
+     * restarted with q.run()
+     * @method pause
+     * @return {Queue} the Queue instance
+     */
+    pause: function () {
+        clearTimeout(this.id);
+        this.id = 0;
+
+        /**
+         * Fired after Queue is paused
+         * @event pause
+         */
+        this.fire('pause');
+        return this;
+    },
+
+    /**
+     * Stop and clear the Queue's queue after the current execution of the
+     * current callback completes.
+     * @method stop
+     * @return {Queue} the Queue instance
+     */
+    stop : function () { 
+        this.pause();
+        this.q = [];
+
+        /**
+         * Fired after Queue is stopped
+         * @event stop
+         */
+        this.fire('stop');
+        return this;
+    }
+};
+Y.augment(Y.Queue,Y.Event.Target);
+
+
+}, '3.0.0pr2' ,{requires:['event']});

=== added file 'loggerhead/static/javascript/yui/build/queue/queue-min.js'
--- loggerhead/static/javascript/yui/build/queue/queue-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/queue/queue-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("queue",function(A){A.Queue=function(){var B=this instanceof A.Queue?this:new A.Queue();B.q=[];return B.add.apply(B,arguments);};A.Queue.prototype={id:0,run:function(){var E=this.q[0],C;if(!E){this.fire("end");return this;}else{if(this.id){return this;}}C=E.fn||E;if(typeof C==="function"){var B=E.timeout||0,D=this;if(B<0){this.id=B;if(E.until){for(;!E.until();){this._exec(C,E);}}else{if(E.iterations){for(;E.iterations-->0;){this._exec(C,E);}}else{this._exec(C,E);}}this._shift();this.id=0;return this.run();}else{if(E.until){if(E.until()){this._shift();return this.run();}}else{if(!E.iterations||!--E.iterations){this._shift();}}this.id=setTimeout(function(){D._exec(C,E);if(D.id){D.id=0;D.run();}},B);}}return this;},_exec:function(B,C){this.fire("beforeCallback",{fn:B,callback:C});B.call(this);this.fire("afterCallback",{fn:B,callback:C});},_shift:function(){this.fire("shiftCallback",this.q.shift());},add:function(){var B=A.Array(arguments,0,true);this.q.splice.apply(this.q,[this.q.length,0].concat(B));this.fire("addCallback",B);return this;},pause:function(){clearTimeout(this.id);this.id=0;this.fire("pause");return this;},stop:function(){this.pause();this.q=[];this.fire("stop");return this;}};A.augment(A.Queue,A.Event.Target);},"3.0.0pr2",{requires:["event"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/queue/queue.js'
--- loggerhead/static/javascript/yui/build/queue/queue.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/queue/queue.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,236 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('queue', function(Y) {
+
+/**
+ * Mechanism to execute a series of callbacks in a non-blocking queue.  Each
+ * callback is executed via setTimout unless configured with a negative
+ * timeout, in which case it is run in blocking mode in the same execution
+ * thread as the previous callback.  Callbacks can be function references or
+ * object literals with the following keys:
+ * <ul>
+ *    <li><code>fn</code> - {Function} REQUIRED the callback function.</li>
+ *    <li><code>timeout</code> - {number} millisecond delay to wait after previous callback completion before executing this callback.  Negative values cause immediate blocking execution.  Default 0.</li>
+ *    <li><code>until</code> - {Function} boolean function executed before each iteration.  Return true to indicate callback completion.</li>
+ *    <li><code>iterations</code> - {Number} number of times to execute the callback before proceeding to the next callback in the queue. Incompatible with <code>until</code>.</li>
+ * </ul>
+ *
+ * @module queue
+ * @class Queue
+ * @constructor
+ * @param callback* {Function|Object} Any number of callbacks to initialize the queue
+ */
+Y.Queue = function () {
+    // Factory or Constructor
+    var me = this instanceof Y.Queue ? this : new Y.Queue();
+
+    /**
+     * The callback queue
+     * @property q
+     * @type {Array}
+     * @protected
+     */
+    me.q = [];
+
+    return me.add.apply(me,arguments);
+};
+
+Y.Queue.prototype = {
+    /**
+     * Timeout id used to pause or stop execution and indicate the execution
+     * state of the Queue.  0 indicates paused or stopped, negatives indicate
+     * blocking execution, and positives indicate non-blocking execution.
+     * @property id
+     * @type {number}
+     * @protected
+     */
+    id   : 0,
+
+    /**
+     * Execute the queue callbacks (also resumes paused Queue).
+     * @method run
+     * @return {Queue} the Queue instance
+     */
+    run : function () {
+        // Grab the first callback in the queue
+        var c  = this.q[0],
+            fn;
+
+        // If there is no callback in the queue or the Queue is currently
+        // in an execution mode, return
+        if (!c) {
+            /**
+             * Event fired after the last queued callback is executed.  Not
+             * fired if the Queue is stopped via q.stop().
+             * @event end
+             */
+            this.fire('end');
+            return this;
+        } else if (this.id) {
+            return this;
+        }
+
+        fn = c.fn || c;
+
+        if (typeof fn === 'function') {
+            var ms   = c.timeout || 0,
+                me   = this;
+
+            // Execute immediately if the callback timeout is negative.
+            if (ms < 0) {
+                this.id = ms;
+                if (c.until) { // test .until condition
+                    for (;!c.until();) {
+                        this._exec(fn,c);
+                    }
+                } else if (c.iterations) { // test .iterations
+                    for (;c.iterations-- > 0;) {
+                        this._exec(fn,c);
+                    }
+                } else { // single shot callback
+                    this._exec(fn,c);
+                }
+                this._shift();
+                this.id = 0;
+                return this.run();
+            } else {
+                if (c.until) { // test .until condition
+                    if (c.until()) {
+                        // Move to the next callback
+                        this._shift();
+                        return this.run();
+                    }
+                } else if (!c.iterations || !--c.iterations) { // .iterations
+                    this._shift();
+                }
+
+                // Set to execute after the configured timeout
+                this.id = setTimeout(function () {
+                    me._exec(fn,c);
+
+                    // Loop unless the Queue was paused from inside the callback
+                    if (me.id) {
+                        // Indicate ready to run state
+                        me.id = 0;
+                        // Start the fun all over again
+                        me.run();
+                    }
+                },ms);
+            }
+        }
+
+        return this;
+    },
+
+    /**
+     * Executes the callback function
+     * @method _exec
+     * @param fn {Function} the function to execute
+     * @param c {Object|Function} the callback as defined during add(c)
+     * @protected
+     */
+    _exec : function (fn,c) {
+        /**
+         * Fired before a callback is executed
+         * @event beforeCallback
+         * @param o {Object} Object literal with the following keys:
+         * <dl>
+         * <dt>fn</dt><dd>The function about to be executed</dd>
+         * <dt>callback</dt><dd>The callback as provided to <code>add(..)</code></dd>
+         * </dl>
+         */
+        this.fire('beforeCallback',{fn:fn,callback:c});
+
+        fn.call(this);
+
+        /**
+         * Fired before a callback is executed
+         * @event afterCallback
+         * @param o {Object} Object literal with the following keys:
+         * <dl>
+         * <dt>fn</dt><dd>The function just executed</dd>
+         * <dt>callback</dt><dd>The callback as provided to <code>add(..)</code></dd>
+         * </dl>
+         */
+        this.fire('afterCallback',{fn:fn,callback:c});
+    },
+
+    /**
+     * Shifts the first callback off the Queue
+     * @method _shift
+     * @private
+     */
+    _shift : function () {
+        /**
+         * Fired after a callback is shifted from the Queue
+         * @event shiftCallback
+         * @param callback {Function|Object} The callback passed to <code>add(..)</code>
+         */
+        this.fire('shiftCallback',this.q.shift());
+    },
+    
+    /**
+     * Add any number of callbacks to the end of the queue
+     * @method add
+     * @param callback* {Function|Object} Any number of callbacks
+     * @return {Queue} the Queue instance
+     */
+    add  : function () {
+        var callbacks = Y.Array(arguments,0,true);
+        this.q.splice.apply(this.q,[this.q.length,0].concat(callbacks));
+
+        /**
+         * Fired from within <code>add(..)</code> after callbacks are queued
+         * @event addCallback
+         * @param callbacks {Array} Array of callbacks passed to <code>add(..)</code>
+         */
+        this.fire('addCallback',callbacks);
+        return this;
+    },
+
+    /**
+     * Pause the execution of the Queue after the execution of the current
+     * callback completes.  If called from code outside of a queued callback,
+     * clears the timeout for the pending callback. Paused Queue can be
+     * restarted with q.run()
+     * @method pause
+     * @return {Queue} the Queue instance
+     */
+    pause: function () {
+        clearTimeout(this.id);
+        this.id = 0;
+
+        /**
+         * Fired after Queue is paused
+         * @event pause
+         */
+        this.fire('pause');
+        return this;
+    },
+
+    /**
+     * Stop and clear the Queue's queue after the current execution of the
+     * current callback completes.
+     * @method stop
+     * @return {Queue} the Queue instance
+     */
+    stop : function () { 
+        this.pause();
+        this.q = [];
+
+        /**
+         * Fired after Queue is stopped
+         * @event stop
+         */
+        this.fire('stop');
+        return this;
+    }
+};
+Y.augment(Y.Queue,Y.Event.Target);
+
+
+}, '3.0.0pr2' ,{requires:['event']});

=== added directory 'loggerhead/static/javascript/yui/build/slider'
=== added file 'loggerhead/static/javascript/yui/build/slider/README'
--- loggerhead/static/javascript/yui/build/slider/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/slider/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,5 @@
+The Slider widget
+    The Slider widget creates an input UI involving a draggable thumb, representing a value, sliding along a rail, representing the finite value range.
+
+3.0.0pr2
+    Initial release

=== added directory 'loggerhead/static/javascript/yui/build/slider/assets'
=== added directory 'loggerhead/static/javascript/yui/build/slider/assets/skins'
=== added directory 'loggerhead/static/javascript/yui/build/slider/assets/skins/sam'
=== added file 'loggerhead/static/javascript/yui/build/slider/assets/skins/sam/rail-classic-x.png'
Binary files loggerhead/static/javascript/yui/build/slider/assets/skins/sam/rail-classic-x.png and loggerhead/static/javascript/yui/build/slider/assets/skins/sam/rail-classic-x.png differ
=== added file 'loggerhead/static/javascript/yui/build/slider/assets/skins/sam/rail-classic-y.png'
Binary files loggerhead/static/javascript/yui/build/slider/assets/skins/sam/rail-classic-y.png and loggerhead/static/javascript/yui/build/slider/assets/skins/sam/rail-classic-y.png differ
=== added file 'loggerhead/static/javascript/yui/build/slider/assets/skins/sam/slider-skin.css'
--- loggerhead/static/javascript/yui/build/slider/assets/skins/sam/slider-skin.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/slider/assets/skins/sam/slider-skin.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,17 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-skin-sam .yui-slider-rail-x {
+    background: url("rail-classic-x.png") repeat-x 0 0;
+    min-height: 19px;
+    *height: 19px;
+}
+
+.yui-skin-sam .yui-slider-rail-y {
+    background: url("rail-classic-y.png") repeat-y 0 0;
+    min-width: 19px;
+    *width: 19px;
+}

=== added file 'loggerhead/static/javascript/yui/build/slider/assets/skins/sam/slider.css'
--- loggerhead/static/javascript/yui/build/slider/assets/skins/sam/slider.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/slider/assets/skins/sam/slider.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-slider{display:-moz-inline-stack;display:inline-block;*display:inline;zoom:1;vertical-align:middle;}.yui-slider-content{position:relative;}.yui-slider-rail{position:relative;}.yui-slider-thumb{position:absolute;}.yui-slider-thumb-image{display:block;}.yui-slider-image-error .yui-slider-thumb{height:10px;width:10px;background:#000;color:#000;overflow:hidden;}.yui-slider-image-error .yui-slider-thumb-image{display:none;}.yui-skin-sam .yui-slider-rail-x{background:url("rail-classic-x.png") repeat-x 0 0;min-height:19px;*height:19px;}.yui-skin-sam .yui-slider-rail-y{background:url("rail-classic-y.png") repeat-y 0 0;min-width:19px;*width:19px;}

=== added file 'loggerhead/static/javascript/yui/build/slider/assets/skins/sam/thumb-classic-x.png'
Binary files loggerhead/static/javascript/yui/build/slider/assets/skins/sam/thumb-classic-x.png and loggerhead/static/javascript/yui/build/slider/assets/skins/sam/thumb-classic-x.png differ
=== added file 'loggerhead/static/javascript/yui/build/slider/assets/skins/sam/thumb-classic-y.png'
Binary files loggerhead/static/javascript/yui/build/slider/assets/skins/sam/thumb-classic-y.png and loggerhead/static/javascript/yui/build/slider/assets/skins/sam/thumb-classic-y.png differ
=== added file 'loggerhead/static/javascript/yui/build/slider/assets/slider-core.css'
--- loggerhead/static/javascript/yui/build/slider/assets/slider-core.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/slider/assets/slider-core.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,41 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-slider {
+    /* xbrowser inline-block styles */
+    display: -moz-inline-stack; /* FF2 */
+    display: inline-block;
+    *display: inline; /* IE 7- (with zoom) */
+    zoom: 1;
+    vertical-align: middle;
+}
+
+.yui-slider-content {
+    position: relative;
+}
+
+.yui-slider-rail {
+    position: relative;
+}
+
+.yui-slider-thumb {
+    position: absolute;
+}
+.yui-slider-thumb-image {
+    /* to collapse vertical space around short thumbs in tall line-height */
+    display: block;
+}
+
+.yui-slider-image-error .yui-slider-thumb {
+    height: 10px;
+    width: 10px;
+    background: #000;
+    color: #000;
+    overflow: hidden;
+}
+.yui-slider-image-error .yui-slider-thumb-image {
+    display: none;
+}

=== added file 'loggerhead/static/javascript/yui/build/slider/slider-debug.js'
--- loggerhead/static/javascript/yui/build/slider/slider-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/slider/slider-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1434 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('slider', function(Y) {
+
+/**
+ * Create a sliding value range input visualized as a draggable thumb on a
+ * background element.
+ * 
+ * @module slider
+ */
+
+var SLIDER = 'slider',
+    RAIL   = 'rail',
+    THUMB  = 'thumb',
+    VALUE  = 'value',
+    MIN    = 'min',
+    MAX    = 'max',
+    THUMB_IMAGE = 'thumbImage',
+    RAIL_SIZE   = 'railSize',
+    CONTENT_BOX = 'contentBox',
+
+    SLIDE_START = 'slideStart',
+    SLIDE_END   = 'slideEnd',
+
+    THUMB_DRAG  = 'thumbDrag',
+    SYNC        = 'sync',
+    VALUE_SET   = 'valueSet',
+    RENDERED    = 'rendered',
+    DISABLED    = 'disabled',
+    DISABLED_CHANGE = 'disabledChange',
+
+    DOT      = '.',
+    PX       = 'px',
+    WIDTH    = 'width',
+    HEIGHT   = 'height',
+    COMPLETE = 'complete',
+
+    L = Y.Lang,
+    isArray  = L.isArray,
+    isBoolean= L.isBoolean,
+    isString = L.isString,
+    isNumber = L.isNumber,
+    
+    getCN    = Y.ClassNameManager.getClassName,
+
+    IMAGE         = 'image',
+    C_RAIL        = getCN(SLIDER,RAIL),
+    C_THUMB       = getCN(SLIDER,THUMB),
+    C_THUMB_IMAGE = getCN(SLIDER,THUMB,IMAGE),
+    C_IMAGE_ERROR = getCN(SLIDER,IMAGE,'error'),
+
+    M        = Math,
+    max      = M.max,
+    round    = M.round,
+    floor    = M.floor,
+    ceil     = M.ceil,
+    abs      = M.abs;
+
+/**
+ * Create a slider to represent an integer value between a given minimum and
+ * maximum.
+ *
+ * @class Slider
+ * @extends Widget
+ * @param config {Object} Configuration object
+ * @constructor
+ */
+function Slider() {
+    Slider.superclass.constructor.apply(this,arguments);
+}
+
+Y.mix(Slider, {
+
+    /**
+     * The identity of the widget.
+     *
+     * @property Slider.NAME
+     * @type String
+     * @static
+     */
+    NAME : SLIDER,
+
+    /**
+     * Object property names used for respective X and Y axis Sliders (e.g.
+     * &quot;left&quot; vs. &quot;top&quot; for placing the thumb according to
+     * its representative value).
+     *
+     * @property Slider.AXIS_KEYS
+     * @type Object
+     * @static
+     */
+    AXIS_KEYS : {
+        x : {
+            offsetEdge    : 'left',
+            dim           : WIDTH,
+            offAxisDim    : HEIGHT,
+            eventPageAxis : 'pageX',
+            ddStick       : 'stickX',
+            xyIndex       : 0
+        },
+        y : {
+            offsetEdge    : 'top',
+            dim           : HEIGHT,
+            offAxisDim    : WIDTH,
+            eventPageAxis : 'pageY',
+            ddStick       : 'stickY',
+            xyIndex       : 1
+        }
+    },
+
+    /**
+     * Static Object hash used to capture existing markup for progressive
+     * enhancement.  Keys correspond to config attribute names and values
+     * are selectors used to inspect the contentBox for an existing node
+     * structure.
+     *
+     * @property Slider.HTML_PARSER
+     * @Type Object
+     * @static
+     */
+    HTML_PARSER : {
+        rail       : DOT + C_RAIL,
+        thumb      : DOT + C_THUMB,
+        thumbImage : DOT + C_THUMB_IMAGE
+    },
+
+    /**
+     * Static property used to define the default attribute configuration of
+     * the Widget.
+     *
+     * @property Slider.ATTRS
+     * @Type Object
+     * @static
+     */
+    ATTRS : {
+
+        /**
+         * Axis upon which the Slider's thumb moves.  &quot;x&quot; for
+         * horizontal, &quot;y&quot; for vertical.
+         *
+         * @attribute axis
+         * @type String
+         * @default &quot;x&quot;
+         * @writeOnce
+         */
+        axis : {
+            value : 'x',
+            writeOnce : true,
+            validator : function (v) {
+                return this._validateNewAxis(v);
+            },
+            set : function (v) {
+                return this._setAxisFn(v);
+            }
+        },
+
+        /**
+         * Integer value associated with the left or top terminus of the
+         * Slider's rail, depending on the configured axis.
+         *
+         * @attribute min
+         * @type Number
+         * @default 0
+         */
+        min : {
+            value : 0,
+            validator : function (v) {
+                return this._validateNewMin(v);
+            }
+        },
+
+        /**
+         * Integer value associated with the right or bottom terminus of the
+         * Slider's rail, depending on the configured axis.
+         *
+         * @attribute max
+         * @type Number
+         * @default 100
+         */
+        max : {
+            value : 100,
+            validator : function (v) {
+                return this._validateNewMax(v);
+            }
+        },
+
+        /**
+         * The current value of the Slider.  This value is interpretted into a
+         * position for the thumb along the Slider's rail.
+         *
+         * @attribute value
+         * @type Number
+         * @default 0
+         */
+        value : {
+            value : 0,
+            validator : function (v) {
+                return this._validateNewValue(v);
+            },
+            set : function (v) {
+                return this._setValueFn(v);
+            }
+        },
+
+        /**
+         * The Node representing the Slider's rail, usually visualized as a
+         * bar of some sort using a background image, along which the thumb
+         * moves.  This Node contains the thumb Node.
+         *
+         * @attribute rail
+         * @type Node
+         * @default null
+         */
+        rail : {
+            value : null,
+            validator : function (v) {
+                return this._validateNewRail(v);
+            },
+            set : function (v) {
+                return this._setRailFn(v);
+            }
+        },
+
+        /**
+         * The Node representing the Slider's thumb, usually visualized as a
+         * pointer using a contained image Node (see thumbImage).  The current
+         * value of the Slider is calculated from the centerpoint of this
+         * Node in relation to the rail Node.  If provided, the thumbImage
+         * Node is contained within this Node.
+         *
+         * If no thumbImage is provided and the Node passed as the thumb is an
+         * <code>img</code> element, the assigned Node will be allocated to the
+         * thumbImage and the thumb container defaulted.
+         *
+         * @attribute thumb
+         * @type Node
+         * @default null
+         */
+        thumb : {
+            value : null,
+            validator : function (v) {
+                return this._validateNewThumb(v);
+            },
+            set : function (v) {
+                return this._setThumbFn(v);
+            }
+        },
+
+        /**
+         * The Node representing the image element to use for the Slider's
+         * thumb.
+         *
+         * Alternately, an image URL can be passed and an <code>img</code>
+         * Node will be generated accordingly.
+         *
+         * If no thumbImage is provided and the Node passed as the thumb is an
+         * <code>img</code> element, the assigned Node will be allocated to the
+         * thumbImage and the thumb container defaulted.
+         *
+         * If thumbImage is provided but its URL resolves to a 404, a default
+         * style will be applied to maintain basic functionality.
+         *
+         * @attribute thumbImage
+         * @type Node|String
+         * @default null
+         */
+        thumbImage : {
+            value : null,
+            validator : function (v) {
+                return this._validateNewThumbImage(v);
+            },
+            set : function (v) {
+                return this._setThumbImageFn(v);
+            }
+        },
+
+        /**
+         * The width or height of the rail element representing the physical
+         * space along which the thumb can move.  CSS size values (e.g. '30em')
+         * accepted but converted to pixels during render.
+         *
+         * Alternately, but not recommended, this attribute can be left
+         * unassigned in favor of specifying height or width.
+         *
+         * @attribute railSize
+         * @type String
+         * @default '0'
+         */
+        railSize : {
+            value : '0',
+            validator : function (v) {
+                return this._validateNewRailSize(v);
+            }
+        },
+
+        /**
+         * Boolean indicating whether clicking and dragging on the rail will
+         * trigger thumb movement.
+         *
+         * @attribute railEnabled
+         * @type @Boolean
+         * @default true
+         */
+        railEnabled : {
+            value : true,
+            validator : isBoolean
+        }
+    }
+});
+
+Y.extend(Slider, Y.Widget, {
+
+    /**
+     * Collection of object property names from the appropriate hash set in
+     * Slider.AXIS_KEYS.
+     *
+     * @property _key
+     * @type Object
+     * @protected
+     */
+    _key : null,
+
+    /**
+     * Factor used to translate positional coordinates (e.g. left or top) to
+     * the Slider's value.
+     *
+     * @property _factor
+     * @type Number
+     * @protected
+     */
+    _factor : 1,
+
+    /**
+     * Pixel dimension of the rail Node's width for X axis Sliders or height
+     * for Y axis Sliders.  Used with _factor to calculate positional
+     * coordinates for the thumb.
+     *
+     * @property _railSize
+     * @type Number
+     * @protected
+     */
+    _railSize : null,
+
+    /**
+     * Pixel dimension of the thumb Node's width for X axis Sliders or height
+     * for Y axis Sliders.  Used with _factor to calculate positional
+     * coordinates for the thumb.
+     *
+     * @property _thumbSize
+     * @type Number
+     * @protected
+     */
+    _thumbSize : null,
+
+    /**
+     * Pixel offset of the point in the thumb element from its top/left edge
+     * to where the value calculation should take place.  By default, this is
+     * calculated to half the width of the thumb, causing the value to be
+     * marked from the center of the thumb.
+     *
+     * @property _thumbOffset
+     * @type Number
+     * @protected
+     */
+    _thumbOffset : 0,
+
+    /**
+     * Object returned from temporary subscription to disabledChange event to
+     * defer setting the disabled state while Slider is loading the thumb
+     * image.
+     *
+     * @property _stall
+     * @type Object
+     * @protected
+     */
+    _stall : false,
+
+    /**
+     * Deferred value for the disabled attribute when stalled (see _stall
+     * property).
+     *
+     * @property _disabled
+     * @type Boolean
+     * @protected
+     */
+    _disabled : false,
+
+    /**
+     * Construction logic executed durint Slider instantiation. Subscribe to
+     * after events for min, max, and railSize.  Publish custom events
+     * including slideStart and slideEnd.
+     *
+     * @method initializer
+     * @protected
+     */
+    initializer : function () {
+        this._key = Slider.AXIS_KEYS[this.get('axis')];
+
+        this.after('minChange',    this._afterMinChange);
+        this.after('maxChange',    this._afterMaxChange);
+
+        this.after('railSizeChange', this._afterRailSizeChange);
+
+        /**
+         * Signals the beginning of a thumb drag operation.  Payload includes
+         * the DD.Drag instance's drag:start event under key ddEvent.
+         *
+         * @event slideStart
+         * @param event {Event.Facade} An Event Facade object with the following attribute specific properties added:
+         *  <dl>
+         *      <dt>ddEvent</dt>
+         *          <dd><code>drag:start</code> event from the managed DD.Drag instance</dd>
+         *  </dl>
+         */
+        this.publish(SLIDE_START);
+
+        /**
+         * Signals the end of a thumb drag operation.  Payload includes
+         * the DD.Drag instance's drag:end event under key ddEvent.
+         *
+         * @event slideEnd
+         * @param event {Event.Facade} An Event Facade object with the following attribute specific properties added:
+         *  <dl>
+         *      <dt>ddEvent</dt>
+         *          <dd><code>drag:end</code> event from the managed DD.Drag instance</dd>
+         *  </dl>
+         */
+        this.publish(SLIDE_END);
+
+        /**
+         * Communicates a request to synchronize the Slider UI with the
+         * attribute state.  Links the sync request with the default sync
+         * logic in the default function _defSyncUI.
+         *
+         * @event sync
+         * @param event {Event.Facade} Event Facade object
+         * @preventable _defSyncUI
+         */
+        this.publish(SYNC,       {defaultFn: this._defSyncUI});
+
+        /**
+         * Signals a value change via API, requiring the thumb position to be
+         * updated.  Triggers the thumb placement logic in the default function
+         * _defSetThumbPosition.
+         *
+         * @event valueSet
+         * @param event {Event.Facade} An Event Facade object with the following attribute specific properties added:
+         *  <dl>
+         *      <dt>changeEv</dt>
+         *          <dd><code>valueChange</code> event fired in response to the change in the value attribute</dd>
+         *  </dl>
+         * @preventable _defSetThumbPosition
+         */
+        this.publish(VALUE_SET,  {defaultFn: this._defSetThumbPosition});
+    },
+
+    /**
+     * Create the DOM structure for the Slider.  Calls _initRail and _initThumb.
+     *
+     * @method renderUI
+     * @protected
+     */
+    renderUI : function () {
+        this._initRail();
+        this._initThumb();
+    },
+
+    /**
+     * Creates the rail element if not provided or discovered via HTML_PARSER.
+     *
+     * @method _initRail
+     * @protected
+     */
+    _initRail : function () {
+        var cb   = this.get(CONTENT_BOX),
+            rail = this.get(RAIL);
+
+        // Create rail if necessary. Make sure it's in the contentBox
+        if (!rail) {
+            rail = cb.appendChild(
+                Y.Node.create('<div class="'+C_RAIL+'"></div>'));
+
+            this.set(RAIL,rail);
+        } else if (!cb.contains(rail)) {
+            cb.appendChild(rail);
+        }
+
+        rail.addClass(C_RAIL);
+        rail.addClass(this.getClassName(RAIL,this.get('axis')));
+    },
+
+    /**
+     * Creates the thumb element (not image) if not provided or discovered via
+     * HTML_PARSER.  If thumb is present and an <code>img</code> element
+     * <em>and</em> no thumbImage provided, reassigns the thumb element to the
+     * thumbImage and defaults the thumb element as a div.
+     *
+     * Makes sure the thumb is a child of the rail element and calls
+     * _initThumbImage if thumbImage is provided.
+     *
+     * @method _initThumb
+     * @protected
+     */
+    _initThumb : function () {
+        var rail    = this.get(RAIL),
+            thumb   = this.get(THUMB);
+
+        // Passed an img element as the thumb
+        if (thumb && !this.get(THUMB_IMAGE) &&
+            thumb.get('nodeName').toLowerCase() === 'img') {
+            this.set(THUMB_IMAGE, thumb);
+            this.set(THUMB,null);
+            thumb = null;
+        }
+
+        if (!thumb) {
+            thumb = Y.Node.create(
+                '<div class="'+C_THUMB+'"></div>');
+
+            this.set(THUMB,thumb);
+        }
+
+        thumb.addClass(C_THUMB);
+
+        if (!rail.contains(thumb)) {
+            rail.appendChild(thumb);
+        }
+
+        if (this.get(THUMB_IMAGE)) {
+            this._initThumbImage();
+        }
+    },
+
+    /**
+     * Ensures the thumbImage is a child of the thumb element.
+     *
+     * @method _initThumbImage
+     * @protected
+     */
+    _initThumbImage : function () {
+        var thumb = this.get(THUMB),
+            img   = this.get(THUMB_IMAGE);
+
+        if (img) {
+            img.replaceClass(C_THUMB,C_THUMB_IMAGE);
+
+            if (!thumb.contains(img)) {
+                thumb.appendChild(img);
+            }
+        }
+    },
+
+    /**
+     * Calls _bindThumbDD to create the Y.DD instance used to handle the thumb
+     * movement and binds Slider interaction to the configured value model.
+     *
+     * @method bindUI
+     * @protected
+     */
+    bindUI : function () {
+        /**
+         * Communicates user interaction with the thumb.  Triggers the logic
+         * to update the value via the default function _defUpdateValueFromDD.
+         *
+         * @event thumbDrag
+         * @param event {Event.Facade} An Event Facade object with the following attribute specific properties added:
+         *  <dl>
+         *      <dt>ddEvent</dt>
+         *          <dd><code>drag:drag</code> event from the managed DD.Drag instance</dd>
+         *  </dl>
+         * @preventable _defUpdateValueFromDD
+         */
+        this.publish(THUMB_DRAG, {defaultFn: this._defUpdateValueFromDD});
+
+        this._bindThumbDD();
+
+        this.after('valueChange',      this._afterValueChange);
+        this.after('thumbImageChange', this._afterThumbImageChange);
+        this.after(DISABLED_CHANGE,    this._afterDisabledChange);
+    },
+
+    /**
+     * Creates the Y.DD instance used to handle the thumb interaction.
+     * 
+     * @method _bindThumbDD
+     * @protected
+     */
+    _bindThumbDD : function () {
+        var ddConf = {
+                node           : this.get(THUMB),
+                constrain2node : this.get(RAIL)
+            },
+            dd;
+
+        ddConf[this._key.ddStick] = true;
+
+        this._dd = dd = new Y.DD.Drag(ddConf);
+        dd.on('drag:start', Y.bind(this._onDDStartDrag, this));
+        dd.on('drag:drag',  Y.bind(this._onDDDrag,      this));
+        dd.on('drag:end',   Y.bind(this._onDDEndDrag,   this));
+
+        this._initRailDD();
+    },
+
+    /**
+     * Subscribes to the rail Node's mousedown event to actuate the thumb when
+     * backgroundEnabled is true.
+     *
+     * @method _initRailDD
+     * @protected
+     */
+    _initRailDD : function () {
+        this.get(RAIL).on('mousedown',Y.bind(this._handleRailMouseDown,this));
+    },
+
+    /**
+     * Moves the thumb to the mousedown position and hands control over to DD
+     * if the Slider is not disabled and railEnabled is true.
+     *
+     * @method _handleRailMouseDown
+     * @param e {Event} Mousedown event facade
+     * @protected
+     */
+    _handleRailMouseDown : function (e) {
+        if (this.get('railEnabled') && !this.get(DISABLED)) {
+            var dd      = this._dd,
+                xyIndex = this._key.xyIndex,
+                xy;
+
+            if (dd.get('primaryButtonOnly') && e.button > 1) {
+                Y.log('Mousedown was not produced by the primary button',
+                      'warn', 'dd-drag');
+                return false;
+            }
+
+            dd._dragThreshMet = true;
+
+            dd._fixIEMouseDown();
+            e.halt();
+
+            Y.DD.DDM.activeDrag = dd;
+
+            // Adjust registered starting position by half the thumb's x/y
+            xy = dd.get('dragNode').getXY();
+            xy[xyIndex] += this._thumbOffset;
+
+            dd._setStartPosition(xy);
+
+            dd.start();
+            dd._moveNode([e.pageX,e.pageY]);
+        }
+    },
+
+    /**
+     * Synchronizes the DOM state with the attribute settings (most notably
+     * railSize and value).  If thumbImage is provided and is still loading,
+     * sync is delayed until it is complete, since the image's dimensions are
+     * taken into consideration for calculations.
+     *
+     * @method syncUI
+     */
+    syncUI : function () {
+        var img = this.get(THUMB_IMAGE);
+
+        if (this._isImageLoading(img)) {
+            Y.log('Thumb image loading. Scheduling sync.','info','slider');
+            // Schedule the sync for when the image loads/errors
+            this._scheduleSync();
+        } else {
+            Y.log('No thumb image, or image already loaded. Syncing immediately.','info','slider');
+            this._ready(img,!this._isImageLoaded(img));
+        }
+    },
+
+    /**
+     * Binds to the load and error event on the thumbImage to sync the DOM
+     * state with the attribute settings when the image resource is resolved.
+     * The Slider is disabled while it waits.
+     *
+     * @method _scheduleSync
+     * @protected
+     */
+    _scheduleSync : function () {
+        var img, handler;
+
+        if (!this._stall) {
+            // disable the control until the image is loaded
+            this._disabled = this.get(DISABLED);
+            this.set(DISABLED,true);
+            this._stall    = this.on(DISABLED_CHANGE,this._stallDisabledChange);
+
+            img     = this.get(THUMB_IMAGE);
+            handler = Y.bind(this._imageLoaded,this,img);
+            img.on('load', handler);
+            img.on('error',handler);
+        }
+    },
+
+    /**
+     * Method subscribed to the disabledChange event when thumbImage is being
+     * loaded.  Prevents manually enabling the Slider until the thumbImage
+     * resource is resolved.  Intended value is stored during load and set upon
+     * completion.
+     *
+     * @method _stallDisabledChange
+     * @param e {Event} Change event for the disabled attribute
+     * @protected
+     */
+    _stallDisabledChange : function (e) {
+        this._disabled = e.newVal;
+        e.preventDefault();
+    },
+
+    /**
+     * Event handler assigned to the thumbImage's load and error event if it
+     * was not loaded prior to instantiation.  Calls _ready method and restores
+     * the Slider's disabled attribute.
+     *
+     * @method _imageLoaded
+     * @param e {Event} load or error event fired by the thumbImage
+     * @param img {Node} The thumbImage Node
+     * @protected
+     */
+    _imageLoaded : function (e,img) {
+        var error = (e.type.toLowerCase().indexOf('error') > -1);
+
+        if (this._stall) {
+            this._stall.detach();
+        }
+
+        Y.log('Thumb image '+e.type+'ed.  Syncing','info','slider');
+
+        this._stall = false;
+
+        this._ready(img,error);
+
+        this.set(DISABLED,this._disabled);
+    },
+
+    /**
+     * Fires the internal sync event, which barring preventDefault should
+     * execute _defSyncUI.
+     *
+     * @method _ready
+     * @param img {Node} the thumbImage Node
+     * @param error {Boolean} Indicates an error while loading the thumbImage
+     * @protected
+     */
+    _ready : function (img,error) {
+        var method = error ? 'addClass' : 'removeClass';
+
+        // If the thumb image url results in 404, assign a class to provide
+        // default thumb dimensions/UI
+        this.get(CONTENT_BOX)[method](C_IMAGE_ERROR);
+
+        this.fire(SYNC);
+    },
+
+    /**
+     * The default synchronization behavior, updating the Slider's DOM state to
+     * match the current attribute values.
+     *
+     * @method _defSyncUI
+     * @param e {Event} Internal sync event
+     * @protected
+     */
+    _defSyncUI : function (e) {
+        this._uiSetThumbSize();
+
+        this._setThumbOffset();
+
+        this._uiSetRailSize();
+
+        this._setRailOffsetXY();
+
+        this._setDDGutter();
+
+        this._setFactor();
+
+        Y.log('placing thumb for value '+this.get(VALUE),'info','slider');
+
+        this.set(VALUE,this.get(VALUE));
+    },
+
+    /**
+     * Captures the thumbs pixel height or width, depending on the Slider's
+     * axis, for use in positioning calculations.
+     *
+     * @method _uiSetThumbSize
+     * @protected
+     */
+    _uiSetThumbSize : function () {
+        var thumb = this.get(THUMB),
+            dim   = this._key.dim,
+            img   = this.get(THUMB_IMAGE),
+            size;
+
+        // offsetWidth fails in hidden containers
+        size = parseInt(thumb.getComputedStyle(dim),10);
+
+        Y.log('thumb '+dim+': '+size+'px','info','slider');
+
+        if (img && this._isImageLoaded(img)) {
+            Y.log('using thumbImage '+dim+' ('+img.get(dim)+') for _thumbSize','info','slider');
+
+            size = img.get(dim);
+        }
+
+        this._thumbSize = size;
+    },
+
+    /**
+     * Sets the _thumbOffset property for use in establishing the point in the
+     * thumb that should align to the rail position representing the calculated
+     * value.
+     *
+     * @method _setThumbOffset
+     * @protected
+     */
+    _setThumbOffset : function () {
+        this._thumbOffset = floor(this._thumbSize / 2);
+        Y.log('_thumbOffset calculated to '+this._thumbOffset+'px','info','slider');
+    },
+
+    /**
+     * Stores the rail Node's pixel height or width, depending on the Slider's
+     * axis, for use in calculating thumb position from the value.
+     *
+     * @method _uiSetRailSize
+     * @protected
+     */
+    _uiSetRailSize : function () {
+        var rail  = this.get(RAIL),
+            thumb = this.get(THUMB),
+            img   = this.get(THUMB_IMAGE),
+            dim   = this._key.dim,
+            size  = this.get(RAIL_SIZE),
+            setxy = false;
+
+        if (parseInt(size,10)) {
+            Y.log('railSize provided: '+size,'info','slider');
+
+            // Convert to pixels
+            rail.setStyle(dim,size);
+            size = parseInt(rail.getComputedStyle(dim),10);
+
+            Y.log('pixel '+dim+' of railSize: '+size+'px', 'info', 'slider');
+        } else {
+            Y.log('defaulting railSize from max of computed style and configured '+dim+' attribute value', 'info', 'slider');
+            // Default from height or width (axis respective), or dims assigned
+            // via css to the rail or thumb, whichever is largest.
+            // Dear implementers, please use railSize, not height/width to
+            // set the rail dims
+            size = this.get(dim);
+            if (parseInt(size,10)) {
+                setxy = true;
+                rail.setStyle(dim,size);
+                size = parseInt(rail.getComputedStyle(dim),10);
+            }
+            size = max(
+                    size|0,
+                    parseInt(thumb.getComputedStyle(dim),10),
+                    parseInt(rail.getComputedStyle(dim),10));
+
+            Y.log('pixel '+dim+' of rail: '+size+'px', 'info', 'slider');
+
+            if (img && this._isImageLoaded(img)) {
+                Y.log('using max of thumbImage '+dim+' ('+img.get(dim)+' and '+size+' for railSize', 'info', 'slider');
+
+                size = max(img.get(dim),size);
+            }
+        }
+
+        rail.setStyle(dim, size + PX);
+
+        this._railSize = size;
+
+        // handle the (not recommended) fallback case of setting rail size via
+        // widget height/width params.  This is the only case that sets the
+        // off-axis rail dim in the code.
+        if (setxy) {
+            dim = this._key.offAxisDim;
+            size = this.get(dim);
+            if (size) {
+                rail.set(dim,size);
+            }
+        }
+    },
+
+    /**
+     * Store the current XY position of the rail Node on the page.  For use in calculating thumb position from value.
+     *
+     * @method _setRailOffsetXY
+     * @protected
+     */
+    _setRailOffsetXY : function () {
+        this._offsetXY = this.get(RAIL).getXY()[this._key.xyIndex] -
+                         this._thumbOffset;
+    },
+
+    /**
+     * Assigns the gutter attribute to the DD instance to allow the thumb to
+     * overshoot the edges of the rail element up to the _thumbOffset.  By
+     * default, this allows the thumb's center point to align with the far left
+     * or top edge of the rail element to represent the min value and the far
+     * right or bottom edge for the max.
+    *
+    * @method _setDDGutter
+    * @protected
+    */
+    _setDDGutter : function () {
+        var gutter = [0,0,0,0],
+            i      = this._key.xyIndex,
+            dim    = this._thumbOffset,
+            start  = -dim,
+            end    = -1 * (this._thumbSize - dim);
+
+        if (i) { // y axis
+            gutter[0] = start;
+            gutter[2] = end;
+        } else {
+            gutter[3] = start;
+            gutter[1] = end;
+        }
+            
+        Y.log('setting DD gutter '+gutter.join(' '),'info','slider');
+
+        this._dd.set('gutter', gutter.join(' '));
+    },
+
+    /**
+     * Calculates the multiplier used to translate the value into a thumb
+     * position.
+     *
+     * @method _setFactor
+     * @protected
+     */
+    _setFactor : function () {
+        this._factor = this._railSize ?
+            (this.get(MAX) - this.get(MIN)) / this._railSize :
+            1;
+        Y.log('_factor set to '+this._factor,'info','slider');
+    },
+
+    /**
+     * Convenience method for accessing the current value of the Slider.
+     * Equivalent to <code>slider.get(&quot;value&quot;)</code>.
+     *
+     * @method getValue
+     * @return {Number} the value
+     */
+    getValue : function () {
+        return this.get(VALUE);
+    },
+
+    /**
+     * Convenience method for updating the current value of the Slider.
+     * Equivalent to <code>slider.set(&quot;value&quot;,val)</code>.
+     *
+     * @method setValue
+     * @param val {Number} the new value
+     */
+    setValue : function (val) {
+        this.set(VALUE,val);
+    },
+
+    /**
+     * Validator applied to new values for the axis attribute. Only
+     * &quot;x&quot; and &quot;y&quot; are permitted.
+     *
+     * @method _validateNewAxis
+     * @param v {String} proposed value for the axis attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewAxis : function (v) {
+        return isString(v) &&
+               v.length === 1 && 'xy'.indexOf(v.toLowerCase()) > -1;
+    },
+
+    /**
+     * Validator applied to the min attribute. Only numbers are allowed.
+     *
+     * @method _validateNewMin
+     * @param v {String} proposed value for the min attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewMin : function (v) {
+        return isNumber(v);
+    },
+
+    /**
+     * Validator applied to the max attribute. Only numbers are allowed.
+     *
+     * @method _validateNewMax
+     * @param v {String} proposed value for the max attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewMax : function (v) {
+        return isNumber(v);
+    },
+
+    /**
+     * Validator applied to the value attribute. Only numbers between the min
+     * and max are allowed.
+     *
+     * @method _validateNewValue
+     * @param v {String} proposed value for the value attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewValue : function (v) {
+        var min    = this.get(MIN),
+            max    = this.get(MAX);
+
+        return isNumber(v) &&
+                (min < max ? (v >= min && v <= max) : (v >= max && v <= min));
+    },
+
+    /**
+     * Validator applied to the rail attribute. Only allows values through
+     * before the Slider is rendered.
+     *
+     * @method _validateNewRail
+     * @param v {String} proposed value for the rail attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewRail : function (v) {
+        return !this.get(RENDERED) || v;
+    },
+
+    /**
+     * Validator applied to the thumb attribute. Only allows values through
+     * before the Slider is rendered.
+     *
+     * @method _validateNewThumb
+     * @param v {String} proposed value for the thumb attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewThumb : function (v) {
+        return !this.get(RENDERED) || v;
+    },
+
+    /**
+     * Validator applied to the thumbImage attribute. Only allows values through
+     * before the Slider is rendered.
+     *
+     * @method _validateNewThumbImage
+     * @param v {String} proposed value for the thumbImage attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewThumbImage : function (v) {
+        return !this.get(RENDERED) || v;
+    },
+
+    /**
+     * Validator applied to the railSize attribute. Only css size values (e.g.
+     * '200px' are allowed.
+     *
+     * @method _validateNewRailSize
+     * @param v {String} proposed value for the railSize attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewRailSize : function (v) {
+        return isString(v) &&
+            (v === '0' || /^\d+(?:p[xtc]|%|e[mx]|in|[mc]m)$/.test(v));
+    },
+
+    /**
+     * Setter applied to the input when updating the railSize attribute.
+     *
+     * @method _setAxisFn
+     * @param v {String} proposed value for the axis attribute
+     * @return {String} lowercased first character of the input string
+     * @protected
+     */
+    _setAxisFn : function (v) {
+        return isString(v) ? v.toLowerCase().charAt(0) : null;
+    },
+
+    /**
+     * Setter applied to the input when updating the value attribute.
+     *
+     * @method _setValueFn
+     * @param v {Number} proposed new value for the Slider
+     * @return {Number} rounded value or configured min if non-number input
+     * @protected
+     */
+    _setValueFn : function (v) {
+        if (!isNumber(v)) { 
+            v = this.get(MIN);
+        }
+
+        return round(v);
+    },
+
+    /**
+     * Setter applied to the input when updating the rail attribute.  Input can
+     * be a Node, raw HTMLElement, or a selector string to locate it.
+     *
+     * @method _setRailFn
+     * @param v {Node|String|HTMLElement} The rail element Node or selector
+     * @return {Node} The Node if found.  Otherwise null.
+     * @protected
+     */
+    _setRailFn : function (v) {
+        return v ? Y.get(v) : null;
+    },
+
+    /**
+     * Setter applied to the input when updating the thumb attribute.  Input can
+     * be a Node, raw HTMLElement, or a selector string to locate it.
+     *
+     * @method _setThumbFn
+     * @param v {Node|String|HTMLElement} The thumb element Node or selector
+     * @return {Node} The Node if found.  Otherwise null.
+     * @protected
+     */
+    _setThumbFn : function (v) {
+        return v ? Y.get(v) : null;
+    },
+
+    /**
+     * Setter applied to the input when updating the thumbImage attribute.
+     * Input can be a Node, raw HTMLElement, selector string to locate it, or
+     * the URL for an image resource.
+     *
+     * String input will be treated as a selector.  If no element is found using
+     * the selector, an <code>img</code> Node will be created with the string
+     * used as the <code>src</code> attribute.
+     *
+     * @method _setThumbImageFn
+     * @param v {Node|String|HTMLElement} The thumbImage element Node, selector,
+     *          or image URL
+     * @return {Node} The Node if found or created.  Otherwise null.
+     * @protected
+     */
+    _setThumbImageFn : function (v) {
+        return v ? Y.get(v) ||
+                Y.Node.create('<img src="'+v+'" alt="Slider thumb">') :
+                null;
+    },
+
+
+
+
+    /**
+     * Caches the current page position of the rail element and fires the
+     * slideStart event in response to the DD's drag:start.
+     *
+     * @method _onDDStartDrag
+     * @param e {Event} the DD instance's drag:start custom event
+     * @protected
+     */
+    _onDDStartDrag : function (e) {
+        Y.log('slide start','info','slider');
+        this._setRailOffsetXY();
+        this.fire(SLIDE_START,{ ddEvent: e });
+    },
+
+    /**
+     * Fires the thumbDrag event to queue Slider value update.
+     *
+     * @method _onDDDrag
+     * @param e {Event} the DD instance's drag:drag custom event
+     * @protected
+     */
+    _onDDDrag : function (e) {
+        Y.log('thumb drag','info','slider');
+        this.fire(THUMB_DRAG, { ddEvent: e });
+    },
+
+    /**
+     * The default value update behavior in response to Slider thumb
+     * interaction.  Calculates the value using stored offsets, the _factor
+     * multiplier and the min value.
+     *
+     * @method _defUpdateValueFromDD
+     * @param e {Event} the internal thumbDrag event
+     * @protected
+     */
+    _defUpdateValueFromDD : function (e) {
+        var before = this.get(VALUE),
+            val    = e.ddEvent[this._key.eventPageAxis] - this._offsetXY;
+
+        Y.log('setting value from thumb drag: before('+before+') raw('+val+') factored('+round(this.get(MIN) + (val * this._factor))+')', 'info','slider');
+
+        val = round(this.get(MIN) + (val * this._factor));
+
+        if (before !== val) {
+            this.set(VALUE, val, { ddEvent: e.ddEvent });
+        }
+    },
+
+    /**
+     * Fires the slideEnd event.
+     *
+     * @method _onDDEndDrag
+     * @param e {Event} the DD instance's drag:end custom event
+     * @protected
+     */
+    _onDDEndDrag : function (e) {
+        Y.log('slide end','info','slider');
+        this.fire(SLIDE_END,{ ddEvent: e });
+    },
+
+
+
+
+    /**
+     * The default behavior for calculating the placement of the thumb in
+     * response to a value attribute update.  This is performed in response
+     * to firing the internal valueSet event.
+     *
+     * @method _defSetThumbPosition
+     * @param e {Event} the valueSet custom event
+     * @protected
+     */
+    _defSetThumbPosition : function (e) {
+        var min = this.get(MIN),
+            max = this.get(MAX),
+            v   = e.changeEv.newVal;
+
+        Y.log('setting thumb position from value attribute update ('+v+')', 'info', 'slider');
+
+        v = round(((v - min) / (max - min)) * this._railSize);
+
+        this._uiPositionThumb(v);
+    },
+
+    /**
+     * Places the thumb at a particular X or Y location based on the configured
+     * axis.
+     *
+     * @method _uiPositionThumb
+     * @param xy {Number} the desired left or top pixel position of the thumb
+     *           in relation to the rail Node.
+     * @protected
+     */
+    _uiPositionThumb : function (xy) {
+        var dd  = this._dd;
+
+        xy += this._offsetXY;
+
+        dd._setStartPosition(dd.get('dragNode').getXY());
+
+        // stickX/stickY config on DD instance will negate off-axis move
+        dd._moveNode([xy,xy],true);
+    },
+
+
+
+    /**
+     * Fires the internal valueSet event in response to a change in the value
+     * attribute.
+     *
+     * @method _afterValueChange
+     * @param e {Event} valueChange custom event
+     * @protected
+     */
+    _afterValueChange : function (e) {
+        if (!e.ddEvent) {
+            Y.log('firing valueSet to position thumb', 'info', 'slider');
+
+            this.fire(VALUE_SET,{ changeEv: e });
+        }
+    },
+
+    /**
+     * Replaces the thumb Node in response to a change in the thumb attribute.
+     * This only has effect before the Slider is rendered.
+     *
+     * @method _afterThumbChange
+     * @param e {Event} thumbChange custom event
+     * @protected
+     */
+    _afterThumbChange : function (e) {
+        var thumb;
+
+        if (this.get(RENDERED)) {
+            if (e.prevValue) {
+                e.prevValue.get('parentNode').removeChild(e.prevValue);
+            }
+
+            this._initThumb();
+            
+            thumb = this.get(THUMB);
+            this._dd.set('node',thumb);
+            this._dd.set('dragNode',thumb);
+
+            this.syncUI();
+        }
+    },
+
+    /**
+     * Sets or replaces the thumb's contained <code>img</code> Node with the
+     * new Node in response to a change in the thumbImage attribute.  This only
+     * has effect before the Slider is rendered.
+     *
+     * @method _afterThumbImageChange
+     * @param e {Event} thumbImageChange custom event
+     * @protected
+     */
+    _afterThumbImageChange : function (e) {
+        if (this.get(RENDERED)) {
+            if (e.prevValue) {
+                e.prevValue.get('parentNode').removeChild(e.prevValue);
+            }
+
+            this._initThumbImage();
+            
+            this.syncUI();
+        }
+    },
+
+    /**
+     * Calls syncUI to update the Slider UI in response to change in the min
+     * attribute.
+     *
+     * @method _afterMinChange
+     * @param e {Event} minChange custom event
+     * @protected
+     */
+    _afterMinChange : function (e) {
+        this._refresh(e);
+    },
+
+    /**
+     * Calls syncUI to update the Slider UI in response to change in the max
+     * attribute.
+     *
+     * @method _afterMaxChange
+     * @param e {Event} maxChange custom event
+     * @protected
+     */
+    _afterMaxChange : function (e) {
+        this._refresh(e);
+    },
+
+    /**
+     * Calls syncUI to update the Slider UI in response to change in the
+     * railSize attribute.
+     *
+     * @method _afterRailSizeChange
+     * @param e {Event} railSizeChange custom event
+     * @protected
+     */
+    _afterRailSizeChange : function (e) {
+        this._refresh(e);
+    },
+
+    /**
+     * Locks or unlocks the DD instance in response to a change in the disabled
+     * attribute.
+     *
+     * @method _afterDisabledChange
+     * @param e {Event} disabledChange custom event
+     * @protected
+     */
+    _afterDisabledChange : function (e) {
+        if (this._dd) {
+            this._dd.set('lock',e.newVal);
+        }
+    },
+
+    /**
+     * Common handler to call syncUI in response to change events that occurred
+     * after the Slider is rendered.
+     *
+     * @method _refresh
+     * @param e {Event} An attribute change event
+     * @protected
+     */
+    _refresh : function (e) {
+        if (e.newVal !== e.prevVal && this.get(RENDERED)) {
+            this.syncUI();
+        }
+    },
+
+    /**
+     * Used to determine if there is a current or pending request for the
+     * thumbImage resource.
+     *
+     * @method _isImageLoading
+     * @param img {Node} <code>img</code> Node
+     * @return Boolean
+     * @protected
+     */
+    _isImageLoading : function (img) {
+        return img && !img.get(COMPLETE);
+    },
+
+    /**
+     * Used to determine if the image resource loaded successfully or there was
+     * an error.
+     *
+     * NOTES:
+     * <ul>
+     *    <li>img load error fired xbrowser for image resources not yet resolved</li>
+     *    <li>img.complete reports false in IE for images not yet loaded as well as images that failed to load</li>
+     *    <li>img.complete true && img.naturalWidth == 0 in FF and Safari indicate image failed to load</li>
+     *    <li>img.complete && img.width == 0 in Opera indicates image failed to load</li>
+     * </ul>
+     *
+     * @method _isImageLoaded
+     * @param img {Node} <code>img</code> Node
+     * @return Boolean
+     * @protected
+     */
+    _isImageLoaded : function (img) {
+        if (img) {
+            var w = img.get('naturalWidth');
+            return img.get(COMPLETE) && (!isNumber(w) ? img.get(WIDTH) : w);
+        }
+
+        return true;
+    }
+
+});
+
+Y.Slider = Slider;
+
+
+}, '3.0.0pr2' ,{requires:['widget','dd-constrain']});

=== added file 'loggerhead/static/javascript/yui/build/slider/slider-min.js'
--- loggerhead/static/javascript/yui/build/slider/slider-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/slider/slider-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("slider",function(A){var i="slider",X="rail",n="thumb",m="value",S="min",p="max",P="thumbImage",o="railSize",b="contentBox",O="slideStart",Z="slideEnd",V="thumbDrag",e="sync",l="valueSet",j="rendered",d="disabled",K="disabledChange",U=".",r="px",D="width",f="height",Q="complete",I=A.Lang,W=I.isArray,g=I.isBoolean,N=I.isString,q=I.isNumber,G=A.ClassNameManager.getClassName,J="image",B=G(i,X),C=G(i,n),R=G(i,n,J),E=G(i,J,"error"),H=Math,T=H.max,k=H.round,F=H.floor,a=H.ceil,c=H.abs;function h(){h.superclass.constructor.apply(this,arguments);}A.mix(h,{NAME:i,AXIS_KEYS:{x:{offsetEdge:"left",dim:D,offAxisDim:f,eventPageAxis:"pageX",ddStick:"stickX",xyIndex:0},y:{offsetEdge:"top",dim:f,offAxisDim:D,eventPageAxis:"pageY",ddStick:"stickY",xyIndex:1}},HTML_PARSER:{rail:U+B,thumb:U+C,thumbImage:U+R},ATTRS:{axis:{value:"x",writeOnce:true,validator:function(L){return this._validateNewAxis(L);},set:function(L){return this._setAxisFn(L);}},min:{value:0,validator:function(L){return this._validateNewMin(L);}},max:{value:100,validator:function(L){return this._validateNewMax(L);}},value:{value:0,validator:function(L){return this._validateNewValue(L);},set:function(L){return this._setValueFn(L);}},rail:{value:null,validator:function(L){return this._validateNewRail(L);},set:function(L){return this._setRailFn(L);}},thumb:{value:null,validator:function(L){return this._validateNewThumb(L);},set:function(L){return this._setThumbFn(L);}},thumbImage:{value:null,validator:function(L){return this._validateNewThumbImage(L);},set:function(L){return this._setThumbImageFn(L);}},railSize:{value:"0",validator:function(L){return this._validateNewRailSize(L);}},railEnabled:{value:true,validator:g}}});A.extend(h,A.Widget,{_key:null,_factor:1,_railSize:null,_thumbSize:null,_thumbOffset:0,_stall:false,_disabled:false,initializer:function(){this._key=h.AXIS_KEYS[this.get("axis")];this.after("minChange",this._afterMinChange);this.after("maxChange",this._afterMaxChange);this.after("railSizeChange",this._afterRailSizeChange);this.publish(O);this.publish(Z);this.publish(e,{defaultFn:this._defSyncUI});this.publish(l,{defaultFn:this._defSetThumbPosition});},renderUI:function(){this._initRail();this._initThumb();},_initRail:function(){var L=this.get(b),M=this.get(X);if(!M){M=L.appendChild(A.Node.create('<div class="'+B+'"></div>'));this.set(X,M);}else{if(!L.contains(M)){L.appendChild(M);}}M.addClass(B);M.addClass(this.getClassName(X,this.get("axis")));},_initThumb:function(){var M=this.get(X),L=this.get(n);if(L&&!this.get(P)&&L.get("nodeName").toLowerCase()==="img"){this.set(P,L);this.set(n,null);L=null;}if(!L){L=A.Node.create('<div class="'+C+'"></div>');this.set(n,L);}L.addClass(C);if(!M.contains(L)){M.appendChild(L);}if(this.get(P)){this._initThumbImage();}},_initThumbImage:function(){var M=this.get(n),L=this.get(P);if(L){L.replaceClass(C,R);if(!M.contains(L)){M.appendChild(L);}}},bindUI:function(){this.publish(V,{defaultFn:this._defUpdateValueFromDD});this._bindThumbDD();this.after("valueChange",this._afterValueChange);this.after("thumbImageChange",this._afterThumbImageChange);this.after(K,this._afterDisabledChange);},_bindThumbDD:function(){var M={node:this.get(n),constrain2node:this.get(X)},L;M[this._key.ddStick]=true;this._dd=L=new A.DD.Drag(M);L.on("drag:start",A.bind(this._onDDStartDrag,this));L.on("drag:drag",A.bind(this._onDDDrag,this));L.on("drag:end",A.bind(this._onDDEndDrag,this));this._initRailDD();},_initRailDD:function(){this.get(X).on("mousedown",A.bind(this._handleRailMouseDown,this));},_handleRailMouseDown:function(Y){if(this.get("railEnabled")&&!this.get(d)){var L=this._dd,s=this._key.xyIndex,M;if(L.get("primaryButtonOnly")&&Y.button>1){return false;}L._dragThreshMet=true;L._fixIEMouseDown();Y.halt();A.DD.DDM.activeDrag=L;M=L.get("dragNode").getXY();M[s]+=this._thumbOffset;L._setStartPosition(M);L.start();L._moveNode([Y.pageX,Y.pageY]);}},syncUI:function(){var L=this.get(P);if(this._isImageLoading(L)){this._scheduleSync();}else{this._ready(L,!this._isImageLoaded(L));}},_scheduleSync:function(){var L,M;if(!this._stall){this._disabled=this.get(d);this.set(d,true);this._stall=this.on(K,this._stallDisabledChange);L=this.get(P);M=A.bind(this._imageLoaded,this,L);L.on("load",M);L.on("error",M);}},_stallDisabledChange:function(L){this._disabled=L.newVal;L.preventDefault();},_imageLoaded:function(Y,L){var M=(Y.type.toLowerCase().indexOf("error")>-1);if(this._stall){this._stall.detach();}this._stall=false;this._ready(L,M);this.set(d,this._disabled);},_ready:function(L,M){var Y=M?"addClass":"removeClass";this.get(b)[Y](E);this.fire(e);},_defSyncUI:function(L){this._uiSetThumbSize();this._setThumbOffset();this._uiSetRailSize();this._setRailOffsetXY();this._setDDGutter();this._setFactor();this.set(m,this.get(m));},_uiSetThumbSize:function(){var M=this.get(n),s=this._key.dim,L=this.get(P),Y;Y=parseInt(M.getComputedStyle(s),10);if(L&&this._isImageLoaded(L)){Y=L.get(s);}this._thumbSize=Y;},_setThumbOffset:function(){this._thumbOffset=F(this._thumbSize/2);},_uiSetRailSize:function(){var u=this.get(X),M=this.get(n),L=this.get(P),t=this._key.dim,Y=this.get(o),s=false;if(parseInt(Y,10)){u.setStyle(t,Y);Y=parseInt(u.getComputedStyle(t),10);}else{Y=this.get(t);if(parseInt(Y,10)){s=true;u.setStyle(t,Y);Y=parseInt(u.getComputedStyle(t),10);}Y=T(Y|0,parseInt(M.getComputedStyle(t),10),parseInt(u.getComputedStyle(t),10));if(L&&this._isImageLoaded(L)){Y=T(L.get(t),Y);}}u.setStyle(t,Y+r);this._railSize=Y;if(s){t=this._key.offAxisDim;Y=this.get(t);if(Y){u.set(t,Y);}}},_setRailOffsetXY:function(){this._offsetXY=this.get(X).getXY()[this._key.xyIndex]-this._thumbOffset;},_setDDGutter:function(){var s=[0,0,0,0],M=this._key.xyIndex,Y=this._thumbOffset,t=-Y,L=-1*(this._thumbSize-Y);if(M){s[0]=t;s[2]=L;}else{s[3]=t;s[1]=L;}this._dd.set("gutter",s.join(" "));},_setFactor:function(){this._factor=this._railSize?(this.get(p)-this.get(S))/this._railSize:1;},getValue:function(){return this.get(m);},setValue:function(L){this.set(m,L);},_validateNewAxis:function(L){return N(L)&&L.length===1&&"xy".indexOf(L.toLowerCase())>-1;
+},_validateNewMin:function(L){return q(L);},_validateNewMax:function(L){return q(L);},_validateNewValue:function(M){var Y=this.get(S),L=this.get(p);return q(M)&&(Y<L?(M>=Y&&M<=L):(M>=L&&M<=Y));},_validateNewRail:function(L){return !this.get(j)||L;},_validateNewThumb:function(L){return !this.get(j)||L;},_validateNewThumbImage:function(L){return !this.get(j)||L;},_validateNewRailSize:function(L){return N(L)&&(L==="0"||/^\d+(?:p[xtc]|%|e[mx]|in|[mc]m)$/.test(L));},_setAxisFn:function(L){return N(L)?L.toLowerCase().charAt(0):null;},_setValueFn:function(L){if(!q(L)){L=this.get(S);}return k(L);},_setRailFn:function(L){return L?A.get(L):null;},_setThumbFn:function(L){return L?A.get(L):null;},_setThumbImageFn:function(L){return L?A.get(L)||A.Node.create('<img src="'+L+'" alt="Slider thumb">'):null;},_onDDStartDrag:function(L){this._setRailOffsetXY();this.fire(O,{ddEvent:L});},_onDDDrag:function(L){this.fire(V,{ddEvent:L});},_defUpdateValueFromDD:function(M){var L=this.get(m),Y=M.ddEvent[this._key.eventPageAxis]-this._offsetXY;Y=k(this.get(S)+(Y*this._factor));if(L!==Y){this.set(m,Y,{ddEvent:M.ddEvent});}},_onDDEndDrag:function(L){this.fire(Z,{ddEvent:L});},_defSetThumbPosition:function(s){var Y=this.get(S),L=this.get(p),M=s.changeEv.newVal;M=k(((M-Y)/(L-Y))*this._railSize);this._uiPositionThumb(M);},_uiPositionThumb:function(M){var L=this._dd;M+=this._offsetXY;L._setStartPosition(L.get("dragNode").getXY());L._moveNode([M,M],true);},_afterValueChange:function(L){if(!L.ddEvent){this.fire(l,{changeEv:L});}},_afterThumbChange:function(M){var L;if(this.get(j)){if(M.prevValue){M.prevValue.get("parentNode").removeChild(M.prevValue);}this._initThumb();L=this.get(n);this._dd.set("node",L);this._dd.set("dragNode",L);this.syncUI();}},_afterThumbImageChange:function(L){if(this.get(j)){if(L.prevValue){L.prevValue.get("parentNode").removeChild(L.prevValue);}this._initThumbImage();this.syncUI();}},_afterMinChange:function(L){this._refresh(L);},_afterMaxChange:function(L){this._refresh(L);},_afterRailSizeChange:function(L){this._refresh(L);},_afterDisabledChange:function(L){if(this._dd){this._dd.set("lock",L.newVal);}},_refresh:function(L){if(L.newVal!==L.prevVal&&this.get(j)){this.syncUI();}},_isImageLoading:function(L){return L&&!L.get(Q);},_isImageLoaded:function(M){if(M){var L=M.get("naturalWidth");return M.get(Q)&&(!q(L)?M.get(D):L);}return true;}});A.Slider=h;},"3.0.0pr2",{requires:["widget","dd-constrain"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/slider/slider.js'
--- loggerhead/static/javascript/yui/build/slider/slider.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/slider/slider.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1412 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('slider', function(Y) {
+
+/**
+ * Create a sliding value range input visualized as a draggable thumb on a
+ * background element.
+ * 
+ * @module slider
+ */
+
+var SLIDER = 'slider',
+    RAIL   = 'rail',
+    THUMB  = 'thumb',
+    VALUE  = 'value',
+    MIN    = 'min',
+    MAX    = 'max',
+    THUMB_IMAGE = 'thumbImage',
+    RAIL_SIZE   = 'railSize',
+    CONTENT_BOX = 'contentBox',
+
+    SLIDE_START = 'slideStart',
+    SLIDE_END   = 'slideEnd',
+
+    THUMB_DRAG  = 'thumbDrag',
+    SYNC        = 'sync',
+    VALUE_SET   = 'valueSet',
+    RENDERED    = 'rendered',
+    DISABLED    = 'disabled',
+    DISABLED_CHANGE = 'disabledChange',
+
+    DOT      = '.',
+    PX       = 'px',
+    WIDTH    = 'width',
+    HEIGHT   = 'height',
+    COMPLETE = 'complete',
+
+    L = Y.Lang,
+    isArray  = L.isArray,
+    isBoolean= L.isBoolean,
+    isString = L.isString,
+    isNumber = L.isNumber,
+    
+    getCN    = Y.ClassNameManager.getClassName,
+
+    IMAGE         = 'image',
+    C_RAIL        = getCN(SLIDER,RAIL),
+    C_THUMB       = getCN(SLIDER,THUMB),
+    C_THUMB_IMAGE = getCN(SLIDER,THUMB,IMAGE),
+    C_IMAGE_ERROR = getCN(SLIDER,IMAGE,'error'),
+
+    M        = Math,
+    max      = M.max,
+    round    = M.round,
+    floor    = M.floor,
+    ceil     = M.ceil,
+    abs      = M.abs;
+
+/**
+ * Create a slider to represent an integer value between a given minimum and
+ * maximum.
+ *
+ * @class Slider
+ * @extends Widget
+ * @param config {Object} Configuration object
+ * @constructor
+ */
+function Slider() {
+    Slider.superclass.constructor.apply(this,arguments);
+}
+
+Y.mix(Slider, {
+
+    /**
+     * The identity of the widget.
+     *
+     * @property Slider.NAME
+     * @type String
+     * @static
+     */
+    NAME : SLIDER,
+
+    /**
+     * Object property names used for respective X and Y axis Sliders (e.g.
+     * &quot;left&quot; vs. &quot;top&quot; for placing the thumb according to
+     * its representative value).
+     *
+     * @property Slider.AXIS_KEYS
+     * @type Object
+     * @static
+     */
+    AXIS_KEYS : {
+        x : {
+            offsetEdge    : 'left',
+            dim           : WIDTH,
+            offAxisDim    : HEIGHT,
+            eventPageAxis : 'pageX',
+            ddStick       : 'stickX',
+            xyIndex       : 0
+        },
+        y : {
+            offsetEdge    : 'top',
+            dim           : HEIGHT,
+            offAxisDim    : WIDTH,
+            eventPageAxis : 'pageY',
+            ddStick       : 'stickY',
+            xyIndex       : 1
+        }
+    },
+
+    /**
+     * Static Object hash used to capture existing markup for progressive
+     * enhancement.  Keys correspond to config attribute names and values
+     * are selectors used to inspect the contentBox for an existing node
+     * structure.
+     *
+     * @property Slider.HTML_PARSER
+     * @Type Object
+     * @static
+     */
+    HTML_PARSER : {
+        rail       : DOT + C_RAIL,
+        thumb      : DOT + C_THUMB,
+        thumbImage : DOT + C_THUMB_IMAGE
+    },
+
+    /**
+     * Static property used to define the default attribute configuration of
+     * the Widget.
+     *
+     * @property Slider.ATTRS
+     * @Type Object
+     * @static
+     */
+    ATTRS : {
+
+        /**
+         * Axis upon which the Slider's thumb moves.  &quot;x&quot; for
+         * horizontal, &quot;y&quot; for vertical.
+         *
+         * @attribute axis
+         * @type String
+         * @default &quot;x&quot;
+         * @writeOnce
+         */
+        axis : {
+            value : 'x',
+            writeOnce : true,
+            validator : function (v) {
+                return this._validateNewAxis(v);
+            },
+            set : function (v) {
+                return this._setAxisFn(v);
+            }
+        },
+
+        /**
+         * Integer value associated with the left or top terminus of the
+         * Slider's rail, depending on the configured axis.
+         *
+         * @attribute min
+         * @type Number
+         * @default 0
+         */
+        min : {
+            value : 0,
+            validator : function (v) {
+                return this._validateNewMin(v);
+            }
+        },
+
+        /**
+         * Integer value associated with the right or bottom terminus of the
+         * Slider's rail, depending on the configured axis.
+         *
+         * @attribute max
+         * @type Number
+         * @default 100
+         */
+        max : {
+            value : 100,
+            validator : function (v) {
+                return this._validateNewMax(v);
+            }
+        },
+
+        /**
+         * The current value of the Slider.  This value is interpretted into a
+         * position for the thumb along the Slider's rail.
+         *
+         * @attribute value
+         * @type Number
+         * @default 0
+         */
+        value : {
+            value : 0,
+            validator : function (v) {
+                return this._validateNewValue(v);
+            },
+            set : function (v) {
+                return this._setValueFn(v);
+            }
+        },
+
+        /**
+         * The Node representing the Slider's rail, usually visualized as a
+         * bar of some sort using a background image, along which the thumb
+         * moves.  This Node contains the thumb Node.
+         *
+         * @attribute rail
+         * @type Node
+         * @default null
+         */
+        rail : {
+            value : null,
+            validator : function (v) {
+                return this._validateNewRail(v);
+            },
+            set : function (v) {
+                return this._setRailFn(v);
+            }
+        },
+
+        /**
+         * The Node representing the Slider's thumb, usually visualized as a
+         * pointer using a contained image Node (see thumbImage).  The current
+         * value of the Slider is calculated from the centerpoint of this
+         * Node in relation to the rail Node.  If provided, the thumbImage
+         * Node is contained within this Node.
+         *
+         * If no thumbImage is provided and the Node passed as the thumb is an
+         * <code>img</code> element, the assigned Node will be allocated to the
+         * thumbImage and the thumb container defaulted.
+         *
+         * @attribute thumb
+         * @type Node
+         * @default null
+         */
+        thumb : {
+            value : null,
+            validator : function (v) {
+                return this._validateNewThumb(v);
+            },
+            set : function (v) {
+                return this._setThumbFn(v);
+            }
+        },
+
+        /**
+         * The Node representing the image element to use for the Slider's
+         * thumb.
+         *
+         * Alternately, an image URL can be passed and an <code>img</code>
+         * Node will be generated accordingly.
+         *
+         * If no thumbImage is provided and the Node passed as the thumb is an
+         * <code>img</code> element, the assigned Node will be allocated to the
+         * thumbImage and the thumb container defaulted.
+         *
+         * If thumbImage is provided but its URL resolves to a 404, a default
+         * style will be applied to maintain basic functionality.
+         *
+         * @attribute thumbImage
+         * @type Node|String
+         * @default null
+         */
+        thumbImage : {
+            value : null,
+            validator : function (v) {
+                return this._validateNewThumbImage(v);
+            },
+            set : function (v) {
+                return this._setThumbImageFn(v);
+            }
+        },
+
+        /**
+         * The width or height of the rail element representing the physical
+         * space along which the thumb can move.  CSS size values (e.g. '30em')
+         * accepted but converted to pixels during render.
+         *
+         * Alternately, but not recommended, this attribute can be left
+         * unassigned in favor of specifying height or width.
+         *
+         * @attribute railSize
+         * @type String
+         * @default '0'
+         */
+        railSize : {
+            value : '0',
+            validator : function (v) {
+                return this._validateNewRailSize(v);
+            }
+        },
+
+        /**
+         * Boolean indicating whether clicking and dragging on the rail will
+         * trigger thumb movement.
+         *
+         * @attribute railEnabled
+         * @type @Boolean
+         * @default true
+         */
+        railEnabled : {
+            value : true,
+            validator : isBoolean
+        }
+    }
+});
+
+Y.extend(Slider, Y.Widget, {
+
+    /**
+     * Collection of object property names from the appropriate hash set in
+     * Slider.AXIS_KEYS.
+     *
+     * @property _key
+     * @type Object
+     * @protected
+     */
+    _key : null,
+
+    /**
+     * Factor used to translate positional coordinates (e.g. left or top) to
+     * the Slider's value.
+     *
+     * @property _factor
+     * @type Number
+     * @protected
+     */
+    _factor : 1,
+
+    /**
+     * Pixel dimension of the rail Node's width for X axis Sliders or height
+     * for Y axis Sliders.  Used with _factor to calculate positional
+     * coordinates for the thumb.
+     *
+     * @property _railSize
+     * @type Number
+     * @protected
+     */
+    _railSize : null,
+
+    /**
+     * Pixel dimension of the thumb Node's width for X axis Sliders or height
+     * for Y axis Sliders.  Used with _factor to calculate positional
+     * coordinates for the thumb.
+     *
+     * @property _thumbSize
+     * @type Number
+     * @protected
+     */
+    _thumbSize : null,
+
+    /**
+     * Pixel offset of the point in the thumb element from its top/left edge
+     * to where the value calculation should take place.  By default, this is
+     * calculated to half the width of the thumb, causing the value to be
+     * marked from the center of the thumb.
+     *
+     * @property _thumbOffset
+     * @type Number
+     * @protected
+     */
+    _thumbOffset : 0,
+
+    /**
+     * Object returned from temporary subscription to disabledChange event to
+     * defer setting the disabled state while Slider is loading the thumb
+     * image.
+     *
+     * @property _stall
+     * @type Object
+     * @protected
+     */
+    _stall : false,
+
+    /**
+     * Deferred value for the disabled attribute when stalled (see _stall
+     * property).
+     *
+     * @property _disabled
+     * @type Boolean
+     * @protected
+     */
+    _disabled : false,
+
+    /**
+     * Construction logic executed durint Slider instantiation. Subscribe to
+     * after events for min, max, and railSize.  Publish custom events
+     * including slideStart and slideEnd.
+     *
+     * @method initializer
+     * @protected
+     */
+    initializer : function () {
+        this._key = Slider.AXIS_KEYS[this.get('axis')];
+
+        this.after('minChange',    this._afterMinChange);
+        this.after('maxChange',    this._afterMaxChange);
+
+        this.after('railSizeChange', this._afterRailSizeChange);
+
+        /**
+         * Signals the beginning of a thumb drag operation.  Payload includes
+         * the DD.Drag instance's drag:start event under key ddEvent.
+         *
+         * @event slideStart
+         * @param event {Event.Facade} An Event Facade object with the following attribute specific properties added:
+         *  <dl>
+         *      <dt>ddEvent</dt>
+         *          <dd><code>drag:start</code> event from the managed DD.Drag instance</dd>
+         *  </dl>
+         */
+        this.publish(SLIDE_START);
+
+        /**
+         * Signals the end of a thumb drag operation.  Payload includes
+         * the DD.Drag instance's drag:end event under key ddEvent.
+         *
+         * @event slideEnd
+         * @param event {Event.Facade} An Event Facade object with the following attribute specific properties added:
+         *  <dl>
+         *      <dt>ddEvent</dt>
+         *          <dd><code>drag:end</code> event from the managed DD.Drag instance</dd>
+         *  </dl>
+         */
+        this.publish(SLIDE_END);
+
+        /**
+         * Communicates a request to synchronize the Slider UI with the
+         * attribute state.  Links the sync request with the default sync
+         * logic in the default function _defSyncUI.
+         *
+         * @event sync
+         * @param event {Event.Facade} Event Facade object
+         * @preventable _defSyncUI
+         */
+        this.publish(SYNC,       {defaultFn: this._defSyncUI});
+
+        /**
+         * Signals a value change via API, requiring the thumb position to be
+         * updated.  Triggers the thumb placement logic in the default function
+         * _defSetThumbPosition.
+         *
+         * @event valueSet
+         * @param event {Event.Facade} An Event Facade object with the following attribute specific properties added:
+         *  <dl>
+         *      <dt>changeEv</dt>
+         *          <dd><code>valueChange</code> event fired in response to the change in the value attribute</dd>
+         *  </dl>
+         * @preventable _defSetThumbPosition
+         */
+        this.publish(VALUE_SET,  {defaultFn: this._defSetThumbPosition});
+    },
+
+    /**
+     * Create the DOM structure for the Slider.  Calls _initRail and _initThumb.
+     *
+     * @method renderUI
+     * @protected
+     */
+    renderUI : function () {
+        this._initRail();
+        this._initThumb();
+    },
+
+    /**
+     * Creates the rail element if not provided or discovered via HTML_PARSER.
+     *
+     * @method _initRail
+     * @protected
+     */
+    _initRail : function () {
+        var cb   = this.get(CONTENT_BOX),
+            rail = this.get(RAIL);
+
+        // Create rail if necessary. Make sure it's in the contentBox
+        if (!rail) {
+            rail = cb.appendChild(
+                Y.Node.create('<div class="'+C_RAIL+'"></div>'));
+
+            this.set(RAIL,rail);
+        } else if (!cb.contains(rail)) {
+            cb.appendChild(rail);
+        }
+
+        rail.addClass(C_RAIL);
+        rail.addClass(this.getClassName(RAIL,this.get('axis')));
+    },
+
+    /**
+     * Creates the thumb element (not image) if not provided or discovered via
+     * HTML_PARSER.  If thumb is present and an <code>img</code> element
+     * <em>and</em> no thumbImage provided, reassigns the thumb element to the
+     * thumbImage and defaults the thumb element as a div.
+     *
+     * Makes sure the thumb is a child of the rail element and calls
+     * _initThumbImage if thumbImage is provided.
+     *
+     * @method _initThumb
+     * @protected
+     */
+    _initThumb : function () {
+        var rail    = this.get(RAIL),
+            thumb   = this.get(THUMB);
+
+        // Passed an img element as the thumb
+        if (thumb && !this.get(THUMB_IMAGE) &&
+            thumb.get('nodeName').toLowerCase() === 'img') {
+            this.set(THUMB_IMAGE, thumb);
+            this.set(THUMB,null);
+            thumb = null;
+        }
+
+        if (!thumb) {
+            thumb = Y.Node.create(
+                '<div class="'+C_THUMB+'"></div>');
+
+            this.set(THUMB,thumb);
+        }
+
+        thumb.addClass(C_THUMB);
+
+        if (!rail.contains(thumb)) {
+            rail.appendChild(thumb);
+        }
+
+        if (this.get(THUMB_IMAGE)) {
+            this._initThumbImage();
+        }
+    },
+
+    /**
+     * Ensures the thumbImage is a child of the thumb element.
+     *
+     * @method _initThumbImage
+     * @protected
+     */
+    _initThumbImage : function () {
+        var thumb = this.get(THUMB),
+            img   = this.get(THUMB_IMAGE);
+
+        if (img) {
+            img.replaceClass(C_THUMB,C_THUMB_IMAGE);
+
+            if (!thumb.contains(img)) {
+                thumb.appendChild(img);
+            }
+        }
+    },
+
+    /**
+     * Calls _bindThumbDD to create the Y.DD instance used to handle the thumb
+     * movement and binds Slider interaction to the configured value model.
+     *
+     * @method bindUI
+     * @protected
+     */
+    bindUI : function () {
+        /**
+         * Communicates user interaction with the thumb.  Triggers the logic
+         * to update the value via the default function _defUpdateValueFromDD.
+         *
+         * @event thumbDrag
+         * @param event {Event.Facade} An Event Facade object with the following attribute specific properties added:
+         *  <dl>
+         *      <dt>ddEvent</dt>
+         *          <dd><code>drag:drag</code> event from the managed DD.Drag instance</dd>
+         *  </dl>
+         * @preventable _defUpdateValueFromDD
+         */
+        this.publish(THUMB_DRAG, {defaultFn: this._defUpdateValueFromDD});
+
+        this._bindThumbDD();
+
+        this.after('valueChange',      this._afterValueChange);
+        this.after('thumbImageChange', this._afterThumbImageChange);
+        this.after(DISABLED_CHANGE,    this._afterDisabledChange);
+    },
+
+    /**
+     * Creates the Y.DD instance used to handle the thumb interaction.
+     * 
+     * @method _bindThumbDD
+     * @protected
+     */
+    _bindThumbDD : function () {
+        var ddConf = {
+                node           : this.get(THUMB),
+                constrain2node : this.get(RAIL)
+            },
+            dd;
+
+        ddConf[this._key.ddStick] = true;
+
+        this._dd = dd = new Y.DD.Drag(ddConf);
+        dd.on('drag:start', Y.bind(this._onDDStartDrag, this));
+        dd.on('drag:drag',  Y.bind(this._onDDDrag,      this));
+        dd.on('drag:end',   Y.bind(this._onDDEndDrag,   this));
+
+        this._initRailDD();
+    },
+
+    /**
+     * Subscribes to the rail Node's mousedown event to actuate the thumb when
+     * backgroundEnabled is true.
+     *
+     * @method _initRailDD
+     * @protected
+     */
+    _initRailDD : function () {
+        this.get(RAIL).on('mousedown',Y.bind(this._handleRailMouseDown,this));
+    },
+
+    /**
+     * Moves the thumb to the mousedown position and hands control over to DD
+     * if the Slider is not disabled and railEnabled is true.
+     *
+     * @method _handleRailMouseDown
+     * @param e {Event} Mousedown event facade
+     * @protected
+     */
+    _handleRailMouseDown : function (e) {
+        if (this.get('railEnabled') && !this.get(DISABLED)) {
+            var dd      = this._dd,
+                xyIndex = this._key.xyIndex,
+                xy;
+
+            if (dd.get('primaryButtonOnly') && e.button > 1) {
+                return false;
+            }
+
+            dd._dragThreshMet = true;
+
+            dd._fixIEMouseDown();
+            e.halt();
+
+            Y.DD.DDM.activeDrag = dd;
+
+            // Adjust registered starting position by half the thumb's x/y
+            xy = dd.get('dragNode').getXY();
+            xy[xyIndex] += this._thumbOffset;
+
+            dd._setStartPosition(xy);
+
+            dd.start();
+            dd._moveNode([e.pageX,e.pageY]);
+        }
+    },
+
+    /**
+     * Synchronizes the DOM state with the attribute settings (most notably
+     * railSize and value).  If thumbImage is provided and is still loading,
+     * sync is delayed until it is complete, since the image's dimensions are
+     * taken into consideration for calculations.
+     *
+     * @method syncUI
+     */
+    syncUI : function () {
+        var img = this.get(THUMB_IMAGE);
+
+        if (this._isImageLoading(img)) {
+            // Schedule the sync for when the image loads/errors
+            this._scheduleSync();
+        } else {
+            this._ready(img,!this._isImageLoaded(img));
+        }
+    },
+
+    /**
+     * Binds to the load and error event on the thumbImage to sync the DOM
+     * state with the attribute settings when the image resource is resolved.
+     * The Slider is disabled while it waits.
+     *
+     * @method _scheduleSync
+     * @protected
+     */
+    _scheduleSync : function () {
+        var img, handler;
+
+        if (!this._stall) {
+            // disable the control until the image is loaded
+            this._disabled = this.get(DISABLED);
+            this.set(DISABLED,true);
+            this._stall    = this.on(DISABLED_CHANGE,this._stallDisabledChange);
+
+            img     = this.get(THUMB_IMAGE);
+            handler = Y.bind(this._imageLoaded,this,img);
+            img.on('load', handler);
+            img.on('error',handler);
+        }
+    },
+
+    /**
+     * Method subscribed to the disabledChange event when thumbImage is being
+     * loaded.  Prevents manually enabling the Slider until the thumbImage
+     * resource is resolved.  Intended value is stored during load and set upon
+     * completion.
+     *
+     * @method _stallDisabledChange
+     * @param e {Event} Change event for the disabled attribute
+     * @protected
+     */
+    _stallDisabledChange : function (e) {
+        this._disabled = e.newVal;
+        e.preventDefault();
+    },
+
+    /**
+     * Event handler assigned to the thumbImage's load and error event if it
+     * was not loaded prior to instantiation.  Calls _ready method and restores
+     * the Slider's disabled attribute.
+     *
+     * @method _imageLoaded
+     * @param e {Event} load or error event fired by the thumbImage
+     * @param img {Node} The thumbImage Node
+     * @protected
+     */
+    _imageLoaded : function (e,img) {
+        var error = (e.type.toLowerCase().indexOf('error') > -1);
+
+        if (this._stall) {
+            this._stall.detach();
+        }
+
+
+        this._stall = false;
+
+        this._ready(img,error);
+
+        this.set(DISABLED,this._disabled);
+    },
+
+    /**
+     * Fires the internal sync event, which barring preventDefault should
+     * execute _defSyncUI.
+     *
+     * @method _ready
+     * @param img {Node} the thumbImage Node
+     * @param error {Boolean} Indicates an error while loading the thumbImage
+     * @protected
+     */
+    _ready : function (img,error) {
+        var method = error ? 'addClass' : 'removeClass';
+
+        // If the thumb image url results in 404, assign a class to provide
+        // default thumb dimensions/UI
+        this.get(CONTENT_BOX)[method](C_IMAGE_ERROR);
+
+        this.fire(SYNC);
+    },
+
+    /**
+     * The default synchronization behavior, updating the Slider's DOM state to
+     * match the current attribute values.
+     *
+     * @method _defSyncUI
+     * @param e {Event} Internal sync event
+     * @protected
+     */
+    _defSyncUI : function (e) {
+        this._uiSetThumbSize();
+
+        this._setThumbOffset();
+
+        this._uiSetRailSize();
+
+        this._setRailOffsetXY();
+
+        this._setDDGutter();
+
+        this._setFactor();
+
+
+        this.set(VALUE,this.get(VALUE));
+    },
+
+    /**
+     * Captures the thumbs pixel height or width, depending on the Slider's
+     * axis, for use in positioning calculations.
+     *
+     * @method _uiSetThumbSize
+     * @protected
+     */
+    _uiSetThumbSize : function () {
+        var thumb = this.get(THUMB),
+            dim   = this._key.dim,
+            img   = this.get(THUMB_IMAGE),
+            size;
+
+        // offsetWidth fails in hidden containers
+        size = parseInt(thumb.getComputedStyle(dim),10);
+
+
+        if (img && this._isImageLoaded(img)) {
+
+            size = img.get(dim);
+        }
+
+        this._thumbSize = size;
+    },
+
+    /**
+     * Sets the _thumbOffset property for use in establishing the point in the
+     * thumb that should align to the rail position representing the calculated
+     * value.
+     *
+     * @method _setThumbOffset
+     * @protected
+     */
+    _setThumbOffset : function () {
+        this._thumbOffset = floor(this._thumbSize / 2);
+    },
+
+    /**
+     * Stores the rail Node's pixel height or width, depending on the Slider's
+     * axis, for use in calculating thumb position from the value.
+     *
+     * @method _uiSetRailSize
+     * @protected
+     */
+    _uiSetRailSize : function () {
+        var rail  = this.get(RAIL),
+            thumb = this.get(THUMB),
+            img   = this.get(THUMB_IMAGE),
+            dim   = this._key.dim,
+            size  = this.get(RAIL_SIZE),
+            setxy = false;
+
+        if (parseInt(size,10)) {
+
+            // Convert to pixels
+            rail.setStyle(dim,size);
+            size = parseInt(rail.getComputedStyle(dim),10);
+
+        } else {
+            // Default from height or width (axis respective), or dims assigned
+            // via css to the rail or thumb, whichever is largest.
+            // Dear implementers, please use railSize, not height/width to
+            // set the rail dims
+            size = this.get(dim);
+            if (parseInt(size,10)) {
+                setxy = true;
+                rail.setStyle(dim,size);
+                size = parseInt(rail.getComputedStyle(dim),10);
+            }
+            size = max(
+                    size|0,
+                    parseInt(thumb.getComputedStyle(dim),10),
+                    parseInt(rail.getComputedStyle(dim),10));
+
+
+            if (img && this._isImageLoaded(img)) {
+
+                size = max(img.get(dim),size);
+            }
+        }
+
+        rail.setStyle(dim, size + PX);
+
+        this._railSize = size;
+
+        // handle the (not recommended) fallback case of setting rail size via
+        // widget height/width params.  This is the only case that sets the
+        // off-axis rail dim in the code.
+        if (setxy) {
+            dim = this._key.offAxisDim;
+            size = this.get(dim);
+            if (size) {
+                rail.set(dim,size);
+            }
+        }
+    },
+
+    /**
+     * Store the current XY position of the rail Node on the page.  For use in calculating thumb position from value.
+     *
+     * @method _setRailOffsetXY
+     * @protected
+     */
+    _setRailOffsetXY : function () {
+        this._offsetXY = this.get(RAIL).getXY()[this._key.xyIndex] -
+                         this._thumbOffset;
+    },
+
+    /**
+     * Assigns the gutter attribute to the DD instance to allow the thumb to
+     * overshoot the edges of the rail element up to the _thumbOffset.  By
+     * default, this allows the thumb's center point to align with the far left
+     * or top edge of the rail element to represent the min value and the far
+     * right or bottom edge for the max.
+    *
+    * @method _setDDGutter
+    * @protected
+    */
+    _setDDGutter : function () {
+        var gutter = [0,0,0,0],
+            i      = this._key.xyIndex,
+            dim    = this._thumbOffset,
+            start  = -dim,
+            end    = -1 * (this._thumbSize - dim);
+
+        if (i) { // y axis
+            gutter[0] = start;
+            gutter[2] = end;
+        } else {
+            gutter[3] = start;
+            gutter[1] = end;
+        }
+            
+
+        this._dd.set('gutter', gutter.join(' '));
+    },
+
+    /**
+     * Calculates the multiplier used to translate the value into a thumb
+     * position.
+     *
+     * @method _setFactor
+     * @protected
+     */
+    _setFactor : function () {
+        this._factor = this._railSize ?
+            (this.get(MAX) - this.get(MIN)) / this._railSize :
+            1;
+    },
+
+    /**
+     * Convenience method for accessing the current value of the Slider.
+     * Equivalent to <code>slider.get(&quot;value&quot;)</code>.
+     *
+     * @method getValue
+     * @return {Number} the value
+     */
+    getValue : function () {
+        return this.get(VALUE);
+    },
+
+    /**
+     * Convenience method for updating the current value of the Slider.
+     * Equivalent to <code>slider.set(&quot;value&quot;,val)</code>.
+     *
+     * @method setValue
+     * @param val {Number} the new value
+     */
+    setValue : function (val) {
+        this.set(VALUE,val);
+    },
+
+    /**
+     * Validator applied to new values for the axis attribute. Only
+     * &quot;x&quot; and &quot;y&quot; are permitted.
+     *
+     * @method _validateNewAxis
+     * @param v {String} proposed value for the axis attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewAxis : function (v) {
+        return isString(v) &&
+               v.length === 1 && 'xy'.indexOf(v.toLowerCase()) > -1;
+    },
+
+    /**
+     * Validator applied to the min attribute. Only numbers are allowed.
+     *
+     * @method _validateNewMin
+     * @param v {String} proposed value for the min attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewMin : function (v) {
+        return isNumber(v);
+    },
+
+    /**
+     * Validator applied to the max attribute. Only numbers are allowed.
+     *
+     * @method _validateNewMax
+     * @param v {String} proposed value for the max attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewMax : function (v) {
+        return isNumber(v);
+    },
+
+    /**
+     * Validator applied to the value attribute. Only numbers between the min
+     * and max are allowed.
+     *
+     * @method _validateNewValue
+     * @param v {String} proposed value for the value attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewValue : function (v) {
+        var min    = this.get(MIN),
+            max    = this.get(MAX);
+
+        return isNumber(v) &&
+                (min < max ? (v >= min && v <= max) : (v >= max && v <= min));
+    },
+
+    /**
+     * Validator applied to the rail attribute. Only allows values through
+     * before the Slider is rendered.
+     *
+     * @method _validateNewRail
+     * @param v {String} proposed value for the rail attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewRail : function (v) {
+        return !this.get(RENDERED) || v;
+    },
+
+    /**
+     * Validator applied to the thumb attribute. Only allows values through
+     * before the Slider is rendered.
+     *
+     * @method _validateNewThumb
+     * @param v {String} proposed value for the thumb attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewThumb : function (v) {
+        return !this.get(RENDERED) || v;
+    },
+
+    /**
+     * Validator applied to the thumbImage attribute. Only allows values through
+     * before the Slider is rendered.
+     *
+     * @method _validateNewThumbImage
+     * @param v {String} proposed value for the thumbImage attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewThumbImage : function (v) {
+        return !this.get(RENDERED) || v;
+    },
+
+    /**
+     * Validator applied to the railSize attribute. Only css size values (e.g.
+     * '200px' are allowed.
+     *
+     * @method _validateNewRailSize
+     * @param v {String} proposed value for the railSize attribute
+     * @return Boolean
+     * @protected
+     */
+    _validateNewRailSize : function (v) {
+        return isString(v) &&
+            (v === '0' || /^\d+(?:p[xtc]|%|e[mx]|in|[mc]m)$/.test(v));
+    },
+
+    /**
+     * Setter applied to the input when updating the railSize attribute.
+     *
+     * @method _setAxisFn
+     * @param v {String} proposed value for the axis attribute
+     * @return {String} lowercased first character of the input string
+     * @protected
+     */
+    _setAxisFn : function (v) {
+        return isString(v) ? v.toLowerCase().charAt(0) : null;
+    },
+
+    /**
+     * Setter applied to the input when updating the value attribute.
+     *
+     * @method _setValueFn
+     * @param v {Number} proposed new value for the Slider
+     * @return {Number} rounded value or configured min if non-number input
+     * @protected
+     */
+    _setValueFn : function (v) {
+        if (!isNumber(v)) { 
+            v = this.get(MIN);
+        }
+
+        return round(v);
+    },
+
+    /**
+     * Setter applied to the input when updating the rail attribute.  Input can
+     * be a Node, raw HTMLElement, or a selector string to locate it.
+     *
+     * @method _setRailFn
+     * @param v {Node|String|HTMLElement} The rail element Node or selector
+     * @return {Node} The Node if found.  Otherwise null.
+     * @protected
+     */
+    _setRailFn : function (v) {
+        return v ? Y.get(v) : null;
+    },
+
+    /**
+     * Setter applied to the input when updating the thumb attribute.  Input can
+     * be a Node, raw HTMLElement, or a selector string to locate it.
+     *
+     * @method _setThumbFn
+     * @param v {Node|String|HTMLElement} The thumb element Node or selector
+     * @return {Node} The Node if found.  Otherwise null.
+     * @protected
+     */
+    _setThumbFn : function (v) {
+        return v ? Y.get(v) : null;
+    },
+
+    /**
+     * Setter applied to the input when updating the thumbImage attribute.
+     * Input can be a Node, raw HTMLElement, selector string to locate it, or
+     * the URL for an image resource.
+     *
+     * String input will be treated as a selector.  If no element is found using
+     * the selector, an <code>img</code> Node will be created with the string
+     * used as the <code>src</code> attribute.
+     *
+     * @method _setThumbImageFn
+     * @param v {Node|String|HTMLElement} The thumbImage element Node, selector,
+     *          or image URL
+     * @return {Node} The Node if found or created.  Otherwise null.
+     * @protected
+     */
+    _setThumbImageFn : function (v) {
+        return v ? Y.get(v) ||
+                Y.Node.create('<img src="'+v+'" alt="Slider thumb">') :
+                null;
+    },
+
+
+
+
+    /**
+     * Caches the current page position of the rail element and fires the
+     * slideStart event in response to the DD's drag:start.
+     *
+     * @method _onDDStartDrag
+     * @param e {Event} the DD instance's drag:start custom event
+     * @protected
+     */
+    _onDDStartDrag : function (e) {
+        this._setRailOffsetXY();
+        this.fire(SLIDE_START,{ ddEvent: e });
+    },
+
+    /**
+     * Fires the thumbDrag event to queue Slider value update.
+     *
+     * @method _onDDDrag
+     * @param e {Event} the DD instance's drag:drag custom event
+     * @protected
+     */
+    _onDDDrag : function (e) {
+        this.fire(THUMB_DRAG, { ddEvent: e });
+    },
+
+    /**
+     * The default value update behavior in response to Slider thumb
+     * interaction.  Calculates the value using stored offsets, the _factor
+     * multiplier and the min value.
+     *
+     * @method _defUpdateValueFromDD
+     * @param e {Event} the internal thumbDrag event
+     * @protected
+     */
+    _defUpdateValueFromDD : function (e) {
+        var before = this.get(VALUE),
+            val    = e.ddEvent[this._key.eventPageAxis] - this._offsetXY;
+
+
+        val = round(this.get(MIN) + (val * this._factor));
+
+        if (before !== val) {
+            this.set(VALUE, val, { ddEvent: e.ddEvent });
+        }
+    },
+
+    /**
+     * Fires the slideEnd event.
+     *
+     * @method _onDDEndDrag
+     * @param e {Event} the DD instance's drag:end custom event
+     * @protected
+     */
+    _onDDEndDrag : function (e) {
+        this.fire(SLIDE_END,{ ddEvent: e });
+    },
+
+
+
+
+    /**
+     * The default behavior for calculating the placement of the thumb in
+     * response to a value attribute update.  This is performed in response
+     * to firing the internal valueSet event.
+     *
+     * @method _defSetThumbPosition
+     * @param e {Event} the valueSet custom event
+     * @protected
+     */
+    _defSetThumbPosition : function (e) {
+        var min = this.get(MIN),
+            max = this.get(MAX),
+            v   = e.changeEv.newVal;
+
+
+        v = round(((v - min) / (max - min)) * this._railSize);
+
+        this._uiPositionThumb(v);
+    },
+
+    /**
+     * Places the thumb at a particular X or Y location based on the configured
+     * axis.
+     *
+     * @method _uiPositionThumb
+     * @param xy {Number} the desired left or top pixel position of the thumb
+     *           in relation to the rail Node.
+     * @protected
+     */
+    _uiPositionThumb : function (xy) {
+        var dd  = this._dd;
+
+        xy += this._offsetXY;
+
+        dd._setStartPosition(dd.get('dragNode').getXY());
+
+        // stickX/stickY config on DD instance will negate off-axis move
+        dd._moveNode([xy,xy],true);
+    },
+
+
+
+    /**
+     * Fires the internal valueSet event in response to a change in the value
+     * attribute.
+     *
+     * @method _afterValueChange
+     * @param e {Event} valueChange custom event
+     * @protected
+     */
+    _afterValueChange : function (e) {
+        if (!e.ddEvent) {
+
+            this.fire(VALUE_SET,{ changeEv: e });
+        }
+    },
+
+    /**
+     * Replaces the thumb Node in response to a change in the thumb attribute.
+     * This only has effect before the Slider is rendered.
+     *
+     * @method _afterThumbChange
+     * @param e {Event} thumbChange custom event
+     * @protected
+     */
+    _afterThumbChange : function (e) {
+        var thumb;
+
+        if (this.get(RENDERED)) {
+            if (e.prevValue) {
+                e.prevValue.get('parentNode').removeChild(e.prevValue);
+            }
+
+            this._initThumb();
+            
+            thumb = this.get(THUMB);
+            this._dd.set('node',thumb);
+            this._dd.set('dragNode',thumb);
+
+            this.syncUI();
+        }
+    },
+
+    /**
+     * Sets or replaces the thumb's contained <code>img</code> Node with the
+     * new Node in response to a change in the thumbImage attribute.  This only
+     * has effect before the Slider is rendered.
+     *
+     * @method _afterThumbImageChange
+     * @param e {Event} thumbImageChange custom event
+     * @protected
+     */
+    _afterThumbImageChange : function (e) {
+        if (this.get(RENDERED)) {
+            if (e.prevValue) {
+                e.prevValue.get('parentNode').removeChild(e.prevValue);
+            }
+
+            this._initThumbImage();
+            
+            this.syncUI();
+        }
+    },
+
+    /**
+     * Calls syncUI to update the Slider UI in response to change in the min
+     * attribute.
+     *
+     * @method _afterMinChange
+     * @param e {Event} minChange custom event
+     * @protected
+     */
+    _afterMinChange : function (e) {
+        this._refresh(e);
+    },
+
+    /**
+     * Calls syncUI to update the Slider UI in response to change in the max
+     * attribute.
+     *
+     * @method _afterMaxChange
+     * @param e {Event} maxChange custom event
+     * @protected
+     */
+    _afterMaxChange : function (e) {
+        this._refresh(e);
+    },
+
+    /**
+     * Calls syncUI to update the Slider UI in response to change in the
+     * railSize attribute.
+     *
+     * @method _afterRailSizeChange
+     * @param e {Event} railSizeChange custom event
+     * @protected
+     */
+    _afterRailSizeChange : function (e) {
+        this._refresh(e);
+    },
+
+    /**
+     * Locks or unlocks the DD instance in response to a change in the disabled
+     * attribute.
+     *
+     * @method _afterDisabledChange
+     * @param e {Event} disabledChange custom event
+     * @protected
+     */
+    _afterDisabledChange : function (e) {
+        if (this._dd) {
+            this._dd.set('lock',e.newVal);
+        }
+    },
+
+    /**
+     * Common handler to call syncUI in response to change events that occurred
+     * after the Slider is rendered.
+     *
+     * @method _refresh
+     * @param e {Event} An attribute change event
+     * @protected
+     */
+    _refresh : function (e) {
+        if (e.newVal !== e.prevVal && this.get(RENDERED)) {
+            this.syncUI();
+        }
+    },
+
+    /**
+     * Used to determine if there is a current or pending request for the
+     * thumbImage resource.
+     *
+     * @method _isImageLoading
+     * @param img {Node} <code>img</code> Node
+     * @return Boolean
+     * @protected
+     */
+    _isImageLoading : function (img) {
+        return img && !img.get(COMPLETE);
+    },
+
+    /**
+     * Used to determine if the image resource loaded successfully or there was
+     * an error.
+     *
+     * NOTES:
+     * <ul>
+     *    <li>img load error fired xbrowser for image resources not yet resolved</li>
+     *    <li>img.complete reports false in IE for images not yet loaded as well as images that failed to load</li>
+     *    <li>img.complete true && img.naturalWidth == 0 in FF and Safari indicate image failed to load</li>
+     *    <li>img.complete && img.width == 0 in Opera indicates image failed to load</li>
+     * </ul>
+     *
+     * @method _isImageLoaded
+     * @param img {Node} <code>img</code> Node
+     * @return Boolean
+     * @protected
+     */
+    _isImageLoaded : function (img) {
+        if (img) {
+            var w = img.get('naturalWidth');
+            return img.get(COMPLETE) && (!isNumber(w) ? img.get(WIDTH) : w);
+        }
+
+        return true;
+    }
+
+});
+
+Y.Slider = Slider;
+
+
+}, '3.0.0pr2' ,{requires:['widget','dd-constrain']});

=== added directory 'loggerhead/static/javascript/yui/build/substitute'
=== added file 'loggerhead/static/javascript/yui/build/substitute/README'
--- loggerhead/static/javascript/yui/build/substitute/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/substitute/README	2008-10-20 07:34:21 +0000
@@ -0,0 +1,5 @@
+YUI substute
+    A string templating utility
+
+3.0.0pr1
+    Initial release

=== added file 'loggerhead/static/javascript/yui/build/substitute/substitute-debug.js'
--- loggerhead/static/javascript/yui/build/substitute/substitute-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/substitute/substitute-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,132 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * String variable substitution and string formatting.
+ * If included, the substitute method is added to the YUI instance.
+ *
+ * @module substitute
+ */
+YUI.add("substitute", function(Y) {
+
+    var L = Y.Lang, DUMP='dump', SPACE=' ', LBRACE='{', RBRACE='}',
+
+    /**
+     * The following methods are added to the YUI instance
+     * @class YUI~substitute
+     */
+
+    /**
+     * Does variable substitution on a string. It scans through the string 
+     * looking for expressions enclosed in { } braces. If an expression 
+     * is found, it is used a key on the object.  If there is a space in
+     * the key, the first word is used for the key and the rest is provided
+     * to an optional function to be used to programatically determine the
+     * value (the extra information might be used for this decision). If 
+     * the value for the key in the object, or what is returned from the
+     * function has a string value, number value, or object value, it is 
+     * substituted for the bracket expression and it repeats.  If this
+     * value is an object, it uses the Object's toString() if this has
+     * been overridden, otherwise it does a shallow dump of the key/value
+     * pairs if Y.dump is available (if dump isn't available, toString()
+     * is used).
+     *
+     * This method is included in the 'substitute' module.  It is not included
+     * in the YUI module.
+     *
+     * @method substitute
+     * @for YUI
+     * @param s {string} The string that will be modified.
+     * @param o An object containing the replacement values
+     * @param f {function} An optional function that can be used to
+     *                     process each match.  It receives the key,
+     *                     value, and any extra metadata included with
+     *                     the key inside of the braces.
+     * @return {string} the substituted string
+     */
+    substitute = function (s, o, f) {
+        var i, j, k, key, v, meta, saved=[], token;
+
+        for (;;) {
+            i = s.lastIndexOf(LBRACE);
+            if (i < 0) {
+                break;
+            }
+            j = s.indexOf(RBRACE, i);
+            if (i + 1 >= j) {
+                break;
+            }
+
+            //Extract key and meta info 
+            token = s.substring(i + 1, j);
+            key = token;
+            meta = null;
+            k = key.indexOf(SPACE);
+            if (k > -1) {
+                meta = key.substring(k + 1);
+                key = key.substring(0, k);
+            }
+
+            // lookup the value
+            v = o[key];
+
+            // if a substitution function was provided, execute it
+            if (f) {
+                v = f(key, v, meta);
+            }
+
+            if (L.isObject(v)) {
+                if (!Y.dump) {
+                    v = v.toString();
+                } else {
+                    if (L.isArray(v)) {
+                        v = Y.dump(v, parseInt(meta, 10));
+                    } else {
+                        meta = meta || "";
+
+                        // look for the keyword 'dump', if found force obj dump
+                        var dump = meta.indexOf(DUMP);
+                        if (dump > -1) {
+                            meta = meta.substring(4);
+                        }
+
+                        // use the toString if it is not the Object toString 
+                        // and the 'dump' meta info was not found
+                        if (v.toString===Object.prototype.toString||dump>-1) {
+                            v = Y.dump(v, parseInt(meta, 10));
+                        } else {
+                            v = v.toString();
+                        }
+                    }
+                }
+            } else if (!L.isString(v) && !L.isNumber(v)) {
+                // This {block} has no replace string. Save it for later.
+                v = "~-" + saved.length + "-~";
+                saved[saved.length] = token;
+
+                // break;
+            }
+
+            s = s.substring(0, i) + v + s.substring(j + 1);
+
+
+        }
+
+        // restore saved {block}s
+        for (i=saved.length-1; i>=0; i=i-1) {
+            s = s.replace(new RegExp("~-" + i + "-~"), "{"  + saved[i] + "}", "g");
+        }
+
+        return s;
+
+    };
+
+    Y.substitute = substitute;
+    L.substitute = substitute;
+
+}, "3.0.0pr2", {
+    optional: ['dump']
+});

=== added file 'loggerhead/static/javascript/yui/build/substitute/substitute-min.js'
--- loggerhead/static/javascript/yui/build/substitute/substitute-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/substitute/substitute-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("substitute",function(G){var B=G.Lang,D="dump",F=" ",C="{",E="}",A=function(S,H,N){var L,K,J,P,Q,R,O=[],I;for(;;){L=S.lastIndexOf(C);if(L<0){break;}K=S.indexOf(E,L);if(L+1>=K){break;}I=S.substring(L+1,K);P=I;R=null;J=P.indexOf(F);if(J>-1){R=P.substring(J+1);P=P.substring(0,J);}Q=H[P];if(N){Q=N(P,Q,R);}if(B.isObject(Q)){if(!G.dump){Q=Q.toString();}else{if(B.isArray(Q)){Q=G.dump(Q,parseInt(R,10));}else{R=R||"";var M=R.indexOf(D);if(M>-1){R=R.substring(4);}if(Q.toString===Object.prototype.toString||M>-1){Q=G.dump(Q,parseInt(R,10));}else{Q=Q.toString();}}}}else{if(!B.isString(Q)&&!B.isNumber(Q)){Q="~-"+O.length+"-~";O[O.length]=I;}}S=S.substring(0,L)+Q+S.substring(K+1);}for(L=O.length-1;L>=0;L=L-1){S=S.replace(new RegExp("~-"+L+"-~"),"{"+O[L]+"}","g");}return S;};G.substitute=A;B.substitute=A;},"3.0.0pr2",{optional:["dump"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/substitute/substitute.js'
--- loggerhead/static/javascript/yui/build/substitute/substitute.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/substitute/substitute.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,132 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * String variable substitution and string formatting.
+ * If included, the substitute method is added to the YUI instance.
+ *
+ * @module substitute
+ */
+YUI.add("substitute", function(Y) {
+
+    var L = Y.Lang, DUMP='dump', SPACE=' ', LBRACE='{', RBRACE='}',
+
+    /**
+     * The following methods are added to the YUI instance
+     * @class YUI~substitute
+     */
+
+    /**
+     * Does variable substitution on a string. It scans through the string 
+     * looking for expressions enclosed in { } braces. If an expression 
+     * is found, it is used a key on the object.  If there is a space in
+     * the key, the first word is used for the key and the rest is provided
+     * to an optional function to be used to programatically determine the
+     * value (the extra information might be used for this decision). If 
+     * the value for the key in the object, or what is returned from the
+     * function has a string value, number value, or object value, it is 
+     * substituted for the bracket expression and it repeats.  If this
+     * value is an object, it uses the Object's toString() if this has
+     * been overridden, otherwise it does a shallow dump of the key/value
+     * pairs if Y.dump is available (if dump isn't available, toString()
+     * is used).
+     *
+     * This method is included in the 'substitute' module.  It is not included
+     * in the YUI module.
+     *
+     * @method substitute
+     * @for YUI
+     * @param s {string} The string that will be modified.
+     * @param o An object containing the replacement values
+     * @param f {function} An optional function that can be used to
+     *                     process each match.  It receives the key,
+     *                     value, and any extra metadata included with
+     *                     the key inside of the braces.
+     * @return {string} the substituted string
+     */
+    substitute = function (s, o, f) {
+        var i, j, k, key, v, meta, saved=[], token;
+
+        for (;;) {
+            i = s.lastIndexOf(LBRACE);
+            if (i < 0) {
+                break;
+            }
+            j = s.indexOf(RBRACE, i);
+            if (i + 1 >= j) {
+                break;
+            }
+
+            //Extract key and meta info 
+            token = s.substring(i + 1, j);
+            key = token;
+            meta = null;
+            k = key.indexOf(SPACE);
+            if (k > -1) {
+                meta = key.substring(k + 1);
+                key = key.substring(0, k);
+            }
+
+            // lookup the value
+            v = o[key];
+
+            // if a substitution function was provided, execute it
+            if (f) {
+                v = f(key, v, meta);
+            }
+
+            if (L.isObject(v)) {
+                if (!Y.dump) {
+                    v = v.toString();
+                } else {
+                    if (L.isArray(v)) {
+                        v = Y.dump(v, parseInt(meta, 10));
+                    } else {
+                        meta = meta || "";
+
+                        // look for the keyword 'dump', if found force obj dump
+                        var dump = meta.indexOf(DUMP);
+                        if (dump > -1) {
+                            meta = meta.substring(4);
+                        }
+
+                        // use the toString if it is not the Object toString 
+                        // and the 'dump' meta info was not found
+                        if (v.toString===Object.prototype.toString||dump>-1) {
+                            v = Y.dump(v, parseInt(meta, 10));
+                        } else {
+                            v = v.toString();
+                        }
+                    }
+                }
+            } else if (!L.isString(v) && !L.isNumber(v)) {
+                // This {block} has no replace string. Save it for later.
+                v = "~-" + saved.length + "-~";
+                saved[saved.length] = token;
+
+                // break;
+            }
+
+            s = s.substring(0, i) + v + s.substring(j + 1);
+
+
+        }
+
+        // restore saved {block}s
+        for (i=saved.length-1; i>=0; i=i-1) {
+            s = s.replace(new RegExp("~-" + i + "-~"), "{"  + saved[i] + "}", "g");
+        }
+
+        return s;
+
+    };
+
+    Y.substitute = substitute;
+    L.substitute = substitute;
+
+}, "3.0.0pr2", {
+    optional: ['dump']
+});

=== added directory 'loggerhead/static/javascript/yui/build/widget'
=== added file 'loggerhead/static/javascript/yui/build/widget/README'
--- loggerhead/static/javascript/yui/build/widget/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,20 @@
+3.0.0PR2 - Initial release
+
+Module Name: "widget"
+Documentation: http://developer.yahoo.com/yui/3/widget
+
+Provides the base Widget class along with an augmentable PluginHost 
+interface.
+
+Widget is the foundation class from which all YUI 3 widgets are derived. 
+
+It provides the following pieces of core functionality:
+
+* The render lifecycle method, in addition to the init and destroy 
+  lifecycle methods provided by Base
+* Abstract rendering methods to support a consistent MVC structure across
+  widgets
+* A common set of base widget attributes
+* Consistent class-name generation support
+* Plugin support
+

=== added directory 'loggerhead/static/javascript/yui/build/widget/assets'
=== added directory 'loggerhead/static/javascript/yui/build/widget/assets/skins'
=== added directory 'loggerhead/static/javascript/yui/build/widget/assets/skins/sam'
=== added file 'loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget-skin.css'
--- loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget-skin.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget-skin.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,6 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/

=== added file 'loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget-stack-skin.css'
--- loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget-stack-skin.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget-stack-skin.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,6 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/

=== added file 'loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget-stack.css'
--- loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget-stack.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget-stack.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-widget-stacked .yui-widget-shim{opacity:0;filter:alpha(opacity=0);position:absolute;border:none;top:0px;left:0px;padding:0;margin:0;z-index:-1;width:100%;height:100%;_width:0;_height:0;}.yui-widget-hide-scrollbars,.yui-widget-hide-scrollbars *{overflow:hidden;}.yui-widget-hide-scrollbars select{display:none;}.yui-widget-show-scrollbars{overflow:auto;}

=== added file 'loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget.css'
--- loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/assets/skins/sam/widget.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-widget-hidden{display:none;}

=== added file 'loggerhead/static/javascript/yui/build/widget/assets/widget-core.css'
--- loggerhead/static/javascript/yui/build/widget/assets/widget-core.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/assets/widget-core.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,9 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-widget-hidden {
+    display:none;
+}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/widget/assets/widget-stack-core.css'
--- loggerhead/static/javascript/yui/build/widget/assets/widget-stack-core.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/assets/widget-stack-core.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,38 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-widget-stacked .yui-widget-shim {
+    opacity:0;
+    filter:alpha(opacity=0);
+    position:absolute;
+    border:none;
+    top:0px;
+    left:0px;
+    padding:0;
+    margin:0;
+    z-index:-1;
+    width:100%;
+    height:100%;
+    /* 
+       We'll be setting these programmatically for IE6, 
+       to account for cases where height is not set 
+    */
+    _width:0;
+    _height:0;
+}
+
+.yui-widget-hide-scrollbars,
+.yui-widget-hide-scrollbars * {
+    overflow: hidden;
+}
+
+.yui-widget-hide-scrollbars select {
+    display: none;
+}
+
+.yui-widget-show-scrollbars {
+    overflow: auto;
+}

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-debug.js'
--- loggerhead/static/javascript/yui/build/widget/widget-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1473 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('widget', function(Y) {
+
+/**
+ * Provides the base Widget class along with an augmentable PluginHost interface
+ *
+ * @module widget
+ */
+
+/**
+ * An augmentable class, which when added to a "Base" based class, allows 
+ * the class to support Plugins, providing plug and unplug methods and performing
+ * instantiation and cleanup during the init and destroy lifecycle phases respectively.
+ *
+ * @class PluginHost
+ */
+
+var L = Y.Lang;
+
+function PluginHost(config) {
+    this._plugins = {};
+
+    this.after("init", function(e, cfg) {this._initPlugins(cfg);});
+    this.after("destroy", this._destroyPlugins);
+}
+
+PluginHost.prototype = {
+
+    /**
+     * Register and instantiate a plugin with the Widget.
+     * 
+     * @method plug
+     * @chainable
+     * @param p {String | Object |Array} Accepts the registered 
+     * namespace for the Plugin or an object literal with an "fn" property
+     * specifying the Plugin class and a "cfg" property specifying
+     * the configuration for the Plugin.
+     * <p>
+     * Additionally an Array can also be passed in, with either the above String or 
+     * Object literal values, allowing for multiple plugin registration in 
+     * a single call.
+     * </p>
+     */
+    plug: function(p) {
+        if (p) {
+            if (L.isArray(p)) {
+                var ln = p.length;
+                for (var i = 0; i < ln; i++) {
+                    this.plug(p[i]);
+                }
+            } else if (L.isFunction(p)) {
+                this._plug(p);
+            } else {
+                this._plug(p.fn, p.cfg);
+            }
+        }
+        return this;
+    },
+
+    /**
+     * Unregister and destroy a plugin already instantiated with the Widget.
+     * 
+     * @method unplug
+     * @param {String} ns The namespace key for the Plugin. If not provided,
+     * all registered plugins are unplugged.
+     * @chainable
+     */
+    unplug: function(ns) {
+        if (ns) {
+            this._unplug(ns);
+        } else {
+            for (ns in this._plugins) {
+                if (Y.Object.owns(this._plugins, ns)) {
+                    this._unplug(ns);
+                }
+            }
+        }
+        return this;
+    },
+
+    /**
+     * Determines if a plugin has been registered and instantiated 
+     * for this widget.
+     * 
+     * @method hasPlugin
+     * @public
+     * @return {Boolean} returns true, if the plugin has been applied
+     * to this widget.
+     */
+    hasPlugin : function(ns) {
+        return (this._plugins[ns] && this[ns]);
+    },
+
+    /**
+     * Initializes static plugins registered on the host (the
+     * "PLUGINS" static property) and any plugins passed in 
+     * for the instance through the "plugins" configuration property.
+     *
+     * @method _initPlugins
+     * @param {Config} the user configuration object for the host.
+     * @private
+     */
+    _initPlugins: function(config) {
+
+        // Class Configuration
+        var classes = this._getClasses(), constructor;
+        for (var i = 0; i < classes.length; i++) {
+            constructor = classes[i];
+            if (constructor.PLUGINS) {
+                this.plug(constructor.PLUGINS);
+            }
+        }
+
+        // User Configuration
+        if (config && config.plugins) {
+            this.plug(config.plugins);
+        }
+    },
+
+    /**
+     * Private method used to unplug and destroy all plugins on the host
+     * @method _destroyPlugins
+     * @private
+     */
+    _destroyPlugins: function() {
+        this._unplug();
+    },
+
+    /**
+     * Private method used to instantiate and attach plugins to the host
+     * @method _plug
+     * @param {Function} PluginClass The plugin class to instantiate
+     * @param {Object} config The configuration object for the plugin
+     * @private
+     */
+    _plug: function(PluginClass, config) {
+        if (PluginClass && PluginClass.NS) {
+            var ns = PluginClass.NS;
+
+            config = config || {};
+            config.owner = this;
+
+            if (this.hasPlugin(ns)) {
+                // Update config
+                this[ns].setAtts(config);
+            } else {
+                // Create new instance
+                this[ns] = new PluginClass(config);
+                this._plugins[ns] = PluginClass;
+            }
+        }
+    },
+
+    /**
+     * Private method used to unregister and destroy a plugin already instantiated with the host.
+     *
+     * @method _unplug
+     * @private
+     * @param {String} ns The namespace key for the Plugin. If not provided,
+     * all registered plugins are unplugged.
+     */
+    _unplug : function(ns) {
+        if (ns) {
+            if (this[ns]) {
+                this[ns].destroy();
+                delete this[ns];
+            }
+            if (this._plugins[ns]) {
+                delete this._plugins[ns];
+            }
+        }
+    }
+};
+
+Y.PluginHost = PluginHost;
+
+/**
+ * Provides the base Widget class along with an augmentable PluginHost interface
+ *
+ * @module widget
+ */
+
+// Local Constants
+var WIDGET = "widget",
+    CONTENT = "content",
+    VISIBLE = "visible",
+    HIDDEN = "hidden",
+    DISABLED = "disabled",
+    FOCUS = "focus",
+    BLUR = "blur",
+    HAS_FOCUS = "hasFocus",
+    WIDTH = "width",
+    HEIGHT = "height",
+    EMPTY = "",
+    HYPHEN = "-",
+    BOUNDING_BOX = "boundingBox",
+    CONTENT_BOX = "contentBox",
+    PARENT_NODE = "parentNode",
+    FIRST_CHILD = "firstChild",
+    OWNER_DOCUMENT = "ownerDocument",
+    BODY = "body",
+    TAB_INDEX = "tabIndex",
+    LOCALE = "locale",
+    INIT_VALUE = "initValue",
+    ID = "id",
+    RENDER = "render",
+    RENDERED = "rendered",
+    DESTROYED = "destroyed",
+
+    ContentUpdate = "contentUpdate",
+
+    O = Y.Object,
+    Node = Y.Node,
+    ClassNameManager = Y.ClassNameManager;
+
+// Widget nodeid-to-instance map for now, 1-to-1.
+var _instances = {};
+
+/**
+ * A base class for widgets, providing:
+ * <ul>
+ *    <li>The render lifecycle method, in addition to the init and destroy 
+ *        lifecycle methods provide by Base</li>
+ *    <li>Abstract methods to support consistent MVC structure across 
+ *        widgets: renderer, renderUI, bindUI, syncUI</li>
+ *    <li>Support for common widget attributes, such as boundingBox, contentBox, visible, 
+ *        disabled, hasFocus, strings</li>
+ *    <li>Plugin registration and activation support</li>
+ * </ul>
+ *
+ * @param config {Object} Object literal specifying widget configuration 
+ * properties.
+ *
+ * @class Widget
+ * @constructor
+ * @extends Base
+ */
+function Widget(config) {
+    Y.log('constructor called', 'life', 'widget');
+
+    this._yuid = Y.guid(WIDGET);
+    this._strings = {};
+
+    Widget.superclass.constructor.apply(this, arguments);
+}
+
+/**
+ * The build configuration for the Widget class.
+ * <p>
+ * Defines the static fields which need to be aggregated,
+ * when this class is used as the main class passed to 
+ * the <a href="Base.html#method_build">Base.build</a> method.
+ * </p>
+ * @property _buildCfg
+ * @type Object
+ * @static
+ * @final
+ * @private
+ */
+Widget._buildCfg = {
+    aggregates : ["PLUGINS", "HTML_PARSER"]
+};
+
+/**
+ * Static property provides a string to identify the class.
+ * <p>
+ * Currently used to apply class identifiers to the bounding box 
+ * and to classify events fired by the widget.
+ * </p>
+ *
+ * @property Widget.NAME
+ * @type String
+ * @static
+ */
+Widget.NAME = WIDGET;
+
+/**
+ * Constant used to identify state changes originating from
+ * the DOM (as opposed to the JavaScript model).
+ *
+ * @property Widget.UI_SRC
+ * @type String
+ * @static
+ * @final
+ */
+Widget.UI_SRC = "ui";
+
+var UI = Widget.UI_SRC;
+
+/**
+ * Static property used to define the default attribute 
+ * configuration for the Widget.
+ * 
+ * @property Widget.ATTRS
+ * @type Object
+ * @static
+ */
+Widget.ATTRS = {
+
+    /**
+     * Flag indicating whether or not this object
+     * has been through the render lifecycle phase.
+     *
+     * @attribute rendered
+     * @readOnly
+     * @default false
+     * @type boolean
+     */
+    rendered: {
+        value:false,
+        readOnly:true
+    },
+
+    /**
+    * @attribute boundingBox
+    * @description The outermost DOM node for the Widget, used for sizing and positioning 
+    * of a Widget as well as a containing element for any decorator elements used 
+    * for skinning.
+    * @type Node
+    */
+    boundingBox: {
+        value:null,
+        set: function(node) {
+            return this._setBoundingBox(node);
+        },
+        writeOnce: true
+    },
+
+    /**
+    * @attribute contentBox
+    * @description A DOM node that is a direct descendent of a Widget's bounding box that 
+    * houses its content.
+    * @type Node
+    */
+    contentBox: {
+        value:null,
+        set: function(node) {
+            return this._setContentBox(node);
+        },
+        writeOnce: true
+    },
+
+    /**
+    * @attribute tabIndex
+    * @description The tabIndex, applied to the bounding box
+    * @type Number
+    */
+    tabIndex: {
+        value: 0
+    },
+
+    /**
+    * @attribute hasFocus
+    * @description Boolean indicating if the Widget has focus.
+    * @default false
+    * @type boolean
+    */
+    hasFocus: {
+        value: false
+    },
+
+    /**
+    * @attribute disabled
+    * @description Boolean indicating if the Widget should be disabled. The disabled implementation
+    * is left to the specific classes extending widget.
+    * @default false
+    * @type boolean
+    */
+    disabled: {
+        value: false
+    },
+
+    /**
+    * @attribute visible
+    * @description Boolean indicating weather or not the Widget is visible.
+    * @default true
+    * @type boolean
+    */
+    visible: {
+        value: true
+    },
+
+    /**
+    * @attribute height
+    * @description String with units, or number, representing the height of the Widget. If a number is provided,
+    * the default unit, defined by the Widgets DEF_UNIT, property is used.
+    * @default ""
+    * @type {String | Number}
+    */
+    height: {
+        value: EMPTY
+    },
+
+    /**
+    * @attribute width
+    * @description String with units, or number, representing the width of the Widget. If a number is provided,
+    * the default unit, defined by the Widgets DEF_UNIT, property is used.
+    * @default ""
+    * @type {String | Number}
+    */
+    width: {
+        value: EMPTY
+    },
+
+    /**
+     * @attribute moveStyles
+     * @description Flag defining whether or not style properties from the content box
+     * should be moved to the bounding box when wrapped (as defined by the WRAP_STYLES property)
+     * @default false
+     * @type boolean
+     */
+    moveStyles: {
+        value: false
+    },
+
+    /**
+     * @attribute locale
+     * @description
+     * The default locale for the widget. NOTE: Using get/set on the "strings" attribute will
+     * return/set strings for this locale.
+     * @default "en"
+     * @type String
+     */
+    locale : {
+        value: "en"
+    },
+
+    /**
+     * @attribute strings
+     * @description Collection of strings used to label elements of the Widget's UI.
+     * @default null
+     * @type Object
+     */
+    strings: {
+        set: function(val) {
+            return this._setStrings(val, this.get(LOCALE));
+        },
+
+        get: function() {
+            return this.getStrings(this.get(LOCALE));
+        }
+    }
+};
+
+/**
+ * Cached lowercase version of Widget.NAME
+ *
+ * @property Widget._NAME_LOWERCASE
+ * @private
+ * @static
+ */
+Widget._NAME_LOWERCASE = Widget.NAME.toLowerCase();
+
+/**
+ * Generate a standard prefixed classname for the Widget, prefixed by the default prefix defined
+ * by the <code>Y.config.classNamePrefix</code> attribute used by <code>ClassNameManager</code> and 
+ * <code>Widget.NAME.toLowerCase()</code> (e.g. "yui-widget-xxxxx-yyyyy", based on default values for 
+ * the prefix and widget class name).
+ * <p>
+ * The instance based version of this method can be used to generate standard prefixed classnames,
+ * based on the instances NAME, as opposed to Widget.NAME. This method should be used when you
+ * need to use a constant class name across different types instances.
+ * </p>
+ * @method getClassName
+ * @param {String*} args* 0..n strings which should be concatenated, using the default separator defined by ClassNameManager, to create the class name
+ */
+Widget.getClassName = function() {
+	var args = Y.Array(arguments, 0, true);
+	args.splice(0, 0, this._NAME_LOWERCASE);
+	return ClassNameManager.getClassName.apply(ClassNameManager, args);
+};
+
+/**
+ * Returns the widget instance whose bounding box contains, or is, the given node. 
+ * <p>
+ * In the case of nested widgets, the nearest bounding box ancestor is used to
+ * return the widget instance.
+ * </p>
+ * @method Widget.getByNode
+ * @static
+ * @param node {Node | String} The node for which to return a Widget instance. If a selector
+ * string is passed in, which selects more than one node, the first node found is used.
+ * @return {Widget} Widget instance, or null if not found.
+ */
+Widget.getByNode = function(node) {
+    var widget,
+        bbMarker = Widget.getClassName();
+
+    node = Node.get(node);
+    if (node) {
+        node = (node.hasClass(bbMarker)) ? node : node.ancestor("." + bbMarker);
+        if (node) {
+            widget = _instances[node.get(ID)];
+        }
+    }
+
+    return widget || null;
+};
+
+/**
+ * Object hash, defining how attribute values are to be parsed from
+ * markup contained in the widget's content box. e.g.:
+ * <pre>
+ *   {
+ *       // Set single Node references using selector syntax 
+ *       // (selector is run through node.query)
+ *       titleNode: "span.yui-title",
+ *       // Set NodeList references using selector syntax 
+ *       // (array indicates selector is to be run through node.queryAll)
+ *       listNodes: ["li.yui-item"],
+ *       // Set other attribute types, using a parse function. 
+ *       // Context is set to the widget instance.
+ *       label: function(contentBox) {
+ *           return contentBox.query("span.title").get("innerHTML");
+ *       }
+ *   }
+ * </pre>
+ * 
+ * @property Widget.HTML_PARSER
+ * @type Object
+ * @static
+ */
+Widget.HTML_PARSER = {};
+
+Y.extend(Widget, Y.Base, {
+
+	/**
+	 * Returns a class name prefixed with the the value of the 
+	 * <code>YUI.config.classNamePrefix</code> attribute + the instances <code>NAME</code> property.
+	 * Uses <code>YUI.config.classNameDelimiter</code> attribute to delimit the provided strings.
+	 * e.g. 
+	 * <code>
+	 * <pre>
+	 *    // returns "yui-slider-foo-bar", for a slider instance
+	 *    var scn = slider.getClassName('foo','bar');
+	 *
+	 *    // returns "yui-overlay-foo-bar", for an overlay instance
+	 *    var ocn = slider.getClassName('foo','bar');
+	 * </pre>
+	 * </code>
+	 *
+	 * @method getClassName
+	 * @param {String}+ One or more classname bits to be joined and prefixed
+	 */
+	getClassName: function () {
+		var args = Y.Array(arguments, 0, true);
+		args.splice(0, 0, this._name);
+		return ClassNameManager.getClassName.apply(ClassNameManager, args);
+	},
+
+    /**
+     * Initializer lifecycle implementation for the Widget class. Registers the 
+     * widget instance, and runs through the Widget's HTML_PARSER definition. 
+     *
+     * @method initializer
+     * @protected
+     * @param  config {Object} Configuration object literal for the widget
+     */
+    initializer: function(config) {
+        Y.log('initializer called', 'life', 'widget');
+
+        /**
+         * Notification event, which widget implementations can fire, when
+         * they change the content of the widget. This event has no default
+         * behavior and cannot be prevented, so the "on" or "after"
+         * moments are effectively equivalent (with on listeners being invoked before 
+         * after listeners).
+         * 
+         * @event widget:contentUpdate
+         * @preventable false
+         * @param {Event.Facade} e The Event Facade
+         */
+        this.publish(ContentUpdate, { preventable:false });
+
+		this._name = this.constructor.NAME.toLowerCase();
+
+        var nodeId = this.get(BOUNDING_BOX).get(ID);
+        if (nodeId) {
+            _instances[nodeId] = this;
+        }
+
+        var htmlConfig = this._parseHTML(this.get(CONTENT_BOX));
+        if (htmlConfig) {
+            Y.aggregate(config, htmlConfig, false);
+        }
+
+        Y.PluginHost.call(this, config);
+    },
+
+    /**
+     * Descructor lifecycle implementation for the Widget class. Purges events attached
+     * to the bounding box (and all child nodes) and removes the Widget from the 
+     * list of registered widgets.
+     *
+     * @method destructor
+     * @protected
+     */
+    destructor: function() {
+        Y.log('destructor called', 'life', 'widget');
+
+        var boundingBox = this.get(BOUNDING_BOX);
+        
+        Y.Event.purgeElement(boundingBox, true);
+
+        var nodeId = boundingBox.get(ID);
+        if (nodeId && nodeId in _instances) {
+            delete _instances[nodeId];
+        }
+    },
+
+    /**
+     * Establishes the initial DOM for the widget. Invoking this
+     * method will lead to the creating of all DOM elements for
+     * the widget (or the manipulation of existing DOM elements 
+     * for the progressive enhancement use case).
+     * <p>
+     * This method should only be invoked once for an initialized
+     * widget.
+     * </p>
+     * <p>
+     * It delegates to the widget specific renderer method to do
+     * the actual work.
+     * </p>
+     *
+     * @method render
+     * @chainable
+     * @final 
+     * @param  parentNode {Object | String} Optional. The Node under which the 
+     * Widget is to be rendered. This can be a Node instance or a CSS selector string. 
+     * <p>
+     * If the selector string returns more than one Node, the first node will be used 
+     * as the parentNode. NOTE: This argument is required if both the boundingBox and contentBox
+     * are not currently in the document. If it's not provided, the Widget will be rendered
+     * to the body of the current document in this case.
+     * </p>
+     */
+    render: function(parentNode) {
+
+        if (this.get(DESTROYED)) {
+            Y.log("Render failed; widget has been destroyed", "error", "widget");
+            return;
+        }
+
+        if (!this.get(RENDERED)) {
+             /**
+             * Lifcyle event for the render phase, fired prior to rendering the UI 
+             * for the widget (prior to invoking the widgets renderer method).
+             * <p>
+             * Subscribers to the "on" moment of this event, will be notified 
+             * before the widget is rendered.
+             * </p>
+             * <p>
+             * Subscribers to the "after" momemt of this event, will be notified
+             * after rendering is complete.
+             * </p>
+             *
+             * @event widget:render
+             * @preventable _defRenderFn
+             * @param {Event.Facade} e The Event Facade
+             */
+            this.publish(RENDER, {queuable:false, defaultFn: this._defRenderFn});
+
+            parentNode = (parentNode) ? Node.get(parentNode) : null;
+            if (parentNode && !parentNode.inDoc()) {
+                parentNode = null;
+            }
+
+            this.fire(RENDER, null, parentNode);
+        }
+
+        return this;
+    },
+
+    /**
+     * Default render handler
+     *
+     * @method _defRenderFn
+     * @protected
+     * @param {Event.Facade} e The Event object
+     * @param {Node} parentNode The parent node to render to, if passed in to the <code>render</code> method
+     */
+    _defRenderFn : function(e, parentNode) {
+
+            this._renderUI(parentNode);
+            this._bindUI();
+            this._syncUI();
+
+            this.renderer();
+
+            this._set(RENDERED, true);
+    },
+
+    /** 
+     * Creates DOM (or manipulates DOM for progressive enhancement)
+     * This method is invoked by render() and is not chained 
+     * automatically for the class hierarchy (like initializer, destructor) 
+     * so it should be chained manually for subclasses if required.
+     * 
+     * @method renderer
+     * @protected
+     */
+    renderer: function() {
+        this.renderUI();
+        this.bindUI();
+        this.syncUI();
+    },
+
+    /**
+     * Configures/Sets up listeners to bind Widget State to UI/DOM
+     * 
+     * This method is not called by framework and is not chained 
+     * automatically for the class hierarchy.
+     * 
+     * @method bindUI
+     * @protected
+     */
+    bindUI: function() {},
+
+    /**
+     * Adds nodes to the DOM 
+     * 
+     * This method is not called by framework and is not chained 
+     * automatically for the class hierarchy.
+     * 
+     * @method renderUI
+     * @protected
+     */
+    renderUI: function() {},
+
+    /**
+     * Refreshes the rendered UI, based on Widget State
+     * 
+     * This method is not called by framework and is not chained
+     * automatically for the class hierarchy.
+     *
+     * @method syncUI
+     * 
+     */
+    syncUI: function(){},
+
+    /**
+    * @method hide
+    * @description Shows the Module element by setting the "visible" attribute to "false".
+    */
+    hide: function() {
+        return this.set(VISIBLE, false);
+    },
+
+    /**
+    * @method show
+    * @description Shows the Module element by setting the "visible" attribute to "true".
+    */
+    show: function() {
+        return this.set(VISIBLE, true);
+    },
+
+    /**
+    * @method focus
+    * @description Causes the Widget to receive the focus by setting the "hasFocus" 
+    * attribute to "true".
+    */
+    focus: function () {
+        return this.set(HAS_FOCUS, true);
+    },
+
+    /**
+    * @method blur
+    * @description Causes the Widget to lose focus by setting the "hasFocus" attribute 
+    * to "false"
+    */            
+    blur: function () {
+        return this.set(HAS_FOCUS, false);
+    },
+
+    /**
+    * @method enable
+    * @description Set the Widget's "disabled" attribute to "false".
+    */
+    enable: function() {
+        return this.set(DISABLED, false);
+    },
+
+    /**
+    * @method disabled
+    * @description Set the Widget's "disabled" attribute to "true".
+    */
+    disable: function() {
+        return this.set(DISABLED, true);
+    },
+
+    /**
+     * Utilitity method used to apply the <code>HTML_PARSER</code> configuration for the 
+     * instance, to retrieve config data values.
+     * 
+     * @method _parseHTML
+     * @private 
+     * @param  node {Node} Root node to use to parse markup for configuration data
+     * @return config {Object} configuration object, with values found in the HTML, populated
+     */
+    _parseHTML : function(node) {
+ 
+        var schema = this._getHtmlParser(),
+            data,
+            val;
+
+        if (schema && node && node.hasChildNodes()) {
+
+            O.each(schema, function(v, k, o) {
+                val = null;
+
+                if (L.isFunction(v)) {
+                    val = v.call(this, node);
+                } else {
+                    if (L.isArray(v)) {
+                        val = node.queryAll(v[0]);
+                    } else {
+                        val = node.query(v);
+                    }
+                }
+
+                if (val !== null && val !== undefined) {
+                    data = data || {};
+                    data[k] = val;
+                }
+
+            }, this);
+        }
+
+        return data;
+    },
+
+    /**
+     * Moves a pre-defined set of style rules (WRAP_STYLES) from one node to another.
+     *
+     * @method _moveStyles
+     * @private
+     * @param {Node} nodeFrom The node to gather the styles from
+     * @param {Node} nodeTo The node to apply the styles to
+     */
+    _moveStyles: function(nodeFrom, nodeTo) {
+
+        var styles = this.WRAP_STYLES,
+            pos = nodeFrom.getStyle('position'),
+            contentBox = this.get(CONTENT_BOX),
+            xy = [0,0],
+            h, w;
+
+        if (!this.get('height')) {
+            h = contentBox.get('offsetHeight');
+        }
+
+        if (!this.get('width')) {
+            w = contentBox.get('offsetWidth');
+        }
+
+        if (pos === 'absolute') {
+            xy = nodeFrom.getXY();
+            nodeTo.setStyles({
+                right: 'auto',
+                bottom: 'auto'
+            });
+
+            nodeFrom.setStyles({
+                right: 'auto',
+                bottom: 'auto'
+            });
+        }
+
+        Y.each(styles, function(v, k) {
+            var s = nodeFrom.getStyle(k);
+            nodeTo.setStyle(k, s);
+            if (v === false) {
+                nodeFrom.setStyle(k, '');
+            } else {
+                nodeFrom.setStyle(k, v);
+            }
+        });
+
+        if (pos === 'absolute') {
+            nodeTo.setXY(xy);
+        }
+
+        if (h) {
+            this.set('height', h);
+        }
+
+        if (w) {
+            this.set('width', w);
+        }
+    },
+
+    /**
+    * Helper method to collect the boundingBox and contentBox, set styles and append to the provided parentNode, if not
+    * already a child. The owner document of the boundingBox, or the owner document of the contentBox will be used 
+    * as the document into which the Widget is rendered if a parentNode is node is not provided. If both the boundingBox and
+    * the contentBox are not currently in the document, and no parentNode is provided, the widget will be rendered 
+    * to the current document's body.
+    *
+    * @method _renderBox
+    * @private
+    * @param {Node} parentNode The parentNode to render the widget to. If not provided, and both the boundingBox and
+    * the contentBox are not currently in the document, the widget will be rendered to the current document's body.
+    */
+    _renderBox: function(parentNode) {
+
+        var contentBox = this.get(CONTENT_BOX),
+            boundingBox = this.get(BOUNDING_BOX),
+            doc = boundingBox.get(OWNER_DOCUMENT) || contentBox.get(OWNER_DOCUMENT),
+            body;
+
+        if (!boundingBox.compareTo(contentBox.get(PARENT_NODE))) {
+            if (this.get('moveStyles')) {
+                this._moveStyles(contentBox, boundingBox);
+            }
+            // If contentBox box is already in the document, have boundingBox box take it's place
+            if (contentBox.inDoc(doc)) {
+                contentBox.get(PARENT_NODE).replaceChild(boundingBox, contentBox);
+            }
+            boundingBox.appendChild(contentBox);
+        }
+
+        if (!boundingBox.inDoc(doc) && !parentNode) {
+            body = Node.get(BODY);
+            if (body.get(FIRST_CHILD)) {
+                // Special case when handling body as default (no parentNode), always try to insert.
+                body.insertBefore(boundingBox, body.get(FIRST_CHILD));
+            } else {
+                body.appendChild(boundingBox);
+            }
+        } else {
+            if (parentNode && !parentNode.compareTo(boundingBox.get(PARENT_NODE))) {
+                parentNode.appendChild(boundingBox);
+            }
+        }
+    },
+
+    /**
+    * Setter for the boundingBox attribute
+    *
+    * @method _setBoundingBox
+    * @private
+    * @param Node/String
+    * @return Node
+    */
+    _setBoundingBox: function(node) {
+        return this._setBox(node, this.BOUNDING_TEMPLATE);
+    },
+
+    /**
+    * Setter for the contentBox attribute
+    *
+    * @method _setContentBox
+    * @private
+    * @param {Node|String} node
+    * @return Node
+    */
+    _setContentBox: function(node) {
+        return this._setBox(node, this.CONTENT_TEMPLATE);
+    },
+
+    /**
+     * Helper method to set the bounding/content box, or create it from
+     * the provided template if not found.
+     *
+     * @method _setBox
+     * @private
+     *
+     * @param {Node|String} node The node reference
+     * @param {String} template HTML string template for the node
+     * @return {Node} The node
+     */
+    _setBox : function(node, template) {
+        node = Node.get(node) || Node.create(template);
+
+        var sid = Y.stamp(node);
+        if (!node.get(ID)) {
+            node.set(ID, sid);
+        }
+        return node;
+    },
+
+    /**
+     * Initializes the UI state for the Widget's bounding/content boxes.
+     *
+     * @method _renderUI
+     * @protected
+     * @param {Node} The parent node to rendering the widget into
+     */
+    _renderUI: function(parentNode) {
+        this._renderBoxClassNames();
+        this._renderBox(parentNode);
+    },
+
+     /**
+      * Applies standard class names to the boundingBox and contentBox
+      * 
+      * @method _renderBoxClassNames
+      * @protected
+      */
+    _renderBoxClassNames : function() {
+        var classes = this._getClasses(),
+            boundingBox = this.get(BOUNDING_BOX),
+            contentBox = this.get(CONTENT_BOX),
+            name;
+
+        boundingBox.addClass(Widget.getClassName());
+
+        // Start from Widget Sub Class
+        for (var i = 2, l = classes.length; i < l; ++i) {
+            name = classes[i].NAME;
+            if (name) {
+                boundingBox.addClass(ClassNameManager.getClassName(name.toLowerCase()));
+            }
+        }
+
+        // Use instance based name for content box
+        contentBox.addClass(this.getClassName(CONTENT));
+    },
+
+    /**
+     * Sets up DOM and CustomEvent listeners for the widget.
+     *
+     * @method _bindUI
+     * @protected
+     */
+    _bindUI: function() {
+        this.after('visibleChange', this._afterVisibleChange);
+        this.after('disabledChange', this._afterDisabledChange);
+        this.after('heightChange', this._afterHeightChange);
+        this.after('widthChange', this._afterWidthChange);
+        this.after('hasFocusChange', this._afterHasFocusChange);
+
+        this._bindDOMListeners();
+    },
+
+    /**
+     * Sets up DOM listeners, on elements rendered by the widget.
+     * 
+     * @method _bindDOMListeners
+     * @protected
+     */
+    _bindDOMListeners : function() {
+        this.get(BOUNDING_BOX).on(FOCUS, Y.bind(this._onFocus, this));
+        this.get(BOUNDING_BOX).on(BLUR, Y.bind(this._onBlur, this));
+    },
+
+    /**
+     * Updates the widget UI to reflect the attribute state.
+     *
+     * @method _syncUI
+     * @protected
+     */
+    _syncUI: function() {
+        this._uiSetVisible(this.get(VISIBLE));
+        this._uiSetDisabled(this.get(DISABLED));
+        this._uiSetHeight(this.get(HEIGHT));
+        this._uiSetWidth(this.get(WIDTH));
+        this._uiSetHasFocus(this.get(HAS_FOCUS));
+        this._uiSetTabIndex(this.get(TAB_INDEX));
+    },
+
+    /**
+     * Sets the height on the widget's bounding box element
+     * 
+     * @method _uiSetHeight
+     * @protected
+     * @param {String | Number} val
+     */
+    _uiSetHeight: function(val) {
+        if (L.isNumber(val)) {
+            val = val + this.DEF_UNIT;
+        }
+        this.get(BOUNDING_BOX).setStyle(HEIGHT, val);
+    },
+
+    /**
+     * Sets the width on the widget's bounding box element
+     *
+     * @method _uiSetWidth
+     * @protected
+     * @param {String | Number} val
+     */
+    _uiSetWidth: function(val) {
+        if (L.isNumber(val)) {
+            val = val + this.DEF_UNIT;
+        }
+        this.get(BOUNDING_BOX).setStyle(WIDTH, val);
+    },
+
+    /**
+     * Sets the visible state for the UI
+     * 
+     * @method _uiSetVisible
+     * @protected
+     * @param {boolean} val
+     */
+    _uiSetVisible: function(val) {
+
+        var box = this.get(BOUNDING_BOX), 
+            sClassName = this.getClassName(HIDDEN);
+
+        if (val === true) { 
+            box.removeClass(sClassName); 
+        } else {
+            box.addClass(sClassName); 
+        }
+    },
+
+    /**
+     * Sets the disabled state for the UI
+     * 
+     * @protected
+     * @param {boolean} val
+     */
+    _uiSetDisabled: function(val) {
+
+        var box = this.get(BOUNDING_BOX), 
+            sClassName = this.getClassName(DISABLED);
+
+        if (val === true) {
+            box.addClass(sClassName);
+        } else {
+            box.removeClass(sClassName);
+        }
+    },
+
+    /**
+     * Sets the hasFocus state for the UI
+     *
+     * @protected
+     * @param {boolean} val
+     * @param {string} src String representing the source that triggered an update to 
+     * the UI.     
+     */
+    _uiSetHasFocus: function(val, src) {
+
+        var box = this.get(BOUNDING_BOX),
+            sClassName = this.getClassName(FOCUS);
+
+        if (val === true) {
+            box.addClass(sClassName);
+            if (src !== UI) {
+                box.focus();
+            }
+        } else {
+            box.removeClass(sClassName);
+            if (src !== UI) {
+                box.blur();
+            }
+        }
+    },
+
+    /**
+    * Set the tabIndex on the widget's rendered UI
+    *
+    * @method _uiSetTabIndex
+    * @protected
+    * @param Number
+    */
+    _uiSetTabIndex: function(index) {
+        this.get(BOUNDING_BOX).set(TAB_INDEX, index);
+    },
+
+    /**
+     * Default visible attribute state change handler
+     *
+     * @method _afterVisibleChange
+     * @protected
+     * @param {Event.Facade} evt The event facade for the attribute change
+     */
+    _afterVisibleChange: function(evt) {
+        this._uiSetVisible(evt.newVal);
+    },
+
+    /**
+     * Default disabled attribute state change handler
+     * 
+     * @method _afterDisabledChange
+     * @protected
+     * @param {Event.Facade} evt The event facade for the attribute change
+     */
+    _afterDisabledChange: function(evt) {
+        this._uiSetDisabled(evt.newVal);
+    },
+
+    /**
+     * Default height attribute state change handler
+     * 
+     * @method _afterHeightChange
+     * @protected
+     * @param {Event.Facade} evt The event facade for the attribute change
+     */
+    _afterHeightChange: function(evt) {
+        this._uiSetHeight(evt.newVal);
+    },
+
+    /**
+     * Default widget attribute state change handler
+     * 
+     * @method _afterWidthChange
+     * @protected
+     * @param {Event.Facade} evt The event facade for the attribute change
+     */
+    _afterWidthChange: function(evt) {
+        this._uiSetWidth(evt.newVal);
+    },
+
+    /**
+     * Default hasFocus attribute state change handler
+     * 
+     * @method _afterHasFocusChange
+     * @protected
+     * @param {Event.Facade} evt The event facade for the attribute change
+     */
+    _afterHasFocusChange: function(evt) {
+        this._uiSetHasFocus(evt.newVal, evt.src);
+    },
+
+    /**
+     * DOM focus event handler, used to sync the state of the Widget with the DOM
+     * 
+     * @method _onFocus
+     * @protected
+     * @param {Event.Facade} evt The event facade for the DOM focus event
+     */
+    _onFocus: function (evt) {
+        this.set(HAS_FOCUS, true, { src: UI });
+    },
+
+    /**
+     * DOM blur event handler, used to sync the state of the Widget with the DOM
+     *
+     * @method _onBlur
+     * @protected
+     * @param {Event.Facade} evt The event facade for the DOM blur event
+     */			
+    _onBlur: function (evt) {
+        this.set(HAS_FOCUS, false, { src: UI });
+    },
+
+    /**
+     * Generic toString implementation for all widgets.
+     *
+     * @method toString
+     * @return {String} The default string value for the widget [ displays the NAME of the instance, and the unique id ]
+     */
+    toString: function() {
+        return this.constructor.NAME + "[" + this._yuid + "]";
+    },
+
+    /**
+     * Default unit to use for dimension values
+     * 
+     * @property DEF_UNIT
+     */
+    DEF_UNIT : "px",
+
+    /**
+     * Static property defining the markup template for content box.
+     *
+     * @property CONTENT_TEMPLATE
+     * @type String
+     */
+    CONTENT_TEMPLATE : "<div></div>",
+
+    /**
+     * Static property defining the markup template for bounding box.
+     *
+     * @property BOUNDING_TEMPLATE
+     * @type String
+     */
+    BOUNDING_TEMPLATE : "<div></div>",
+
+    /**
+     * Static property listing the styles that are mimiced on the bounding box from the content box.
+     *
+     * @property WRAP_STYLES
+     * @type Object
+     */
+    WRAP_STYLES : {
+        height: '100%',
+        width: '100%',
+        zIndex: false,
+        position: 'static',
+        top: '0',
+        left: '0',
+        bottom: '',
+        right: '',
+        padding: '',
+        margin: ''
+    },
+
+    /**
+     * Sets strings for a particular locale, merging with any existing
+     * strings which may already be defined for the locale.
+     *
+     * @method _setStrings
+     * @protected
+     * @param {Object} strings The hash of string key/values to set
+     * @param {Object} locale The locale for the string values being set
+     */
+    _setStrings : function(strings, locale) {
+        var strs = this._strings;
+        locale = locale.toLowerCase();
+
+        if (!strs[locale]) {
+            strs[locale] = {};
+        }
+
+        Y.aggregate(strs[locale], strings, true);
+        return strs[locale];
+    },
+
+    /**
+     * Returns the strings key/value hash for a paricular locale, without locale lookup applied.
+     *
+     * @method _getStrings
+     * @protected
+     * @param {Object} locale
+     */
+    _getStrings : function(locale) {
+        return this._strings[locale.toLowerCase()];
+    },
+
+    /**
+     * Gets the entire strings hash for a particular locale, performing locale lookup.
+     * <p>
+     * If no values of the key are defined for a particular locale the value for the 
+     * default locale (in initial locale set for the class) is returned.
+     * </p>
+     * @method getStrings
+     * @param {String} locale (optional) The locale for which the string value is required. Defaults to the current locale, if not provided.
+     */
+    // TODO: Optimize/Cache. Clear cache on _setStrings call.
+    getStrings : function(locale) {
+
+        locale = (locale || this.get(LOCALE)).toLowerCase();
+
+        Y.log("getStrings: For " + locale, "info", "widget"); 
+
+        var defLocale = this.getDefaultLocale().toLowerCase(),
+            defStrs = this._getStrings(defLocale),
+            strs = (defStrs) ? Y.merge(defStrs) : {},
+            localeSegments = locale.split(HYPHEN);
+
+        // If locale is different than the default, or needs lookup support
+        if (locale !== defLocale || localeSegments.length > 1) {
+            var lookup = "";
+            for (var i = 0, l = localeSegments.length; i < l; ++i) {
+                lookup += localeSegments[i];
+
+                Y.log("getStrings: Merging in strings from: " + lookup, "info", "widget"); 
+
+                var localeStrs = this._getStrings(lookup);
+                if (localeStrs) {
+                    Y.aggregate(strs, localeStrs, true);
+                }
+                lookup += HYPHEN;
+            }
+        }
+
+        return strs;
+    },
+
+    /**
+     * Gets the string for a particular key, for a particular locale, performing locale lookup.
+     * <p>
+     * If no values if defined for the key, for the given locale, the value for the 
+     * default locale (in initial locale set for the class) is returned.
+     * </p>
+     * @method getString
+     * @param {String} key The key.
+     * @param {String} locale (optional) The locale for which the string value is required. Defaults to the current locale, if not provided.
+     */
+    getString : function(key, locale) {
+
+        locale = (locale || this.get(LOCALE)).toLowerCase();
+
+        Y.log("getString: For " + locale, "info", "widget"); 
+
+        var defLocale = (this.getDefaultLocale()).toLowerCase(),
+            strs = this._getStrings(defLocale) || {},
+            str = strs[key],
+            idx = locale.lastIndexOf(HYPHEN);
+
+        // If locale is different than the default, or needs lookup support
+        if (locale !== defLocale || idx != -1) {
+            do {
+                Y.log("getString: Performing lookup for: " + locale, "info", "widget"); 
+
+                strs = this._getStrings(locale);
+                if (strs && key in strs) {
+                    str = strs[key];
+                    break;
+                }
+                idx = locale.lastIndexOf(HYPHEN);
+                // Chop of last locale segment
+                if (idx != -1) {
+                    locale = locale.substring(0, idx);
+                }
+
+            } while (idx != -1);
+        }
+
+        return str;
+    },
+
+    /**
+     * Returns the default locale for the widget (the locale value defined by the
+     * widget class, or provided by the user during construction).
+     *
+     * @method getDefaultLocale
+     * @return {String} The default locale for the widget
+     */
+    getDefaultLocale : function() {
+        return this._conf.get(LOCALE, INIT_VALUE);
+    },
+
+    /**
+     * Private stings hash, used to store strings in locale specific buckets.
+     *
+     * @property _strings
+     * @private
+     * @type Object
+     */
+    _strings: null,
+
+    /**
+     * Gets the HTML_PARSER definition for this instance, by merging HTML_PARSER
+     * definitions across the class hierarchy.
+     *
+     * @method _getHtmlParser
+     * @return {Object} HTML_PARSER definition for this instance
+     */
+    _getHtmlParser : function() {
+        if (!this._HTML_PARSER) {
+            var classes = this._getClasses(),
+                parser = {};
+
+            for (var i = 0, l = classes.length; i < l; i++) {
+                var p = classes[i].HTML_PARSER;
+                if (p) {
+                    Y.mix(parser, p, true);
+                }
+            }
+
+            this._HTML_PARSER = parser;
+        }
+
+        return this._HTML_PARSER;
+    }
+});
+
+/**
+ * Static registration of default plugins for the class.
+ * 
+ * @property Widget.PLUGINS
+ * @static
+ */
+Widget.PLUGINS = [];
+
+Y.mix(Widget, Y.PluginHost, false, null, 1); // straightup augment, no wrapper functions
+
+Y.Widget = Widget;
+
+
+
+}, '3.0.0pr2' ,{requires:['base', 'node', 'classnamemanager']});

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-min.js'
--- loggerhead/static/javascript/yui/build/widget/widget-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("widget",function(F){var T=F.Lang;function k(L){this._plugins={};this.after("init",function(Y,O){this._initPlugins(O);});this.after("destroy",this._destroyPlugins);}k.prototype={plug:function(Y){if(Y){if(T.isArray(Y)){var O=Y.length;for(var L=0;L<O;L++){this.plug(Y[L]);}}else{if(T.isFunction(Y)){this._plug(Y);}else{this._plug(Y.fn,Y.cfg);}}}return this;},unplug:function(L){if(L){this._unplug(L);}else{for(L in this._plugins){if(F.Object.owns(this._plugins,L)){this._unplug(L);}}}return this;},hasPlugin:function(L){return(this._plugins[L]&&this[L]);},_initPlugins:function(L){var Y=this._getClasses(),m;for(var O=0;O<Y.length;O++){m=Y[O];if(m.PLUGINS){this.plug(m.PLUGINS);}}if(L&&L.plugins){this.plug(L.plugins);}},_destroyPlugins:function(){this._unplug();},_plug:function(Y,L){if(Y&&Y.NS){var O=Y.NS;L=L||{};L.owner=this;if(this.hasPlugin(O)){this[O].setAtts(L);}else{this[O]=new Y(L);this._plugins[O]=Y;}}},_unplug:function(L){if(L){if(this[L]){this[L].destroy();delete this[L];}if(this._plugins[L]){delete this._plugins[L];}}}};F.PluginHost=k;var c="widget",P="content",e="visible",g="hidden",h="disabled",H="focus",D="blur",A="hasFocus",J="width",a="height",l="",b="-",j="boundingBox",W="contentBox",S="parentNode",C="firstChild",d="ownerDocument",f="body",E="tabIndex",I="locale",K="initValue",U="id",V="render",B="rendered",Z="destroyed",N="contentUpdate",M=F.Object,i=F.Node,Q=F.ClassNameManager;var X={};function G(L){this._yuid=F.guid(c);this._strings={};G.superclass.constructor.apply(this,arguments);}G._buildCfg={aggregates:["PLUGINS","HTML_PARSER"]};G.NAME=c;G.UI_SRC="ui";var R=G.UI_SRC;G.ATTRS={rendered:{value:false,readOnly:true},boundingBox:{value:null,set:function(L){return this._setBoundingBox(L);},writeOnce:true},contentBox:{value:null,set:function(L){return this._setContentBox(L);},writeOnce:true},tabIndex:{value:0},hasFocus:{value:false},disabled:{value:false},visible:{value:true},height:{value:l},width:{value:l},moveStyles:{value:false},locale:{value:"en"},strings:{set:function(L){return this._setStrings(L,this.get(I));},get:function(){return this.getStrings(this.get(I));}}};G._NAME_LOWERCASE=G.NAME.toLowerCase();G.getClassName=function(){var L=F.Array(arguments,0,true);L.splice(0,0,this._NAME_LOWERCASE);return Q.getClassName.apply(Q,L);};G.getByNode=function(L){var O,Y=G.getClassName();L=i.get(L);if(L){L=(L.hasClass(Y))?L:L.ancestor("."+Y);if(L){O=X[L.get(U)];}}return O||null;};G.HTML_PARSER={};F.extend(G,F.Base,{getClassName:function(){var L=F.Array(arguments,0,true);L.splice(0,0,this._name);return Q.getClassName.apply(Q,L);},initializer:function(L){this.publish(N,{preventable:false});this._name=this.constructor.NAME.toLowerCase();var Y=this.get(j).get(U);if(Y){X[Y]=this;}var O=this._parseHTML(this.get(W));if(O){F.aggregate(L,O,false);}F.PluginHost.call(this,L);},destructor:function(){var L=this.get(j);F.Event.purgeElement(L,true);var O=L.get(U);if(O&&O in X){delete X[O];}},render:function(L){if(this.get(Z)){return;}if(!this.get(B)){this.publish(V,{queuable:false,defaultFn:this._defRenderFn});L=(L)?i.get(L):null;if(L&&!L.inDoc()){L=null;}this.fire(V,null,L);}return this;},_defRenderFn:function(O,L){this._renderUI(L);this._bindUI();this._syncUI();this.renderer();this._set(B,true);},renderer:function(){this.renderUI();this.bindUI();this.syncUI();},bindUI:function(){},renderUI:function(){},syncUI:function(){},hide:function(){return this.set(e,false);},show:function(){return this.set(e,true);},focus:function(){return this.set(A,true);},blur:function(){return this.set(A,false);},enable:function(){return this.set(h,false);},disable:function(){return this.set(h,true);},_parseHTML:function(O){var L=this._getHtmlParser(),Y,m;if(L&&O&&O.hasChildNodes()){M.each(L,function(p,n,q){m=null;if(T.isFunction(p)){m=p.call(this,O);}else{if(T.isArray(p)){m=O.queryAll(p[0]);}else{m=O.query(p);}}if(m!==null&&m!==undefined){Y=Y||{};Y[n]=m;}},this);}return Y;},_moveStyles:function(n,p){var m=this.WRAP_STYLES,q=n.getStyle("position"),O=this.get(W),o=[0,0],Y,L;if(!this.get("height")){Y=O.get("offsetHeight");}if(!this.get("width")){L=O.get("offsetWidth");}if(q==="absolute"){o=n.getXY();p.setStyles({right:"auto",bottom:"auto"});n.setStyles({right:"auto",bottom:"auto"});}F.each(m,function(t,r){var u=n.getStyle(r);p.setStyle(r,u);if(t===false){n.setStyle(r,"");}else{n.setStyle(r,t);}});if(q==="absolute"){p.setXY(o);}if(Y){this.set("height",Y);}if(L){this.set("width",L);}},_renderBox:function(O){var Y=this.get(W),m=this.get(j),n=m.get(d)||Y.get(d),L;if(!m.compareTo(Y.get(S))){if(this.get("moveStyles")){this._moveStyles(Y,m);}if(Y.inDoc(n)){Y.get(S).replaceChild(m,Y);}m.appendChild(Y);}if(!m.inDoc(n)&&!O){L=i.get(f);if(L.get(C)){L.insertBefore(m,L.get(C));}else{L.appendChild(m);}}else{if(O&&!O.compareTo(m.get(S))){O.appendChild(m);}}},_setBoundingBox:function(L){return this._setBox(L,this.BOUNDING_TEMPLATE);},_setContentBox:function(L){return this._setBox(L,this.CONTENT_TEMPLATE);},_setBox:function(Y,O){Y=i.get(Y)||i.create(O);var L=F.stamp(Y);if(!Y.get(U)){Y.set(U,L);}return Y;},_renderUI:function(L){this._renderBoxClassNames();this._renderBox(L);},_renderBoxClassNames:function(){var o=this._getClasses(),m=this.get(j),O=this.get(W),Y;m.addClass(G.getClassName());for(var n=2,L=o.length;n<L;++n){Y=o[n].NAME;if(Y){m.addClass(Q.getClassName(Y.toLowerCase()));}}O.addClass(this.getClassName(P));},_bindUI:function(){this.after("visibleChange",this._afterVisibleChange);this.after("disabledChange",this._afterDisabledChange);this.after("heightChange",this._afterHeightChange);this.after("widthChange",this._afterWidthChange);this.after("hasFocusChange",this._afterHasFocusChange);this._bindDOMListeners();},_bindDOMListeners:function(){this.get(j).on(H,F.bind(this._onFocus,this));this.get(j).on(D,F.bind(this._onBlur,this));},_syncUI:function(){this._uiSetVisible(this.get(e));this._uiSetDisabled(this.get(h));this._uiSetHeight(this.get(a));this._uiSetWidth(this.get(J));this._uiSetHasFocus(this.get(A));this._uiSetTabIndex(this.get(E));
+},_uiSetHeight:function(L){if(T.isNumber(L)){L=L+this.DEF_UNIT;}this.get(j).setStyle(a,L);},_uiSetWidth:function(L){if(T.isNumber(L)){L=L+this.DEF_UNIT;}this.get(j).setStyle(J,L);},_uiSetVisible:function(Y){var O=this.get(j),L=this.getClassName(g);if(Y===true){O.removeClass(L);}else{O.addClass(L);}},_uiSetDisabled:function(Y){var O=this.get(j),L=this.getClassName(h);if(Y===true){O.addClass(L);}else{O.removeClass(L);}},_uiSetHasFocus:function(m,Y){var O=this.get(j),L=this.getClassName(H);if(m===true){O.addClass(L);if(Y!==R){O.focus();}}else{O.removeClass(L);if(Y!==R){O.blur();}}},_uiSetTabIndex:function(L){this.get(j).set(E,L);},_afterVisibleChange:function(L){this._uiSetVisible(L.newVal);},_afterDisabledChange:function(L){this._uiSetDisabled(L.newVal);},_afterHeightChange:function(L){this._uiSetHeight(L.newVal);},_afterWidthChange:function(L){this._uiSetWidth(L.newVal);},_afterHasFocusChange:function(L){this._uiSetHasFocus(L.newVal,L.src);},_onFocus:function(L){this.set(A,true,{src:R});},_onBlur:function(L){this.set(A,false,{src:R});},toString:function(){return this.constructor.NAME+"["+this._yuid+"]";},DEF_UNIT:"px",CONTENT_TEMPLATE:"<div></div>",BOUNDING_TEMPLATE:"<div></div>",WRAP_STYLES:{height:"100%",width:"100%",zIndex:false,position:"static",top:"0",left:"0",bottom:"",right:"",padding:"",margin:""},_setStrings:function(O,L){var Y=this._strings;L=L.toLowerCase();if(!Y[L]){Y[L]={};}F.aggregate(Y[L],O,true);return Y[L];},_getStrings:function(L){return this._strings[L.toLowerCase()];},getStrings:function(r){r=(r||this.get(I)).toLowerCase();var p=this.getDefaultLocale().toLowerCase(),O=this._getStrings(p),q=(O)?F.merge(O):{},o=r.split(b);if(r!==p||o.length>1){var L="";for(var m=0,Y=o.length;m<Y;++m){L+=o[m];var n=this._getStrings(L);if(n){F.aggregate(q,n,true);}L+=b;}}return q;},getString:function(Y,O){O=(O||this.get(I)).toLowerCase();var m=(this.getDefaultLocale()).toLowerCase(),n=this._getStrings(m)||{},o=n[Y],L=O.lastIndexOf(b);if(O!==m||L!=-1){do{n=this._getStrings(O);if(n&&Y in n){o=n[Y];break;}L=O.lastIndexOf(b);if(L!=-1){O=O.substring(0,L);}}while(L!=-1);}return o;},getDefaultLocale:function(){return this._conf.get(I,K);},_strings:null,_getHtmlParser:function(){if(!this._HTML_PARSER){var Y=this._getClasses(),n={};for(var O=0,L=Y.length;O<L;O++){var m=Y[O].HTML_PARSER;if(m){F.mix(n,m,true);}}this._HTML_PARSER=n;}return this._HTML_PARSER;}});G.PLUGINS=[];F.mix(G,F.PluginHost,false,null,1);F.Widget=G;},"3.0.0pr2",{requires:["base","node","classnamemanager"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-position-debug.js'
--- loggerhead/static/javascript/yui/build/widget/widget-position-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-position-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,269 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('widget-position', function(Y) {
+
+/**
+ * Provides basic XY positioning support for Widgets, though an extension
+ *
+ * @module widget-position
+ */
+    var Lang = Y.Lang,
+        Widget = Y.Widget,
+
+        XY_COORD = "xy",
+
+        POSITIONED = "positioned",
+        BOUNDING_BOX = "boundingBox",
+
+        RENDERUI = "renderUI",
+        BINDUI = "bindUI",
+        SYNCUI = "syncUI",
+
+        UI = Widget.UI_SRC,
+
+        XYChange = "xyChange";
+
+    /**
+     * Widget extension, which can be used to add positioning support to the base Widget class, 
+     * through the <a href="Base.html#method_build">Base.build</a> method.
+     *
+     * @class WidgetPosition
+     * @param {Object} config User configuration object
+     */
+    function Position(config) {
+        this._posNode = this.get(BOUNDING_BOX);
+
+        // WIDGET METHOD OVERLAP
+        Y.after(this._renderUIPosition, this, RENDERUI);
+        Y.after(this._syncUIPosition, this, SYNCUI);
+        Y.after(this._bindUIPosition, this, BINDUI);
+    }
+
+    /**
+     * Static property used to define the default attribute 
+     * configuration introduced by WidgetPosition.
+     * 
+     * @property WidgetPosition.ATTRS
+     * @static
+     * @type Object
+     */
+    Position.ATTRS = {
+
+        /**
+         * @attribute x
+         * @type number
+         * @default 0
+         *
+         * @description Page X co-ordinate for the widget. This attribute acts as a facade for the 
+         * xy attribute. Changes in position can be monitored by listening for xyChange events.
+         */
+        x: {
+            set: function(val) {
+                this._setX(val);
+            },
+            get: function() {
+                return this._getX();
+            }
+        },
+
+        /**
+         * @attribute y
+         * @type number
+         * @default 0
+         *
+         * @description Page Y co-ordinate for the widget. This attribute acts as a facade for the 
+         * xy attribute. Changes in position can be monitored by listening for xyChange events.
+         */
+        y: {
+            set: function(val) {
+                this._setY(val);
+            },
+            get: function() {
+                return this._getY();
+            }
+        },
+
+        /**
+         * @attribute xy
+         * @type Array
+         * @default [0,0]
+         *
+         * @description Page XY co-ordinate pair for the widget.
+         */
+        xy: {
+            value:[0,0],
+            validator: function(val) {
+                return this._validateXY(val);
+            }
+        }
+    };
+
+    /**
+     * Default class used to mark the boundingBox of a positioned widget.
+     *
+     * @property WidgetPosition.POSITIONED_CLASS_NAME
+     * @type String
+     * @default "yui-widget-positioned"
+     * @static
+     */
+    Position.POSITIONED_CLASS_NAME = Widget.getClassName(POSITIONED);
+
+    Position.prototype = {
+
+        /**
+         * Creates/Initializes the DOM to support xy page positioning.
+         * <p>
+         * This method in invoked after renderUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _renderUIPosition
+         * @protected
+         */
+        _renderUIPosition : function() {
+            this._posNode.addClass(Position.POSITIONED_CLASS_NAME);
+        },
+
+        /**
+         * Synchronizes the UI to match the Widgets xy page position state.
+         * <p>
+         * This method in invoked after syncUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _syncUIPosition
+         * @protected
+         */
+        _syncUIPosition : function() {
+            this._uiSetXY(this.get(XY_COORD));
+        },
+
+        /**
+         * Binds event listeners responsible for updating the UI state in response to 
+         * Widget position related state changes.
+         * <p>
+         * This method in invoked after bindUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _bindUIPosition
+         * @protected
+         */
+        _bindUIPosition :function() {
+            this.after(XYChange, this._afterXYChange);
+        },
+
+        /**
+         * Moves the Widget to the specified page xy co-ordinate position.
+         *
+         * @method move
+         *
+         * @param {Number} x The new x position
+         * @param {Number} y The new y position
+         * <p>Or</p>
+         * @param {Array} x, y values passed as an array ([x, y]), to support
+         * simple pass through of Node.getXY results
+         */
+        move: function () {
+            var args = arguments,
+                coord = (Lang.isArray(args[0])) ? args[0] : [args[0], args[1]];
+                this.set(XY_COORD, coord);
+        },
+
+        /**
+         * Synchronizes the Panel's "xy", "x", and "y" properties with the 
+         * Widget's position in the DOM.
+         *
+         * @method syncXY
+         */
+        syncXY : function () {
+            this.set(XY_COORD, this._posNode.getXY(), {src: UI});
+        },
+
+        /**
+         * Default validator for the XY attribute
+         *
+         * @method _validateXY
+         * @param {Array} val The XY page co-ordinate value which is being set.
+         * @return {boolean} true if valid, false if not.
+         */
+        _validateXY : function(val) {
+            return (Lang.isArray(val) && Lang.isNumber(val[0]) && Lang.isNumber(val[1]));
+        },
+
+        /**
+         * Default setter for the X attribute. The setter passes the X value through
+         * to the XY attribute, which is the sole store for the XY state.
+         *
+         * @method _setX
+         * @param {Number} val The X page co-ordinate value
+         */
+        _setX : function(val) {
+            this.set(XY_COORD, [val, this.get(XY_COORD)[0]]);
+        },
+
+        /**
+         * Default setter for the Y attribute. The setter passes the Y value through
+         * to the XY attribute, which is the sole store for the XY state.
+         *
+         * @method _setY
+         * @param {Number} val The Y page co-ordinate value
+         */
+        _setY : function(val) {
+            this.set(XY_COORD, [this.get(XY_COORD)[1], val]);
+        },
+
+        /**
+         * Default getter for the X attribute. The value is retrieved from 
+         * the XY attribute, which is the sole store for the XY state.
+         *
+         * @method _getX
+         * @return {Number} The X page co-ordinate value
+         */
+        _getX : function() {
+            return this.get(XY_COORD)[0];
+        },
+
+        /**
+         * Default getter for the Y attribute. The value is retrieved from 
+         * the XY attribute, which is the sole store for the XY state.
+         *
+         * @method _getY
+         * @return {Number} The Y page co-ordinate value
+         */
+        _getY : function() {
+            return this.get(XY_COORD)[1];
+        },
+
+        /**
+         * Default attribute change listener for the xy attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         * 
+         * @method _afterXYChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterXYChange : function(e) {
+            if (e.src != UI) {
+                this._uiSetXY(e.newVal);
+            }
+        },
+
+        /**
+         * Updates the UI to reflect the XY page co-ordinates passed in.
+         * 
+         * @method _uiSetXY
+         * @protected
+         * @param {String} val The XY page co-ordinates value to be reflected in the UI
+         */
+        _uiSetXY : function(val) {
+            this._posNode.setXY(val);
+        }
+    };
+
+    Y.WidgetPosition = Position;
+
+
+
+}, '3.0.0pr2' ,{requires:['widget']});

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-position-ext-debug.js'
--- loggerhead/static/javascript/yui/build/widget/widget-position-ext-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-position-ext-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,403 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('widget-position-ext', function(Y) {
+
+/**
+ * Provides extended/advanced XY positioning support for Widgets, through an extension.
+ *
+ * It builds on top of the widget-position module, to provide alignmentment and centering support.
+ * Future releases aim to add constrained and fixed positioning support.
+ *
+ * @module widget-position-ext
+ */
+        var L = Y.Lang,
+            ALIGN = "align",
+
+            BINDUI = "bindUI",
+            SYNCUI = "syncUI",
+
+            OFFSET_WIDTH = "offsetWidth",
+            OFFSET_HEIGHT = "offsetHeight",
+            VIEWPORT_REGION = "viewportRegion",
+            REGION = "region",
+
+            AlignChange = "alignChange";
+
+        /**
+         * Widget extension, which can be used to add extended XY positioning support to the base Widget class,
+         * through the <a href="Base.html#method_build">Base.build</a> method.
+         *
+         * @class WidgetPositionExt
+         * @param {Object} User configuration object
+         */
+        function PositionExt(config) {
+            Y.after(this._syncUIPosExtras, this, SYNCUI);
+            Y.after(this._bindUIPosExtras, this, BINDUI);
+        }
+
+        /**
+         * Static property used to define the default attribute 
+         * configuration introduced by WidgetPositionExt.
+         * 
+         * @property WidgetPositionExt.ATTRS
+         * @type Object
+         * @static
+         */
+        PositionExt.ATTRS = {
+
+            /**
+             * @attribute align
+             * @type Object
+             * @default null
+             * @desciption The align attribute is used to align a reference point on the widget, with the refernce point on another node, or the viewport. 
+             * The object which align expects has the following properties:
+             * <dl>
+             *       <dt>node</dt>
+             *       <dd>
+             *         The node to which the Widget is to be aligned. If set to null, or not provided, the Widget is aligned to the viewport
+             *       </dd>
+             *       <dt>points</dt>
+             *       <dd>
+             *         <p>
+             *         A two element array, defining the two points on the Widget and node/viewport which are to be aligned. The first element is the point on the Widget, and the second element is the point on the node/viewport.
+             *         Supported alignment points are defined as static properties on <code>WidgetPositionExt</code>.
+             *         </p>
+             *         <p>
+             *         e.g. <code>[WidgetPositionExt.TR, WidgetPositionExt.TL]</code> aligns the Top-Right corner of the Widget with the
+             *         Top-Left corner of the node/viewport, and <code>[WidgetPositionExt.CC, WidgetPositionExt.TC]</code> aligns the Center of the 
+             *         Widget with the Top-Center edge of the node/viewport.
+             *         </p>
+             *       </dd>
+             *   </dl>
+             */
+            align: {
+                value:null
+            },
+
+            /**
+             * @attribute centered
+             * @type {boolean | node} 
+             * @default false
+             * @description A convenience attribute, which can be used as a shortcut for the align attribute.
+             * If set to true, the Widget is centered in the viewport. If set to a node reference or valid selector string,
+             * the Widget will be centered within the node. If set the false, no center positioning is applied.
+             */
+            centered: {
+                set: function(val) {
+                    return this._setAlignCenter(val);
+                },
+                value:false
+            }
+        };
+
+        /**
+         * Constant used to specify the top-left corner for alignment
+         * 
+         * @property WidgetPositionExt.TL
+         * @type String
+         * @static
+         * @value "tl"
+         */
+        PositionExt.TL = "tl";
+        /**
+         * Constant used to specify the top-right corner for alignment
+         * 
+         * @property WidgetPositionExt.TR
+         * @type String
+         * @static
+         * @value "tr"
+         */
+        PositionExt.TR = "tr";
+        /**
+         * Constant used to specify the bottom-left corner for alignment
+         * 
+         * @property WidgetPositionExt.BL
+         * @type String
+         * @static
+         * @value "bl"
+         */
+        PositionExt.BL = "bl";
+        /**
+         * Constant used to specify the bottom-right corner for alignment
+         * 
+         * @property WidgetPositionExt.BR
+         * @type String
+         * @static
+         * @value "br"
+         */
+        PositionExt.BR = "br";
+        /**
+         * Constant used to specify the top edge-center point for alignment
+         * 
+         * @property WidgetPositionExt.TC
+         * @type String
+         * @static
+         * @value "tc"
+         */
+        PositionExt.TC = "tc";
+        /**
+         * Constant used to specify the right edge, center point for alignment
+         * 
+         * @property WidgetPositionExt.RC
+         * @type String
+         * @static
+         * @value "rc"
+         */
+        PositionExt.RC = "rc";
+        /**
+         * Constant used to specify the bottom edge, center point for alignment
+         * 
+         * @property WidgetPositionExt.BC
+         * @type String
+         * @static
+         * @value "bc"
+         */
+        PositionExt.BC = "bc";
+        /**
+         * Constant used to specify the left edge, center point for alignment
+         * 
+         * @property WidgetPositionExt.LC
+         * @type String
+         * @static
+         * @value "lc"
+         */
+        PositionExt.LC = "lc";
+        /**
+         * Constant used to specify the center of widget/node/viewport for alignment
+         * 
+         * @property WidgetPositionExt.CC
+         * @type String
+         * @static
+         * @value "cc"
+         */
+        PositionExt.CC = "cc";
+
+        PositionExt.prototype = {
+
+            /**
+             * Synchronizes the UI to match the Widgets extended positioning state.
+             * This method in invoked after syncUI is invoked for the Widget class
+             * using YUI's aop infrastructure.
+             *
+             * @method _syncUIPosExtras
+             * @protected
+             */
+            _syncUIPosExtras : function() {
+                var align = this.get(ALIGN);
+                if (align) {
+                    this._uiSetAlign(align.node, align.points);
+                }
+            },
+
+            /**
+             * Binds event listeners responsible for updating the UI state in response to 
+             * Widget extended positioning related state changes.
+             * <p>
+             * This method is invoked after bindUI is invoked for the Widget class
+             * using YUI's aop infrastructure.
+             * </p>
+             * @method _bindUIStack
+             * @protected
+             */
+            _bindUIPosExtras : function() {
+                this.after(AlignChange, this._afterAlignChange);
+            },
+
+            /**
+             * Default setter for center attribute changes. Sets up the appropriate value, and passes 
+             * it through the to the align attribute.
+             *
+             * @method _setAlignCenter
+             * @protected
+             * @param {boolean | node} The attribute value being set. 
+             * @return {Number} The attribute value being set.
+             */
+            _setAlignCenter : function(val) {
+                if (val) {
+                    this.set(ALIGN, {
+                        node: val === true ? null : val,
+                        points: [PositionExt.CC, PositionExt.CC]
+                    });
+                }
+                return val;
+            },
+
+            /**
+             * Default attribute change listener for the align attribute, responsible
+             * for updating the UI, in response to attribute changes.
+             * 
+             * @method _afterAlignChange
+             * @protected
+             * @param {Event.Facade} e The event facade for the attribute change
+             */
+            _afterAlignChange : function(e) {
+                if (e.newVal) {
+                    this._uiSetAlign(e.newVal.node, e.newVal.points);
+                }
+            },
+
+            /**
+             * Updates the UI to reflect the align value passed in (see the align attribute documentation, for the object stucture expected)
+             * @method _uiSetAlign
+             * @protected
+             * @param {Node | null} The node to align to, or null to indicate the viewport
+             */
+            _uiSetAlign: function (node, points) {
+
+                if (!L.isArray(points) || points.length != 2) {
+                    Y.fail("align: Invalid Points Arguments");
+                    return;
+                }
+
+                var nodeRegion, widgetPoint, nodePoint, xy;
+
+                if (!node) {
+                    nodeRegion = this._posNode.get(VIEWPORT_REGION);
+                } else {
+                    node = Y.Node.get(node);
+                    if (node) {
+                        nodeRegion = node.get(REGION);
+                    }
+                }
+
+                if (nodeRegion) {
+
+                    // TODO: ViewportRegion doesn't have width/height - Workaround until normalized in Node/Dom
+                    nodeRegion.width = nodeRegion.width || nodeRegion.right - nodeRegion.left;
+                    nodeRegion.height = nodeRegion.height || nodeRegion.bottom - nodeRegion.top;
+
+                    widgetPoint = points[0];
+                    nodePoint = points[1];
+
+                    // TODO: Optimize KWeight - Would lookup table help?
+                    switch (nodePoint) {
+                        case PositionExt.TL:
+                            xy = [nodeRegion.left, nodeRegion.top];
+                            break;
+                        case PositionExt.TR:
+                            xy = [nodeRegion.right, nodeRegion.top];
+                            break;
+                        case PositionExt.BL:
+                            xy = [nodeRegion.left, nodeRegion.bottom];
+                            break;
+                        case PositionExt.BR:
+                            xy = [nodeRegion.right, nodeRegion.bottom];
+                            break;
+                        case PositionExt.TC:
+                            xy = [nodeRegion.left + Math.floor(nodeRegion.width/2), nodeRegion.top];
+                            break;
+                        case PositionExt.BC:
+                            xy = [nodeRegion.left + Math.floor(nodeRegion.width/2), nodeRegion.bottom];
+                            break;
+                        case PositionExt.LC:
+                            xy = [nodeRegion.left, nodeRegion.top + Math.floor(nodeRegion.height/2)];
+                            break;
+                        case PositionExt.RC:
+                            xy = [nodeRegion.right, nodeRegion.top + Math.floor(nodeRegion.height/2), widgetPoint];
+                            break;
+                        case PositionExt.CC:
+                            xy = [nodeRegion.left + Math.floor(nodeRegion.width/2), nodeRegion.top + Math.floor(nodeRegion.height/2), widgetPoint];
+                            break;
+                        default:
+                            Y.log("align: Invalid Points Arguments", "info", "widget-position-extras");
+                            break;
+                    }
+
+                    if (xy) {
+                        this._doAlign(widgetPoint, xy[0], xy[1]);
+                    }
+                }
+            },
+
+            /**
+             * Helper method, used to align the given point on the widget, with the XY page co-ordinates provided.
+             *
+             * @method _doAlign
+             * @private
+             * @param {String} widgetPoint Supported point constant (e.g. WidgetPositionExt.TL)
+             * @param {Number} x X page co-ordinate to align to
+             * @param {Number} y Y page co-ordinate to align to
+             */
+            _doAlign : function(widgetPoint, x, y) {
+                var widgetNode = this._posNode,
+                    xy;
+
+                switch (widgetPoint) {
+                    case PositionExt.TL:
+                        xy = [x, y];
+                        break;
+                    case PositionExt.TR:
+                        xy = [x - widgetNode.get(OFFSET_WIDTH), y];
+                        break;
+                    case PositionExt.BL:
+                        xy = [x, y - widgetNode.get(OFFSET_HEIGHT)];
+                        break;
+                    case PositionExt.BR:
+                        xy = [x - widgetNode.get(OFFSET_WIDTH), y - widgetNode.get(OFFSET_HEIGHT)];
+                        break;
+                    case PositionExt.TC:
+                        xy = [x - (widgetNode.get(OFFSET_WIDTH)/2), y];
+                        break;
+                    case PositionExt.BC:
+                        xy = [x - (widgetNode.get(OFFSET_WIDTH)/2), y - widgetNode.get(OFFSET_HEIGHT)];
+                        break;
+                    case PositionExt.LC:
+                        xy = [x, y - (widgetNode.get(OFFSET_HEIGHT)/2)];
+                        break;
+                    case PositionExt.RC:
+                        xy = [(x - widgetNode.get(OFFSET_WIDTH)), y - (widgetNode.get(OFFSET_HEIGHT)/2)];
+                        break;
+                    case PositionExt.CC:
+                        xy = [x - (widgetNode.get(OFFSET_WIDTH)/2), y - (widgetNode.get(OFFSET_HEIGHT)/2)];
+                        break;
+                    default:
+                        Y.log("align: Invalid Points Argument", "info", "widget-position-extras");
+                        break;
+                }
+
+                if (xy) {
+                    this.move(xy);
+                }
+            },
+
+            /**
+             * Aligns the Widget to the provided node (or viewport) using the provided
+             * points. The method can be invoked directly, however it will result in 
+             * the align attribute being out of sync with current position of the of Widget.
+             * 
+             * @method align
+             * @param {Node | String | null} node A reference (or selector string) for the Node which with the Widget is to be aligned.
+             * If null is passed in, the Widget will be aligned with the viewport.
+             * @param {Array[2]} points A two element array, specifying the points on the Widget and node/viewport which need to be aligned. 
+             * The first entry is the point on the Widget, and the second entry is the point on the node/viewport which need to align.
+             * Valid point references are defined as static constants on the WidgetPositionExt class. 
+             * 
+             * e.g. [WidgetPositionExt.TL, WidgetPositionExt.TR] will align the top-left corner of the Widget with the top-right corner of the node/viewport.
+             */
+            align: function (node, points) {
+                this.set(ALIGN, {node: node, points:points});
+            },
+
+            /**
+             * Centers the container in the viewport, or if a node is passed in,
+             * the node.
+             *
+             * @method centered
+             * @param {Node | String} node Optional. A node reference or selector string defining the node 
+             * inside which the Widget is to be centered. If not passed in, the Widget will be centered in the 
+             * viewport.
+             */
+            centered: function (node) {
+                this.align(node, [PositionExt.CC, PositionExt.CC]);
+            }
+        };
+
+        Y.WidgetPositionExt = PositionExt;
+
+
+
+}, '3.0.0pr2' ,{requires:['widget', 'widget-position']});

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-position-ext-min.js'
--- loggerhead/static/javascript/yui/build/widget/widget-position-ext-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-position-ext-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("widget-position-ext",function(A){var H=A.Lang,C="align",E="bindUI",B="syncUI",D="offsetWidth",I="offsetHeight",K="viewportRegion",G="region",J="alignChange";function F(L){A.after(this._syncUIPosExtras,this,B);A.after(this._bindUIPosExtras,this,E);}F.ATTRS={align:{value:null},centered:{set:function(L){return this._setAlignCenter(L);},value:false}};F.TL="tl";F.TR="tr";F.BL="bl";F.BR="br";F.TC="tc";F.RC="rc";F.BC="bc";F.LC="lc";F.CC="cc";F.prototype={_syncUIPosExtras:function(){var L=this.get(C);if(L){this._uiSetAlign(L.node,L.points);}},_bindUIPosExtras:function(){this.after(J,this._afterAlignChange);},_setAlignCenter:function(L){if(L){this.set(C,{node:L===true?null:L,points:[F.CC,F.CC]});}return L;},_afterAlignChange:function(L){if(L.newVal){this._uiSetAlign(L.newVal.node,L.newVal.points);}},_uiSetAlign:function(O,N){if(!H.isArray(N)||N.length!=2){A.fail("align: Invalid Points Arguments");return;}var M,L,P,Q;if(!O){M=this._posNode.get(K);}else{O=A.Node.get(O);if(O){M=O.get(G);}}if(M){M.width=M.width||M.right-M.left;M.height=M.height||M.bottom-M.top;L=N[0];P=N[1];switch(P){case F.TL:Q=[M.left,M.top];break;case F.TR:Q=[M.right,M.top];break;case F.BL:Q=[M.left,M.bottom];break;case F.BR:Q=[M.right,M.bottom];break;case F.TC:Q=[M.left+Math.floor(M.width/2),M.top];break;case F.BC:Q=[M.left+Math.floor(M.width/2),M.bottom];break;case F.LC:Q=[M.left,M.top+Math.floor(M.height/2)];break;case F.RC:Q=[M.right,M.top+Math.floor(M.height/2),L];break;case F.CC:Q=[M.left+Math.floor(M.width/2),M.top+Math.floor(M.height/2),L];break;default:break;}if(Q){this._doAlign(L,Q[0],Q[1]);}}},_doAlign:function(M,L,P){var O=this._posNode,N;switch(M){case F.TL:N=[L,P];break;case F.TR:N=[L-O.get(D),P];break;case F.BL:N=[L,P-O.get(I)];break;case F.BR:N=[L-O.get(D),P-O.get(I)];break;case F.TC:N=[L-(O.get(D)/2),P];break;case F.BC:N=[L-(O.get(D)/2),P-O.get(I)];break;case F.LC:N=[L,P-(O.get(I)/2)];break;case F.RC:N=[(L-O.get(D)),P-(O.get(I)/2)];break;case F.CC:N=[L-(O.get(D)/2),P-(O.get(I)/2)];break;default:break;}if(N){this.move(N);}},align:function(M,L){this.set(C,{node:M,points:L});},centered:function(L){this.align(L,[F.CC,F.CC]);}};A.WidgetPositionExt=F;},"3.0.0pr2",{requires:["widget","widget-position"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-position-ext.js'
--- loggerhead/static/javascript/yui/build/widget/widget-position-ext.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-position-ext.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,401 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('widget-position-ext', function(Y) {
+
+/**
+ * Provides extended/advanced XY positioning support for Widgets, through an extension.
+ *
+ * It builds on top of the widget-position module, to provide alignmentment and centering support.
+ * Future releases aim to add constrained and fixed positioning support.
+ *
+ * @module widget-position-ext
+ */
+        var L = Y.Lang,
+            ALIGN = "align",
+
+            BINDUI = "bindUI",
+            SYNCUI = "syncUI",
+
+            OFFSET_WIDTH = "offsetWidth",
+            OFFSET_HEIGHT = "offsetHeight",
+            VIEWPORT_REGION = "viewportRegion",
+            REGION = "region",
+
+            AlignChange = "alignChange";
+
+        /**
+         * Widget extension, which can be used to add extended XY positioning support to the base Widget class,
+         * through the <a href="Base.html#method_build">Base.build</a> method.
+         *
+         * @class WidgetPositionExt
+         * @param {Object} User configuration object
+         */
+        function PositionExt(config) {
+            Y.after(this._syncUIPosExtras, this, SYNCUI);
+            Y.after(this._bindUIPosExtras, this, BINDUI);
+        }
+
+        /**
+         * Static property used to define the default attribute 
+         * configuration introduced by WidgetPositionExt.
+         * 
+         * @property WidgetPositionExt.ATTRS
+         * @type Object
+         * @static
+         */
+        PositionExt.ATTRS = {
+
+            /**
+             * @attribute align
+             * @type Object
+             * @default null
+             * @desciption The align attribute is used to align a reference point on the widget, with the refernce point on another node, or the viewport. 
+             * The object which align expects has the following properties:
+             * <dl>
+             *       <dt>node</dt>
+             *       <dd>
+             *         The node to which the Widget is to be aligned. If set to null, or not provided, the Widget is aligned to the viewport
+             *       </dd>
+             *       <dt>points</dt>
+             *       <dd>
+             *         <p>
+             *         A two element array, defining the two points on the Widget and node/viewport which are to be aligned. The first element is the point on the Widget, and the second element is the point on the node/viewport.
+             *         Supported alignment points are defined as static properties on <code>WidgetPositionExt</code>.
+             *         </p>
+             *         <p>
+             *         e.g. <code>[WidgetPositionExt.TR, WidgetPositionExt.TL]</code> aligns the Top-Right corner of the Widget with the
+             *         Top-Left corner of the node/viewport, and <code>[WidgetPositionExt.CC, WidgetPositionExt.TC]</code> aligns the Center of the 
+             *         Widget with the Top-Center edge of the node/viewport.
+             *         </p>
+             *       </dd>
+             *   </dl>
+             */
+            align: {
+                value:null
+            },
+
+            /**
+             * @attribute centered
+             * @type {boolean | node} 
+             * @default false
+             * @description A convenience attribute, which can be used as a shortcut for the align attribute.
+             * If set to true, the Widget is centered in the viewport. If set to a node reference or valid selector string,
+             * the Widget will be centered within the node. If set the false, no center positioning is applied.
+             */
+            centered: {
+                set: function(val) {
+                    return this._setAlignCenter(val);
+                },
+                value:false
+            }
+        };
+
+        /**
+         * Constant used to specify the top-left corner for alignment
+         * 
+         * @property WidgetPositionExt.TL
+         * @type String
+         * @static
+         * @value "tl"
+         */
+        PositionExt.TL = "tl";
+        /**
+         * Constant used to specify the top-right corner for alignment
+         * 
+         * @property WidgetPositionExt.TR
+         * @type String
+         * @static
+         * @value "tr"
+         */
+        PositionExt.TR = "tr";
+        /**
+         * Constant used to specify the bottom-left corner for alignment
+         * 
+         * @property WidgetPositionExt.BL
+         * @type String
+         * @static
+         * @value "bl"
+         */
+        PositionExt.BL = "bl";
+        /**
+         * Constant used to specify the bottom-right corner for alignment
+         * 
+         * @property WidgetPositionExt.BR
+         * @type String
+         * @static
+         * @value "br"
+         */
+        PositionExt.BR = "br";
+        /**
+         * Constant used to specify the top edge-center point for alignment
+         * 
+         * @property WidgetPositionExt.TC
+         * @type String
+         * @static
+         * @value "tc"
+         */
+        PositionExt.TC = "tc";
+        /**
+         * Constant used to specify the right edge, center point for alignment
+         * 
+         * @property WidgetPositionExt.RC
+         * @type String
+         * @static
+         * @value "rc"
+         */
+        PositionExt.RC = "rc";
+        /**
+         * Constant used to specify the bottom edge, center point for alignment
+         * 
+         * @property WidgetPositionExt.BC
+         * @type String
+         * @static
+         * @value "bc"
+         */
+        PositionExt.BC = "bc";
+        /**
+         * Constant used to specify the left edge, center point for alignment
+         * 
+         * @property WidgetPositionExt.LC
+         * @type String
+         * @static
+         * @value "lc"
+         */
+        PositionExt.LC = "lc";
+        /**
+         * Constant used to specify the center of widget/node/viewport for alignment
+         * 
+         * @property WidgetPositionExt.CC
+         * @type String
+         * @static
+         * @value "cc"
+         */
+        PositionExt.CC = "cc";
+
+        PositionExt.prototype = {
+
+            /**
+             * Synchronizes the UI to match the Widgets extended positioning state.
+             * This method in invoked after syncUI is invoked for the Widget class
+             * using YUI's aop infrastructure.
+             *
+             * @method _syncUIPosExtras
+             * @protected
+             */
+            _syncUIPosExtras : function() {
+                var align = this.get(ALIGN);
+                if (align) {
+                    this._uiSetAlign(align.node, align.points);
+                }
+            },
+
+            /**
+             * Binds event listeners responsible for updating the UI state in response to 
+             * Widget extended positioning related state changes.
+             * <p>
+             * This method is invoked after bindUI is invoked for the Widget class
+             * using YUI's aop infrastructure.
+             * </p>
+             * @method _bindUIStack
+             * @protected
+             */
+            _bindUIPosExtras : function() {
+                this.after(AlignChange, this._afterAlignChange);
+            },
+
+            /**
+             * Default setter for center attribute changes. Sets up the appropriate value, and passes 
+             * it through the to the align attribute.
+             *
+             * @method _setAlignCenter
+             * @protected
+             * @param {boolean | node} The attribute value being set. 
+             * @return {Number} The attribute value being set.
+             */
+            _setAlignCenter : function(val) {
+                if (val) {
+                    this.set(ALIGN, {
+                        node: val === true ? null : val,
+                        points: [PositionExt.CC, PositionExt.CC]
+                    });
+                }
+                return val;
+            },
+
+            /**
+             * Default attribute change listener for the align attribute, responsible
+             * for updating the UI, in response to attribute changes.
+             * 
+             * @method _afterAlignChange
+             * @protected
+             * @param {Event.Facade} e The event facade for the attribute change
+             */
+            _afterAlignChange : function(e) {
+                if (e.newVal) {
+                    this._uiSetAlign(e.newVal.node, e.newVal.points);
+                }
+            },
+
+            /**
+             * Updates the UI to reflect the align value passed in (see the align attribute documentation, for the object stucture expected)
+             * @method _uiSetAlign
+             * @protected
+             * @param {Node | null} The node to align to, or null to indicate the viewport
+             */
+            _uiSetAlign: function (node, points) {
+
+                if (!L.isArray(points) || points.length != 2) {
+                    Y.fail("align: Invalid Points Arguments");
+                    return;
+                }
+
+                var nodeRegion, widgetPoint, nodePoint, xy;
+
+                if (!node) {
+                    nodeRegion = this._posNode.get(VIEWPORT_REGION);
+                } else {
+                    node = Y.Node.get(node);
+                    if (node) {
+                        nodeRegion = node.get(REGION);
+                    }
+                }
+
+                if (nodeRegion) {
+
+                    // TODO: ViewportRegion doesn't have width/height - Workaround until normalized in Node/Dom
+                    nodeRegion.width = nodeRegion.width || nodeRegion.right - nodeRegion.left;
+                    nodeRegion.height = nodeRegion.height || nodeRegion.bottom - nodeRegion.top;
+
+                    widgetPoint = points[0];
+                    nodePoint = points[1];
+
+                    // TODO: Optimize KWeight - Would lookup table help?
+                    switch (nodePoint) {
+                        case PositionExt.TL:
+                            xy = [nodeRegion.left, nodeRegion.top];
+                            break;
+                        case PositionExt.TR:
+                            xy = [nodeRegion.right, nodeRegion.top];
+                            break;
+                        case PositionExt.BL:
+                            xy = [nodeRegion.left, nodeRegion.bottom];
+                            break;
+                        case PositionExt.BR:
+                            xy = [nodeRegion.right, nodeRegion.bottom];
+                            break;
+                        case PositionExt.TC:
+                            xy = [nodeRegion.left + Math.floor(nodeRegion.width/2), nodeRegion.top];
+                            break;
+                        case PositionExt.BC:
+                            xy = [nodeRegion.left + Math.floor(nodeRegion.width/2), nodeRegion.bottom];
+                            break;
+                        case PositionExt.LC:
+                            xy = [nodeRegion.left, nodeRegion.top + Math.floor(nodeRegion.height/2)];
+                            break;
+                        case PositionExt.RC:
+                            xy = [nodeRegion.right, nodeRegion.top + Math.floor(nodeRegion.height/2), widgetPoint];
+                            break;
+                        case PositionExt.CC:
+                            xy = [nodeRegion.left + Math.floor(nodeRegion.width/2), nodeRegion.top + Math.floor(nodeRegion.height/2), widgetPoint];
+                            break;
+                        default:
+                            break;
+                    }
+
+                    if (xy) {
+                        this._doAlign(widgetPoint, xy[0], xy[1]);
+                    }
+                }
+            },
+
+            /**
+             * Helper method, used to align the given point on the widget, with the XY page co-ordinates provided.
+             *
+             * @method _doAlign
+             * @private
+             * @param {String} widgetPoint Supported point constant (e.g. WidgetPositionExt.TL)
+             * @param {Number} x X page co-ordinate to align to
+             * @param {Number} y Y page co-ordinate to align to
+             */
+            _doAlign : function(widgetPoint, x, y) {
+                var widgetNode = this._posNode,
+                    xy;
+
+                switch (widgetPoint) {
+                    case PositionExt.TL:
+                        xy = [x, y];
+                        break;
+                    case PositionExt.TR:
+                        xy = [x - widgetNode.get(OFFSET_WIDTH), y];
+                        break;
+                    case PositionExt.BL:
+                        xy = [x, y - widgetNode.get(OFFSET_HEIGHT)];
+                        break;
+                    case PositionExt.BR:
+                        xy = [x - widgetNode.get(OFFSET_WIDTH), y - widgetNode.get(OFFSET_HEIGHT)];
+                        break;
+                    case PositionExt.TC:
+                        xy = [x - (widgetNode.get(OFFSET_WIDTH)/2), y];
+                        break;
+                    case PositionExt.BC:
+                        xy = [x - (widgetNode.get(OFFSET_WIDTH)/2), y - widgetNode.get(OFFSET_HEIGHT)];
+                        break;
+                    case PositionExt.LC:
+                        xy = [x, y - (widgetNode.get(OFFSET_HEIGHT)/2)];
+                        break;
+                    case PositionExt.RC:
+                        xy = [(x - widgetNode.get(OFFSET_WIDTH)), y - (widgetNode.get(OFFSET_HEIGHT)/2)];
+                        break;
+                    case PositionExt.CC:
+                        xy = [x - (widgetNode.get(OFFSET_WIDTH)/2), y - (widgetNode.get(OFFSET_HEIGHT)/2)];
+                        break;
+                    default:
+                        break;
+                }
+
+                if (xy) {
+                    this.move(xy);
+                }
+            },
+
+            /**
+             * Aligns the Widget to the provided node (or viewport) using the provided
+             * points. The method can be invoked directly, however it will result in 
+             * the align attribute being out of sync with current position of the of Widget.
+             * 
+             * @method align
+             * @param {Node | String | null} node A reference (or selector string) for the Node which with the Widget is to be aligned.
+             * If null is passed in, the Widget will be aligned with the viewport.
+             * @param {Array[2]} points A two element array, specifying the points on the Widget and node/viewport which need to be aligned. 
+             * The first entry is the point on the Widget, and the second entry is the point on the node/viewport which need to align.
+             * Valid point references are defined as static constants on the WidgetPositionExt class. 
+             * 
+             * e.g. [WidgetPositionExt.TL, WidgetPositionExt.TR] will align the top-left corner of the Widget with the top-right corner of the node/viewport.
+             */
+            align: function (node, points) {
+                this.set(ALIGN, {node: node, points:points});
+            },
+
+            /**
+             * Centers the container in the viewport, or if a node is passed in,
+             * the node.
+             *
+             * @method centered
+             * @param {Node | String} node Optional. A node reference or selector string defining the node 
+             * inside which the Widget is to be centered. If not passed in, the Widget will be centered in the 
+             * viewport.
+             */
+            centered: function (node) {
+                this.align(node, [PositionExt.CC, PositionExt.CC]);
+            }
+        };
+
+        Y.WidgetPositionExt = PositionExt;
+
+
+
+}, '3.0.0pr2' ,{requires:['widget', 'widget-position']});

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-position-min.js'
--- loggerhead/static/javascript/yui/build/widget/widget-position-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-position-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("widget-position",function(A){var H=A.Lang,J=A.Widget,K="xy",F="positioned",I="boundingBox",L="renderUI",G="bindUI",D="syncUI",C=J.UI_SRC,E="xyChange";function B(M){this._posNode=this.get(I);A.after(this._renderUIPosition,this,L);A.after(this._syncUIPosition,this,D);A.after(this._bindUIPosition,this,G);}B.ATTRS={x:{set:function(M){this._setX(M);},get:function(){return this._getX();}},y:{set:function(M){this._setY(M);},get:function(){return this._getY();}},xy:{value:[0,0],validator:function(M){return this._validateXY(M);}}};B.POSITIONED_CLASS_NAME=J.getClassName(F);B.prototype={_renderUIPosition:function(){this._posNode.addClass(B.POSITIONED_CLASS_NAME);},_syncUIPosition:function(){this._uiSetXY(this.get(K));},_bindUIPosition:function(){this.after(E,this._afterXYChange);},move:function(){var M=arguments,N=(H.isArray(M[0]))?M[0]:[M[0],M[1]];this.set(K,N);},syncXY:function(){this.set(K,this._posNode.getXY(),{src:C});},_validateXY:function(M){return(H.isArray(M)&&H.isNumber(M[0])&&H.isNumber(M[1]));},_setX:function(M){this.set(K,[M,this.get(K)[0]]);},_setY:function(M){this.set(K,[this.get(K)[1],M]);},_getX:function(){return this.get(K)[0];},_getY:function(){return this.get(K)[1];},_afterXYChange:function(M){if(M.src!=C){this._uiSetXY(M.newVal);}},_uiSetXY:function(M){this._posNode.setXY(M);}};A.WidgetPosition=B;},"3.0.0pr2",{requires:["widget"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-position.js'
--- loggerhead/static/javascript/yui/build/widget/widget-position.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-position.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,269 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('widget-position', function(Y) {
+
+/**
+ * Provides basic XY positioning support for Widgets, though an extension
+ *
+ * @module widget-position
+ */
+    var Lang = Y.Lang,
+        Widget = Y.Widget,
+
+        XY_COORD = "xy",
+
+        POSITIONED = "positioned",
+        BOUNDING_BOX = "boundingBox",
+
+        RENDERUI = "renderUI",
+        BINDUI = "bindUI",
+        SYNCUI = "syncUI",
+
+        UI = Widget.UI_SRC,
+
+        XYChange = "xyChange";
+
+    /**
+     * Widget extension, which can be used to add positioning support to the base Widget class, 
+     * through the <a href="Base.html#method_build">Base.build</a> method.
+     *
+     * @class WidgetPosition
+     * @param {Object} config User configuration object
+     */
+    function Position(config) {
+        this._posNode = this.get(BOUNDING_BOX);
+
+        // WIDGET METHOD OVERLAP
+        Y.after(this._renderUIPosition, this, RENDERUI);
+        Y.after(this._syncUIPosition, this, SYNCUI);
+        Y.after(this._bindUIPosition, this, BINDUI);
+    }
+
+    /**
+     * Static property used to define the default attribute 
+     * configuration introduced by WidgetPosition.
+     * 
+     * @property WidgetPosition.ATTRS
+     * @static
+     * @type Object
+     */
+    Position.ATTRS = {
+
+        /**
+         * @attribute x
+         * @type number
+         * @default 0
+         *
+         * @description Page X co-ordinate for the widget. This attribute acts as a facade for the 
+         * xy attribute. Changes in position can be monitored by listening for xyChange events.
+         */
+        x: {
+            set: function(val) {
+                this._setX(val);
+            },
+            get: function() {
+                return this._getX();
+            }
+        },
+
+        /**
+         * @attribute y
+         * @type number
+         * @default 0
+         *
+         * @description Page Y co-ordinate for the widget. This attribute acts as a facade for the 
+         * xy attribute. Changes in position can be monitored by listening for xyChange events.
+         */
+        y: {
+            set: function(val) {
+                this._setY(val);
+            },
+            get: function() {
+                return this._getY();
+            }
+        },
+
+        /**
+         * @attribute xy
+         * @type Array
+         * @default [0,0]
+         *
+         * @description Page XY co-ordinate pair for the widget.
+         */
+        xy: {
+            value:[0,0],
+            validator: function(val) {
+                return this._validateXY(val);
+            }
+        }
+    };
+
+    /**
+     * Default class used to mark the boundingBox of a positioned widget.
+     *
+     * @property WidgetPosition.POSITIONED_CLASS_NAME
+     * @type String
+     * @default "yui-widget-positioned"
+     * @static
+     */
+    Position.POSITIONED_CLASS_NAME = Widget.getClassName(POSITIONED);
+
+    Position.prototype = {
+
+        /**
+         * Creates/Initializes the DOM to support xy page positioning.
+         * <p>
+         * This method in invoked after renderUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _renderUIPosition
+         * @protected
+         */
+        _renderUIPosition : function() {
+            this._posNode.addClass(Position.POSITIONED_CLASS_NAME);
+        },
+
+        /**
+         * Synchronizes the UI to match the Widgets xy page position state.
+         * <p>
+         * This method in invoked after syncUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _syncUIPosition
+         * @protected
+         */
+        _syncUIPosition : function() {
+            this._uiSetXY(this.get(XY_COORD));
+        },
+
+        /**
+         * Binds event listeners responsible for updating the UI state in response to 
+         * Widget position related state changes.
+         * <p>
+         * This method in invoked after bindUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _bindUIPosition
+         * @protected
+         */
+        _bindUIPosition :function() {
+            this.after(XYChange, this._afterXYChange);
+        },
+
+        /**
+         * Moves the Widget to the specified page xy co-ordinate position.
+         *
+         * @method move
+         *
+         * @param {Number} x The new x position
+         * @param {Number} y The new y position
+         * <p>Or</p>
+         * @param {Array} x, y values passed as an array ([x, y]), to support
+         * simple pass through of Node.getXY results
+         */
+        move: function () {
+            var args = arguments,
+                coord = (Lang.isArray(args[0])) ? args[0] : [args[0], args[1]];
+                this.set(XY_COORD, coord);
+        },
+
+        /**
+         * Synchronizes the Panel's "xy", "x", and "y" properties with the 
+         * Widget's position in the DOM.
+         *
+         * @method syncXY
+         */
+        syncXY : function () {
+            this.set(XY_COORD, this._posNode.getXY(), {src: UI});
+        },
+
+        /**
+         * Default validator for the XY attribute
+         *
+         * @method _validateXY
+         * @param {Array} val The XY page co-ordinate value which is being set.
+         * @return {boolean} true if valid, false if not.
+         */
+        _validateXY : function(val) {
+            return (Lang.isArray(val) && Lang.isNumber(val[0]) && Lang.isNumber(val[1]));
+        },
+
+        /**
+         * Default setter for the X attribute. The setter passes the X value through
+         * to the XY attribute, which is the sole store for the XY state.
+         *
+         * @method _setX
+         * @param {Number} val The X page co-ordinate value
+         */
+        _setX : function(val) {
+            this.set(XY_COORD, [val, this.get(XY_COORD)[0]]);
+        },
+
+        /**
+         * Default setter for the Y attribute. The setter passes the Y value through
+         * to the XY attribute, which is the sole store for the XY state.
+         *
+         * @method _setY
+         * @param {Number} val The Y page co-ordinate value
+         */
+        _setY : function(val) {
+            this.set(XY_COORD, [this.get(XY_COORD)[1], val]);
+        },
+
+        /**
+         * Default getter for the X attribute. The value is retrieved from 
+         * the XY attribute, which is the sole store for the XY state.
+         *
+         * @method _getX
+         * @return {Number} The X page co-ordinate value
+         */
+        _getX : function() {
+            return this.get(XY_COORD)[0];
+        },
+
+        /**
+         * Default getter for the Y attribute. The value is retrieved from 
+         * the XY attribute, which is the sole store for the XY state.
+         *
+         * @method _getY
+         * @return {Number} The Y page co-ordinate value
+         */
+        _getY : function() {
+            return this.get(XY_COORD)[1];
+        },
+
+        /**
+         * Default attribute change listener for the xy attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         * 
+         * @method _afterXYChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterXYChange : function(e) {
+            if (e.src != UI) {
+                this._uiSetXY(e.newVal);
+            }
+        },
+
+        /**
+         * Updates the UI to reflect the XY page co-ordinates passed in.
+         * 
+         * @method _uiSetXY
+         * @protected
+         * @param {String} val The XY page co-ordinates value to be reflected in the UI
+         */
+        _uiSetXY : function(val) {
+            this._posNode.setXY(val);
+        }
+    };
+
+    Y.WidgetPosition = Position;
+
+
+
+}, '3.0.0pr2' ,{requires:['widget']});

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-stack-debug.js'
--- loggerhead/static/javascript/yui/build/widget/widget-stack-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-stack-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,459 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('widget-stack', function(Y) {
+
+/**
+ * Provides stackable (z-index) support for Widgets through an extension.
+ *
+ * @module widget-stack
+ */
+    var L = Y.Lang,
+        UA = Y.UA,
+        Node = Y.Node,
+        Widget = Y.Widget,
+
+        ZINDEX = "zIndex",
+        SHIM = "shim",
+        VISIBLE = "visible",
+
+        BOUNDING_BOX = "boundingBox",
+
+        RENDER_UI = "renderUI",
+        BIND_UI = "bindUI",
+        SYNC_UI = "syncUI",
+
+        OFFSET_WIDTH = "offsetWidth",
+        OFFSET_HEIGHT = "offsetHeight",
+        PARENT_NODE = "parentNode",
+        FIRST_CHILD = "firstChild",
+
+        WIDTH = "width",
+        HEIGHT = "height",
+        PX = "px",
+
+        // HANDLE KEYS
+        SHIM_DEFERRED = "shimdeferred",
+        SHIM_RESIZE = "shimresize",
+
+        // Events
+        VisibleChange = "visibleChange",
+        WidthChange = "widthChange",
+        HeightChange = "heightChange",
+        ShimChange = "shimChange",
+        ZIndexChange = "zIndexChange",
+        ContentUpdate = "contentUpdate",
+
+        // CSS
+        STACKED = "stacked",
+        SHOW_SCROLLBARS = "show-scrollbars",
+        HIDE_SCROLLBARS = "hide-scrollbars";
+
+    /**
+     * Widget extension, which can be used to add stackable (z-index) support to the 
+     * base Widget class along with a shimming solution, through the 
+     * <a href="Base.html#method_build">Base.build</a> method.
+     *
+     * @class WidgetStack
+     * @param {Object} User configuration object
+     */
+    function Stack(config) {
+        this._stackNode = this.get(BOUNDING_BOX);
+        this._stackHandles = {};
+
+        // WIDGET METHOD OVERLAP
+        Y.after(this._renderUIStack, this, RENDER_UI);
+        Y.after(this._syncUIStack, this, SYNC_UI);
+        Y.after(this._bindUIStack, this, BIND_UI);
+    }
+
+    // Static Properties
+    /**
+     * Static property used to define the default attribute 
+     * configuration introduced by WidgetStack.
+     * 
+     * @property WidgetStack.ATTRS
+     * @type Object
+     * @static
+     */
+    Stack.ATTRS = {
+        /**
+         * @attribute shim
+         * @type boolean
+         * @default false, for all browsers other than IE6, for which a shim is enabled by default.
+         * 
+         * @description Boolean flag to indicate whether or not a shim should be added to the Widgets
+         * boundingBox, to protect it from select box bleedthrough.
+         */
+        shim: {
+            value: (UA.ie == 6)
+        },
+
+        /**
+         * @attribute zIndex
+         * @type number
+         * @default 0
+         * @description The z-index to apply to the Widgets boundingBox. Non-numerical values for 
+         * zIndex will be converted to 0
+         */
+        zIndex: {
+            value:0,
+            set: function(val) {
+                return this._setZIndex(val);
+            }
+        }
+    };
+
+    /**
+     * The HTML parsing rules for the WidgetStack class.
+     * 
+     * @property WidgetStack.HTML_PARSER
+     * @static
+     * @type Object
+     */
+    Stack.HTML_PARSER = {
+        zIndex: function(contentBox) {
+            return contentBox.getStyle(ZINDEX);
+        }
+    };
+
+    /**
+     * Default class used to mark the shim element
+     *
+     * @property WidgetStack.SHIM_CLASS_NAME
+     * @type String
+     * @static
+     * @default "yui-widget-shim"
+     */
+    Stack.SHIM_CLASS_NAME = Widget.getClassName(SHIM);
+
+    /**
+     * Default class used to mark the boundingBox of a stacked widget.
+     * 
+     * @property WidgetStack.STACKED_CLASS_NAME
+     * @type String
+     * @static
+     * @default "yui-widget-stacked"
+     */
+    Stack.STACKED_CLASS_NAME = Widget.getClassName(STACKED);
+
+    /**
+     * Default markup template used to generate the shim element.
+     * 
+     * @property WidgetStack.SHIM_TEMPLATE
+     * @type String
+     * @static
+     */
+    Stack.SHIM_TEMPLATE = '<iframe class="' + Stack.SHIM_CLASS_NAME + '" frameborder="0" title="Widget Stacking Shim" src="javascript:false" tabindex="-1" role="presentation"></iframe>';
+
+    Stack.prototype = {
+
+        /**
+         * Synchronizes the UI to match the Widgets stack state. This method in 
+         * invoked after syncUI is invoked for the Widget class using YUI's aop infrastructure.
+         *
+         * @method _syncUIStack
+         * @protected
+         */
+        _syncUIStack: function() {
+            this._uiSetShim(this.get(SHIM));
+            this._uiSetZIndex(this.get(ZINDEX));
+        },
+
+        /**
+         * Binds event listeners responsible for updating the UI state in response to 
+         * Widget stack related state changes.
+         * <p>
+         * This method is invoked after bindUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _bindUIStack
+         * @protected
+         */
+        _bindUIStack: function() {
+            this.after(ShimChange, this._afterShimChange);
+            this.after(ZIndexChange, this._afterZIndexChange);
+        },
+
+        /**
+         * Creates/Initializes the DOM to support stackability.
+         * <p>
+         * This method in invoked after renderUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _renderUIStack
+         * @protected
+         */
+        _renderUIStack: function() {
+            this._stackNode.addClass(Stack.STACKED_CLASS_NAME);
+
+            // TODO:DEPENDENCY Env.os
+            var isMac = navigator.userAgent.toLowerCase().indexOf("macintosh") != -1;
+            if (isMac && UA.gecko && UA.gecko <= 1.9) {
+                this._fixMacGeckoScrollbars();
+            }
+        },
+
+        /**
+         * Default setter for zIndex attribute changes. Normalizes zIndex values to 
+         * numbers, converting non-numerical values to 0.
+         *
+         * @method _setZIndex
+         * @protected
+         * @param {String | Number} zIndex
+         * @return {Number} Normalized zIndex
+         */
+        _setZIndex: function(zIndex) {
+            if (L.isString(zIndex)) {
+                zIndex = parseInt(zIndex, 10);
+            }
+            if (!L.isNumber(zIndex)) {
+                zIndex = 0;
+            }
+            return zIndex;
+        },
+
+        /**
+         * Default attribute change listener for the shim attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         *
+         * @method _afterShimChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterShimChange : function(e) {
+            this._uiSetShim(e.newVal);
+        },
+
+        /**
+         * Default attribute change listener for the zIndex attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         * 
+         * @method _afterZIndexChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterZIndexChange : function(e) {
+            this._uiSetZIndex(e.newVal);
+        },
+
+        /**
+         * Updates the UI to reflect the zIndex value passed in.
+         *
+         * @method _uiSetZIndex
+         * @protected
+         * @param {number} zIndex The zindex to be reflected in the UI
+         */
+        _uiSetZIndex: function (zIndex) {
+            this._stackNode.setStyle(ZINDEX, zIndex);
+        },
+
+        /**
+         * Updates the UI to enable/disable the shim. If the widget is not currently visible,
+         * creation of the shim is deferred until it is made visible, for performance reasons.
+         *
+         * @method _uiSetShim
+         * @protected
+         * @param {boolean} enable If true, creates/renders the shim, if false, removes it.
+         */
+        _uiSetShim: function (enable) {
+            if (enable) {
+                // Lazy creation
+                if (this.get(VISIBLE)) {
+                    this._renderShim();
+                } else {
+                    this._renderShimDeferred();
+                }
+            } else {
+                this._destroyShim();
+            }
+        },
+
+        /**
+         * Sets up change handlers for the visible attribute, to defer shim creation/rendering 
+         * until the Widget is made visible.
+         * 
+         * @method _renderShimDeferred
+         * @private
+         */
+        _renderShimDeferred : function() {
+
+            this._stackHandles[SHIM_DEFERRED] = this._stackHandles[SHIM_DEFERRED] || [];
+
+            var handles = this._stackHandles[SHIM_DEFERRED],
+                createBeforeVisible = function(e) {
+                    if (e.newVal) {
+                        this._renderShim();
+                    }
+                };
+
+            handles.push(this.on(VisibleChange, createBeforeVisible));
+        },
+
+        /**
+         * Sets up event listeners to resize the shim when the size of the Widget changes.
+         * <p>
+         * NOTE: This method is only used for IE6 currently, since IE6 doesn't support a way to
+         * resize the shim purely through CSS, when the Widget does not have an explicit width/height 
+         * set.
+         * </p>
+         * @method _addShimResizeHandlers
+         * @private
+         */
+        _addShimResizeHandlers : function() {
+
+            this._stackHandles[SHIM_RESIZE] = this._stackHandles[SHIM_RESIZE] || [];
+
+            var sizeShim = this.sizeShim,
+                handles = this._stackHandles[SHIM_RESIZE];
+
+            this.sizeShim();
+
+            handles.push(this.after(VisibleChange, sizeShim));
+            handles.push(this.after(WidthChange, sizeShim));
+            handles.push(this.after(HeightChange, sizeShim));
+            handles.push(this.after(ContentUpdate, sizeShim));
+        },
+
+        /**
+         * Detaches any handles stored for the provided key
+         *
+         * @method _detachStackHandles
+         * @param String handleKey The key defining the group of handles which should be detached
+         * @private
+         */
+        _detachStackHandles : function(handleKey) {
+            var handles = this._stackHandles[handleKey],
+                handle;
+
+            if (handles && handles.length > 0) {
+                while((handle = handles.pop())) {
+                    handle.detach();
+                }
+            }
+        },
+
+        /**
+         * Creates the shim element and adds it to the DOM
+         *
+         * @method _renderShim
+         * @private
+         */
+        _renderShim : function() {
+            var shimEl = this._shimNode,
+                stackEl = this._stackNode;
+
+            if (!shimEl) {
+                shimEl = this._shimNode = this._getShimTemplate();
+                stackEl.insertBefore(shimEl, stackEl.get(FIRST_CHILD));
+
+                if (UA.ie == 6) {
+                    this._addShimResizeHandlers();
+                }
+                this._detachStackHandles(SHIM_DEFERRED);
+            }
+        },
+
+        /**
+         * Removes the shim from the DOM, and detaches any related event
+         * listeners.
+         *
+         * @method _destroyShim
+         * @private
+         */
+        _destroyShim : function() {
+            if (this._shimNode) {
+                this._shimNode.get(PARENT_NODE).removeChild(this._shimNode);
+                this._shimNode = null;
+
+                this._detachStackHandles(SHIM_DEFERRED);
+                this._detachStackHandles(SHIM_RESIZE);
+            }
+        },
+
+        /**
+         * Applies the CSS classes required to fix scrollbar bleedthrough, for FF2/Mac
+         * 
+         * @method _fixMacGeckoScrollbars
+         * @private
+         */
+        _fixMacGeckoScrollbars: function() {
+            this._toggleMacGeckoScrollbars();
+            this.after(VisibleChange, this._toggleMacGeckoScrollbars);
+        },
+
+        /**
+         * Flip the hide/show scrollbar classes applied to the Widget based on visibility, 
+         * to prevent scrollbar bleedthrough on FF2/Mac,
+         *
+         * @method _toggleMacGeckoScrollbars
+         * @private
+         */
+        _toggleMacGeckoScrollbars : function() {
+            if (this.get(VISIBLE)) {
+                this._showMacGeckoScrollbars();
+            } else {
+                this._hideMacGeckoScrollbars();
+            }
+        },
+
+        /**
+         * Set CSS classes on the Widgets boundingBox, to prevent scrollbar bleedthrough on FF2/Mac, when the Widget is hidden.
+         *
+         * @method _hideMacGeckoScrollbars
+         * @private
+         */
+        _hideMacGeckoScrollbars: function () {
+            this._stackNode.replaceClass(Widget.getClassName(SHOW_SCROLLBARS), Widget.getClassName(HIDE_SCROLLBARS));
+        },
+
+        /**
+         * Set CSS classes on the Widgets boundingBox, to prevent scrollbar bleedthrough on FF2/Mac, when the Widget is visible.
+         *
+         * @method _hideMacGeckoScrollbars
+         * @private
+         */
+        _showMacGeckoScrollbars: function () {
+            this._stackNode.replaceClass(Widget.getClassName(HIDE_SCROLLBARS), Widget.getClassName(SHOW_SCROLLBARS));
+        },
+
+        /**
+         * For IE6, synchronizes the size and position of iframe shim to that of 
+         * Widget bounding box which it is protecting. For all other browsers,
+         * this method does not do anything.
+         *
+         * @method sizeShim
+         */
+        sizeShim: function () {
+            var shim = this._shimNode,
+                node = this._stackNode;
+
+            if (shim && UA.ie === 6 && this.get(VISIBLE)) {
+                shim.setStyle(WIDTH, node.get(OFFSET_WIDTH) + PX);
+                shim.setStyle(HEIGHT, node.get(OFFSET_HEIGHT) + PX);
+            }
+        },
+
+        /**
+         * Creates a cloned shim node, using the SHIM_TEMPLATE html template, for use on a new instance.
+         *
+         * @method _getShimTemplate
+         * @private
+         * @return {Node} node A new shim Node instance.
+         */
+        _getShimTemplate : function() {
+            if (!Stack._SHIM_TEMPLATE) {
+                Stack._SHIM_TEMPLATE = Node.create(Stack.SHIM_TEMPLATE);
+            }
+            return Stack._SHIM_TEMPLATE.cloneNode(true);
+        }
+    };
+
+    Y.WidgetStack = Stack;
+
+
+
+}, '3.0.0pr2' ,{requires:['widget']});

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-stack-min.js'
--- loggerhead/static/javascript/yui/build/widget/widget-stack-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-stack-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("widget-stack",function(E){var O=E.Lang,U=E.UA,d=E.Node,F=E.Widget,c="zIndex",Q="shim",a="visible",f="boundingBox",X="renderUI",G="bindUI",T="syncUI",R="offsetWidth",D="offsetHeight",N="parentNode",A="firstChild",H="width",W="height",M="px",P="shimdeferred",g="shimresize",Z="visibleChange",C="widthChange",K="heightChange",b="shimChange",B="zIndexChange",I="contentUpdate",S="stacked",e="show-scrollbars",J="hide-scrollbars";function V(L){this._stackNode=this.get(f);this._stackHandles={};E.after(this._renderUIStack,this,X);E.after(this._syncUIStack,this,T);E.after(this._bindUIStack,this,G);}V.ATTRS={shim:{value:(U.ie==6)},zIndex:{value:0,set:function(L){return this._setZIndex(L);}}};V.HTML_PARSER={zIndex:function(L){return L.getStyle(c);}};V.SHIM_CLASS_NAME=F.getClassName(Q);V.STACKED_CLASS_NAME=F.getClassName(S);V.SHIM_TEMPLATE='<iframe class="'+V.SHIM_CLASS_NAME+'" frameborder="0" title="Widget Stacking Shim" src="javascript:false" tabindex="-1" role="presentation"></iframe>';V.prototype={_syncUIStack:function(){this._uiSetShim(this.get(Q));this._uiSetZIndex(this.get(c));},_bindUIStack:function(){this.after(b,this._afterShimChange);this.after(B,this._afterZIndexChange);},_renderUIStack:function(){this._stackNode.addClass(V.STACKED_CLASS_NAME);var L=navigator.userAgent.toLowerCase().indexOf("macintosh")!=-1;if(L&&U.gecko&&U.gecko<=1.9){this._fixMacGeckoScrollbars();}},_setZIndex:function(L){if(O.isString(L)){L=parseInt(L,10);}if(!O.isNumber(L)){L=0;}return L;},_afterShimChange:function(L){this._uiSetShim(L.newVal);},_afterZIndexChange:function(L){this._uiSetZIndex(L.newVal);},_uiSetZIndex:function(L){this._stackNode.setStyle(c,L);},_uiSetShim:function(L){if(L){if(this.get(a)){this._renderShim();}else{this._renderShimDeferred();}}else{this._destroyShim();}},_renderShimDeferred:function(){this._stackHandles[P]=this._stackHandles[P]||[];var Y=this._stackHandles[P],L=function(h){if(h.newVal){this._renderShim();}};Y.push(this.on(Z,L));},_addShimResizeHandlers:function(){this._stackHandles[g]=this._stackHandles[g]||[];var Y=this.sizeShim,L=this._stackHandles[g];this.sizeShim();L.push(this.after(Z,Y));L.push(this.after(C,Y));L.push(this.after(K,Y));L.push(this.after(I,Y));},_detachStackHandles:function(L){var Y=this._stackHandles[L],h;if(Y&&Y.length>0){while((h=Y.pop())){h.detach();}}},_renderShim:function(){var L=this._shimNode,Y=this._stackNode;if(!L){L=this._shimNode=this._getShimTemplate();Y.insertBefore(L,Y.get(A));if(U.ie==6){this._addShimResizeHandlers();}this._detachStackHandles(P);}},_destroyShim:function(){if(this._shimNode){this._shimNode.get(N).removeChild(this._shimNode);this._shimNode=null;this._detachStackHandles(P);this._detachStackHandles(g);}},_fixMacGeckoScrollbars:function(){this._toggleMacGeckoScrollbars();this.after(Z,this._toggleMacGeckoScrollbars);},_toggleMacGeckoScrollbars:function(){if(this.get(a)){this._showMacGeckoScrollbars();}else{this._hideMacGeckoScrollbars();}},_hideMacGeckoScrollbars:function(){this._stackNode.replaceClass(F.getClassName(e),F.getClassName(J));},_showMacGeckoScrollbars:function(){this._stackNode.replaceClass(F.getClassName(J),F.getClassName(e));},sizeShim:function(){var Y=this._shimNode,L=this._stackNode;if(Y&&U.ie===6&&this.get(a)){Y.setStyle(H,L.get(R)+M);Y.setStyle(W,L.get(D)+M);}},_getShimTemplate:function(){if(!V._SHIM_TEMPLATE){V._SHIM_TEMPLATE=d.create(V.SHIM_TEMPLATE);}return V._SHIM_TEMPLATE.cloneNode(true);}};E.WidgetStack=V;},"3.0.0pr2",{requires:["widget"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-stack.js'
--- loggerhead/static/javascript/yui/build/widget/widget-stack.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-stack.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,459 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('widget-stack', function(Y) {
+
+/**
+ * Provides stackable (z-index) support for Widgets through an extension.
+ *
+ * @module widget-stack
+ */
+    var L = Y.Lang,
+        UA = Y.UA,
+        Node = Y.Node,
+        Widget = Y.Widget,
+
+        ZINDEX = "zIndex",
+        SHIM = "shim",
+        VISIBLE = "visible",
+
+        BOUNDING_BOX = "boundingBox",
+
+        RENDER_UI = "renderUI",
+        BIND_UI = "bindUI",
+        SYNC_UI = "syncUI",
+
+        OFFSET_WIDTH = "offsetWidth",
+        OFFSET_HEIGHT = "offsetHeight",
+        PARENT_NODE = "parentNode",
+        FIRST_CHILD = "firstChild",
+
+        WIDTH = "width",
+        HEIGHT = "height",
+        PX = "px",
+
+        // HANDLE KEYS
+        SHIM_DEFERRED = "shimdeferred",
+        SHIM_RESIZE = "shimresize",
+
+        // Events
+        VisibleChange = "visibleChange",
+        WidthChange = "widthChange",
+        HeightChange = "heightChange",
+        ShimChange = "shimChange",
+        ZIndexChange = "zIndexChange",
+        ContentUpdate = "contentUpdate",
+
+        // CSS
+        STACKED = "stacked",
+        SHOW_SCROLLBARS = "show-scrollbars",
+        HIDE_SCROLLBARS = "hide-scrollbars";
+
+    /**
+     * Widget extension, which can be used to add stackable (z-index) support to the 
+     * base Widget class along with a shimming solution, through the 
+     * <a href="Base.html#method_build">Base.build</a> method.
+     *
+     * @class WidgetStack
+     * @param {Object} User configuration object
+     */
+    function Stack(config) {
+        this._stackNode = this.get(BOUNDING_BOX);
+        this._stackHandles = {};
+
+        // WIDGET METHOD OVERLAP
+        Y.after(this._renderUIStack, this, RENDER_UI);
+        Y.after(this._syncUIStack, this, SYNC_UI);
+        Y.after(this._bindUIStack, this, BIND_UI);
+    }
+
+    // Static Properties
+    /**
+     * Static property used to define the default attribute 
+     * configuration introduced by WidgetStack.
+     * 
+     * @property WidgetStack.ATTRS
+     * @type Object
+     * @static
+     */
+    Stack.ATTRS = {
+        /**
+         * @attribute shim
+         * @type boolean
+         * @default false, for all browsers other than IE6, for which a shim is enabled by default.
+         * 
+         * @description Boolean flag to indicate whether or not a shim should be added to the Widgets
+         * boundingBox, to protect it from select box bleedthrough.
+         */
+        shim: {
+            value: (UA.ie == 6)
+        },
+
+        /**
+         * @attribute zIndex
+         * @type number
+         * @default 0
+         * @description The z-index to apply to the Widgets boundingBox. Non-numerical values for 
+         * zIndex will be converted to 0
+         */
+        zIndex: {
+            value:0,
+            set: function(val) {
+                return this._setZIndex(val);
+            }
+        }
+    };
+
+    /**
+     * The HTML parsing rules for the WidgetStack class.
+     * 
+     * @property WidgetStack.HTML_PARSER
+     * @static
+     * @type Object
+     */
+    Stack.HTML_PARSER = {
+        zIndex: function(contentBox) {
+            return contentBox.getStyle(ZINDEX);
+        }
+    };
+
+    /**
+     * Default class used to mark the shim element
+     *
+     * @property WidgetStack.SHIM_CLASS_NAME
+     * @type String
+     * @static
+     * @default "yui-widget-shim"
+     */
+    Stack.SHIM_CLASS_NAME = Widget.getClassName(SHIM);
+
+    /**
+     * Default class used to mark the boundingBox of a stacked widget.
+     * 
+     * @property WidgetStack.STACKED_CLASS_NAME
+     * @type String
+     * @static
+     * @default "yui-widget-stacked"
+     */
+    Stack.STACKED_CLASS_NAME = Widget.getClassName(STACKED);
+
+    /**
+     * Default markup template used to generate the shim element.
+     * 
+     * @property WidgetStack.SHIM_TEMPLATE
+     * @type String
+     * @static
+     */
+    Stack.SHIM_TEMPLATE = '<iframe class="' + Stack.SHIM_CLASS_NAME + '" frameborder="0" title="Widget Stacking Shim" src="javascript:false" tabindex="-1" role="presentation"></iframe>';
+
+    Stack.prototype = {
+
+        /**
+         * Synchronizes the UI to match the Widgets stack state. This method in 
+         * invoked after syncUI is invoked for the Widget class using YUI's aop infrastructure.
+         *
+         * @method _syncUIStack
+         * @protected
+         */
+        _syncUIStack: function() {
+            this._uiSetShim(this.get(SHIM));
+            this._uiSetZIndex(this.get(ZINDEX));
+        },
+
+        /**
+         * Binds event listeners responsible for updating the UI state in response to 
+         * Widget stack related state changes.
+         * <p>
+         * This method is invoked after bindUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _bindUIStack
+         * @protected
+         */
+        _bindUIStack: function() {
+            this.after(ShimChange, this._afterShimChange);
+            this.after(ZIndexChange, this._afterZIndexChange);
+        },
+
+        /**
+         * Creates/Initializes the DOM to support stackability.
+         * <p>
+         * This method in invoked after renderUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _renderUIStack
+         * @protected
+         */
+        _renderUIStack: function() {
+            this._stackNode.addClass(Stack.STACKED_CLASS_NAME);
+
+            // TODO:DEPENDENCY Env.os
+            var isMac = navigator.userAgent.toLowerCase().indexOf("macintosh") != -1;
+            if (isMac && UA.gecko && UA.gecko <= 1.9) {
+                this._fixMacGeckoScrollbars();
+            }
+        },
+
+        /**
+         * Default setter for zIndex attribute changes. Normalizes zIndex values to 
+         * numbers, converting non-numerical values to 0.
+         *
+         * @method _setZIndex
+         * @protected
+         * @param {String | Number} zIndex
+         * @return {Number} Normalized zIndex
+         */
+        _setZIndex: function(zIndex) {
+            if (L.isString(zIndex)) {
+                zIndex = parseInt(zIndex, 10);
+            }
+            if (!L.isNumber(zIndex)) {
+                zIndex = 0;
+            }
+            return zIndex;
+        },
+
+        /**
+         * Default attribute change listener for the shim attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         *
+         * @method _afterShimChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterShimChange : function(e) {
+            this._uiSetShim(e.newVal);
+        },
+
+        /**
+         * Default attribute change listener for the zIndex attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         * 
+         * @method _afterZIndexChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterZIndexChange : function(e) {
+            this._uiSetZIndex(e.newVal);
+        },
+
+        /**
+         * Updates the UI to reflect the zIndex value passed in.
+         *
+         * @method _uiSetZIndex
+         * @protected
+         * @param {number} zIndex The zindex to be reflected in the UI
+         */
+        _uiSetZIndex: function (zIndex) {
+            this._stackNode.setStyle(ZINDEX, zIndex);
+        },
+
+        /**
+         * Updates the UI to enable/disable the shim. If the widget is not currently visible,
+         * creation of the shim is deferred until it is made visible, for performance reasons.
+         *
+         * @method _uiSetShim
+         * @protected
+         * @param {boolean} enable If true, creates/renders the shim, if false, removes it.
+         */
+        _uiSetShim: function (enable) {
+            if (enable) {
+                // Lazy creation
+                if (this.get(VISIBLE)) {
+                    this._renderShim();
+                } else {
+                    this._renderShimDeferred();
+                }
+            } else {
+                this._destroyShim();
+            }
+        },
+
+        /**
+         * Sets up change handlers for the visible attribute, to defer shim creation/rendering 
+         * until the Widget is made visible.
+         * 
+         * @method _renderShimDeferred
+         * @private
+         */
+        _renderShimDeferred : function() {
+
+            this._stackHandles[SHIM_DEFERRED] = this._stackHandles[SHIM_DEFERRED] || [];
+
+            var handles = this._stackHandles[SHIM_DEFERRED],
+                createBeforeVisible = function(e) {
+                    if (e.newVal) {
+                        this._renderShim();
+                    }
+                };
+
+            handles.push(this.on(VisibleChange, createBeforeVisible));
+        },
+
+        /**
+         * Sets up event listeners to resize the shim when the size of the Widget changes.
+         * <p>
+         * NOTE: This method is only used for IE6 currently, since IE6 doesn't support a way to
+         * resize the shim purely through CSS, when the Widget does not have an explicit width/height 
+         * set.
+         * </p>
+         * @method _addShimResizeHandlers
+         * @private
+         */
+        _addShimResizeHandlers : function() {
+
+            this._stackHandles[SHIM_RESIZE] = this._stackHandles[SHIM_RESIZE] || [];
+
+            var sizeShim = this.sizeShim,
+                handles = this._stackHandles[SHIM_RESIZE];
+
+            this.sizeShim();
+
+            handles.push(this.after(VisibleChange, sizeShim));
+            handles.push(this.after(WidthChange, sizeShim));
+            handles.push(this.after(HeightChange, sizeShim));
+            handles.push(this.after(ContentUpdate, sizeShim));
+        },
+
+        /**
+         * Detaches any handles stored for the provided key
+         *
+         * @method _detachStackHandles
+         * @param String handleKey The key defining the group of handles which should be detached
+         * @private
+         */
+        _detachStackHandles : function(handleKey) {
+            var handles = this._stackHandles[handleKey],
+                handle;
+
+            if (handles && handles.length > 0) {
+                while((handle = handles.pop())) {
+                    handle.detach();
+                }
+            }
+        },
+
+        /**
+         * Creates the shim element and adds it to the DOM
+         *
+         * @method _renderShim
+         * @private
+         */
+        _renderShim : function() {
+            var shimEl = this._shimNode,
+                stackEl = this._stackNode;
+
+            if (!shimEl) {
+                shimEl = this._shimNode = this._getShimTemplate();
+                stackEl.insertBefore(shimEl, stackEl.get(FIRST_CHILD));
+
+                if (UA.ie == 6) {
+                    this._addShimResizeHandlers();
+                }
+                this._detachStackHandles(SHIM_DEFERRED);
+            }
+        },
+
+        /**
+         * Removes the shim from the DOM, and detaches any related event
+         * listeners.
+         *
+         * @method _destroyShim
+         * @private
+         */
+        _destroyShim : function() {
+            if (this._shimNode) {
+                this._shimNode.get(PARENT_NODE).removeChild(this._shimNode);
+                this._shimNode = null;
+
+                this._detachStackHandles(SHIM_DEFERRED);
+                this._detachStackHandles(SHIM_RESIZE);
+            }
+        },
+
+        /**
+         * Applies the CSS classes required to fix scrollbar bleedthrough, for FF2/Mac
+         * 
+         * @method _fixMacGeckoScrollbars
+         * @private
+         */
+        _fixMacGeckoScrollbars: function() {
+            this._toggleMacGeckoScrollbars();
+            this.after(VisibleChange, this._toggleMacGeckoScrollbars);
+        },
+
+        /**
+         * Flip the hide/show scrollbar classes applied to the Widget based on visibility, 
+         * to prevent scrollbar bleedthrough on FF2/Mac,
+         *
+         * @method _toggleMacGeckoScrollbars
+         * @private
+         */
+        _toggleMacGeckoScrollbars : function() {
+            if (this.get(VISIBLE)) {
+                this._showMacGeckoScrollbars();
+            } else {
+                this._hideMacGeckoScrollbars();
+            }
+        },
+
+        /**
+         * Set CSS classes on the Widgets boundingBox, to prevent scrollbar bleedthrough on FF2/Mac, when the Widget is hidden.
+         *
+         * @method _hideMacGeckoScrollbars
+         * @private
+         */
+        _hideMacGeckoScrollbars: function () {
+            this._stackNode.replaceClass(Widget.getClassName(SHOW_SCROLLBARS), Widget.getClassName(HIDE_SCROLLBARS));
+        },
+
+        /**
+         * Set CSS classes on the Widgets boundingBox, to prevent scrollbar bleedthrough on FF2/Mac, when the Widget is visible.
+         *
+         * @method _hideMacGeckoScrollbars
+         * @private
+         */
+        _showMacGeckoScrollbars: function () {
+            this._stackNode.replaceClass(Widget.getClassName(HIDE_SCROLLBARS), Widget.getClassName(SHOW_SCROLLBARS));
+        },
+
+        /**
+         * For IE6, synchronizes the size and position of iframe shim to that of 
+         * Widget bounding box which it is protecting. For all other browsers,
+         * this method does not do anything.
+         *
+         * @method sizeShim
+         */
+        sizeShim: function () {
+            var shim = this._shimNode,
+                node = this._stackNode;
+
+            if (shim && UA.ie === 6 && this.get(VISIBLE)) {
+                shim.setStyle(WIDTH, node.get(OFFSET_WIDTH) + PX);
+                shim.setStyle(HEIGHT, node.get(OFFSET_HEIGHT) + PX);
+            }
+        },
+
+        /**
+         * Creates a cloned shim node, using the SHIM_TEMPLATE html template, for use on a new instance.
+         *
+         * @method _getShimTemplate
+         * @private
+         * @return {Node} node A new shim Node instance.
+         */
+        _getShimTemplate : function() {
+            if (!Stack._SHIM_TEMPLATE) {
+                Stack._SHIM_TEMPLATE = Node.create(Stack.SHIM_TEMPLATE);
+            }
+            return Stack._SHIM_TEMPLATE.cloneNode(true);
+        }
+    };
+
+    Y.WidgetStack = Stack;
+
+
+
+}, '3.0.0pr2' ,{requires:['widget']});

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-stdmod-debug.js'
--- loggerhead/static/javascript/yui/build/widget/widget-stdmod-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-stdmod-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,740 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('widget-stdmod', function(Y) {
+
+/**
+ * Provides standard module support for Widgets through an extension.
+ * 
+ * @module widget-stdmod
+ */
+    var L = Y.Lang,
+        Node = Y.Node,
+        UA = Y.UA,
+        Widget = Y.Widget,
+
+        EMPTY = "",
+        HD = "hd",
+        BD = "bd",
+        FT = "ft",
+        HEADER = "header",
+        BODY = "body",
+        FOOTER = "footer",
+        FILL_HEIGHT = "fillHeight",
+        STDMOD = "stdmod",
+
+        PX = "px",
+        NODE_SUFFIX = "Node",
+        CONTENT_SUFFIX = "Content",
+        INNER_HTML = "innerHTML",
+        FIRST_CHILD = "firstChild",
+        CHILD_NODES = "childNodes",
+
+        CONTENT_BOX = "contentBox",
+        BOUNDING_BOX = "boundingBox",
+
+        HEIGHT = "height",
+        OFFSET_HEIGHT = "offsetHeight",
+        AUTO = "auto",
+
+        HeaderChange = "headerContentChange",
+        BodyChange = "bodyContentChange",
+        FooterChange = "footerContentChange",
+        FillHeightChange = "fillHeightChange",
+        HeightChange = "HeightChange",        
+        ContentUpdate = "contentUpdate",
+
+        RENDERUI = "renderUI",
+        BINDUI = "bindUI",
+        SYNCUI = "syncUI";
+
+    /**
+     * Widget extension, which can be used to add Standard Module support to the 
+     * base Widget class, through the <a href="Base.html#method_build">Base.build</a> 
+     * method.
+     * <p>
+     * The extension adds header, body and footer sections to the Widget's content box and 
+     * provides the corresponding methods and attributes to modify the contents of these sections.
+     * </p>
+     * @class WidgetStdMod
+     * @param {Object} The user configuration object
+     */
+    function StdMod(config) {
+
+        this._stdModNode = this.get(CONTENT_BOX);
+
+        Y.after(this._renderUIStdMod, this, RENDERUI);
+        Y.after(this._bindUIStdMod, this, BINDUI);
+        Y.after(this._syncUIStdMod, this, SYNCUI);
+    }
+
+    /**
+     * Constant used to refer the the standard module header, in methods which expect a section specifier
+     * 
+     * @property WidgetStdMod.HEADER
+     * @static
+     * @type String
+     */
+    StdMod.HEADER = HEADER;
+    /**
+     * Constant used to refer the the standard module body, in methods which expect a section specifier
+     * 
+     * @property WidgetStdMod.BODY
+     * @static
+     * @type String
+     */
+    StdMod.BODY = BODY;
+    /**
+     * Constant used to refer the the standard module footer, in methods which expect a section specifier
+     * 
+     * @property WidgetStdMod.FOOTER
+     * @static
+     * @type String
+     */
+    StdMod.FOOTER = FOOTER;
+
+    /**
+     * Constant used to specify insertion position, when adding content to sections of the standard module in 
+     * methods which expect a "where" argument.
+     * <p>
+     * Inserts new content <em>before</em> the sections existing content.
+     * </p>
+     * @property WidgetStdMod.AFTER
+     * @static
+     * @type String
+     */
+    StdMod.AFTER = "after";
+
+    /**
+     * Constant used to specify insertion position, when adding content to sections of the standard module in
+     * methods which expect a "where" argument.
+     * <p>
+     * Inserts new content <em>before</em> the sections existing content.
+     * </p>
+     * @property WidgetStdMod.BEFORE
+     * @static
+     * @type String
+     */
+    StdMod.BEFORE = "before";
+    /**
+     * Constant used to specify insertion position, when adding content to sections of the standard module in
+     * methods which expect a "where" argument.
+     * <p>
+     * <em>Replaces</em> the sections existing content, with new content.
+     * </p>
+     * @property WidgetStdMod.REPLACE
+     * @static
+     * @type String
+     */
+    StdMod.REPLACE = "replace";
+
+    var STD_HEADER = StdMod.HEADER,
+        STD_BODY = StdMod.BODY,
+        STD_FOOTER = StdMod.FOOTER,
+        AFTER = StdMod.AFTER,
+        BEFORE = StdMod.BEFORE;
+
+    /**
+     * Static property used to define the default attribute 
+     * configuration introduced by WidgetStdMod.
+     * 
+     * @property WidgetStdMod.ATTRS
+     * @type Object
+     * @static
+     */
+    StdMod.ATTRS = {
+
+        /**
+         * @attribute headerContent
+         * @type {String | Node}
+         * @default undefined
+         * @description The content to be added to the header section. This will replace any existing content
+         * in the header. If you want to append, or insert new content, use the <a href="#method_setStdModContent">setStdModContent</a> method.
+         */
+        headerContent: {
+            get: function(val) {
+                var live = this._getStdModContent(STD_HEADER);
+                return (live === null) ? val : live;
+            }
+        },
+        
+        /**
+         * @attribute footerContent
+         * @type {String | Node}
+         * @default undefined
+         * @description The content to be added to the footer section. This will replace any existing content
+         * in the footer. If you want to append, or insert new content, use the <a href="#method_setStdModContent">setStdModContent</a> method.
+         */
+        footerContent: {
+            get: function(val) {
+                var live = this._getStdModContent(STD_FOOTER);
+                return (live === null) ? val : live;
+            }
+        },
+        
+        /**
+         * @attribute bodyContent
+         * @type {String | Node}
+         * @default undefined
+         * @description The content to be added to the body section. This will replace any existing content
+         * in the body. If you want to append, or insert new content, use the <a href="#method_setStdModContent">setStdModContent</a> method.
+         */
+        bodyContent: {
+            get: function(val) {
+                var live = this._getStdModContent(STD_BODY);
+                return (live === null) ? val : live;
+            }
+        },
+        
+        /**
+         * @attribute fillHeight
+         * @type {String}
+         * @default WidgetStdMod.BODY
+         * @description The section (WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER) which should be resized to fill the height of the standard module, when a 
+         * height is set on the Widget. If a height is not set on the widget, then all sections are sized based on 
+         * their content.
+         */
+        fillHeight: {
+            value: StdMod.BODY,
+            validator: function(val) {
+                 return this._validateFillHeight(val);
+            }
+        }
+    };
+
+    /**
+     * The HTML parsing rules for the WidgetStdMod class.
+     * 
+     * @property WidgetStdMod.HTML_PARSER
+     * @static
+     * @type Object
+     */
+    StdMod.HTML_PARSER = {
+        headerContent: function(contentBox) {
+            return this._parseStdModHTML(STD_HEADER);
+        },
+
+        bodyContent: function(contentBox) {
+            return this._parseStdModHTML(STD_BODY);
+        },
+
+        footerContent : function(contentBox) {
+            return this._parseStdModHTML(STD_FOOTER);
+        }
+    };
+
+    /**
+     * Static hash of default class names used for the header,
+     * body and footer sections of the standard module, keyed by
+     * the section identifier (WidgetStdMod.STD_HEADER, WidgetStdMod.STD_BODY, WidgetStdMod.STD_FOOTER)
+     *
+     * @property WidgetStdMod.SECTION_CLASS_NAMES
+     * @static
+     * @type Object
+     */
+    StdMod.SECTION_CLASS_NAMES = {
+        header: Widget.getClassName(HD),
+        body: Widget.getClassName(BD),
+        footer: Widget.getClassName(FT)
+    };
+
+    /**
+     * The template HTML strings for each of the standard module sections. Section entries are keyed by the section constants,
+     * WidgetStdMod.HEADER, WidgetStdMod.BODY, WidgetStdMod.FOOTER, and contain the HTML to be added for each section.
+     * e.g.
+     * <pre>
+     *    {
+     *       header : '&lt;div class="yui-widget-hd"&gt;&lt;/div&gt;',
+     *       body : '&lt;div class="yui-widget-bd"&gt;&lt;/div&gt;',
+     *       footer : '&lt;div class="yui-widget-ft"&gt;&lt;/div&gt;'
+     *    }
+     * </pre>
+     * @property WidgetStdMod.TEMPLATES
+     * @type Object
+     * @static
+     */
+    StdMod.TEMPLATES = {
+        header : '<div class="' + StdMod.SECTION_CLASS_NAMES[STD_HEADER] + '"></div>',
+        body : '<div class="' + StdMod.SECTION_CLASS_NAMES[STD_BODY] + '"></div>',
+        footer : '<div class="' + StdMod.SECTION_CLASS_NAMES[STD_FOOTER] + '"></div>'
+    };
+
+    /**
+     * Stores nodes created from the WidgetStdMod.TEMPLATES strings,
+     * which are cloned to create new header, footer, body sections for
+     * new instances.
+     *
+     * @property WidgetStdMod._TEMPLATES
+     * @static
+     * @private
+     */
+    StdMod._TEMPLATES = {};
+
+    StdMod.prototype = {
+
+        /**
+         * Synchronizes the UI to match the Widgets standard module state.
+         * <p>
+         * This method is invoked after syncUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _syncUIStdMod
+         * @protected
+         */
+        _syncUIStdMod : function() {
+            this._uiSetStdMod(STD_HEADER, this.get(STD_HEADER + CONTENT_SUFFIX));
+            this._uiSetStdMod(STD_BODY, this.get(STD_BODY + CONTENT_SUFFIX));
+            this._uiSetStdMod(STD_FOOTER, this.get(STD_FOOTER + CONTENT_SUFFIX));
+            this._uiSetFillHeight(this.get(FILL_HEIGHT));
+        },
+
+        /**
+         * Creates/Initializes the DOM for standard module support.
+         * <p>
+         * This method is invoked after renderUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _renderUIStdMod
+         * @protected
+         */
+        _renderUIStdMod : function() {
+            this._stdModNode.addClass(Widget.getClassName(STDMOD));
+        },
+
+        /**
+         * Binds event listeners responsible for updating the UI state in response to 
+         * Widget standard module related state changes.
+         * <p>
+         * This method is invoked after bindUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _bindUIStdMod
+         * @protected
+         */
+        _bindUIStdMod : function() {
+            this.after(HeaderChange, this._afterHeaderChange);
+            this.after(BodyChange, this._afterBodyChange);
+            this.after(FooterChange, this._afterFooterChange);
+
+            this.after(FillHeightChange, this._afterFillHeightChange);
+            this.after(HeightChange, this._fillHeight);            
+            this.after(ContentUpdate, this._fillHeight);
+        },
+
+        /**
+         * Default attribute change listener for the headerContent attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         *
+         * @method _afterHeaderChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterHeaderChange : function(e) {
+            this._uiSetStdMod(STD_HEADER, e.newVal, e.stdModPosition);
+        },
+
+        /**
+         * Default attribute change listener for the bodyContent attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         *
+         * @method _afterBodyChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterBodyChange : function(e) {
+            this._uiSetStdMod(STD_BODY, e.newVal, e.stdModPosition);
+        },
+
+        /**
+         * Default attribute change listener for the footerContent attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         *
+         * @method _afterFooterChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterFooterChange : function(e) {
+            this._uiSetStdMod(STD_FOOTER, e.newVal, e.stdModPosition);
+        },
+
+        /**
+         * Default attribute change listener for the fillHeight attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         * 
+         * @method _afterFillHeightChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterFillHeightChange: function (e) {
+            this._uiSetFillHeight(e.newVal);
+        },
+
+        /**
+         * Default validator for the fillHeight attribute. Verifies that the 
+         * value set is a valid section specifier - one of WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER,
+         * or a falsey value if fillHeight is to be disabled.
+         *
+         * @method _validateFillHeight
+         * @protected
+         * @param {String} val The section which should be setup to fill height, or false/null to disable fillHeight
+         * @return true if valid, false if not
+         */
+        _validateFillHeight : function(val) {
+            return !val || val == StdMod.BODY || val == StdMod.HEADER || val == StdMod.FOOTER;    
+        },
+
+        /**
+         * Updates the rendered UI, to resize the provided section so that the standard module fills out 
+         * the specified widget height. Note: This method does not check whether or not a height is set 
+         * on the Widget.
+         * 
+         * @method _uiSetFillHeight
+         * @protected
+         * @param {String} fillSection A valid section specifier - one of WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER
+         */
+        _uiSetFillHeight : function(fillSection) {
+            var fillNode = this.getStdModNode(fillSection);
+            var currNode = this._currFillNode;
+
+            if (currNode && fillNode !== currNode){
+                currNode.setStyle(HEIGHT, EMPTY);
+            }
+
+            if (fillNode) {
+                this._currFillNode = fillNode;
+            }
+
+            this._fillHeight();
+        },
+
+        /**
+         * Updates the rendered UI, to resize the current section specified by the fillHeight attribute, so
+         * that the standard module fills out the Widget height. If a height has not been set on Widget,
+         * the section is not resized (height is set to "auto").
+         * 
+         * @method _fillHeight
+         * @private
+         */
+        _fillHeight : function() {
+            if (this.get(FILL_HEIGHT)) {
+                var height = this.get(HEIGHT);
+                if (height != EMPTY && height != AUTO) {
+                    this.fillHeight(this._currFillNode);    
+                }
+            }
+        },
+
+        /**
+         * Updates the rendered UI, adding the provided content (either an HTML string, or node reference),
+         * to the specified section. The content is either added before, after or replaces existing content
+         * in the section, based on the value of the <code>where</code> argument.
+         * 
+         * @method _uiSetStdMod
+         * @protected
+         * 
+         * @param {String} section The section to be updated. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER. 
+         * @param {String | Node} content The new content (either as an HTML string, or Node reference) to add to the section
+         * @param {String} where Optional. Either WidgetStdMod.AFTER, WidgetStdMod.BEFORE or WidgetStdMod.REPLACE.
+         * If not provided, the content will replace existing content in the section.
+         */
+        _uiSetStdMod : function(section, content, where) {
+            if (content) {
+                var node = this.getStdModNode(section) || this._renderStdMod(section);
+                if (content instanceof Node) {
+                    this._addNodeRef(node, content, where);
+                } else {
+                    this._addNodeHTML(node, content, where);
+                }
+                this.fire(ContentUpdate);
+            }
+        },
+
+        /**
+         * Creates the DOM node for the given section, and inserts it into the correct location in the contentBox.
+         *
+         * @method _renderStdMod
+         * @protected
+         * @param {String} section The section to create/render. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @return {Node} A reference to the added section node
+         */
+        _renderStdMod : function(section) {
+
+            var contentBox = this.get(CONTENT_BOX),
+                sectionNode = this._findStdModSection(section);
+
+            if (!sectionNode) {
+                sectionNode = this._getStdModTemplate(section);
+            }
+
+            this._insertStdModSection(contentBox, section, sectionNode);
+
+            this[section + NODE_SUFFIX] = sectionNode;
+            return this[section + NODE_SUFFIX];
+        },
+
+        /**
+         * Helper method to insert the Node for the given section into the correct location in the contentBox.
+         *
+         * @method _insertStdModSection
+         * @private
+         * @param {Node} contentBox A reference to the Widgets content box.
+         * @param {String} section The section to create/render. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @param {Node} sectionNode The Node for the section.
+         */
+        _insertStdModSection : function(contentBox, section, sectionNode) {
+            var fc = contentBox.get(FIRST_CHILD);
+
+            if (section === STD_FOOTER || !fc) {
+                contentBox.appendChild(sectionNode);
+            } else {
+                if (section === STD_HEADER) {
+                    contentBox.insertBefore(sectionNode, fc);
+                } else {
+                    // BODY
+                    var footer = this[STD_FOOTER + NODE_SUFFIX];
+                    if (footer) {
+                        contentBox.insertBefore(sectionNode, footer);
+                    } else {
+                        contentBox.appendChild(sectionNode);
+                    }
+                }
+            }
+        },
+
+        /**
+         * Gets a new Node reference for the given standard module section, by cloning
+         * the stored template node.
+         *
+         * @method _getStdModTemplate
+         * @protected
+         * @param {String} section The section to create a new node for. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @return {Node} The new Node instance for the section
+         */
+        _getStdModTemplate : function(section) {
+            var template = StdMod._TEMPLATES[section];
+
+            if (!template) {
+                StdMod._TEMPLATES[section] = template = Node.create(StdMod.TEMPLATES[section]);
+            }
+            return template.cloneNode(true);
+        },
+
+        /**
+         * Helper method to add the given HTML string to the node reference provided.
+         * The HTML is added either before, after or replaces the existing node content 
+         * based on the value of the <code>where</code> argument.
+         *
+         * @method _addNodeHTML
+         * @private
+         * 
+         * @param {Node} node The section Node to be updated.
+         * @param {String} html The new content HTML string to be added to the section Node.
+         * @param {String} where Optional. Either WidgetStdMod.AFTER, WidgetStdMod.BEFORE or WidgetStdMod.REPLACE.
+         * If not provided, the content will replace Nodes existing content.
+         */
+        _addNodeHTML : function(node, html, where) {
+            if (where == AFTER) {
+                node.set(INNER_HTML, node.get(INNER_HTML) + html);
+            } else if (where == BEFORE) {
+                node.set(INNER_HTML, html + node.get(INNER_HTML));
+            } else {
+                node.set(INNER_HTML, html);
+            }
+        },
+
+        /**
+         * Helper method to add nodes, to another node.
+         * The child node(s) are added either before, after or replaces the existing node content 
+         * based on the value of the <code>where</code> argument.
+         * 
+         * @method _addNodeRef
+         * @private
+         * 
+         * @param {Node} node The section Node to be updated.
+         * @param {Node} child The new content Node to be added to section Node provided.
+         * @param {String} where Optional. Either WidgetStdMod.AFTER, WidgetStdMod.BEFORE or WidgetStdMod.REPLACE.
+         * If not provided, the content will replace existing content in the Node.
+         */
+        _addNodeRef : function(node, children, where) {
+            var append = true, 
+                i, s;
+
+            if (where == BEFORE) {
+                if (node.get(FIRST_CHILD)) {
+                    for (i = node.size() - 1; i >=0; --i) {
+                        node.insertBefore(children.item(i), node.get(FIRST_CHILD));
+                    }
+                    append = false;
+                }
+            } else if (where != AFTER) { // replace
+                node.set(INNER_HTML, EMPTY);
+            }
+            if (append) {
+                for (i = 0, s = children.size(); i < s; ++i) {
+                    node.appendChild(children.item(i));
+                }
+            }
+        },
+
+        /**
+         * Helper method to obtain the precise height of the node provided, including padding and border.
+         * The height could be a sub-pixel value for certain browsers, such as Firefox 3.
+         *
+         * @method _getPreciseHeight
+         * @private
+         * @param {Node} node The node for which the precise height is required.
+         * @return {Number} The height of the Node including borders and padding, possibly a float.
+         */
+        _getPreciseHeight : function(node) {
+            var height = (node) ? node.get(OFFSET_HEIGHT) : 0,
+                getBCR = "getBoundingClientRect";
+
+            if (node && node.hasMethod(getBCR)) {
+                var preciseRegion = node.invoke(getBCR);
+                if (preciseRegion) {
+                    height = preciseRegion.bottom - preciseRegion.top;
+                }
+            }
+
+            return height;
+        },
+
+        /**
+         * Helper method to query the rendered contents of the contentBox to find the
+         * node for the given section if it exists.
+         * 
+         * @method _findStdModSection
+         * @private
+         * @param {String} section The section for which the render Node is to be found. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @return {Node} The rendered node for the given section, or null if not found.
+         */
+        _findStdModSection: function(section) {
+            return this.get(CONTENT_BOX).query("> ." + StdMod.SECTION_CLASS_NAMES[section]);
+        },
+
+        /**
+         * Utility method, used by WidgetStdMods HTML_PARSER implementation
+         * to extract data for each section from markup.
+         *
+         * @method _parseStdModHTML
+         * @private
+         * @param {String} section
+         * @return {String} Inner HTML string with the contents of the section
+         */
+        _parseStdModHTML : function(section) {
+            var node = this._findStdModSection(section);
+            return (node) ? node.get(INNER_HTML) : "";
+        },
+
+        /**
+         * Retrieves the child nodes (content) of a standard module section
+         * 
+         * @method _getStdModContent
+         * @private
+         * @param {String} section The standard module section whose child nodes are to be retrieved. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @return {Node} The child node collection of the standard module section.
+         */
+        _getStdModContent : function(section) {
+            return (this[section + NODE_SUFFIX]) ? this[section + NODE_SUFFIX].get(CHILD_NODES) : null;
+        },
+
+        /**
+         * Updates the body section of the standard module with the content provided (either an HTML string, or node reference).
+         * <p>
+         * This method can be used instead of the corresponding section content attribute if you'd like to retain the current content of the section,
+         * and insert content before or after it, by specifying the <code>where</code> argument.
+         * </p>
+         * @method setStdModContent
+         * @param {String} section The standard module section whose content is to be updated. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @param {String | Node} content The content to be added, either an HTML string or a Node reference.
+         * @param {String} where Optional. Either WidgetStdMod.AFTER, WidgetStdMod.BEFORE or WidgetStdMod.REPLACE.
+         * If not provided, the content will replace existing content in the section.
+         */
+        setStdModContent : function(section, content, where) {
+            this.set(section + CONTENT_SUFFIX, content, {stdModPosition:where});
+        },
+
+        /**
+         * Returns the node reference for the given section. Note: The DOM is not queried for the node reference. The reference
+         * stored by the widget instance is returned if set.
+         * 
+         * @method getStdModNode
+         * @param {String} section The section whose node reference is required. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @return {Node} The node reference for the section, or null if not set.
+         */
+        getStdModNode : function(section) {
+            return this[section + NODE_SUFFIX] || null;
+        },
+
+        /**
+         * Sets the height on the provided header, body or footer element to 
+         * fill out the height of the Widget. It determines the height of the 
+         * widgets bounding box, based on it's configured height value, and 
+         * sets the height of the provided section to fill out any 
+         * space remaining after the other standard module section heights 
+         * have been accounted for.
+         * 
+         * <p><strong>NOTE:</strong> This method is not designed to work if an explicit 
+         * height has not been set on the Widget, since for an "auto" height Widget, 
+         * the heights of the header/body/footer will drive the height of the Widget.</p>
+         *
+         * @method fillHeight
+         * @param {Node} node The node which should be resized to fill out the height
+         * of the Widget bounding box. Should be a standard module section node which belongs
+         * to the widget.
+         */
+        fillHeight : function(node) {
+            if (node) {
+                var boundingBox = this.get(BOUNDING_BOX),
+                    stdModNodes = [this.headerNode, this.bodyNode, this.footerNode],
+                    stdModNode,
+                    total = 0,
+                    filled = 0,
+                    remaining = 0,
+                    validNode = false;
+
+                for (var i = 0, l = stdModNodes.length; i < l; i++) {
+                    stdModNode = stdModNodes[i];
+                    if (stdModNode) {
+                        if (stdModNode !== node) {
+                            filled += this._getPreciseHeight(stdModNode);
+                        } else {
+                            validNode = true;
+                        }
+                    }
+                }
+
+                if (validNode) {
+                    if (UA.ie || UA.opera) {
+                        // Need to set height to 0, to allow height to be reduced
+                        node.setStyle(HEIGHT, 0 + PX);
+                    }
+
+                    total = parseInt(boundingBox.getComputedStyle(HEIGHT), 10);
+                    if (L.isNumber(total)) {
+                        remaining = total - filled;
+
+                        if (remaining >= 0) {
+                            node.setStyle(HEIGHT, remaining + PX);
+                        }
+
+                        // Re-adjust height if required, to account for el padding and border
+                        var offsetHeight = this.get(CONTENT_BOX).get(OFFSET_HEIGHT); 
+                        if (offsetHeight != total) {
+                            remaining = remaining - (offsetHeight - total);
+                            node.setStyle(HEIGHT, remaining + PX);
+                        }
+                    }
+                }
+            }
+        }
+    };
+
+    Y.WidgetStdMod = StdMod;
+
+
+
+}, '3.0.0pr2' ,{requires:['widget']});

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-stdmod-min.js'
--- loggerhead/static/javascript/yui/build/widget/widget-stdmod-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-stdmod-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,7 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("widget-stdmod",function(A){var D=A.Lang,O=A.Node,U=A.UA,C=A.Widget,B="",g="hd",e="bd",H="ft",b="header",i="body",h="footer",m="fillHeight",K="stdmod",p="px",R="Node",f="Content",k="innerHTML",a="firstChild",G="childNodes",S="contentBox",l="boundingBox",W="height",d="offsetHeight",V="auto",J="headerContentChange",Z="bodyContentChange",M="footerContentChange",P="fillHeightChange",Q="HeightChange",n="contentUpdate",T="renderUI",c="bindUI",E="syncUI";function o(L){this._stdModNode=this.get(S);A.after(this._renderUIStdMod,this,T);A.after(this._bindUIStdMod,this,c);A.after(this._syncUIStdMod,this,E);}o.HEADER=b;o.BODY=i;o.FOOTER=h;o.AFTER="after";o.BEFORE="before";o.REPLACE="replace";var I=o.HEADER,X=o.BODY,N=o.FOOTER,j=o.AFTER,F=o.BEFORE;o.ATTRS={headerContent:{get:function(Y){var L=this._getStdModContent(I);return(L===null)?Y:L;}},footerContent:{get:function(Y){var L=this._getStdModContent(N);return(L===null)?Y:L;}},bodyContent:{get:function(Y){var L=this._getStdModContent(X);return(L===null)?Y:L;}},fillHeight:{value:o.BODY,validator:function(L){return this._validateFillHeight(L);}}};o.HTML_PARSER={headerContent:function(L){return this._parseStdModHTML(I);},bodyContent:function(L){return this._parseStdModHTML(X);},footerContent:function(L){return this._parseStdModHTML(N);}};o.SECTION_CLASS_NAMES={header:C.getClassName(g),body:C.getClassName(e),footer:C.getClassName(H)};o.TEMPLATES={header:'<div class="'+o.SECTION_CLASS_NAMES[I]+'"></div>',body:'<div class="'+o.SECTION_CLASS_NAMES[X]+'"></div>',footer:'<div class="'+o.SECTION_CLASS_NAMES[N]+'"></div>'};o._TEMPLATES={};o.prototype={_syncUIStdMod:function(){this._uiSetStdMod(I,this.get(I+f));this._uiSetStdMod(X,this.get(X+f));this._uiSetStdMod(N,this.get(N+f));this._uiSetFillHeight(this.get(m));},_renderUIStdMod:function(){this._stdModNode.addClass(C.getClassName(K));},_bindUIStdMod:function(){this.after(J,this._afterHeaderChange);this.after(Z,this._afterBodyChange);this.after(M,this._afterFooterChange);this.after(P,this._afterFillHeightChange);this.after(Q,this._fillHeight);this.after(n,this._fillHeight);},_afterHeaderChange:function(L){this._uiSetStdMod(I,L.newVal,L.stdModPosition);},_afterBodyChange:function(L){this._uiSetStdMod(X,L.newVal,L.stdModPosition);},_afterFooterChange:function(L){this._uiSetStdMod(N,L.newVal,L.stdModPosition);},_afterFillHeightChange:function(L){this._uiSetFillHeight(L.newVal);},_validateFillHeight:function(L){return !L||L==o.BODY||L==o.HEADER||L==o.FOOTER;},_uiSetFillHeight:function(q){var Y=this.getStdModNode(q);var L=this._currFillNode;if(L&&Y!==L){L.setStyle(W,B);}if(Y){this._currFillNode=Y;}this._fillHeight();},_fillHeight:function(){if(this.get(m)){var L=this.get(W);if(L!=B&&L!=V){this.fillHeight(this._currFillNode);}}},_uiSetStdMod:function(r,q,L){if(q){var Y=this.getStdModNode(r)||this._renderStdMod(r);if(q instanceof O){this._addNodeRef(Y,q,L);}else{this._addNodeHTML(Y,q,L);}this.fire(n);}},_renderStdMod:function(q){var L=this.get(S),Y=this._findStdModSection(q);if(!Y){Y=this._getStdModTemplate(q);}this._insertStdModSection(L,q,Y);this[q+R]=Y;return this[q+R];},_insertStdModSection:function(L,r,q){var Y=L.get(a);if(r===N||!Y){L.appendChild(q);}else{if(r===I){L.insertBefore(q,Y);}else{var s=this[N+R];if(s){L.insertBefore(q,s);}else{L.appendChild(q);}}}},_getStdModTemplate:function(Y){var L=o._TEMPLATES[Y];if(!L){o._TEMPLATES[Y]=L=O.create(o.TEMPLATES[Y]);}return L.cloneNode(true);},_addNodeHTML:function(q,Y,L){if(L==j){q.set(k,q.get(k)+Y);}else{if(L==F){q.set(k,Y+q.get(k));}else{q.set(k,Y);}}},_addNodeRef:function(u,r,Y){var L=true,q,t;if(Y==F){if(u.get(a)){for(q=u.size()-1;q>=0;--q){u.insertBefore(r.item(q),u.get(a));}L=false;}}else{if(Y!=j){u.set(k,B);}}if(L){for(q=0,t=r.size();q<t;++q){u.appendChild(r.item(q));}}},_getPreciseHeight:function(q){var L=(q)?q.get(d):0,r="getBoundingClientRect";if(q&&q.hasMethod(r)){var Y=q.invoke(r);if(Y){L=Y.bottom-Y.top;}}return L;},_findStdModSection:function(L){return this.get(S).query("> ."+o.SECTION_CLASS_NAMES[L]);},_parseStdModHTML:function(Y){var L=this._findStdModSection(Y);return(L)?L.get(k):"";},_getStdModContent:function(L){return(this[L+R])?this[L+R].get(G):null;},setStdModContent:function(q,Y,L){this.set(q+f,Y,{stdModPosition:L});},getStdModNode:function(L){return this[L+R]||null;},fillHeight:function(q){if(q){var u=this.get(l),w=[this.headerNode,this.bodyNode,this.footerNode],Y,x=0,y=0,t=0,s=false;for(var v=0,r=w.length;v<r;v++){Y=w[v];if(Y){if(Y!==q){y+=this._getPreciseHeight(Y);}else{s=true;}}}if(s){if(U.ie||U.opera){q.setStyle(W,0+p);}x=parseInt(u.getComputedStyle(W),10);if(D.isNumber(x)){t=x-y;if(t>=0){q.setStyle(W,t+p);}var L=this.get(S).get(d);if(L!=x){t=t-(L-x);q.setStyle(W,t+p);}}}}}};A.WidgetStdMod=o;},"3.0.0pr2",{requires:["widget"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/widget/widget-stdmod.js'
--- loggerhead/static/javascript/yui/build/widget/widget-stdmod.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget-stdmod.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,740 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('widget-stdmod', function(Y) {
+
+/**
+ * Provides standard module support for Widgets through an extension.
+ * 
+ * @module widget-stdmod
+ */
+    var L = Y.Lang,
+        Node = Y.Node,
+        UA = Y.UA,
+        Widget = Y.Widget,
+
+        EMPTY = "",
+        HD = "hd",
+        BD = "bd",
+        FT = "ft",
+        HEADER = "header",
+        BODY = "body",
+        FOOTER = "footer",
+        FILL_HEIGHT = "fillHeight",
+        STDMOD = "stdmod",
+
+        PX = "px",
+        NODE_SUFFIX = "Node",
+        CONTENT_SUFFIX = "Content",
+        INNER_HTML = "innerHTML",
+        FIRST_CHILD = "firstChild",
+        CHILD_NODES = "childNodes",
+
+        CONTENT_BOX = "contentBox",
+        BOUNDING_BOX = "boundingBox",
+
+        HEIGHT = "height",
+        OFFSET_HEIGHT = "offsetHeight",
+        AUTO = "auto",
+
+        HeaderChange = "headerContentChange",
+        BodyChange = "bodyContentChange",
+        FooterChange = "footerContentChange",
+        FillHeightChange = "fillHeightChange",
+        HeightChange = "HeightChange",        
+        ContentUpdate = "contentUpdate",
+
+        RENDERUI = "renderUI",
+        BINDUI = "bindUI",
+        SYNCUI = "syncUI";
+
+    /**
+     * Widget extension, which can be used to add Standard Module support to the 
+     * base Widget class, through the <a href="Base.html#method_build">Base.build</a> 
+     * method.
+     * <p>
+     * The extension adds header, body and footer sections to the Widget's content box and 
+     * provides the corresponding methods and attributes to modify the contents of these sections.
+     * </p>
+     * @class WidgetStdMod
+     * @param {Object} The user configuration object
+     */
+    function StdMod(config) {
+
+        this._stdModNode = this.get(CONTENT_BOX);
+
+        Y.after(this._renderUIStdMod, this, RENDERUI);
+        Y.after(this._bindUIStdMod, this, BINDUI);
+        Y.after(this._syncUIStdMod, this, SYNCUI);
+    }
+
+    /**
+     * Constant used to refer the the standard module header, in methods which expect a section specifier
+     * 
+     * @property WidgetStdMod.HEADER
+     * @static
+     * @type String
+     */
+    StdMod.HEADER = HEADER;
+    /**
+     * Constant used to refer the the standard module body, in methods which expect a section specifier
+     * 
+     * @property WidgetStdMod.BODY
+     * @static
+     * @type String
+     */
+    StdMod.BODY = BODY;
+    /**
+     * Constant used to refer the the standard module footer, in methods which expect a section specifier
+     * 
+     * @property WidgetStdMod.FOOTER
+     * @static
+     * @type String
+     */
+    StdMod.FOOTER = FOOTER;
+
+    /**
+     * Constant used to specify insertion position, when adding content to sections of the standard module in 
+     * methods which expect a "where" argument.
+     * <p>
+     * Inserts new content <em>before</em> the sections existing content.
+     * </p>
+     * @property WidgetStdMod.AFTER
+     * @static
+     * @type String
+     */
+    StdMod.AFTER = "after";
+
+    /**
+     * Constant used to specify insertion position, when adding content to sections of the standard module in
+     * methods which expect a "where" argument.
+     * <p>
+     * Inserts new content <em>before</em> the sections existing content.
+     * </p>
+     * @property WidgetStdMod.BEFORE
+     * @static
+     * @type String
+     */
+    StdMod.BEFORE = "before";
+    /**
+     * Constant used to specify insertion position, when adding content to sections of the standard module in
+     * methods which expect a "where" argument.
+     * <p>
+     * <em>Replaces</em> the sections existing content, with new content.
+     * </p>
+     * @property WidgetStdMod.REPLACE
+     * @static
+     * @type String
+     */
+    StdMod.REPLACE = "replace";
+
+    var STD_HEADER = StdMod.HEADER,
+        STD_BODY = StdMod.BODY,
+        STD_FOOTER = StdMod.FOOTER,
+        AFTER = StdMod.AFTER,
+        BEFORE = StdMod.BEFORE;
+
+    /**
+     * Static property used to define the default attribute 
+     * configuration introduced by WidgetStdMod.
+     * 
+     * @property WidgetStdMod.ATTRS
+     * @type Object
+     * @static
+     */
+    StdMod.ATTRS = {
+
+        /**
+         * @attribute headerContent
+         * @type {String | Node}
+         * @default undefined
+         * @description The content to be added to the header section. This will replace any existing content
+         * in the header. If you want to append, or insert new content, use the <a href="#method_setStdModContent">setStdModContent</a> method.
+         */
+        headerContent: {
+            get: function(val) {
+                var live = this._getStdModContent(STD_HEADER);
+                return (live === null) ? val : live;
+            }
+        },
+        
+        /**
+         * @attribute footerContent
+         * @type {String | Node}
+         * @default undefined
+         * @description The content to be added to the footer section. This will replace any existing content
+         * in the footer. If you want to append, or insert new content, use the <a href="#method_setStdModContent">setStdModContent</a> method.
+         */
+        footerContent: {
+            get: function(val) {
+                var live = this._getStdModContent(STD_FOOTER);
+                return (live === null) ? val : live;
+            }
+        },
+        
+        /**
+         * @attribute bodyContent
+         * @type {String | Node}
+         * @default undefined
+         * @description The content to be added to the body section. This will replace any existing content
+         * in the body. If you want to append, or insert new content, use the <a href="#method_setStdModContent">setStdModContent</a> method.
+         */
+        bodyContent: {
+            get: function(val) {
+                var live = this._getStdModContent(STD_BODY);
+                return (live === null) ? val : live;
+            }
+        },
+        
+        /**
+         * @attribute fillHeight
+         * @type {String}
+         * @default WidgetStdMod.BODY
+         * @description The section (WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER) which should be resized to fill the height of the standard module, when a 
+         * height is set on the Widget. If a height is not set on the widget, then all sections are sized based on 
+         * their content.
+         */
+        fillHeight: {
+            value: StdMod.BODY,
+            validator: function(val) {
+                 return this._validateFillHeight(val);
+            }
+        }
+    };
+
+    /**
+     * The HTML parsing rules for the WidgetStdMod class.
+     * 
+     * @property WidgetStdMod.HTML_PARSER
+     * @static
+     * @type Object
+     */
+    StdMod.HTML_PARSER = {
+        headerContent: function(contentBox) {
+            return this._parseStdModHTML(STD_HEADER);
+        },
+
+        bodyContent: function(contentBox) {
+            return this._parseStdModHTML(STD_BODY);
+        },
+
+        footerContent : function(contentBox) {
+            return this._parseStdModHTML(STD_FOOTER);
+        }
+    };
+
+    /**
+     * Static hash of default class names used for the header,
+     * body and footer sections of the standard module, keyed by
+     * the section identifier (WidgetStdMod.STD_HEADER, WidgetStdMod.STD_BODY, WidgetStdMod.STD_FOOTER)
+     *
+     * @property WidgetStdMod.SECTION_CLASS_NAMES
+     * @static
+     * @type Object
+     */
+    StdMod.SECTION_CLASS_NAMES = {
+        header: Widget.getClassName(HD),
+        body: Widget.getClassName(BD),
+        footer: Widget.getClassName(FT)
+    };
+
+    /**
+     * The template HTML strings for each of the standard module sections. Section entries are keyed by the section constants,
+     * WidgetStdMod.HEADER, WidgetStdMod.BODY, WidgetStdMod.FOOTER, and contain the HTML to be added for each section.
+     * e.g.
+     * <pre>
+     *    {
+     *       header : '&lt;div class="yui-widget-hd"&gt;&lt;/div&gt;',
+     *       body : '&lt;div class="yui-widget-bd"&gt;&lt;/div&gt;',
+     *       footer : '&lt;div class="yui-widget-ft"&gt;&lt;/div&gt;'
+     *    }
+     * </pre>
+     * @property WidgetStdMod.TEMPLATES
+     * @type Object
+     * @static
+     */
+    StdMod.TEMPLATES = {
+        header : '<div class="' + StdMod.SECTION_CLASS_NAMES[STD_HEADER] + '"></div>',
+        body : '<div class="' + StdMod.SECTION_CLASS_NAMES[STD_BODY] + '"></div>',
+        footer : '<div class="' + StdMod.SECTION_CLASS_NAMES[STD_FOOTER] + '"></div>'
+    };
+
+    /**
+     * Stores nodes created from the WidgetStdMod.TEMPLATES strings,
+     * which are cloned to create new header, footer, body sections for
+     * new instances.
+     *
+     * @property WidgetStdMod._TEMPLATES
+     * @static
+     * @private
+     */
+    StdMod._TEMPLATES = {};
+
+    StdMod.prototype = {
+
+        /**
+         * Synchronizes the UI to match the Widgets standard module state.
+         * <p>
+         * This method is invoked after syncUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _syncUIStdMod
+         * @protected
+         */
+        _syncUIStdMod : function() {
+            this._uiSetStdMod(STD_HEADER, this.get(STD_HEADER + CONTENT_SUFFIX));
+            this._uiSetStdMod(STD_BODY, this.get(STD_BODY + CONTENT_SUFFIX));
+            this._uiSetStdMod(STD_FOOTER, this.get(STD_FOOTER + CONTENT_SUFFIX));
+            this._uiSetFillHeight(this.get(FILL_HEIGHT));
+        },
+
+        /**
+         * Creates/Initializes the DOM for standard module support.
+         * <p>
+         * This method is invoked after renderUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _renderUIStdMod
+         * @protected
+         */
+        _renderUIStdMod : function() {
+            this._stdModNode.addClass(Widget.getClassName(STDMOD));
+        },
+
+        /**
+         * Binds event listeners responsible for updating the UI state in response to 
+         * Widget standard module related state changes.
+         * <p>
+         * This method is invoked after bindUI is invoked for the Widget class
+         * using YUI's aop infrastructure.
+         * </p>
+         * @method _bindUIStdMod
+         * @protected
+         */
+        _bindUIStdMod : function() {
+            this.after(HeaderChange, this._afterHeaderChange);
+            this.after(BodyChange, this._afterBodyChange);
+            this.after(FooterChange, this._afterFooterChange);
+
+            this.after(FillHeightChange, this._afterFillHeightChange);
+            this.after(HeightChange, this._fillHeight);            
+            this.after(ContentUpdate, this._fillHeight);
+        },
+
+        /**
+         * Default attribute change listener for the headerContent attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         *
+         * @method _afterHeaderChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterHeaderChange : function(e) {
+            this._uiSetStdMod(STD_HEADER, e.newVal, e.stdModPosition);
+        },
+
+        /**
+         * Default attribute change listener for the bodyContent attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         *
+         * @method _afterBodyChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterBodyChange : function(e) {
+            this._uiSetStdMod(STD_BODY, e.newVal, e.stdModPosition);
+        },
+
+        /**
+         * Default attribute change listener for the footerContent attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         *
+         * @method _afterFooterChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterFooterChange : function(e) {
+            this._uiSetStdMod(STD_FOOTER, e.newVal, e.stdModPosition);
+        },
+
+        /**
+         * Default attribute change listener for the fillHeight attribute, responsible
+         * for updating the UI, in response to attribute changes.
+         * 
+         * @method _afterFillHeightChange
+         * @protected
+         * @param {Event.Facade} e The event facade for the attribute change
+         */
+        _afterFillHeightChange: function (e) {
+            this._uiSetFillHeight(e.newVal);
+        },
+
+        /**
+         * Default validator for the fillHeight attribute. Verifies that the 
+         * value set is a valid section specifier - one of WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER,
+         * or a falsey value if fillHeight is to be disabled.
+         *
+         * @method _validateFillHeight
+         * @protected
+         * @param {String} val The section which should be setup to fill height, or false/null to disable fillHeight
+         * @return true if valid, false if not
+         */
+        _validateFillHeight : function(val) {
+            return !val || val == StdMod.BODY || val == StdMod.HEADER || val == StdMod.FOOTER;    
+        },
+
+        /**
+         * Updates the rendered UI, to resize the provided section so that the standard module fills out 
+         * the specified widget height. Note: This method does not check whether or not a height is set 
+         * on the Widget.
+         * 
+         * @method _uiSetFillHeight
+         * @protected
+         * @param {String} fillSection A valid section specifier - one of WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER
+         */
+        _uiSetFillHeight : function(fillSection) {
+            var fillNode = this.getStdModNode(fillSection);
+            var currNode = this._currFillNode;
+
+            if (currNode && fillNode !== currNode){
+                currNode.setStyle(HEIGHT, EMPTY);
+            }
+
+            if (fillNode) {
+                this._currFillNode = fillNode;
+            }
+
+            this._fillHeight();
+        },
+
+        /**
+         * Updates the rendered UI, to resize the current section specified by the fillHeight attribute, so
+         * that the standard module fills out the Widget height. If a height has not been set on Widget,
+         * the section is not resized (height is set to "auto").
+         * 
+         * @method _fillHeight
+         * @private
+         */
+        _fillHeight : function() {
+            if (this.get(FILL_HEIGHT)) {
+                var height = this.get(HEIGHT);
+                if (height != EMPTY && height != AUTO) {
+                    this.fillHeight(this._currFillNode);    
+                }
+            }
+        },
+
+        /**
+         * Updates the rendered UI, adding the provided content (either an HTML string, or node reference),
+         * to the specified section. The content is either added before, after or replaces existing content
+         * in the section, based on the value of the <code>where</code> argument.
+         * 
+         * @method _uiSetStdMod
+         * @protected
+         * 
+         * @param {String} section The section to be updated. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER. 
+         * @param {String | Node} content The new content (either as an HTML string, or Node reference) to add to the section
+         * @param {String} where Optional. Either WidgetStdMod.AFTER, WidgetStdMod.BEFORE or WidgetStdMod.REPLACE.
+         * If not provided, the content will replace existing content in the section.
+         */
+        _uiSetStdMod : function(section, content, where) {
+            if (content) {
+                var node = this.getStdModNode(section) || this._renderStdMod(section);
+                if (content instanceof Node) {
+                    this._addNodeRef(node, content, where);
+                } else {
+                    this._addNodeHTML(node, content, where);
+                }
+                this.fire(ContentUpdate);
+            }
+        },
+
+        /**
+         * Creates the DOM node for the given section, and inserts it into the correct location in the contentBox.
+         *
+         * @method _renderStdMod
+         * @protected
+         * @param {String} section The section to create/render. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @return {Node} A reference to the added section node
+         */
+        _renderStdMod : function(section) {
+
+            var contentBox = this.get(CONTENT_BOX),
+                sectionNode = this._findStdModSection(section);
+
+            if (!sectionNode) {
+                sectionNode = this._getStdModTemplate(section);
+            }
+
+            this._insertStdModSection(contentBox, section, sectionNode);
+
+            this[section + NODE_SUFFIX] = sectionNode;
+            return this[section + NODE_SUFFIX];
+        },
+
+        /**
+         * Helper method to insert the Node for the given section into the correct location in the contentBox.
+         *
+         * @method _insertStdModSection
+         * @private
+         * @param {Node} contentBox A reference to the Widgets content box.
+         * @param {String} section The section to create/render. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @param {Node} sectionNode The Node for the section.
+         */
+        _insertStdModSection : function(contentBox, section, sectionNode) {
+            var fc = contentBox.get(FIRST_CHILD);
+
+            if (section === STD_FOOTER || !fc) {
+                contentBox.appendChild(sectionNode);
+            } else {
+                if (section === STD_HEADER) {
+                    contentBox.insertBefore(sectionNode, fc);
+                } else {
+                    // BODY
+                    var footer = this[STD_FOOTER + NODE_SUFFIX];
+                    if (footer) {
+                        contentBox.insertBefore(sectionNode, footer);
+                    } else {
+                        contentBox.appendChild(sectionNode);
+                    }
+                }
+            }
+        },
+
+        /**
+         * Gets a new Node reference for the given standard module section, by cloning
+         * the stored template node.
+         *
+         * @method _getStdModTemplate
+         * @protected
+         * @param {String} section The section to create a new node for. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @return {Node} The new Node instance for the section
+         */
+        _getStdModTemplate : function(section) {
+            var template = StdMod._TEMPLATES[section];
+
+            if (!template) {
+                StdMod._TEMPLATES[section] = template = Node.create(StdMod.TEMPLATES[section]);
+            }
+            return template.cloneNode(true);
+        },
+
+        /**
+         * Helper method to add the given HTML string to the node reference provided.
+         * The HTML is added either before, after or replaces the existing node content 
+         * based on the value of the <code>where</code> argument.
+         *
+         * @method _addNodeHTML
+         * @private
+         * 
+         * @param {Node} node The section Node to be updated.
+         * @param {String} html The new content HTML string to be added to the section Node.
+         * @param {String} where Optional. Either WidgetStdMod.AFTER, WidgetStdMod.BEFORE or WidgetStdMod.REPLACE.
+         * If not provided, the content will replace Nodes existing content.
+         */
+        _addNodeHTML : function(node, html, where) {
+            if (where == AFTER) {
+                node.set(INNER_HTML, node.get(INNER_HTML) + html);
+            } else if (where == BEFORE) {
+                node.set(INNER_HTML, html + node.get(INNER_HTML));
+            } else {
+                node.set(INNER_HTML, html);
+            }
+        },
+
+        /**
+         * Helper method to add nodes, to another node.
+         * The child node(s) are added either before, after or replaces the existing node content 
+         * based on the value of the <code>where</code> argument.
+         * 
+         * @method _addNodeRef
+         * @private
+         * 
+         * @param {Node} node The section Node to be updated.
+         * @param {Node} child The new content Node to be added to section Node provided.
+         * @param {String} where Optional. Either WidgetStdMod.AFTER, WidgetStdMod.BEFORE or WidgetStdMod.REPLACE.
+         * If not provided, the content will replace existing content in the Node.
+         */
+        _addNodeRef : function(node, children, where) {
+            var append = true, 
+                i, s;
+
+            if (where == BEFORE) {
+                if (node.get(FIRST_CHILD)) {
+                    for (i = node.size() - 1; i >=0; --i) {
+                        node.insertBefore(children.item(i), node.get(FIRST_CHILD));
+                    }
+                    append = false;
+                }
+            } else if (where != AFTER) { // replace
+                node.set(INNER_HTML, EMPTY);
+            }
+            if (append) {
+                for (i = 0, s = children.size(); i < s; ++i) {
+                    node.appendChild(children.item(i));
+                }
+            }
+        },
+
+        /**
+         * Helper method to obtain the precise height of the node provided, including padding and border.
+         * The height could be a sub-pixel value for certain browsers, such as Firefox 3.
+         *
+         * @method _getPreciseHeight
+         * @private
+         * @param {Node} node The node for which the precise height is required.
+         * @return {Number} The height of the Node including borders and padding, possibly a float.
+         */
+        _getPreciseHeight : function(node) {
+            var height = (node) ? node.get(OFFSET_HEIGHT) : 0,
+                getBCR = "getBoundingClientRect";
+
+            if (node && node.hasMethod(getBCR)) {
+                var preciseRegion = node.invoke(getBCR);
+                if (preciseRegion) {
+                    height = preciseRegion.bottom - preciseRegion.top;
+                }
+            }
+
+            return height;
+        },
+
+        /**
+         * Helper method to query the rendered contents of the contentBox to find the
+         * node for the given section if it exists.
+         * 
+         * @method _findStdModSection
+         * @private
+         * @param {String} section The section for which the render Node is to be found. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @return {Node} The rendered node for the given section, or null if not found.
+         */
+        _findStdModSection: function(section) {
+            return this.get(CONTENT_BOX).query("> ." + StdMod.SECTION_CLASS_NAMES[section]);
+        },
+
+        /**
+         * Utility method, used by WidgetStdMods HTML_PARSER implementation
+         * to extract data for each section from markup.
+         *
+         * @method _parseStdModHTML
+         * @private
+         * @param {String} section
+         * @return {String} Inner HTML string with the contents of the section
+         */
+        _parseStdModHTML : function(section) {
+            var node = this._findStdModSection(section);
+            return (node) ? node.get(INNER_HTML) : "";
+        },
+
+        /**
+         * Retrieves the child nodes (content) of a standard module section
+         * 
+         * @method _getStdModContent
+         * @private
+         * @param {String} section The standard module section whose child nodes are to be retrieved. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @return {Node} The child node collection of the standard module section.
+         */
+        _getStdModContent : function(section) {
+            return (this[section + NODE_SUFFIX]) ? this[section + NODE_SUFFIX].get(CHILD_NODES) : null;
+        },
+
+        /**
+         * Updates the body section of the standard module with the content provided (either an HTML string, or node reference).
+         * <p>
+         * This method can be used instead of the corresponding section content attribute if you'd like to retain the current content of the section,
+         * and insert content before or after it, by specifying the <code>where</code> argument.
+         * </p>
+         * @method setStdModContent
+         * @param {String} section The standard module section whose content is to be updated. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @param {String | Node} content The content to be added, either an HTML string or a Node reference.
+         * @param {String} where Optional. Either WidgetStdMod.AFTER, WidgetStdMod.BEFORE or WidgetStdMod.REPLACE.
+         * If not provided, the content will replace existing content in the section.
+         */
+        setStdModContent : function(section, content, where) {
+            this.set(section + CONTENT_SUFFIX, content, {stdModPosition:where});
+        },
+
+        /**
+         * Returns the node reference for the given section. Note: The DOM is not queried for the node reference. The reference
+         * stored by the widget instance is returned if set.
+         * 
+         * @method getStdModNode
+         * @param {String} section The section whose node reference is required. Either WidgetStdMod.HEADER, WidgetStdMod.BODY or WidgetStdMod.FOOTER.
+         * @return {Node} The node reference for the section, or null if not set.
+         */
+        getStdModNode : function(section) {
+            return this[section + NODE_SUFFIX] || null;
+        },
+
+        /**
+         * Sets the height on the provided header, body or footer element to 
+         * fill out the height of the Widget. It determines the height of the 
+         * widgets bounding box, based on it's configured height value, and 
+         * sets the height of the provided section to fill out any 
+         * space remaining after the other standard module section heights 
+         * have been accounted for.
+         * 
+         * <p><strong>NOTE:</strong> This method is not designed to work if an explicit 
+         * height has not been set on the Widget, since for an "auto" height Widget, 
+         * the heights of the header/body/footer will drive the height of the Widget.</p>
+         *
+         * @method fillHeight
+         * @param {Node} node The node which should be resized to fill out the height
+         * of the Widget bounding box. Should be a standard module section node which belongs
+         * to the widget.
+         */
+        fillHeight : function(node) {
+            if (node) {
+                var boundingBox = this.get(BOUNDING_BOX),
+                    stdModNodes = [this.headerNode, this.bodyNode, this.footerNode],
+                    stdModNode,
+                    total = 0,
+                    filled = 0,
+                    remaining = 0,
+                    validNode = false;
+
+                for (var i = 0, l = stdModNodes.length; i < l; i++) {
+                    stdModNode = stdModNodes[i];
+                    if (stdModNode) {
+                        if (stdModNode !== node) {
+                            filled += this._getPreciseHeight(stdModNode);
+                        } else {
+                            validNode = true;
+                        }
+                    }
+                }
+
+                if (validNode) {
+                    if (UA.ie || UA.opera) {
+                        // Need to set height to 0, to allow height to be reduced
+                        node.setStyle(HEIGHT, 0 + PX);
+                    }
+
+                    total = parseInt(boundingBox.getComputedStyle(HEIGHT), 10);
+                    if (L.isNumber(total)) {
+                        remaining = total - filled;
+
+                        if (remaining >= 0) {
+                            node.setStyle(HEIGHT, remaining + PX);
+                        }
+
+                        // Re-adjust height if required, to account for el padding and border
+                        var offsetHeight = this.get(CONTENT_BOX).get(OFFSET_HEIGHT); 
+                        if (offsetHeight != total) {
+                            remaining = remaining - (offsetHeight - total);
+                            node.setStyle(HEIGHT, remaining + PX);
+                        }
+                    }
+                }
+            }
+        }
+    };
+
+    Y.WidgetStdMod = StdMod;
+
+
+
+}, '3.0.0pr2' ,{requires:['widget']});

=== added file 'loggerhead/static/javascript/yui/build/widget/widget.js'
--- loggerhead/static/javascript/yui/build/widget/widget.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/widget/widget.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1465 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('widget', function(Y) {
+
+/**
+ * Provides the base Widget class along with an augmentable PluginHost interface
+ *
+ * @module widget
+ */
+
+/**
+ * An augmentable class, which when added to a "Base" based class, allows 
+ * the class to support Plugins, providing plug and unplug methods and performing
+ * instantiation and cleanup during the init and destroy lifecycle phases respectively.
+ *
+ * @class PluginHost
+ */
+
+var L = Y.Lang;
+
+function PluginHost(config) {
+    this._plugins = {};
+
+    this.after("init", function(e, cfg) {this._initPlugins(cfg);});
+    this.after("destroy", this._destroyPlugins);
+}
+
+PluginHost.prototype = {
+
+    /**
+     * Register and instantiate a plugin with the Widget.
+     * 
+     * @method plug
+     * @chainable
+     * @param p {String | Object |Array} Accepts the registered 
+     * namespace for the Plugin or an object literal with an "fn" property
+     * specifying the Plugin class and a "cfg" property specifying
+     * the configuration for the Plugin.
+     * <p>
+     * Additionally an Array can also be passed in, with either the above String or 
+     * Object literal values, allowing for multiple plugin registration in 
+     * a single call.
+     * </p>
+     */
+    plug: function(p) {
+        if (p) {
+            if (L.isArray(p)) {
+                var ln = p.length;
+                for (var i = 0; i < ln; i++) {
+                    this.plug(p[i]);
+                }
+            } else if (L.isFunction(p)) {
+                this._plug(p);
+            } else {
+                this._plug(p.fn, p.cfg);
+            }
+        }
+        return this;
+    },
+
+    /**
+     * Unregister and destroy a plugin already instantiated with the Widget.
+     * 
+     * @method unplug
+     * @param {String} ns The namespace key for the Plugin. If not provided,
+     * all registered plugins are unplugged.
+     * @chainable
+     */
+    unplug: function(ns) {
+        if (ns) {
+            this._unplug(ns);
+        } else {
+            for (ns in this._plugins) {
+                if (Y.Object.owns(this._plugins, ns)) {
+                    this._unplug(ns);
+                }
+            }
+        }
+        return this;
+    },
+
+    /**
+     * Determines if a plugin has been registered and instantiated 
+     * for this widget.
+     * 
+     * @method hasPlugin
+     * @public
+     * @return {Boolean} returns true, if the plugin has been applied
+     * to this widget.
+     */
+    hasPlugin : function(ns) {
+        return (this._plugins[ns] && this[ns]);
+    },
+
+    /**
+     * Initializes static plugins registered on the host (the
+     * "PLUGINS" static property) and any plugins passed in 
+     * for the instance through the "plugins" configuration property.
+     *
+     * @method _initPlugins
+     * @param {Config} the user configuration object for the host.
+     * @private
+     */
+    _initPlugins: function(config) {
+
+        // Class Configuration
+        var classes = this._getClasses(), constructor;
+        for (var i = 0; i < classes.length; i++) {
+            constructor = classes[i];
+            if (constructor.PLUGINS) {
+                this.plug(constructor.PLUGINS);
+            }
+        }
+
+        // User Configuration
+        if (config && config.plugins) {
+            this.plug(config.plugins);
+        }
+    },
+
+    /**
+     * Private method used to unplug and destroy all plugins on the host
+     * @method _destroyPlugins
+     * @private
+     */
+    _destroyPlugins: function() {
+        this._unplug();
+    },
+
+    /**
+     * Private method used to instantiate and attach plugins to the host
+     * @method _plug
+     * @param {Function} PluginClass The plugin class to instantiate
+     * @param {Object} config The configuration object for the plugin
+     * @private
+     */
+    _plug: function(PluginClass, config) {
+        if (PluginClass && PluginClass.NS) {
+            var ns = PluginClass.NS;
+
+            config = config || {};
+            config.owner = this;
+
+            if (this.hasPlugin(ns)) {
+                // Update config
+                this[ns].setAtts(config);
+            } else {
+                // Create new instance
+                this[ns] = new PluginClass(config);
+                this._plugins[ns] = PluginClass;
+            }
+        }
+    },
+
+    /**
+     * Private method used to unregister and destroy a plugin already instantiated with the host.
+     *
+     * @method _unplug
+     * @private
+     * @param {String} ns The namespace key for the Plugin. If not provided,
+     * all registered plugins are unplugged.
+     */
+    _unplug : function(ns) {
+        if (ns) {
+            if (this[ns]) {
+                this[ns].destroy();
+                delete this[ns];
+            }
+            if (this._plugins[ns]) {
+                delete this._plugins[ns];
+            }
+        }
+    }
+};
+
+Y.PluginHost = PluginHost;
+
+/**
+ * Provides the base Widget class along with an augmentable PluginHost interface
+ *
+ * @module widget
+ */
+
+// Local Constants
+var WIDGET = "widget",
+    CONTENT = "content",
+    VISIBLE = "visible",
+    HIDDEN = "hidden",
+    DISABLED = "disabled",
+    FOCUS = "focus",
+    BLUR = "blur",
+    HAS_FOCUS = "hasFocus",
+    WIDTH = "width",
+    HEIGHT = "height",
+    EMPTY = "",
+    HYPHEN = "-",
+    BOUNDING_BOX = "boundingBox",
+    CONTENT_BOX = "contentBox",
+    PARENT_NODE = "parentNode",
+    FIRST_CHILD = "firstChild",
+    OWNER_DOCUMENT = "ownerDocument",
+    BODY = "body",
+    TAB_INDEX = "tabIndex",
+    LOCALE = "locale",
+    INIT_VALUE = "initValue",
+    ID = "id",
+    RENDER = "render",
+    RENDERED = "rendered",
+    DESTROYED = "destroyed",
+
+    ContentUpdate = "contentUpdate",
+
+    O = Y.Object,
+    Node = Y.Node,
+    ClassNameManager = Y.ClassNameManager;
+
+// Widget nodeid-to-instance map for now, 1-to-1.
+var _instances = {};
+
+/**
+ * A base class for widgets, providing:
+ * <ul>
+ *    <li>The render lifecycle method, in addition to the init and destroy 
+ *        lifecycle methods provide by Base</li>
+ *    <li>Abstract methods to support consistent MVC structure across 
+ *        widgets: renderer, renderUI, bindUI, syncUI</li>
+ *    <li>Support for common widget attributes, such as boundingBox, contentBox, visible, 
+ *        disabled, hasFocus, strings</li>
+ *    <li>Plugin registration and activation support</li>
+ * </ul>
+ *
+ * @param config {Object} Object literal specifying widget configuration 
+ * properties.
+ *
+ * @class Widget
+ * @constructor
+ * @extends Base
+ */
+function Widget(config) {
+
+    this._yuid = Y.guid(WIDGET);
+    this._strings = {};
+
+    Widget.superclass.constructor.apply(this, arguments);
+}
+
+/**
+ * The build configuration for the Widget class.
+ * <p>
+ * Defines the static fields which need to be aggregated,
+ * when this class is used as the main class passed to 
+ * the <a href="Base.html#method_build">Base.build</a> method.
+ * </p>
+ * @property _buildCfg
+ * @type Object
+ * @static
+ * @final
+ * @private
+ */
+Widget._buildCfg = {
+    aggregates : ["PLUGINS", "HTML_PARSER"]
+};
+
+/**
+ * Static property provides a string to identify the class.
+ * <p>
+ * Currently used to apply class identifiers to the bounding box 
+ * and to classify events fired by the widget.
+ * </p>
+ *
+ * @property Widget.NAME
+ * @type String
+ * @static
+ */
+Widget.NAME = WIDGET;
+
+/**
+ * Constant used to identify state changes originating from
+ * the DOM (as opposed to the JavaScript model).
+ *
+ * @property Widget.UI_SRC
+ * @type String
+ * @static
+ * @final
+ */
+Widget.UI_SRC = "ui";
+
+var UI = Widget.UI_SRC;
+
+/**
+ * Static property used to define the default attribute 
+ * configuration for the Widget.
+ * 
+ * @property Widget.ATTRS
+ * @type Object
+ * @static
+ */
+Widget.ATTRS = {
+
+    /**
+     * Flag indicating whether or not this object
+     * has been through the render lifecycle phase.
+     *
+     * @attribute rendered
+     * @readOnly
+     * @default false
+     * @type boolean
+     */
+    rendered: {
+        value:false,
+        readOnly:true
+    },
+
+    /**
+    * @attribute boundingBox
+    * @description The outermost DOM node for the Widget, used for sizing and positioning 
+    * of a Widget as well as a containing element for any decorator elements used 
+    * for skinning.
+    * @type Node
+    */
+    boundingBox: {
+        value:null,
+        set: function(node) {
+            return this._setBoundingBox(node);
+        },
+        writeOnce: true
+    },
+
+    /**
+    * @attribute contentBox
+    * @description A DOM node that is a direct descendent of a Widget's bounding box that 
+    * houses its content.
+    * @type Node
+    */
+    contentBox: {
+        value:null,
+        set: function(node) {
+            return this._setContentBox(node);
+        },
+        writeOnce: true
+    },
+
+    /**
+    * @attribute tabIndex
+    * @description The tabIndex, applied to the bounding box
+    * @type Number
+    */
+    tabIndex: {
+        value: 0
+    },
+
+    /**
+    * @attribute hasFocus
+    * @description Boolean indicating if the Widget has focus.
+    * @default false
+    * @type boolean
+    */
+    hasFocus: {
+        value: false
+    },
+
+    /**
+    * @attribute disabled
+    * @description Boolean indicating if the Widget should be disabled. The disabled implementation
+    * is left to the specific classes extending widget.
+    * @default false
+    * @type boolean
+    */
+    disabled: {
+        value: false
+    },
+
+    /**
+    * @attribute visible
+    * @description Boolean indicating weather or not the Widget is visible.
+    * @default true
+    * @type boolean
+    */
+    visible: {
+        value: true
+    },
+
+    /**
+    * @attribute height
+    * @description String with units, or number, representing the height of the Widget. If a number is provided,
+    * the default unit, defined by the Widgets DEF_UNIT, property is used.
+    * @default ""
+    * @type {String | Number}
+    */
+    height: {
+        value: EMPTY
+    },
+
+    /**
+    * @attribute width
+    * @description String with units, or number, representing the width of the Widget. If a number is provided,
+    * the default unit, defined by the Widgets DEF_UNIT, property is used.
+    * @default ""
+    * @type {String | Number}
+    */
+    width: {
+        value: EMPTY
+    },
+
+    /**
+     * @attribute moveStyles
+     * @description Flag defining whether or not style properties from the content box
+     * should be moved to the bounding box when wrapped (as defined by the WRAP_STYLES property)
+     * @default false
+     * @type boolean
+     */
+    moveStyles: {
+        value: false
+    },
+
+    /**
+     * @attribute locale
+     * @description
+     * The default locale for the widget. NOTE: Using get/set on the "strings" attribute will
+     * return/set strings for this locale.
+     * @default "en"
+     * @type String
+     */
+    locale : {
+        value: "en"
+    },
+
+    /**
+     * @attribute strings
+     * @description Collection of strings used to label elements of the Widget's UI.
+     * @default null
+     * @type Object
+     */
+    strings: {
+        set: function(val) {
+            return this._setStrings(val, this.get(LOCALE));
+        },
+
+        get: function() {
+            return this.getStrings(this.get(LOCALE));
+        }
+    }
+};
+
+/**
+ * Cached lowercase version of Widget.NAME
+ *
+ * @property Widget._NAME_LOWERCASE
+ * @private
+ * @static
+ */
+Widget._NAME_LOWERCASE = Widget.NAME.toLowerCase();
+
+/**
+ * Generate a standard prefixed classname for the Widget, prefixed by the default prefix defined
+ * by the <code>Y.config.classNamePrefix</code> attribute used by <code>ClassNameManager</code> and 
+ * <code>Widget.NAME.toLowerCase()</code> (e.g. "yui-widget-xxxxx-yyyyy", based on default values for 
+ * the prefix and widget class name).
+ * <p>
+ * The instance based version of this method can be used to generate standard prefixed classnames,
+ * based on the instances NAME, as opposed to Widget.NAME. This method should be used when you
+ * need to use a constant class name across different types instances.
+ * </p>
+ * @method getClassName
+ * @param {String*} args* 0..n strings which should be concatenated, using the default separator defined by ClassNameManager, to create the class name
+ */
+Widget.getClassName = function() {
+	var args = Y.Array(arguments, 0, true);
+	args.splice(0, 0, this._NAME_LOWERCASE);
+	return ClassNameManager.getClassName.apply(ClassNameManager, args);
+};
+
+/**
+ * Returns the widget instance whose bounding box contains, or is, the given node. 
+ * <p>
+ * In the case of nested widgets, the nearest bounding box ancestor is used to
+ * return the widget instance.
+ * </p>
+ * @method Widget.getByNode
+ * @static
+ * @param node {Node | String} The node for which to return a Widget instance. If a selector
+ * string is passed in, which selects more than one node, the first node found is used.
+ * @return {Widget} Widget instance, or null if not found.
+ */
+Widget.getByNode = function(node) {
+    var widget,
+        bbMarker = Widget.getClassName();
+
+    node = Node.get(node);
+    if (node) {
+        node = (node.hasClass(bbMarker)) ? node : node.ancestor("." + bbMarker);
+        if (node) {
+            widget = _instances[node.get(ID)];
+        }
+    }
+
+    return widget || null;
+};
+
+/**
+ * Object hash, defining how attribute values are to be parsed from
+ * markup contained in the widget's content box. e.g.:
+ * <pre>
+ *   {
+ *       // Set single Node references using selector syntax 
+ *       // (selector is run through node.query)
+ *       titleNode: "span.yui-title",
+ *       // Set NodeList references using selector syntax 
+ *       // (array indicates selector is to be run through node.queryAll)
+ *       listNodes: ["li.yui-item"],
+ *       // Set other attribute types, using a parse function. 
+ *       // Context is set to the widget instance.
+ *       label: function(contentBox) {
+ *           return contentBox.query("span.title").get("innerHTML");
+ *       }
+ *   }
+ * </pre>
+ * 
+ * @property Widget.HTML_PARSER
+ * @type Object
+ * @static
+ */
+Widget.HTML_PARSER = {};
+
+Y.extend(Widget, Y.Base, {
+
+	/**
+	 * Returns a class name prefixed with the the value of the 
+	 * <code>YUI.config.classNamePrefix</code> attribute + the instances <code>NAME</code> property.
+	 * Uses <code>YUI.config.classNameDelimiter</code> attribute to delimit the provided strings.
+	 * e.g. 
+	 * <code>
+	 * <pre>
+	 *    // returns "yui-slider-foo-bar", for a slider instance
+	 *    var scn = slider.getClassName('foo','bar');
+	 *
+	 *    // returns "yui-overlay-foo-bar", for an overlay instance
+	 *    var ocn = slider.getClassName('foo','bar');
+	 * </pre>
+	 * </code>
+	 *
+	 * @method getClassName
+	 * @param {String}+ One or more classname bits to be joined and prefixed
+	 */
+	getClassName: function () {
+		var args = Y.Array(arguments, 0, true);
+		args.splice(0, 0, this._name);
+		return ClassNameManager.getClassName.apply(ClassNameManager, args);
+	},
+
+    /**
+     * Initializer lifecycle implementation for the Widget class. Registers the 
+     * widget instance, and runs through the Widget's HTML_PARSER definition. 
+     *
+     * @method initializer
+     * @protected
+     * @param  config {Object} Configuration object literal for the widget
+     */
+    initializer: function(config) {
+
+        /**
+         * Notification event, which widget implementations can fire, when
+         * they change the content of the widget. This event has no default
+         * behavior and cannot be prevented, so the "on" or "after"
+         * moments are effectively equivalent (with on listeners being invoked before 
+         * after listeners).
+         * 
+         * @event widget:contentUpdate
+         * @preventable false
+         * @param {Event.Facade} e The Event Facade
+         */
+        this.publish(ContentUpdate, { preventable:false });
+
+		this._name = this.constructor.NAME.toLowerCase();
+
+        var nodeId = this.get(BOUNDING_BOX).get(ID);
+        if (nodeId) {
+            _instances[nodeId] = this;
+        }
+
+        var htmlConfig = this._parseHTML(this.get(CONTENT_BOX));
+        if (htmlConfig) {
+            Y.aggregate(config, htmlConfig, false);
+        }
+
+        Y.PluginHost.call(this, config);
+    },
+
+    /**
+     * Descructor lifecycle implementation for the Widget class. Purges events attached
+     * to the bounding box (and all child nodes) and removes the Widget from the 
+     * list of registered widgets.
+     *
+     * @method destructor
+     * @protected
+     */
+    destructor: function() {
+
+        var boundingBox = this.get(BOUNDING_BOX);
+        
+        Y.Event.purgeElement(boundingBox, true);
+
+        var nodeId = boundingBox.get(ID);
+        if (nodeId && nodeId in _instances) {
+            delete _instances[nodeId];
+        }
+    },
+
+    /**
+     * Establishes the initial DOM for the widget. Invoking this
+     * method will lead to the creating of all DOM elements for
+     * the widget (or the manipulation of existing DOM elements 
+     * for the progressive enhancement use case).
+     * <p>
+     * This method should only be invoked once for an initialized
+     * widget.
+     * </p>
+     * <p>
+     * It delegates to the widget specific renderer method to do
+     * the actual work.
+     * </p>
+     *
+     * @method render
+     * @chainable
+     * @final 
+     * @param  parentNode {Object | String} Optional. The Node under which the 
+     * Widget is to be rendered. This can be a Node instance or a CSS selector string. 
+     * <p>
+     * If the selector string returns more than one Node, the first node will be used 
+     * as the parentNode. NOTE: This argument is required if both the boundingBox and contentBox
+     * are not currently in the document. If it's not provided, the Widget will be rendered
+     * to the body of the current document in this case.
+     * </p>
+     */
+    render: function(parentNode) {
+
+        if (this.get(DESTROYED)) {
+            return;
+        }
+
+        if (!this.get(RENDERED)) {
+             /**
+             * Lifcyle event for the render phase, fired prior to rendering the UI 
+             * for the widget (prior to invoking the widgets renderer method).
+             * <p>
+             * Subscribers to the "on" moment of this event, will be notified 
+             * before the widget is rendered.
+             * </p>
+             * <p>
+             * Subscribers to the "after" momemt of this event, will be notified
+             * after rendering is complete.
+             * </p>
+             *
+             * @event widget:render
+             * @preventable _defRenderFn
+             * @param {Event.Facade} e The Event Facade
+             */
+            this.publish(RENDER, {queuable:false, defaultFn: this._defRenderFn});
+
+            parentNode = (parentNode) ? Node.get(parentNode) : null;
+            if (parentNode && !parentNode.inDoc()) {
+                parentNode = null;
+            }
+
+            this.fire(RENDER, null, parentNode);
+        }
+
+        return this;
+    },
+
+    /**
+     * Default render handler
+     *
+     * @method _defRenderFn
+     * @protected
+     * @param {Event.Facade} e The Event object
+     * @param {Node} parentNode The parent node to render to, if passed in to the <code>render</code> method
+     */
+    _defRenderFn : function(e, parentNode) {
+
+            this._renderUI(parentNode);
+            this._bindUI();
+            this._syncUI();
+
+            this.renderer();
+
+            this._set(RENDERED, true);
+    },
+
+    /** 
+     * Creates DOM (or manipulates DOM for progressive enhancement)
+     * This method is invoked by render() and is not chained 
+     * automatically for the class hierarchy (like initializer, destructor) 
+     * so it should be chained manually for subclasses if required.
+     * 
+     * @method renderer
+     * @protected
+     */
+    renderer: function() {
+        this.renderUI();
+        this.bindUI();
+        this.syncUI();
+    },
+
+    /**
+     * Configures/Sets up listeners to bind Widget State to UI/DOM
+     * 
+     * This method is not called by framework and is not chained 
+     * automatically for the class hierarchy.
+     * 
+     * @method bindUI
+     * @protected
+     */
+    bindUI: function() {},
+
+    /**
+     * Adds nodes to the DOM 
+     * 
+     * This method is not called by framework and is not chained 
+     * automatically for the class hierarchy.
+     * 
+     * @method renderUI
+     * @protected
+     */
+    renderUI: function() {},
+
+    /**
+     * Refreshes the rendered UI, based on Widget State
+     * 
+     * This method is not called by framework and is not chained
+     * automatically for the class hierarchy.
+     *
+     * @method syncUI
+     * 
+     */
+    syncUI: function(){},
+
+    /**
+    * @method hide
+    * @description Shows the Module element by setting the "visible" attribute to "false".
+    */
+    hide: function() {
+        return this.set(VISIBLE, false);
+    },
+
+    /**
+    * @method show
+    * @description Shows the Module element by setting the "visible" attribute to "true".
+    */
+    show: function() {
+        return this.set(VISIBLE, true);
+    },
+
+    /**
+    * @method focus
+    * @description Causes the Widget to receive the focus by setting the "hasFocus" 
+    * attribute to "true".
+    */
+    focus: function () {
+        return this.set(HAS_FOCUS, true);
+    },
+
+    /**
+    * @method blur
+    * @description Causes the Widget to lose focus by setting the "hasFocus" attribute 
+    * to "false"
+    */            
+    blur: function () {
+        return this.set(HAS_FOCUS, false);
+    },
+
+    /**
+    * @method enable
+    * @description Set the Widget's "disabled" attribute to "false".
+    */
+    enable: function() {
+        return this.set(DISABLED, false);
+    },
+
+    /**
+    * @method disabled
+    * @description Set the Widget's "disabled" attribute to "true".
+    */
+    disable: function() {
+        return this.set(DISABLED, true);
+    },
+
+    /**
+     * Utilitity method used to apply the <code>HTML_PARSER</code> configuration for the 
+     * instance, to retrieve config data values.
+     * 
+     * @method _parseHTML
+     * @private 
+     * @param  node {Node} Root node to use to parse markup for configuration data
+     * @return config {Object} configuration object, with values found in the HTML, populated
+     */
+    _parseHTML : function(node) {
+ 
+        var schema = this._getHtmlParser(),
+            data,
+            val;
+
+        if (schema && node && node.hasChildNodes()) {
+
+            O.each(schema, function(v, k, o) {
+                val = null;
+
+                if (L.isFunction(v)) {
+                    val = v.call(this, node);
+                } else {
+                    if (L.isArray(v)) {
+                        val = node.queryAll(v[0]);
+                    } else {
+                        val = node.query(v);
+                    }
+                }
+
+                if (val !== null && val !== undefined) {
+                    data = data || {};
+                    data[k] = val;
+                }
+
+            }, this);
+        }
+
+        return data;
+    },
+
+    /**
+     * Moves a pre-defined set of style rules (WRAP_STYLES) from one node to another.
+     *
+     * @method _moveStyles
+     * @private
+     * @param {Node} nodeFrom The node to gather the styles from
+     * @param {Node} nodeTo The node to apply the styles to
+     */
+    _moveStyles: function(nodeFrom, nodeTo) {
+
+        var styles = this.WRAP_STYLES,
+            pos = nodeFrom.getStyle('position'),
+            contentBox = this.get(CONTENT_BOX),
+            xy = [0,0],
+            h, w;
+
+        if (!this.get('height')) {
+            h = contentBox.get('offsetHeight');
+        }
+
+        if (!this.get('width')) {
+            w = contentBox.get('offsetWidth');
+        }
+
+        if (pos === 'absolute') {
+            xy = nodeFrom.getXY();
+            nodeTo.setStyles({
+                right: 'auto',
+                bottom: 'auto'
+            });
+
+            nodeFrom.setStyles({
+                right: 'auto',
+                bottom: 'auto'
+            });
+        }
+
+        Y.each(styles, function(v, k) {
+            var s = nodeFrom.getStyle(k);
+            nodeTo.setStyle(k, s);
+            if (v === false) {
+                nodeFrom.setStyle(k, '');
+            } else {
+                nodeFrom.setStyle(k, v);
+            }
+        });
+
+        if (pos === 'absolute') {
+            nodeTo.setXY(xy);
+        }
+
+        if (h) {
+            this.set('height', h);
+        }
+
+        if (w) {
+            this.set('width', w);
+        }
+    },
+
+    /**
+    * Helper method to collect the boundingBox and contentBox, set styles and append to the provided parentNode, if not
+    * already a child. The owner document of the boundingBox, or the owner document of the contentBox will be used 
+    * as the document into which the Widget is rendered if a parentNode is node is not provided. If both the boundingBox and
+    * the contentBox are not currently in the document, and no parentNode is provided, the widget will be rendered 
+    * to the current document's body.
+    *
+    * @method _renderBox
+    * @private
+    * @param {Node} parentNode The parentNode to render the widget to. If not provided, and both the boundingBox and
+    * the contentBox are not currently in the document, the widget will be rendered to the current document's body.
+    */
+    _renderBox: function(parentNode) {
+
+        var contentBox = this.get(CONTENT_BOX),
+            boundingBox = this.get(BOUNDING_BOX),
+            doc = boundingBox.get(OWNER_DOCUMENT) || contentBox.get(OWNER_DOCUMENT),
+            body;
+
+        if (!boundingBox.compareTo(contentBox.get(PARENT_NODE))) {
+            if (this.get('moveStyles')) {
+                this._moveStyles(contentBox, boundingBox);
+            }
+            // If contentBox box is already in the document, have boundingBox box take it's place
+            if (contentBox.inDoc(doc)) {
+                contentBox.get(PARENT_NODE).replaceChild(boundingBox, contentBox);
+            }
+            boundingBox.appendChild(contentBox);
+        }
+
+        if (!boundingBox.inDoc(doc) && !parentNode) {
+            body = Node.get(BODY);
+            if (body.get(FIRST_CHILD)) {
+                // Special case when handling body as default (no parentNode), always try to insert.
+                body.insertBefore(boundingBox, body.get(FIRST_CHILD));
+            } else {
+                body.appendChild(boundingBox);
+            }
+        } else {
+            if (parentNode && !parentNode.compareTo(boundingBox.get(PARENT_NODE))) {
+                parentNode.appendChild(boundingBox);
+            }
+        }
+    },
+
+    /**
+    * Setter for the boundingBox attribute
+    *
+    * @method _setBoundingBox
+    * @private
+    * @param Node/String
+    * @return Node
+    */
+    _setBoundingBox: function(node) {
+        return this._setBox(node, this.BOUNDING_TEMPLATE);
+    },
+
+    /**
+    * Setter for the contentBox attribute
+    *
+    * @method _setContentBox
+    * @private
+    * @param {Node|String} node
+    * @return Node
+    */
+    _setContentBox: function(node) {
+        return this._setBox(node, this.CONTENT_TEMPLATE);
+    },
+
+    /**
+     * Helper method to set the bounding/content box, or create it from
+     * the provided template if not found.
+     *
+     * @method _setBox
+     * @private
+     *
+     * @param {Node|String} node The node reference
+     * @param {String} template HTML string template for the node
+     * @return {Node} The node
+     */
+    _setBox : function(node, template) {
+        node = Node.get(node) || Node.create(template);
+
+        var sid = Y.stamp(node);
+        if (!node.get(ID)) {
+            node.set(ID, sid);
+        }
+        return node;
+    },
+
+    /**
+     * Initializes the UI state for the Widget's bounding/content boxes.
+     *
+     * @method _renderUI
+     * @protected
+     * @param {Node} The parent node to rendering the widget into
+     */
+    _renderUI: function(parentNode) {
+        this._renderBoxClassNames();
+        this._renderBox(parentNode);
+    },
+
+     /**
+      * Applies standard class names to the boundingBox and contentBox
+      * 
+      * @method _renderBoxClassNames
+      * @protected
+      */
+    _renderBoxClassNames : function() {
+        var classes = this._getClasses(),
+            boundingBox = this.get(BOUNDING_BOX),
+            contentBox = this.get(CONTENT_BOX),
+            name;
+
+        boundingBox.addClass(Widget.getClassName());
+
+        // Start from Widget Sub Class
+        for (var i = 2, l = classes.length; i < l; ++i) {
+            name = classes[i].NAME;
+            if (name) {
+                boundingBox.addClass(ClassNameManager.getClassName(name.toLowerCase()));
+            }
+        }
+
+        // Use instance based name for content box
+        contentBox.addClass(this.getClassName(CONTENT));
+    },
+
+    /**
+     * Sets up DOM and CustomEvent listeners for the widget.
+     *
+     * @method _bindUI
+     * @protected
+     */
+    _bindUI: function() {
+        this.after('visibleChange', this._afterVisibleChange);
+        this.after('disabledChange', this._afterDisabledChange);
+        this.after('heightChange', this._afterHeightChange);
+        this.after('widthChange', this._afterWidthChange);
+        this.after('hasFocusChange', this._afterHasFocusChange);
+
+        this._bindDOMListeners();
+    },
+
+    /**
+     * Sets up DOM listeners, on elements rendered by the widget.
+     * 
+     * @method _bindDOMListeners
+     * @protected
+     */
+    _bindDOMListeners : function() {
+        this.get(BOUNDING_BOX).on(FOCUS, Y.bind(this._onFocus, this));
+        this.get(BOUNDING_BOX).on(BLUR, Y.bind(this._onBlur, this));
+    },
+
+    /**
+     * Updates the widget UI to reflect the attribute state.
+     *
+     * @method _syncUI
+     * @protected
+     */
+    _syncUI: function() {
+        this._uiSetVisible(this.get(VISIBLE));
+        this._uiSetDisabled(this.get(DISABLED));
+        this._uiSetHeight(this.get(HEIGHT));
+        this._uiSetWidth(this.get(WIDTH));
+        this._uiSetHasFocus(this.get(HAS_FOCUS));
+        this._uiSetTabIndex(this.get(TAB_INDEX));
+    },
+
+    /**
+     * Sets the height on the widget's bounding box element
+     * 
+     * @method _uiSetHeight
+     * @protected
+     * @param {String | Number} val
+     */
+    _uiSetHeight: function(val) {
+        if (L.isNumber(val)) {
+            val = val + this.DEF_UNIT;
+        }
+        this.get(BOUNDING_BOX).setStyle(HEIGHT, val);
+    },
+
+    /**
+     * Sets the width on the widget's bounding box element
+     *
+     * @method _uiSetWidth
+     * @protected
+     * @param {String | Number} val
+     */
+    _uiSetWidth: function(val) {
+        if (L.isNumber(val)) {
+            val = val + this.DEF_UNIT;
+        }
+        this.get(BOUNDING_BOX).setStyle(WIDTH, val);
+    },
+
+    /**
+     * Sets the visible state for the UI
+     * 
+     * @method _uiSetVisible
+     * @protected
+     * @param {boolean} val
+     */
+    _uiSetVisible: function(val) {
+
+        var box = this.get(BOUNDING_BOX), 
+            sClassName = this.getClassName(HIDDEN);
+
+        if (val === true) { 
+            box.removeClass(sClassName); 
+        } else {
+            box.addClass(sClassName); 
+        }
+    },
+
+    /**
+     * Sets the disabled state for the UI
+     * 
+     * @protected
+     * @param {boolean} val
+     */
+    _uiSetDisabled: function(val) {
+
+        var box = this.get(BOUNDING_BOX), 
+            sClassName = this.getClassName(DISABLED);
+
+        if (val === true) {
+            box.addClass(sClassName);
+        } else {
+            box.removeClass(sClassName);
+        }
+    },
+
+    /**
+     * Sets the hasFocus state for the UI
+     *
+     * @protected
+     * @param {boolean} val
+     * @param {string} src String representing the source that triggered an update to 
+     * the UI.     
+     */
+    _uiSetHasFocus: function(val, src) {
+
+        var box = this.get(BOUNDING_BOX),
+            sClassName = this.getClassName(FOCUS);
+
+        if (val === true) {
+            box.addClass(sClassName);
+            if (src !== UI) {
+                box.focus();
+            }
+        } else {
+            box.removeClass(sClassName);
+            if (src !== UI) {
+                box.blur();
+            }
+        }
+    },
+
+    /**
+    * Set the tabIndex on the widget's rendered UI
+    *
+    * @method _uiSetTabIndex
+    * @protected
+    * @param Number
+    */
+    _uiSetTabIndex: function(index) {
+        this.get(BOUNDING_BOX).set(TAB_INDEX, index);
+    },
+
+    /**
+     * Default visible attribute state change handler
+     *
+     * @method _afterVisibleChange
+     * @protected
+     * @param {Event.Facade} evt The event facade for the attribute change
+     */
+    _afterVisibleChange: function(evt) {
+        this._uiSetVisible(evt.newVal);
+    },
+
+    /**
+     * Default disabled attribute state change handler
+     * 
+     * @method _afterDisabledChange
+     * @protected
+     * @param {Event.Facade} evt The event facade for the attribute change
+     */
+    _afterDisabledChange: function(evt) {
+        this._uiSetDisabled(evt.newVal);
+    },
+
+    /**
+     * Default height attribute state change handler
+     * 
+     * @method _afterHeightChange
+     * @protected
+     * @param {Event.Facade} evt The event facade for the attribute change
+     */
+    _afterHeightChange: function(evt) {
+        this._uiSetHeight(evt.newVal);
+    },
+
+    /**
+     * Default widget attribute state change handler
+     * 
+     * @method _afterWidthChange
+     * @protected
+     * @param {Event.Facade} evt The event facade for the attribute change
+     */
+    _afterWidthChange: function(evt) {
+        this._uiSetWidth(evt.newVal);
+    },
+
+    /**
+     * Default hasFocus attribute state change handler
+     * 
+     * @method _afterHasFocusChange
+     * @protected
+     * @param {Event.Facade} evt The event facade for the attribute change
+     */
+    _afterHasFocusChange: function(evt) {
+        this._uiSetHasFocus(evt.newVal, evt.src);
+    },
+
+    /**
+     * DOM focus event handler, used to sync the state of the Widget with the DOM
+     * 
+     * @method _onFocus
+     * @protected
+     * @param {Event.Facade} evt The event facade for the DOM focus event
+     */
+    _onFocus: function (evt) {
+        this.set(HAS_FOCUS, true, { src: UI });
+    },
+
+    /**
+     * DOM blur event handler, used to sync the state of the Widget with the DOM
+     *
+     * @method _onBlur
+     * @protected
+     * @param {Event.Facade} evt The event facade for the DOM blur event
+     */			
+    _onBlur: function (evt) {
+        this.set(HAS_FOCUS, false, { src: UI });
+    },
+
+    /**
+     * Generic toString implementation for all widgets.
+     *
+     * @method toString
+     * @return {String} The default string value for the widget [ displays the NAME of the instance, and the unique id ]
+     */
+    toString: function() {
+        return this.constructor.NAME + "[" + this._yuid + "]";
+    },
+
+    /**
+     * Default unit to use for dimension values
+     * 
+     * @property DEF_UNIT
+     */
+    DEF_UNIT : "px",
+
+    /**
+     * Static property defining the markup template for content box.
+     *
+     * @property CONTENT_TEMPLATE
+     * @type String
+     */
+    CONTENT_TEMPLATE : "<div></div>",
+
+    /**
+     * Static property defining the markup template for bounding box.
+     *
+     * @property BOUNDING_TEMPLATE
+     * @type String
+     */
+    BOUNDING_TEMPLATE : "<div></div>",
+
+    /**
+     * Static property listing the styles that are mimiced on the bounding box from the content box.
+     *
+     * @property WRAP_STYLES
+     * @type Object
+     */
+    WRAP_STYLES : {
+        height: '100%',
+        width: '100%',
+        zIndex: false,
+        position: 'static',
+        top: '0',
+        left: '0',
+        bottom: '',
+        right: '',
+        padding: '',
+        margin: ''
+    },
+
+    /**
+     * Sets strings for a particular locale, merging with any existing
+     * strings which may already be defined for the locale.
+     *
+     * @method _setStrings
+     * @protected
+     * @param {Object} strings The hash of string key/values to set
+     * @param {Object} locale The locale for the string values being set
+     */
+    _setStrings : function(strings, locale) {
+        var strs = this._strings;
+        locale = locale.toLowerCase();
+
+        if (!strs[locale]) {
+            strs[locale] = {};
+        }
+
+        Y.aggregate(strs[locale], strings, true);
+        return strs[locale];
+    },
+
+    /**
+     * Returns the strings key/value hash for a paricular locale, without locale lookup applied.
+     *
+     * @method _getStrings
+     * @protected
+     * @param {Object} locale
+     */
+    _getStrings : function(locale) {
+        return this._strings[locale.toLowerCase()];
+    },
+
+    /**
+     * Gets the entire strings hash for a particular locale, performing locale lookup.
+     * <p>
+     * If no values of the key are defined for a particular locale the value for the 
+     * default locale (in initial locale set for the class) is returned.
+     * </p>
+     * @method getStrings
+     * @param {String} locale (optional) The locale for which the string value is required. Defaults to the current locale, if not provided.
+     */
+    // TODO: Optimize/Cache. Clear cache on _setStrings call.
+    getStrings : function(locale) {
+
+        locale = (locale || this.get(LOCALE)).toLowerCase();
+
+
+        var defLocale = this.getDefaultLocale().toLowerCase(),
+            defStrs = this._getStrings(defLocale),
+            strs = (defStrs) ? Y.merge(defStrs) : {},
+            localeSegments = locale.split(HYPHEN);
+
+        // If locale is different than the default, or needs lookup support
+        if (locale !== defLocale || localeSegments.length > 1) {
+            var lookup = "";
+            for (var i = 0, l = localeSegments.length; i < l; ++i) {
+                lookup += localeSegments[i];
+
+
+                var localeStrs = this._getStrings(lookup);
+                if (localeStrs) {
+                    Y.aggregate(strs, localeStrs, true);
+                }
+                lookup += HYPHEN;
+            }
+        }
+
+        return strs;
+    },
+
+    /**
+     * Gets the string for a particular key, for a particular locale, performing locale lookup.
+     * <p>
+     * If no values if defined for the key, for the given locale, the value for the 
+     * default locale (in initial locale set for the class) is returned.
+     * </p>
+     * @method getString
+     * @param {String} key The key.
+     * @param {String} locale (optional) The locale for which the string value is required. Defaults to the current locale, if not provided.
+     */
+    getString : function(key, locale) {
+
+        locale = (locale || this.get(LOCALE)).toLowerCase();
+
+
+        var defLocale = (this.getDefaultLocale()).toLowerCase(),
+            strs = this._getStrings(defLocale) || {},
+            str = strs[key],
+            idx = locale.lastIndexOf(HYPHEN);
+
+        // If locale is different than the default, or needs lookup support
+        if (locale !== defLocale || idx != -1) {
+            do {
+
+                strs = this._getStrings(locale);
+                if (strs && key in strs) {
+                    str = strs[key];
+                    break;
+                }
+                idx = locale.lastIndexOf(HYPHEN);
+                // Chop of last locale segment
+                if (idx != -1) {
+                    locale = locale.substring(0, idx);
+                }
+
+            } while (idx != -1);
+        }
+
+        return str;
+    },
+
+    /**
+     * Returns the default locale for the widget (the locale value defined by the
+     * widget class, or provided by the user during construction).
+     *
+     * @method getDefaultLocale
+     * @return {String} The default locale for the widget
+     */
+    getDefaultLocale : function() {
+        return this._conf.get(LOCALE, INIT_VALUE);
+    },
+
+    /**
+     * Private stings hash, used to store strings in locale specific buckets.
+     *
+     * @property _strings
+     * @private
+     * @type Object
+     */
+    _strings: null,
+
+    /**
+     * Gets the HTML_PARSER definition for this instance, by merging HTML_PARSER
+     * definitions across the class hierarchy.
+     *
+     * @method _getHtmlParser
+     * @return {Object} HTML_PARSER definition for this instance
+     */
+    _getHtmlParser : function() {
+        if (!this._HTML_PARSER) {
+            var classes = this._getClasses(),
+                parser = {};
+
+            for (var i = 0, l = classes.length; i < l; i++) {
+                var p = classes[i].HTML_PARSER;
+                if (p) {
+                    Y.mix(parser, p, true);
+                }
+            }
+
+            this._HTML_PARSER = parser;
+        }
+
+        return this._HTML_PARSER;
+    }
+});
+
+/**
+ * Static registration of default plugins for the class.
+ * 
+ * @property Widget.PLUGINS
+ * @static
+ */
+Widget.PLUGINS = [];
+
+Y.mix(Widget, Y.PluginHost, false, null, 1); // straightup augment, no wrapper functions
+
+Y.Widget = Widget;
+
+
+
+}, '3.0.0pr2' ,{requires:['base', 'node', 'classnamemanager']});

=== added directory 'loggerhead/static/javascript/yui/build/yui'
=== added directory 'loggerhead/static/javascript/yui/build/yui-base'
=== added file 'loggerhead/static/javascript/yui/build/yui-base/README'
--- loggerhead/static/javascript/yui/build/yui-base/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yui-base/README	2008-10-20 07:34:21 +0000
@@ -0,0 +1,7 @@
+YUI Base
+    Provides base YUI functionality, including module registration and consumption utils,
+    language/array/object utilities, browser detection, and a setTimout/setInterval 
+    wrapper.
+
+3.0.0pr1
+    Inital release

=== added file 'loggerhead/static/javascript/yui/build/yui-base/yui-base-debug.js'
--- loggerhead/static/javascript/yui/build/yui-base/yui-base-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yui-base/yui-base-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1536 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * YUI core
+ * @module yui
+ */
+(function() {
+
+    var _instances = {},
+
+// @TODO: this needs to be created at build time from module metadata
+
+        _APPLY_TO_WHITE_LIST = {
+            'io.xdrReady': 1,
+            'io.start': 1,
+            'io.success': 1,
+            'io.failure': 1,
+            'io.abort': 1
+        };
+        
+
+if (typeof YUI === 'undefined' || !YUI) {
+
+    /**
+     * The YUI global namespace object.  If YUI is already defined, the
+     * existing YUI object will not be overwritten so that defined
+     * namespaces are preserved.  
+     *
+     * @class YUI
+     * @constructor
+     * @global
+     * @uses Event.Target
+     * @param o Optional configuration object.  Options:
+     * <ul>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>Global:</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>debug:
+     *  Turn debug statements on or off</li>
+     *  <li>useBrowserConsole:
+     *  Log to the browser console if debug is on and the console is available</li>
+     *  <li>logInclude:
+     *  A hash of log sources that should be logged.  If specified, only log messages from these sources will be logged.
+     *  
+     *  </li>
+     *  <li>logExclude:
+     *  A hash of log sources that should be not be logged.  If specified, all sources are logged if not on this list.</li>
+     *  <li>throwFail:
+     *  If throwFail is set, Y.fail will generate or re-throw a JS error.  Otherwise the failure is logged.
+     *  <li>win:
+     *  The target window/frame</li>
+     *  <li>core:
+     *  A list of modules that defines the YUI core (overrides the default)</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>For event and get:</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>pollInterval:
+     *  The default poll interval</li>
+     *  <li>-------------------------------------------------------------------------</li>
+     *  <li>For loader:</li>
+     *  <li>-------------------------------------------------------------------------</li>
+     *  <li>base:
+     *  The base dir</li>
+     *  <li>secureBase:
+     *  The secure base dir (not implemented)</li>
+     *  <li>comboBase:
+     *  The YUI combo service base dir. Ex: http://yui.yahooapis.com/combo?</li>
+     *  <li>root:
+     *  The root path to prepend to module names for the combo service. Ex: 2.5.2/build/</li>
+     *  <li>filter:
+     *  
+     * A filter to apply to result urls.  This filter will modify the default
+     * path for all modules.  The default path for the YUI library is the
+     * minified version of the files (e.g., event-min.js).  The filter property
+     * can be a predefined filter or a custom filter.  The valid predefined 
+     * filters are:
+     * <dl>
+     *  <dt>DEBUG</dt>
+     *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+     *      This option will automatically include the logger widget</dd>
+     *  <dt>RAW</dt>
+     *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+     * </dl>
+     * You can also define a custom filter, which must be an object literal 
+     * containing a search expression and a replace string:
+     * <pre>
+     *  myFilter: &#123; 
+     *      'searchExp': "-min\\.js", 
+     *      'replaceStr': "-debug.js"
+     *  &#125;
+     * </pre>
+     *
+     *  </li>
+     *  <li>combine:
+     *  Use the YUI combo service to reduce the number of http connections required to load your dependencies</li>
+     *  <li>ignore:
+     *  A list of modules that should never be dynamically loaded</li>
+     *  <li>force:
+     *  A list of modules that should always be loaded when required, even if already present on the page</li>
+     *  <li>insertBefore:
+     *  Node or id for a node that should be used as the insertion point for new nodes</li>
+     *  <li>charset:
+     *  charset for dynamic nodes</li>
+     *  <li>timeout:
+     *  number of milliseconds before a timeout occurs when dynamically loading nodes.  in not set, there is no timeout</li>
+     *  <li>context:
+     *  execution context for all callbacks</li>
+     *  <li>onSuccess:
+     *  callback for the 'success' event</li>
+     *  <li>onFailure:
+     *  callback for the 'failure' event</li>
+     *  <li>onTimeout:
+     *  callback for the 'timeout' event</li>
+     *  <li>onProgress:
+     *  callback executed each time a script or css file is loaded</li>
+     *  <li>modules:
+     *  A list of module definitions.  See Loader.addModule for the supported module metadata</li>
+     * </ul>
+     */
+
+    /*global YUI*/
+    YUI = function(o) {
+        var Y = this;
+
+        // Allow instantiation without the new operator
+        if (!(Y instanceof YUI)) {
+            return new YUI(o);
+        } else {
+            // set up the core environment
+            Y._init(o);
+
+            // bind the specified additional modules for this instance
+            Y._setup();
+
+            return Y;
+        }
+    };
+}
+
+// The prototype contains the functions that are required to allow the external
+// modules to be registered and for the instance to be initialized.
+YUI.prototype = {
+
+    /**
+     * Initialize this YUI instance
+     * @param o config options
+     * @private
+     */
+    _init: function(o) {
+        
+
+        o = o || {};
+
+        // find targeted window and @TODO create facades
+        var w = (o.win) ? (o.win.contentWindow) : o.win  || window;
+        o.win = w;
+        o.doc = w.document;
+        o.debug = ('debug' in o) ? o.debug : true;
+        o.useBrowserConsole = ('useBrowserConsole' in o) ? o.useBrowserConsole : true;
+        o.throwFail = ('throwFail' in o) ? o.throwFail : true;
+    
+        // add a reference to o for anything that needs it
+        // before _setup is called.
+        this.config = o;
+
+        this.Env = {
+            // @todo expand the new module metadata
+            mods: {},
+            _idx: 0,
+            _pre: 'yuid',
+            _used: {},
+            _attached: {},
+            _yidx: 0,
+            _uidx: 0
+        };
+
+        if (YUI.Env) {
+            this.Env._yidx = ++YUI.Env._idx;
+            this.id = this.stamp(this);
+            _instances[this.id] = this;
+        }
+
+        this.constructor = YUI;
+
+        this.log(this.id + ') init ');
+    },
+    
+    /**
+     * Finishes the instance setup. Attaches whatever modules were defined
+     * when the yui modules was registered.
+     * @method _setup
+     * @private
+     */
+    _setup: function(o) {
+        this.use("yui");
+        // @TODO eval the need to copy the config
+        this.config = this.merge(this.config);
+    },
+
+    /**
+     * Executes a method on a YUI instance with
+     * the specified id if the specified method is whitelisted.
+     * @method applyTo
+     * @param id {string} the YUI instance id
+     * @param method {string} the name of the method to exectute.
+     * Ex: 'Object.keys'
+     * @param args {Array} the arguments to apply to the method
+     * @return {object} the return value from the applied method or null
+     */
+    applyTo: function(id, method, args) {
+
+        if (!(method in _APPLY_TO_WHITE_LIST)) {
+            this.fail(method + ': applyTo not allowed');
+            return null;
+        }
+
+        var instance = _instances[id];
+
+        if (instance) {
+
+            var nest = method.split('.'), m = instance;
+
+            for (var i=0; i<nest.length; i=i+1) {
+
+                m = m[nest[i]];
+
+                if (!m) {
+                    this.fail('applyTo not found: ' + method);
+                }
+            }
+
+            return m.apply(instance, args);
+        }
+
+        return null;
+    }, 
+
+    /**
+     * Register a module
+     * @method add
+     * @param name {string} module name
+     * @param fn {Function} entry point into the module that
+     * is used to bind module to the YUI instance
+     * @param version {string} version string
+     * @return {YUI} the YUI instance
+     *
+     * requires   - features that should be present before loading
+     * optional   - optional features that should be present if load optional defined
+     * use  - features that should be attached automatically
+     * skinnable  -
+     * rollup
+     * omit - features that should not be loaded if this module is present
+     */
+    add: function(name, fn, version, details) {
+
+        // this.log('Adding a new component ' + name);
+
+        // @todo expand this to include version mapping
+        
+        // @todo allow requires/supersedes
+
+        // @todo may want to restore the build property
+        
+        // @todo fire moduleAvailable event
+        
+        var m = {
+            name: name, 
+            fn: fn,
+            version: version,
+            details: details || {}
+        };
+
+        YUI.Env.mods[name] = m;
+
+        return this; // chain support
+    },
+
+    _attach: function(r, fromLoader) {
+
+        var mods = YUI.Env.mods,
+            attached = this.Env._attached;
+
+        for (var i=0, l=r.length; i<l; i=i+1) {
+            var name = r[i], m = mods[name], mm;
+            if (!attached[name] && m) {
+
+                attached[name] = true;
+
+                var d = m.details, req = d.requires, use = d.use;
+
+                if (req) {
+                    this._attach(this.Array(req));
+                }
+
+                this.log('attaching ' + name, 'info', 'YUI');
+
+                if (m.fn) {
+                    m.fn(this);
+                }
+
+                if (use) {
+                    this._attach(this.Array(use));
+                }
+            }
+        }
+
+    },
+
+    /**
+     * Bind a module to a YUI instance
+     * @param modules* {string} 1-n modules to bind (uses arguments array)
+     * @param *callback {function} callback function executed when 
+     * the instance has the required functionality.  If included, it
+     * must be the last parameter.
+     *
+     * @TODO 
+     * Implement versioning?  loader can load different versions?
+     * Should sub-modules/plugins be normal modules, or do
+     * we add syntax for specifying these?
+     *
+     * YUI().use('dragdrop')
+     * YUI().use('dragdrop:2.4.0'); // specific version
+     * YUI().use('dragdrop:2.4.0-'); // at least this version
+     * YUI().use('dragdrop:2.4.0-2.9999.9999'); // version range
+     * YUI().use('*'); // use all available modules
+     * YUI().use('lang+dump+substitute'); // use lang and some plugins
+     * YUI().use('lang+*'); // use lang and all known plugins
+     *
+     *
+     * @return {YUI} the YUI instance
+     */
+    use: function() {
+
+        var Y = this, 
+            a=Array.prototype.slice.call(arguments, 0), 
+            mods = YUI.Env.mods, 
+            used = Y.Env._used,
+            loader, 
+            firstArg = a[0], 
+            dynamic = false,
+            callback = a[a.length-1];
+
+        // Y.log(Y.id + ': use called: ' + a + ' :: ' + callback);
+
+        // The last argument supplied to use can be a load complete callback
+        if (typeof callback === 'function') {
+            a.pop();
+            Y.Env._callback = callback;
+        } else {
+            callback = null;
+        }
+
+        // YUI().use('*'); // bind everything available
+        if (firstArg === "*") {
+            a = [];
+            for (var k in mods) {
+                if (mods.hasOwnProperty(k)) {
+                    a.push(k);
+                }
+            }
+
+            return Y.use.apply(Y, a);
+
+        }
+        // Y.log('loader before: ' + a.join(','));
+       
+
+        // use loader to expand dependencies and sort the 
+        // requirements if it is available.
+        if (Y.Loader) {
+            dynamic = true;
+            loader = new Y.Loader(Y.config);
+            loader.require(a);
+            loader.ignoreRegistered = true;
+            loader.allowRollup = false;
+            loader.calculate();
+            a = loader.sorted;
+        }
+
+        // Y.log('loader after: ' + a.join(','));
+
+        var missing = [], r = [], f = function(name) {
+
+            // only attach a module once
+            if (used[name]) {
+                // Y.log(name + ' already used');
+                return;
+            }
+
+            var m = mods[name], j, req, use;
+
+            if (m) {
+                used[name] = true;
+
+                // Y.log('found ' + name);
+                req = m.details.requires;
+                use = m.details.use;
+            } else {
+                Y.log('module not found: ' + name, 'info', 'yui');
+                missing.push(name);
+            }
+
+            // make sure requirements are attached
+            if (req) {
+                if (Y.Lang.isString(req)) {
+                    f(req);
+                } else {
+                    for (j = 0; j < req.length; j = j + 1) {
+                        f(req[j]);
+                    }
+                }
+            }
+
+            // add this module to full list of things to attach
+            // Y.log('using ' + name);
+            r.push(name);
+
+        };
+
+        // process each requirement and any additional requirements 
+        // the module metadata specifies
+        for (var i=0, l=a.length; i<l; i=i+1) {
+            f(a[i]);
+        }
+
+        // Y.log('all reqs: ' + r + ' --- missing: ' + missing);
+
+        var onComplete = function(fromLoader) {
+
+            // Y.log('Use complete');
+
+            fromLoader = fromLoader || {
+                success: true,
+                msg: 'not dynamic'
+            };
+
+            if (Y.Env._callback) {
+
+                var cb = Y.Env._callback;
+                Y.Env._callback = null;
+                cb(Y, fromLoader);
+            }
+
+            if (Y.fire) {
+                Y.fire('yui:load', Y, fromLoader);
+            }
+        };
+
+
+        // dynamic load
+        if (Y.Loader && missing.length) {
+            Y.log('Attempting to dynamically load the missing modules ' + missing, 'info', 'yui');
+            loader = new Y.Loader(Y.config);
+            loader.onSuccess = onComplete;
+            loader.onFailure = onComplete;
+            loader.onTimeout = onComplete;
+            loader.attaching = a;
+            loader.require(missing);
+            loader.insert();
+        } else {
+            Y._attach(r);
+            onComplete();
+        }
+
+        return Y; // chain support var yui = YUI().use('dragdrop');
+    },
+
+
+    /**
+     * Returns the namespace specified and creates it if it doesn't exist
+     * <pre>
+     * YUI.namespace("property.package");
+     * YUI.namespace("YAHOO.property.package");
+     * </pre>
+     * Either of the above would create YAHOO.property, then
+     * YUI.property.package
+     *
+     * Be careful when naming packages. Reserved words may work in some browsers
+     * and not others. For instance, the following will fail in Safari:
+     * <pre>
+     * YUI.namespace("really.long.nested.namespace");
+     * </pre>
+     * This fails because "long" is a future reserved word in ECMAScript
+     *
+     * @method namespace
+     * @param  {string*} arguments 1-n namespaces to create 
+     * @return {object}  A reference to the last namespace object created
+     */
+    namespace: function() {
+        var a=arguments, o=null, i, j, d;
+        for (i=0; i<a.length; i=i+1) {
+            d = a[i].split(".");
+            o = this;
+            for (j=(d[0] == "YAHOO") ? 1 : 0; j<d.length; j=j+1) {
+                o[d[j]] = o[d[j]] || {};
+                o = o[d[j]];
+            }
+        }
+        return o;
+    },
+
+    // this is replaced if the log module is included
+    log: function() {
+
+    },
+
+    /**
+     * Report an error.  The reporting mechanism is controled by
+     * the 'throwFail' configuration attribute.  If throwFail is
+     * not specified, the message is written to the logger, otherwise
+     * a JS error is thrown
+     * @method fail
+     * @param msg {string} the failure message
+     * @param e {Error} Optional JS error that was caught.  If supplied
+     * and throwFail is specified, this error will be re-thrown.
+     * @return {YUI} this YUI instance
+     */
+    fail: function(msg, e) {
+        if (this.config.throwFail) {
+            throw (e || new Error(msg)); 
+        } else {
+            var instance = this;
+            instance.log(msg, "error"); // don't scrub this one
+        }
+
+        return this;
+    },
+
+    /**
+     * Generate an id that is unique among all YUI instances
+     * @method guid
+     * @param pre {string} optional guid prefix
+     * @return {string} the guid
+     */
+    guid: function(pre) {
+        var e = this.Env, p = (pre) || e._pre;
+        return p +'-' + e._yidx + '-' + e._uidx++;
+    },
+
+    /**
+     * Stamps an object with a guid.  If the object already
+     * has one, a new one is not created
+     * @method stamp
+     * @param o The object to stamp
+     * @return {string} The object's guid
+     */
+    stamp: function(o) {
+
+        if (!o) {
+            return o;
+        }
+
+        var uid = (typeof o === 'string') ? o : o._yuid;
+
+        if (!uid) {
+            uid = this.guid();
+            o._yuid = uid;
+        }
+
+        return uid;
+    }
+};
+
+// Give the YUI global the same properties as an instance.
+// This makes it so that the YUI global can be used like the YAHOO
+// global was used prior to 3.x.  More importantly, the YUI global
+// provides global metadata, so env needs to be configured.
+// @TODO review
+
+    var Y = YUI, p = Y.prototype, i;
+
+    // inheritance utilities are not available yet
+    for (i in p) {
+        if (true) {
+            Y[i] = p[i];
+        }
+    }
+
+    // set up the environment
+    Y._init();
+
+
+})();
+/**
+ * YUI stub
+ * @module yui
+ * @submodule yui-base
+ */
+// This is just a stub to for dependency processing
+YUI.add("yui-base", null, "3.0.0pr2");
+/*
+ * YUI console logger
+ * @module yui
+ * @submodule log
+ */
+YUI.add("log", function(instance) {
+
+    /**
+     * If the 'debug' config is true, a 'yui:log' event will be
+     * dispatched, which the logger widget and anything else
+     * can consume.  If the 'useBrowserConsole' config is true, it will
+     * write to the browser console if available.
+     *
+     * @method log
+     * @for YUI
+     * @param  {String}  msg  The message to log.
+     * @param  {String}  cat  The log category for the message.  Default
+     *                        categories are "info", "warn", "error", time".
+     *                        Custom categories can be used as well. (opt)
+     * @param  {String}  src  The source of the the message (opt)
+     * @param  {boolean} silent If true, the log event won't fire
+     * @return {YUI}      YUI instance
+     */
+    instance.log = function(msg, cat, src, silent) {
+
+        var Y = instance, c = Y.config, es = Y.Env._eventstack,
+            // bail = (es && es.logging);
+            bail = false; 
+
+        // suppress log message if the config is off or the event stack
+        // or the event call stack contains a consumer of the yui:log event
+        if (c.debug && !bail) {
+
+            // apply source filters
+            if (src) {
+
+                var exc = c.logExclude, inc = c.logInclude;
+
+                // console.log('checking src filter: ' + src + ', inc: ' + inc + ', exc: ' + exc);
+
+                if (inc && !(src in inc)) {
+                    // console.log('bail: inc list found, but src is not in list: ' + src);
+                    bail = true;
+                } else if (exc && (src in exc)) {
+                    // console.log('bail: exc list found, and src is in it: ' + src);
+                    bail = true;
+                }
+            }
+
+            if (!bail) {
+
+                if (c.useBrowserConsole) {
+                    var m = (src) ? src + ': ' + msg : msg;
+                    if (typeof console != 'undefined') {
+                        var f = (cat && console[cat]) ? cat : 'log';
+                        console[f](m);
+                    } else if (typeof opera != 'undefined') {
+                        opera.postError(m);
+                    }
+                }
+
+                if (Y.fire && !bail && !silent) {
+                    Y.fire('yui:log', msg, cat, src);
+                }
+            }
+        }
+
+        return Y;
+    };
+
+}, "3.0.0pr2");
+/*
+ * YUI lang utils
+ * @module yui
+ * @submodule lang
+ */
+YUI.add("lang", function(Y) {
+
+    /**
+     * Provides the language utilites and extensions used by the library
+     * @class Lang
+     * @static
+     */
+    Y.Lang = Y.Lang || {};
+
+    var L = Y.Lang, 
+
+    ARRAY_TOSTRING = '[object Array]',
+    FUNCTION_TOSTRING = '[object Function]',
+    STRING = 'string',
+    OBJECT = 'object',
+    BOOLEAN = 'boolean',
+    UNDEFINED = 'undefined',
+    OP = Object.prototype;
+
+    /**
+     * Determines whether or not the provided object is an array.
+     * Testing typeof/instanceof/constructor of arrays across frame 
+     * boundaries isn't possible in Safari unless you have a reference
+     * to the other frame to test against its Array prototype.  To
+     * handle this case, we test well-known array properties instead.
+     * properties.
+     * @TODO can we kill this cross frame hack?
+     * @method isArray
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is an array
+     */
+    L.isArray = function(o) { 
+        return OP.toString.apply(o) === ARRAY_TOSTRING;
+    };
+
+    /**
+     * Determines whether or not the provided object is a boolean
+     * @method isBoolean
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a boolean
+     */
+    L.isBoolean = function(o) {
+        return typeof o === BOOLEAN;
+    };
+    
+    /**
+     * Determines whether or not the provided object is a function
+     * Note: Internet Explorer thinks certain functions are objects:
+     *
+     * var obj = document.createElement("object");
+     * Y.Lang.isFunction(obj.getAttribute) // reports false in IE
+     *
+     * var input = document.createElement("input"); // append to body
+     * Y.Lang.isFunction(input.focus) // reports false in IE
+     *
+     * You will have to implement additional tests if these functions
+     * matter to you.
+     *
+     * @method isFunction
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a function
+     */
+    L.isFunction = function(o) {
+        return OP.toString.apply(o) === FUNCTION_TOSTRING;
+    };
+        
+    /**
+     * Determines whether or not the supplied object is a date instance
+     * @method isDate
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a date
+     */
+    L.isDate = function(o) {
+        return o instanceof Date;
+    };
+
+    /**
+     * Determines whether or not the provided object is null
+     * @method isNull
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is null
+     */
+    L.isNull = function(o) {
+        return o === null;
+    };
+        
+    /**
+     * Determines whether or not the provided object is a legal number
+     * @method isNumber
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a number
+     */
+    L.isNumber = function(o) {
+        return typeof o === 'number' && isFinite(o);
+    };
+      
+    /**
+     * Determines whether or not the provided object is of type object
+     * or function
+     * @method isObject
+     * @static
+     * @param o The object to test
+     * @param failfn {boolean} fail if the input is a function
+     * @return {boolean} true if o is an object
+     */  
+    L.isObject = function(o, failfn) {
+return (o && (typeof o === OBJECT || (!failfn && L.isFunction(o)))) || false;
+    };
+        
+    /**
+     * Determines whether or not the provided object is a string
+     * @method isString
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a string
+     */
+    L.isString = function(o) {
+        return typeof o === STRING;
+    };
+        
+    /**
+     * Determines whether or not the provided object is undefined
+     * @method isUndefined
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is undefined
+     */
+    L.isUndefined = function(o) {
+        return typeof o === UNDEFINED;
+    };
+    
+    /**
+     * Returns a string without any leading or trailing whitespace.  If 
+     * the input is not a string, the input will be returned untouched.
+     * @method trim
+     * @static
+     * @param s {string} the string to trim
+     * @return {string} the trimmed string
+     */
+    L.trim = function(s){
+        try {
+            return s.replace(/^\s+|\s+$/g, "");
+        } catch(e) {
+            return s;
+        }
+    };
+
+    /**
+     * A convenience method for detecting a legitimate non-null value.
+     * Returns false for null/undefined/NaN, true for other values, 
+     * including 0/false/''
+     * @method isValue
+     * @static
+     * @param o The item to test
+     * @return {boolean} true if it is not null/undefined/NaN || false
+     */
+    L.isValue = function(o) {
+// return (o || o === false || o === 0 || o === ''); // Infinity fails
+return (L.isObject(o) || L.isString(o) || L.isNumber(o) || L.isBoolean(o));
+    };
+
+}, "3.0.0pr2");
+
+
+/*
+ * Array utilities
+ * @module yui
+ * @submodule array
+ */
+
+/**
+ * YUI core
+ * @module yui
+ */
+
+YUI.add("array", function(Y) {
+
+    var L = Y.Lang, Native = Array.prototype;
+
+    /**
+     * Adds the following array utilities to the YUI instance
+     * @class YUI~array
+     */
+
+    /** 
+     * Y.Array(o) returns an array:
+     * - Arrays are return unmodified unless the start position is specified.
+     * - "Array-like" collections (@see Array.test) are converted to arrays
+     * - For everything else, a new array is created with the input as the sole item
+     * - The start position is used if the input is or is like an array to return
+     *   a subset of the collection.
+     *
+     *   @TODO this will not automatically convert elements that are also collections
+     *   such as forms and selects.  Passing true as the third param will
+     *   force a conversion.
+     *
+     * @method Array
+     * @static
+     *   @param o the item to arrayify
+     *   @param i {int} if an array or array-like, this is the start index
+     *   @param al {boolean} if true, it forces the array-like fork.  This
+     *   can be used to avoid multiple array.test calls.
+     *   @return {Array} the resulting array
+     */
+    Y.Array = function(o, i, al) {
+        var t = (al) ? 2 : Y.Array.test(o);
+
+        // switch (t) {
+        //     case 1:
+        //         // return (i) ? o.slice(i) : o;
+        //     case 2:
+        //         return Native.slice.call(o, i || 0);
+        //     default:
+        //         return [o];
+        // }
+
+        if (t) {
+            return Native.slice.call(o, i || 0);
+        } else {
+            return [o];
+        }
+
+    };
+
+    var A = Y.Array;
+    
+    /** 
+     * Evaluates the input to determine if it is an array, array-like, or 
+     * something else.  This is used to handle the arguments collection 
+     * available within functions, and HTMLElement collections
+     *
+     * @method Array.test
+     * @static
+     *
+     * @todo current implementation (intenionally) will not implicitly 
+     * handle html elements that are array-like (forms, selects, etc).  
+     *
+     * @return {int} a number indicating the results:
+     * 0: Not an array or an array-like collection
+     * 1: A real array. 
+     * 2: array-like collection.
+     */
+    A.test = function(o) {
+        var r = 0;
+        if (L.isObject(o, true)) {
+            if (L.isArray(o)) {
+                r = 1; 
+            } else {
+                try {
+                    // indexed, but no tagName (element) or alert (window)
+                    if ("length" in o && 
+                        !("tagName" in o) && 
+                        !("alert" in o) && 
+                        (!Y.Lang.isFunction(o.size) || o.size() > 1)) {
+                            r = 2;
+                    }
+                        
+                } catch(ex) {}
+            }
+        }
+        return r;
+    };
+
+    /**
+     * Executes the supplied function on each item in the array.
+     * @method Array.each
+     * @param a {Array} the array to iterate
+     * @param f {Function} the function to execute on each item
+     * @param o Optional context object
+     * @static
+     * @return {YUI} the YUI instance
+     */
+    A.each = (Native.forEach) ?
+        function (a, f, o) { 
+            Native.forEach.call(a, f, o || Y);
+            return Y;
+        } :
+        function (a, f, o) { 
+            var l = a.length, i;
+            for (i = 0; i < l; i=i+1) {
+                f.call(o || Y, a[i], i, a);
+            }
+            return Y;
+        };
+
+    /**
+     * Executes the supplied function on each item in the array.
+     * Returning true from the processing function will stop the 
+     * processing of the remaining
+     * items.
+     * @method Array.some
+     * @param a {Array} the array to iterate
+     * @param f {Function} the function to execute on each item
+     * @param o Optional context object
+     * @static
+     * @return {boolean} true if the 
+     */
+     A.some = (Native.forEach) ?
+        function (a, f, o) { 
+            Native.some.call(a, f, o || Y);
+            return Y;
+        } :
+        function (a, f, o) {
+            var l = a.length;
+            for (var i = 0; i < l; i=i+1) {
+                if (f.call(o, a[i], i, a)) {
+                    return true;
+                }
+            }
+            return false;
+        };
+
+    /**
+     * Returns an object using the first array as keys, and
+     * the second as values.  If the second array is not
+     * provided the value is set to true for each.
+     * @method Array.hash
+     * @static
+     * @param k {Array} keyset
+     * @param v {Array} optional valueset
+     * @return {object} the hash
+     */
+    A.hash = function(k, v) {
+        var o = {}, l = k.length, vl = v && v.length, i;
+        for (i=0; i<l; i=i+1) {
+            o[k[i]] = (vl && vl > i) ? v[i] : true;
+        }
+
+        return o;
+    };
+
+
+    /**
+     * Returns the index of the first item in the array
+     * that contains the specified value, -1 if the
+     * value isn't found.
+     * @TODO use native method if avail
+     * @method Array.indexOf
+     * @static
+     * @param a {Array} the array to search
+     * @param val the value to search for
+     * @return {int} the index of the item that contains the value or -1
+     */
+    A.indexOf = function(a, val) {
+        for (var i=0; i<a.length; i=i+1) {
+            if (a[i] === val) {
+                return i;
+            }
+        }
+
+        return -1;
+    };
+
+}, "3.0.0pr2");
+/*
+ * YUI core utilities
+ * @module yui
+ * @submodule core
+ */
+// requires lang
+YUI.add("core", function(Y) {
+
+    var L = Y.Lang, 
+    A = Y.Array,
+    OP = Object.prototype, 
+    IEF = ["toString", "valueOf"], 
+    PROTO = 'prototype',
+
+    /**
+     * IE will not enumerate native functions in a derived object even if the
+     * function was overridden.  This is a workaround for specific functions 
+     * we care about on the Object prototype. 
+     * @property _iefix
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param w a whitelist object (the keys are the valid items to reference)
+     * @private
+     * @for YUI
+     */
+    _iefix = (Y.UA && Y.UA.ie) ?
+        function(r, s, w) {
+            for (var i=0, a=IEF; i<a.length; i=i+1) {
+                var n = a[i], f = s[n];
+                if (L.isFunction(f) && f != OP[n]) {
+                    if (!w || (n in w)) {
+                        r[n]=f;
+                    }
+                }
+            }
+        } : function() {};
+   
+
+    /**
+     * Returns a new object containing all of the properties of
+     * all the supplied objects.  The properties from later objects
+     * will overwrite those in earlier objects.  Passing in a
+     * single object will create a shallow copy of it.  For a deep
+     * copy, use clone.
+     * @method merge
+     * @param arguments {Object*} the objects to merge
+     * @return {object} the new merged object
+     */
+    Y.merge = function() {
+        // var o={}, a=arguments;
+        // for (var i=0, l=a.length; i<l; i=i+1) {
+        //var a=arguments, o=Y.Object(a[0]);
+        var a=arguments, o={};
+        for (var i=0, l=a.length; i<l; i=i+1) {
+            Y.mix(o, a[i], true);
+        }
+        return o;
+    };
+       
+    /**
+     * Applies the supplier's properties to the receiver.  By default
+     * all prototype and static propertes on the supplier are applied
+     * to the corresponding spot on the receiver.  By default all
+     * properties are applied, and a property that is already on the
+     * reciever will not be overwritten.  The default behavior can
+     * be modified by supplying the appropriate parameters.
+     *
+     * @TODO add constants for the modes
+     *
+     * @method mix
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param ov {boolean} if true, properties already on the receiver
+     * will be overwritten if found on the supplier.
+     * @param wl {string[]} a whitelist.  If supplied, only properties in 
+     * this list will be applied to the receiver.
+     * @param {int} mode what should be copies, and to where
+     *        default(0): object to object
+     *        1: prototype to prototype (old augment)
+     *        2: prototype to prototype and object props (new augment)
+     *        3: prototype to object
+     *        4: object to prototype
+     * @param merge {boolean} merge objects instead of overwriting/ignoring
+     * Used by Y.aggregate
+     * @return {object} the augmented object
+     * @TODO review for PR2
+     */
+    Y.mix = function(r, s, ov, wl, mode, merge) {
+
+        if (!s||!r) {
+            return Y;
+        }
+
+        var w = (wl && wl.length) ? A.hash(wl) : null, m = merge,
+
+            f = function(fr, fs, proto, iwl) {
+
+                var arr = m && L.isArray(fr);
+
+                for (var i in fs) { 
+
+                    if (fs.hasOwnProperty(i)) {
+
+                        // We never want to overwrite the prototype
+                        // if (PROTO === i) {
+                        if (PROTO === i || '_yuid' === i) {
+                            continue;
+                        }
+
+                        // Y.log('i: ' + i + ", " + fs[i]);
+                        // @TODO deal with the hasownprop issue
+
+                        // check white list if it was supplied
+                        if (!w || iwl || (i in w)) {
+                            // if the receiver has this property, it is an object,
+                            // and merge is specified, merge the two objects.
+                            if (m && L.isObject(fr[i], true)) {
+                                // console.log('aggregate RECURSE: ' + i);
+                                // @TODO recursive or no?
+                                // Y.mix(fr[i], fs[i]); // not recursive
+                                f(fr[i], fs[i], proto, true); // recursive
+                            // otherwise apply the property only if overwrite
+                            // is specified or the receiver doesn't have one.
+                            // @TODO make sure the 'arr' check isn't desructive
+                            } else if (!arr && (ov || !(i in fr))) {
+                                // console.log('hash: ' + i);
+                                fr[i] = fs[i];
+                            // if merge is specified and the receiver is an array,
+                            // append the array item
+                            } else if (arr) {
+                                // console.log('array: ' + i);
+                                // @TODO probably will need to remove dups
+                                fr.push(fs[i]);
+                            }
+                        }
+                    }
+                }
+
+                _iefix(fr, fs, w);
+            };
+
+        var rp = r.prototype, sp = s.prototype;
+
+        switch (mode) {
+            case 1: // proto to proto
+                f(rp, sp, true);
+                break;
+            case 2: // object to object and proto to proto
+                f(r, s);
+                f(rp, sp, true);
+                break;
+            case 3: // proto to static
+                f(r, sp, true);
+                break;
+            case 4: // static to proto
+                f(rp, s);
+                break;
+            default:  // object to object
+                f(r, s);
+        }
+
+        return r;
+    };
+
+    
+
+}, "3.0.0pr2");
+/*
+ * YUI object utilities
+ * @module yui
+ * @submodule object
+ */
+YUI.add("object", function(Y) {
+
+    /**
+     * Adds the following Object utilities to the YUI instance
+     * @class YUI~object
+     */
+
+    /**
+     * Y.Object(o) returns a new object based upon the supplied object.  
+     * @method Object
+     * @static
+     * @param o the supplier object
+     * @return {object} the new object
+     */
+    Y.Object = function(o) {
+        var F = function() {};
+        F.prototype = o;
+        return new F();
+    }; 
+
+    var O = Y.Object, L = Y.Lang;
+
+    /**
+     * Determines whether or not the property was added
+     * to the object instance.  Returns false if the property is not present
+     * in the object, or was inherited from the prototype.
+     *
+     * @deprecated Safari 1.x support has been removed, so this is simply a 
+     * wrapper for the native implementation.  Use the native implementation
+     * directly instead.
+     *
+     * @TODO Remove in PR2
+     *
+     * @method Object.owns
+     * @static
+     * @param o {any} The object being testing
+     * @param p {string} the property to look for
+     * @return {boolean} true if the object has the property on the instance
+     */
+    O.owns = function(o, p) {
+        return (o && o.hasOwnProperty) ? o.hasOwnProperty(p) : false;
+    };
+
+    /**
+     * Returns an array containing the object's keys
+     * @method Object.keys
+     * @static
+     * @param o an object
+     * @return {string[]} the keys
+     */
+    O.keys = function(o) {
+        var a=[], i;
+        for (i in o) {
+            if (o.hasOwnProperty(i)) {
+                a.push(i);
+            }
+        }
+
+        return a;
+    };
+
+    /**
+     * Executes a function on each item. The function
+     * receives the value, the key, and the object
+     * as paramters (in that order).
+     * @method Object.each
+     * @static
+     * @param o the object to iterate
+     * @param f {function} the function to execute
+     * @param c the execution context
+     * @param proto {boolean} include proto
+     * @return {YUI} the YUI instance
+     */
+    O.each = function (o, f, c, proto) {
+        var s = c || Y;
+
+        for (var i in o) {
+            if (proto || o.hasOwnProperty(i)) {
+                f.call(s, o[i], i, o);
+            }
+        }
+        return Y;
+    };
+}, "3.0.0pr2");
+/*
+ * YUI user agent detection
+ * @module yui
+ * @submodule ua
+ */
+YUI.add("ua", function(Y) {
+
+    /**
+     * Browser/platform detection
+     * @class UA
+     * @static
+     */
+    Y.UA = function() {
+
+        var o={
+
+            /**
+             * Internet Explorer version number or 0.  Example: 6
+             * @property ie
+             * @type float
+             * @static
+             */
+            ie:0,
+
+            /**
+             * Opera version number or 0.  Example: 9.2
+             * @property opera
+             * @type float
+             * @static
+             */
+            opera:0,
+
+            /**
+             * Gecko engine revision number.  Will evaluate to 1 if Gecko 
+             * is detected but the revision could not be found. Other browsers
+             * will be 0.  Example: 1.8
+             * <pre>
+             * Firefox 1.0.0.4: 1.7.8   <-- Reports 1.7
+             * Firefox 1.5.0.9: 1.8.0.9 <-- Reports 1.8
+             * Firefox 2.0.0.3: 1.8.1.3 <-- Reports 1.8
+             * Firefox 3 alpha: 1.9a4   <-- Reports 1.9
+             * </pre>
+             * @property gecko
+             * @type float
+             * @static
+             */
+            gecko:0,
+
+            /**
+             * AppleWebKit version.  KHTML browsers that are not WebKit browsers 
+             * will evaluate to 1, other browsers 0.  Example: 418.9.1
+             * <pre>
+             * Safari 1.3.2 (312.6): 312.8.1 <-- Reports 312.8 -- currently the 
+             *                                   latest available for Mac OSX 10.3.
+             * Safari 2.0.2:         416     <-- hasOwnProperty introduced
+             * Safari 2.0.4:         418     <-- preventDefault fixed
+             * Safari 2.0.4 (419.3): 418.9.1 <-- One version of Safari may run
+             *                                   different versions of webkit
+             * Safari 2.0.4 (419.3): 419     <-- Tiger installations that have been
+             *                                   updated, but not updated
+             *                                   to the latest patch.
+             * Webkit 212 nightly:   522+    <-- Safari 3.0 precursor (with native SVG
+             *                                   and many major issues fixed).
+             * Safari 3.0.4 (523.12) 523.12  <-- First Tiger release - automatic update
+             *                                   from 2.x via the 10.4.11 OS patch
+             *                                   
+             * </pre>
+             * http://developer.apple.com/internet/safari/uamatrix.html
+             * @property webkit
+             * @type float
+             * @static
+             */
+            webkit:0,
+
+            /**
+             * The mobile property will be set to a string containing any relevant
+             * user agent information when a modern mobile browser is detected.
+             * Currently limited to Safari on the iPhone/iPod Touch, Nokia N-series
+             * devices with the WebKit-based browser, and Opera Mini.  
+             * @property mobile 
+             * @type string
+             * @static
+             */
+            mobile: null 
+        };
+
+        var ua=navigator.userAgent, m;
+
+        // Modern KHTML browsers should qualify as Safari X-Grade
+        if ((/KHTML/).test(ua)) {
+            o.webkit=1;
+        }
+        // Modern WebKit browsers are at least X-Grade
+        m=ua.match(/AppleWebKit\/([^\s]*)/);
+        if (m&&m[1]) {
+            o.webkit=parseFloat(m[1]);
+
+            // Mobile browser check
+            if (/ Mobile\//.test(ua)) {
+                o.mobile = "Apple"; // iPhone or iPod Touch
+            } else {
+                m=ua.match(/NokiaN[^\/]*/);
+                if (m) {
+                    o.mobile = m[0]; // Nokia N-series, ex: NokiaN95
+                }
+            }
+
+        }
+
+        if (!o.webkit) { // not webkit
+            // @todo check Opera/8.01 (J2ME/MIDP; Opera Mini/2.0.4509/1316; fi; U; ssr)
+            m=ua.match(/Opera[\s\/]([^\s]*)/);
+            if (m&&m[1]) {
+                o.opera=parseFloat(m[1]);
+                m=ua.match(/Opera Mini[^;]*/);
+                if (m) {
+                    o.mobile = m[0]; // ex: Opera Mini/2.0.4509/1316
+                }
+            } else { // not opera or webkit
+                m=ua.match(/MSIE\s([^;]*)/);
+                if (m&&m[1]) {
+                    o.ie=parseFloat(m[1]);
+                } else { // not opera, webkit, or ie
+                    m=ua.match(/Gecko\/([^\s]*)/);
+                    if (m) {
+                        o.gecko=1; // Gecko detected, look for revision
+                        m=ua.match(/rv:([^\s\)]*)/);
+                        if (m&&m[1]) {
+                            o.gecko=parseFloat(m[1]);
+                        }
+                    }
+                }
+            }
+        }
+        
+        return o;
+    }();
+}, "3.0.0pr2");
+/*
+ * YUI setTimeout/setInterval abstraction
+ * @module yui
+ * @submodule later
+ */
+YUI.add("later", function(Y) {
+
+    var L = Y.Lang;
+
+    /**
+     * Executes the supplied function in the context of the supplied 
+     * object 'when' milliseconds later.  Executes the function a 
+     * single time unless periodic is set to true.
+     * @method later
+     * @for YUI
+     * @param when {int} the number of milliseconds to wait until the fn 
+     * is executed.
+     * @param o the context object.
+     * @param fn {Function|String} the function to execute or the name of 
+     * the method in the 'o' object to execute.
+     * @param data [Array] data that is provided to the function.  This accepts
+     * either a single item or an array.  If an array is provided, the
+     * function is executed with one parameter for each array item.  If
+     * you need to pass a single array parameter, it needs to be wrapped in
+     * an array [myarray].
+     * @param periodic {boolean} if true, executes continuously at supplied 
+     * interval until canceled.
+     * @return {object} a timer object. Call the cancel() method on this object to 
+     * stop the timer.
+     */
+    var later = function(when, o, fn, data, periodic) {
+        when = when || 0; 
+        o = o || {};
+        var m=fn, d=data, f, r;
+
+        if (L.isString(fn)) {
+            m = o[fn];
+        }
+
+        if (!m) {
+            Y.fail("method undefined");
+        }
+
+        if (!L.isArray(d)) {
+            d = [data];
+        }
+
+        f = function() {
+            m.apply(o, d);
+        };
+
+        r = (periodic) ? setInterval(f, when) : setTimeout(f, when);
+
+        return {
+            interval: periodic,
+            cancel: function() {
+                if (this.interval) {
+                    clearInterval(r);
+                } else {
+                    clearTimeout(r);
+                }
+            }
+        };
+    };
+
+    Y.later = later;
+    L.later = later;
+
+}, "3.0.0pr2");
+/*
+ * YUI initializer
+ * @module yui
+ * @submodule init
+ */
+(function() {
+
+    var min = ['yui-base', 'log', 'lang', 'array', 'core'], core,
+
+    M = function(Y) {
+
+        var C = Y.config;
+
+        // apply the minimal required functionality
+        Y.use.apply(Y, min);
+
+        Y.log(Y.id + ' initialized', 'info', 'yui');
+
+        if (C.core) {
+
+            core = C.core;
+
+        } else {
+
+            core = ["object", "ua", "later"];
+
+            core.push(
+              "get", 
+              "loader");
+        }
+
+        Y.use.apply(Y, core);
+
+    };
+     
+    YUI.add("yui", M, "3.0.0pr2");
+    
+    // {
+        // the following will be bound automatically when this code is loaded
+      //   use: core
+    // });
+
+})();

=== added file 'loggerhead/static/javascript/yui/build/yui-base/yui-base-min.js'
--- loggerhead/static/javascript/yui/build/yui-base/yui-base-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yui-base/yui-base-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,8 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+(function(){var D={},B={"io.xdrReady":1,"io.start":1,"io.success":1,"io.failure":1,"io.abort":1};if(typeof YUI==="undefined"||!YUI){YUI=function(G){var F=this;if(!(F instanceof YUI)){return new YUI(G);}else{F._init(G);F._setup();return F;}};}YUI.prototype={_init:function(G){G=G||{};var F=(G.win)?(G.win.contentWindow):G.win||window;G.win=F;G.doc=F.document;G.debug=("debug" in G)?G.debug:true;G.useBrowserConsole=("useBrowserConsole" in G)?G.useBrowserConsole:true;G.throwFail=("throwFail" in G)?G.throwFail:true;this.config=G;this.Env={mods:{},_idx:0,_pre:"yuid",_used:{},_attached:{},_yidx:0,_uidx:0};if(YUI.Env){this.Env._yidx=++YUI.Env._idx;this.id=this.stamp(this);D[this.id]=this;}this.constructor=YUI;},_setup:function(F){this.use("yui");this.config=this.merge(this.config);},applyTo:function(L,K,H){if(!(K in B)){this.fail(K+": applyTo not allowed");return null;}var G=D[L];if(G){var J=K.split("."),F=G;for(var I=0;I<J.length;I=I+1){F=F[J[I]];if(!F){this.fail("applyTo not found: "+K);}}return F.apply(G,H);}return null;},add:function(H,J,G,I){var F={name:H,fn:J,version:G,details:I||{}};YUI.Env.mods[H]=F;return this;},_attach:function(G,K){var Q=YUI.Env.mods,H=this.Env._attached;for(var N=0,L=G.length;N<L;N=N+1){var I=G[N],J=Q[I],M;if(!H[I]&&J){H[I]=true;var O=J.details,P=O.requires,F=O.use;if(P){this._attach(this.Array(P));}if(J.fn){J.fn(this);}if(F){this._attach(this.Array(F));}}}},use:function(){var G=this,P=Array.prototype.slice.call(arguments,0),S=YUI.Env.mods,T=G.Env._used,Q,K=P[0],I=false,R=P[P.length-1];if(typeof R==="function"){P.pop();G.Env._callback=R;}else{R=null;}if(K==="*"){P=[];for(var L in S){if(S.hasOwnProperty(L)){P.push(L);}}return G.use.apply(G,P);}if(G.Loader){I=true;Q=new G.Loader(G.config);Q.require(P);Q.ignoreRegistered=true;Q.allowRollup=false;Q.calculate();P=Q.sorted;}var N=[],F=[],O=function(X){if(T[X]){return;}var U=S[X],W,Y,V;if(U){T[X]=true;Y=U.details.requires;V=U.details.use;}else{N.push(X);}if(Y){if(G.Lang.isString(Y)){O(Y);}else{for(W=0;W<Y.length;W=W+1){O(Y[W]);}}}F.push(X);};for(var M=0,J=P.length;M<J;M=M+1){O(P[M]);}var H=function(V){V=V||{success:true,msg:"not dynamic"};if(G.Env._callback){var U=G.Env._callback;G.Env._callback=null;U(G,V);}if(G.fire){G.fire("yui:load",G,V);}};if(G.Loader&&N.length){Q=new G.Loader(G.config);Q.onSuccess=H;Q.onFailure=H;Q.onTimeout=H;Q.attaching=P;Q.require(N);Q.insert();}else{G._attach(F);H();}return G;},namespace:function(){var F=arguments,J=null,H,G,I;for(H=0;H<F.length;H=H+1){I=F[H].split(".");J=this;for(G=(I[0]=="YAHOO")?1:0;G<I.length;G=G+1){J[I[G]]=J[I[G]]||{};J=J[I[G]];}}return J;},log:function(){},fail:function(H,G){if(this.config.throwFail){throw (G||new Error(H));}else{var F=this;F.log(H,"error");}return this;},guid:function(H){var G=this.Env,F=(H)||G._pre;return F+"-"+G._yidx+"-"+G._uidx++;},stamp:function(G){if(!G){return G;}var F=(typeof G==="string")?G:G._yuid;if(!F){F=this.guid();G._yuid=F;}return F;}};var E=YUI,C=E.prototype,A;for(A in C){if(true){E[A]=C[A];}}E._init();})();YUI.add("yui-base",null,"3.0.0pr2");YUI.add("log",function(A){A.log=function(D,K,B,I){var C=A,J=C.config,L=C.Env._eventstack,G=false;if(J.debug&&!G){if(B){var M=J.logExclude,F=J.logInclude;if(F&&!(B in F)){G=true;}else{if(M&&(B in M)){G=true;}}}if(!G){if(J.useBrowserConsole){var E=(B)?B+": "+D:D;if(typeof console!="undefined"){var H=(K&&console[K])?K:"log";console[H](E);}else{if(typeof opera!="undefined"){opera.postError(E);}}}if(C.fire&&!G&&!I){C.fire("yui:log",D,K,B);}}}return C;};},"3.0.0pr2");YUI.add("lang",function(B){B.Lang=B.Lang||{};var H=B.Lang,E="[object Array]",I="[object Function]",F="string",C="object",D="boolean",G="undefined",A=Object.prototype;H.isArray=function(J){return A.toString.apply(J)===E;};H.isBoolean=function(J){return typeof J===D;};H.isFunction=function(J){return A.toString.apply(J)===I;};H.isDate=function(J){return J instanceof Date;};H.isNull=function(J){return J===null;};H.isNumber=function(J){return typeof J==="number"&&isFinite(J);};H.isObject=function(K,J){return(K&&(typeof K===C||(!J&&H.isFunction(K))))||false;};H.isString=function(J){return typeof J===F;};H.isUndefined=function(J){return typeof J===G;};H.trim=function(J){try{return J.replace(/^\s+|\s+$/g,"");}catch(K){return J;}};H.isValue=function(J){return(H.isObject(J)||H.isString(J)||H.isNumber(J)||H.isBoolean(J));};},"3.0.0pr2");YUI.add("array",function(E){var C=E.Lang,D=Array.prototype;E.Array=function(H,F,G){var A=(G)?2:E.Array.test(H);if(A){return D.slice.call(H,F||0);}else{return[H];}};var B=E.Array;B.test=function(G){var F=0;if(C.isObject(G,true)){if(C.isArray(G)){F=1;}else{try{if("length" in G&&!("tagName" in G)&&!("alert" in G)&&(!E.Lang.isFunction(G.size)||G.size()>1)){F=2;}}catch(A){}}}return F;};B.each=(D.forEach)?function(A,F,G){D.forEach.call(A,F,G||E);return E;}:function(F,H,I){var A=F.length,G;for(G=0;G<A;G=G+1){H.call(I||E,F[G],G,F);}return E;};B.some=(D.forEach)?function(A,F,G){D.some.call(A,F,G||E);return E;}:function(F,H,I){var A=F.length;for(var G=0;G<A;G=G+1){if(H.call(I,F[G],G,F)){return true;}}return false;};B.hash=function(G,F){var J={},A=G.length,I=F&&F.length,H;for(H=0;H<A;H=H+1){J[G[H]]=(I&&I>H)?F[H]:true;}return J;};B.indexOf=function(A,G){for(var F=0;F<A.length;F=F+1){if(A[F]===G){return F;}}return -1;};},"3.0.0pr2");YUI.add("core",function(H){var D=H.Lang,C=H.Array,B=Object.prototype,G=["toString","valueOf"],F="prototype",E=(H.UA&&H.UA.ie)?function(L,K,I){for(var J=0,A=G;J<A.length;J=J+1){var N=A[J],M=K[N];if(D.isFunction(M)&&M!=B[N]){if(!I||(N in I)){L[N]=M;}}}}:function(){};H.merge=function(){var I=arguments,K={};for(var J=0,A=I.length;J<A;J=J+1){H.mix(K,I[J],true);}return K;};H.mix=function(A,R,J,Q,M,O){if(!R||!A){return H;}var P=(Q&&Q.length)?C.hash(Q):null,K=O,N=function(U,T,X,W){var S=K&&D.isArray(U);for(var V in T){if(T.hasOwnProperty(V)){if(F===V||"_yuid"===V){continue;}if(!P||W||(V in P)){if(K&&D.isObject(U[V],true)){N(U[V],T[V],X,true);}else{if(!S&&(J||!(V in U))){U[V]=T[V];}else{if(S){U.push(T[V]);}}}}}}E(U,T,P);
+};var L=A.prototype,I=R.prototype;switch(M){case 1:N(L,I,true);break;case 2:N(A,R);N(L,I,true);break;case 3:N(A,I,true);break;case 4:N(L,R);break;default:N(A,R);}return A;};},"3.0.0pr2");YUI.add("object",function(C){C.Object=function(E){var D=function(){};D.prototype=E;return new D();};var B=C.Object,A=C.Lang;B.owns=function(E,D){return(E&&E.hasOwnProperty)?E.hasOwnProperty(D):false;};B.keys=function(F){var D=[],E;for(E in F){if(F.hasOwnProperty(E)){D.push(E);}}return D;};B.each=function(H,G,I,F){var E=I||C;for(var D in H){if(F||H.hasOwnProperty(D)){G.call(E,H[D],D,H);}}return C;};},"3.0.0pr2");YUI.add("ua",function(A){A.UA=function(){var D={ie:0,opera:0,gecko:0,webkit:0,mobile:null};var C=navigator.userAgent,B;if((/KHTML/).test(C)){D.webkit=1;}B=C.match(/AppleWebKit\/([^\s]*)/);if(B&&B[1]){D.webkit=parseFloat(B[1]);if(/ Mobile\//.test(C)){D.mobile="Apple";}else{B=C.match(/NokiaN[^\/]*/);if(B){D.mobile=B[0];}}}if(!D.webkit){B=C.match(/Opera[\s\/]([^\s]*)/);if(B&&B[1]){D.opera=parseFloat(B[1]);B=C.match(/Opera Mini[^;]*/);if(B){D.mobile=B[0];}}else{B=C.match(/MSIE\s([^;]*)/);if(B&&B[1]){D.ie=parseFloat(B[1]);}else{B=C.match(/Gecko\/([^\s]*)/);if(B){D.gecko=1;B=C.match(/rv:([^\s\)]*)/);if(B&&B[1]){D.gecko=parseFloat(B[1]);}}}}}return D;}();},"3.0.0pr2");YUI.add("later",function(C){var A=C.Lang;var B=function(K,E,L,G,H){K=K||0;E=E||{};var F=L,J=G,I,D;if(A.isString(L)){F=E[L];}if(!F){C.fail("method undefined");}if(!A.isArray(J)){J=[G];}I=function(){F.apply(E,J);};D=(H)?setInterval(I,K):setTimeout(I,K);return{interval:H,cancel:function(){if(this.interval){clearInterval(D);}else{clearTimeout(D);}}};};C.later=B;A.later=B;},"3.0.0pr2");(function(){var B=["yui-base","log","lang","array","core"],A,C=function(E){var D=E.config;E.use.apply(E,B);if(D.core){A=D.core;}else{A=["object","ua","later"];A.push("get","loader");}E.use.apply(E,A);};YUI.add("yui",C,"3.0.0pr2");})();
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/yui-base/yui-base.js'
--- loggerhead/static/javascript/yui/build/yui-base/yui-base.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yui-base/yui-base.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,1521 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * YUI core
+ * @module yui
+ */
+(function() {
+
+    var _instances = {},
+
+// @TODO: this needs to be created at build time from module metadata
+
+        _APPLY_TO_WHITE_LIST = {
+            'io.xdrReady': 1,
+            'io.start': 1,
+            'io.success': 1,
+            'io.failure': 1,
+            'io.abort': 1
+        };
+        
+
+if (typeof YUI === 'undefined' || !YUI) {
+
+    /**
+     * The YUI global namespace object.  If YUI is already defined, the
+     * existing YUI object will not be overwritten so that defined
+     * namespaces are preserved.  
+     *
+     * @class YUI
+     * @constructor
+     * @global
+     * @uses Event.Target
+     * @param o Optional configuration object.  Options:
+     * <ul>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>Global:</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>debug:
+     *  Turn debug statements on or off</li>
+     *  <li>useBrowserConsole:
+     *  Log to the browser console if debug is on and the console is available</li>
+     *  <li>logInclude:
+     *  A hash of log sources that should be logged.  If specified, only log messages from these sources will be logged.
+     *  
+     *  </li>
+     *  <li>logExclude:
+     *  A hash of log sources that should be not be logged.  If specified, all sources are logged if not on this list.</li>
+     *  <li>throwFail:
+     *  If throwFail is set, Y.fail will generate or re-throw a JS error.  Otherwise the failure is logged.
+     *  <li>win:
+     *  The target window/frame</li>
+     *  <li>core:
+     *  A list of modules that defines the YUI core (overrides the default)</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>For event and get:</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>pollInterval:
+     *  The default poll interval</li>
+     *  <li>-------------------------------------------------------------------------</li>
+     *  <li>For loader:</li>
+     *  <li>-------------------------------------------------------------------------</li>
+     *  <li>base:
+     *  The base dir</li>
+     *  <li>secureBase:
+     *  The secure base dir (not implemented)</li>
+     *  <li>comboBase:
+     *  The YUI combo service base dir. Ex: http://yui.yahooapis.com/combo?</li>
+     *  <li>root:
+     *  The root path to prepend to module names for the combo service. Ex: 2.5.2/build/</li>
+     *  <li>filter:
+     *  
+     * A filter to apply to result urls.  This filter will modify the default
+     * path for all modules.  The default path for the YUI library is the
+     * minified version of the files (e.g., event-min.js).  The filter property
+     * can be a predefined filter or a custom filter.  The valid predefined 
+     * filters are:
+     * <dl>
+     *  <dt>DEBUG</dt>
+     *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+     *      This option will automatically include the logger widget</dd>
+     *  <dt>RAW</dt>
+     *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+     * </dl>
+     * You can also define a custom filter, which must be an object literal 
+     * containing a search expression and a replace string:
+     * <pre>
+     *  myFilter: &#123; 
+     *      'searchExp': "-min\\.js", 
+     *      'replaceStr': "-debug.js"
+     *  &#125;
+     * </pre>
+     *
+     *  </li>
+     *  <li>combine:
+     *  Use the YUI combo service to reduce the number of http connections required to load your dependencies</li>
+     *  <li>ignore:
+     *  A list of modules that should never be dynamically loaded</li>
+     *  <li>force:
+     *  A list of modules that should always be loaded when required, even if already present on the page</li>
+     *  <li>insertBefore:
+     *  Node or id for a node that should be used as the insertion point for new nodes</li>
+     *  <li>charset:
+     *  charset for dynamic nodes</li>
+     *  <li>timeout:
+     *  number of milliseconds before a timeout occurs when dynamically loading nodes.  in not set, there is no timeout</li>
+     *  <li>context:
+     *  execution context for all callbacks</li>
+     *  <li>onSuccess:
+     *  callback for the 'success' event</li>
+     *  <li>onFailure:
+     *  callback for the 'failure' event</li>
+     *  <li>onTimeout:
+     *  callback for the 'timeout' event</li>
+     *  <li>onProgress:
+     *  callback executed each time a script or css file is loaded</li>
+     *  <li>modules:
+     *  A list of module definitions.  See Loader.addModule for the supported module metadata</li>
+     * </ul>
+     */
+
+    /*global YUI*/
+    YUI = function(o) {
+        var Y = this;
+
+        // Allow instantiation without the new operator
+        if (!(Y instanceof YUI)) {
+            return new YUI(o);
+        } else {
+            // set up the core environment
+            Y._init(o);
+
+            // bind the specified additional modules for this instance
+            Y._setup();
+
+            return Y;
+        }
+    };
+}
+
+// The prototype contains the functions that are required to allow the external
+// modules to be registered and for the instance to be initialized.
+YUI.prototype = {
+
+    /**
+     * Initialize this YUI instance
+     * @param o config options
+     * @private
+     */
+    _init: function(o) {
+        
+
+        o = o || {};
+
+        // find targeted window and @TODO create facades
+        var w = (o.win) ? (o.win.contentWindow) : o.win  || window;
+        o.win = w;
+        o.doc = w.document;
+        o.debug = ('debug' in o) ? o.debug : true;
+        o.useBrowserConsole = ('useBrowserConsole' in o) ? o.useBrowserConsole : true;
+        o.throwFail = ('throwFail' in o) ? o.throwFail : true;
+    
+        // add a reference to o for anything that needs it
+        // before _setup is called.
+        this.config = o;
+
+        this.Env = {
+            // @todo expand the new module metadata
+            mods: {},
+            _idx: 0,
+            _pre: 'yuid',
+            _used: {},
+            _attached: {},
+            _yidx: 0,
+            _uidx: 0
+        };
+
+        if (YUI.Env) {
+            this.Env._yidx = ++YUI.Env._idx;
+            this.id = this.stamp(this);
+            _instances[this.id] = this;
+        }
+
+        this.constructor = YUI;
+
+    },
+    
+    /**
+     * Finishes the instance setup. Attaches whatever modules were defined
+     * when the yui modules was registered.
+     * @method _setup
+     * @private
+     */
+    _setup: function(o) {
+        this.use("yui");
+        // @TODO eval the need to copy the config
+        this.config = this.merge(this.config);
+    },
+
+    /**
+     * Executes a method on a YUI instance with
+     * the specified id if the specified method is whitelisted.
+     * @method applyTo
+     * @param id {string} the YUI instance id
+     * @param method {string} the name of the method to exectute.
+     * Ex: 'Object.keys'
+     * @param args {Array} the arguments to apply to the method
+     * @return {object} the return value from the applied method or null
+     */
+    applyTo: function(id, method, args) {
+
+        if (!(method in _APPLY_TO_WHITE_LIST)) {
+            this.fail(method + ': applyTo not allowed');
+            return null;
+        }
+
+        var instance = _instances[id];
+
+        if (instance) {
+
+            var nest = method.split('.'), m = instance;
+
+            for (var i=0; i<nest.length; i=i+1) {
+
+                m = m[nest[i]];
+
+                if (!m) {
+                    this.fail('applyTo not found: ' + method);
+                }
+            }
+
+            return m.apply(instance, args);
+        }
+
+        return null;
+    }, 
+
+    /**
+     * Register a module
+     * @method add
+     * @param name {string} module name
+     * @param fn {Function} entry point into the module that
+     * is used to bind module to the YUI instance
+     * @param version {string} version string
+     * @return {YUI} the YUI instance
+     *
+     * requires   - features that should be present before loading
+     * optional   - optional features that should be present if load optional defined
+     * use  - features that should be attached automatically
+     * skinnable  -
+     * rollup
+     * omit - features that should not be loaded if this module is present
+     */
+    add: function(name, fn, version, details) {
+
+
+        // @todo expand this to include version mapping
+        
+        // @todo allow requires/supersedes
+
+        // @todo may want to restore the build property
+        
+        // @todo fire moduleAvailable event
+        
+        var m = {
+            name: name, 
+            fn: fn,
+            version: version,
+            details: details || {}
+        };
+
+        YUI.Env.mods[name] = m;
+
+        return this; // chain support
+    },
+
+    _attach: function(r, fromLoader) {
+
+        var mods = YUI.Env.mods,
+            attached = this.Env._attached;
+
+        for (var i=0, l=r.length; i<l; i=i+1) {
+            var name = r[i], m = mods[name], mm;
+            if (!attached[name] && m) {
+
+                attached[name] = true;
+
+                var d = m.details, req = d.requires, use = d.use;
+
+                if (req) {
+                    this._attach(this.Array(req));
+                }
+
+
+                if (m.fn) {
+                    m.fn(this);
+                }
+
+                if (use) {
+                    this._attach(this.Array(use));
+                }
+            }
+        }
+
+    },
+
+    /**
+     * Bind a module to a YUI instance
+     * @param modules* {string} 1-n modules to bind (uses arguments array)
+     * @param *callback {function} callback function executed when 
+     * the instance has the required functionality.  If included, it
+     * must be the last parameter.
+     *
+     * @TODO 
+     * Implement versioning?  loader can load different versions?
+     * Should sub-modules/plugins be normal modules, or do
+     * we add syntax for specifying these?
+     *
+     * YUI().use('dragdrop')
+     * YUI().use('dragdrop:2.4.0'); // specific version
+     * YUI().use('dragdrop:2.4.0-'); // at least this version
+     * YUI().use('dragdrop:2.4.0-2.9999.9999'); // version range
+     * YUI().use('*'); // use all available modules
+     * YUI().use('lang+dump+substitute'); // use lang and some plugins
+     * YUI().use('lang+*'); // use lang and all known plugins
+     *
+     *
+     * @return {YUI} the YUI instance
+     */
+    use: function() {
+
+        var Y = this, 
+            a=Array.prototype.slice.call(arguments, 0), 
+            mods = YUI.Env.mods, 
+            used = Y.Env._used,
+            loader, 
+            firstArg = a[0], 
+            dynamic = false,
+            callback = a[a.length-1];
+
+
+        // The last argument supplied to use can be a load complete callback
+        if (typeof callback === 'function') {
+            a.pop();
+            Y.Env._callback = callback;
+        } else {
+            callback = null;
+        }
+
+        // YUI().use('*'); // bind everything available
+        if (firstArg === "*") {
+            a = [];
+            for (var k in mods) {
+                if (mods.hasOwnProperty(k)) {
+                    a.push(k);
+                }
+            }
+
+            return Y.use.apply(Y, a);
+
+        }
+       
+
+        // use loader to expand dependencies and sort the 
+        // requirements if it is available.
+        if (Y.Loader) {
+            dynamic = true;
+            loader = new Y.Loader(Y.config);
+            loader.require(a);
+            loader.ignoreRegistered = true;
+            loader.allowRollup = false;
+            loader.calculate();
+            a = loader.sorted;
+        }
+
+
+        var missing = [], r = [], f = function(name) {
+
+            // only attach a module once
+            if (used[name]) {
+                return;
+            }
+
+            var m = mods[name], j, req, use;
+
+            if (m) {
+                used[name] = true;
+
+                req = m.details.requires;
+                use = m.details.use;
+            } else {
+                missing.push(name);
+            }
+
+            // make sure requirements are attached
+            if (req) {
+                if (Y.Lang.isString(req)) {
+                    f(req);
+                } else {
+                    for (j = 0; j < req.length; j = j + 1) {
+                        f(req[j]);
+                    }
+                }
+            }
+
+            // add this module to full list of things to attach
+            r.push(name);
+
+        };
+
+        // process each requirement and any additional requirements 
+        // the module metadata specifies
+        for (var i=0, l=a.length; i<l; i=i+1) {
+            f(a[i]);
+        }
+
+
+        var onComplete = function(fromLoader) {
+
+
+            fromLoader = fromLoader || {
+                success: true,
+                msg: 'not dynamic'
+            };
+
+            if (Y.Env._callback) {
+
+                var cb = Y.Env._callback;
+                Y.Env._callback = null;
+                cb(Y, fromLoader);
+            }
+
+            if (Y.fire) {
+                Y.fire('yui:load', Y, fromLoader);
+            }
+        };
+
+
+        // dynamic load
+        if (Y.Loader && missing.length) {
+            loader = new Y.Loader(Y.config);
+            loader.onSuccess = onComplete;
+            loader.onFailure = onComplete;
+            loader.onTimeout = onComplete;
+            loader.attaching = a;
+            loader.require(missing);
+            loader.insert();
+        } else {
+            Y._attach(r);
+            onComplete();
+        }
+
+        return Y; // chain support var yui = YUI().use('dragdrop');
+    },
+
+
+    /**
+     * Returns the namespace specified and creates it if it doesn't exist
+     * <pre>
+     * YUI.namespace("property.package");
+     * YUI.namespace("YAHOO.property.package");
+     * </pre>
+     * Either of the above would create YAHOO.property, then
+     * YUI.property.package
+     *
+     * Be careful when naming packages. Reserved words may work in some browsers
+     * and not others. For instance, the following will fail in Safari:
+     * <pre>
+     * YUI.namespace("really.long.nested.namespace");
+     * </pre>
+     * This fails because "long" is a future reserved word in ECMAScript
+     *
+     * @method namespace
+     * @param  {string*} arguments 1-n namespaces to create 
+     * @return {object}  A reference to the last namespace object created
+     */
+    namespace: function() {
+        var a=arguments, o=null, i, j, d;
+        for (i=0; i<a.length; i=i+1) {
+            d = a[i].split(".");
+            o = this;
+            for (j=(d[0] == "YAHOO") ? 1 : 0; j<d.length; j=j+1) {
+                o[d[j]] = o[d[j]] || {};
+                o = o[d[j]];
+            }
+        }
+        return o;
+    },
+
+    // this is replaced if the log module is included
+    log: function() {
+
+    },
+
+    /**
+     * Report an error.  The reporting mechanism is controled by
+     * the 'throwFail' configuration attribute.  If throwFail is
+     * not specified, the message is written to the logger, otherwise
+     * a JS error is thrown
+     * @method fail
+     * @param msg {string} the failure message
+     * @param e {Error} Optional JS error that was caught.  If supplied
+     * and throwFail is specified, this error will be re-thrown.
+     * @return {YUI} this YUI instance
+     */
+    fail: function(msg, e) {
+        if (this.config.throwFail) {
+            throw (e || new Error(msg)); 
+        } else {
+            var instance = this;
+            instance.log(msg, "error"); // don't scrub this one
+        }
+
+        return this;
+    },
+
+    /**
+     * Generate an id that is unique among all YUI instances
+     * @method guid
+     * @param pre {string} optional guid prefix
+     * @return {string} the guid
+     */
+    guid: function(pre) {
+        var e = this.Env, p = (pre) || e._pre;
+        return p +'-' + e._yidx + '-' + e._uidx++;
+    },
+
+    /**
+     * Stamps an object with a guid.  If the object already
+     * has one, a new one is not created
+     * @method stamp
+     * @param o The object to stamp
+     * @return {string} The object's guid
+     */
+    stamp: function(o) {
+
+        if (!o) {
+            return o;
+        }
+
+        var uid = (typeof o === 'string') ? o : o._yuid;
+
+        if (!uid) {
+            uid = this.guid();
+            o._yuid = uid;
+        }
+
+        return uid;
+    }
+};
+
+// Give the YUI global the same properties as an instance.
+// This makes it so that the YUI global can be used like the YAHOO
+// global was used prior to 3.x.  More importantly, the YUI global
+// provides global metadata, so env needs to be configured.
+// @TODO review
+
+    var Y = YUI, p = Y.prototype, i;
+
+    // inheritance utilities are not available yet
+    for (i in p) {
+        if (true) {
+            Y[i] = p[i];
+        }
+    }
+
+    // set up the environment
+    Y._init();
+
+
+})();
+/**
+ * YUI stub
+ * @module yui
+ * @submodule yui-base
+ */
+// This is just a stub to for dependency processing
+YUI.add("yui-base", null, "3.0.0pr2");
+/*
+ * YUI console logger
+ * @module yui
+ * @submodule log
+ */
+YUI.add("log", function(instance) {
+
+    /**
+     * If the 'debug' config is true, a 'yui:log' event will be
+     * dispatched, which the logger widget and anything else
+     * can consume.  If the 'useBrowserConsole' config is true, it will
+     * write to the browser console if available.
+     *
+     * @method log
+     * @for YUI
+     * @param  {String}  msg  The message to log.
+     * @param  {String}  cat  The log category for the message.  Default
+     *                        categories are "info", "warn", "error", time".
+     *                        Custom categories can be used as well. (opt)
+     * @param  {String}  src  The source of the the message (opt)
+     * @param  {boolean} silent If true, the log event won't fire
+     * @return {YUI}      YUI instance
+     */
+    instance.log = function(msg, cat, src, silent) {
+
+        var Y = instance, c = Y.config, es = Y.Env._eventstack,
+            // bail = (es && es.logging);
+            bail = false; 
+
+        // suppress log message if the config is off or the event stack
+        // or the event call stack contains a consumer of the yui:log event
+        if (c.debug && !bail) {
+
+            // apply source filters
+            if (src) {
+
+                var exc = c.logExclude, inc = c.logInclude;
+
+                // console.log('checking src filter: ' + src + ', inc: ' + inc + ', exc: ' + exc);
+
+                if (inc && !(src in inc)) {
+                    // console.log('bail: inc list found, but src is not in list: ' + src);
+                    bail = true;
+                } else if (exc && (src in exc)) {
+                    // console.log('bail: exc list found, and src is in it: ' + src);
+                    bail = true;
+                }
+            }
+
+            if (!bail) {
+
+                if (c.useBrowserConsole) {
+                    var m = (src) ? src + ': ' + msg : msg;
+                    if (typeof console != 'undefined') {
+                        var f = (cat && console[cat]) ? cat : 'log';
+                        console[f](m);
+                    } else if (typeof opera != 'undefined') {
+                        opera.postError(m);
+                    }
+                }
+
+                if (Y.fire && !bail && !silent) {
+                    Y.fire('yui:log', msg, cat, src);
+                }
+            }
+        }
+
+        return Y;
+    };
+
+}, "3.0.0pr2");
+/*
+ * YUI lang utils
+ * @module yui
+ * @submodule lang
+ */
+YUI.add("lang", function(Y) {
+
+    /**
+     * Provides the language utilites and extensions used by the library
+     * @class Lang
+     * @static
+     */
+    Y.Lang = Y.Lang || {};
+
+    var L = Y.Lang, 
+
+    ARRAY_TOSTRING = '[object Array]',
+    FUNCTION_TOSTRING = '[object Function]',
+    STRING = 'string',
+    OBJECT = 'object',
+    BOOLEAN = 'boolean',
+    UNDEFINED = 'undefined',
+    OP = Object.prototype;
+
+    /**
+     * Determines whether or not the provided object is an array.
+     * Testing typeof/instanceof/constructor of arrays across frame 
+     * boundaries isn't possible in Safari unless you have a reference
+     * to the other frame to test against its Array prototype.  To
+     * handle this case, we test well-known array properties instead.
+     * properties.
+     * @TODO can we kill this cross frame hack?
+     * @method isArray
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is an array
+     */
+    L.isArray = function(o) { 
+        return OP.toString.apply(o) === ARRAY_TOSTRING;
+    };
+
+    /**
+     * Determines whether or not the provided object is a boolean
+     * @method isBoolean
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a boolean
+     */
+    L.isBoolean = function(o) {
+        return typeof o === BOOLEAN;
+    };
+    
+    /**
+     * Determines whether or not the provided object is a function
+     * Note: Internet Explorer thinks certain functions are objects:
+     *
+     * var obj = document.createElement("object");
+     * Y.Lang.isFunction(obj.getAttribute) // reports false in IE
+     *
+     * var input = document.createElement("input"); // append to body
+     * Y.Lang.isFunction(input.focus) // reports false in IE
+     *
+     * You will have to implement additional tests if these functions
+     * matter to you.
+     *
+     * @method isFunction
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a function
+     */
+    L.isFunction = function(o) {
+        return OP.toString.apply(o) === FUNCTION_TOSTRING;
+    };
+        
+    /**
+     * Determines whether or not the supplied object is a date instance
+     * @method isDate
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a date
+     */
+    L.isDate = function(o) {
+        return o instanceof Date;
+    };
+
+    /**
+     * Determines whether or not the provided object is null
+     * @method isNull
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is null
+     */
+    L.isNull = function(o) {
+        return o === null;
+    };
+        
+    /**
+     * Determines whether or not the provided object is a legal number
+     * @method isNumber
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a number
+     */
+    L.isNumber = function(o) {
+        return typeof o === 'number' && isFinite(o);
+    };
+      
+    /**
+     * Determines whether or not the provided object is of type object
+     * or function
+     * @method isObject
+     * @static
+     * @param o The object to test
+     * @param failfn {boolean} fail if the input is a function
+     * @return {boolean} true if o is an object
+     */  
+    L.isObject = function(o, failfn) {
+return (o && (typeof o === OBJECT || (!failfn && L.isFunction(o)))) || false;
+    };
+        
+    /**
+     * Determines whether or not the provided object is a string
+     * @method isString
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a string
+     */
+    L.isString = function(o) {
+        return typeof o === STRING;
+    };
+        
+    /**
+     * Determines whether or not the provided object is undefined
+     * @method isUndefined
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is undefined
+     */
+    L.isUndefined = function(o) {
+        return typeof o === UNDEFINED;
+    };
+    
+    /**
+     * Returns a string without any leading or trailing whitespace.  If 
+     * the input is not a string, the input will be returned untouched.
+     * @method trim
+     * @static
+     * @param s {string} the string to trim
+     * @return {string} the trimmed string
+     */
+    L.trim = function(s){
+        try {
+            return s.replace(/^\s+|\s+$/g, "");
+        } catch(e) {
+            return s;
+        }
+    };
+
+    /**
+     * A convenience method for detecting a legitimate non-null value.
+     * Returns false for null/undefined/NaN, true for other values, 
+     * including 0/false/''
+     * @method isValue
+     * @static
+     * @param o The item to test
+     * @return {boolean} true if it is not null/undefined/NaN || false
+     */
+    L.isValue = function(o) {
+// return (o || o === false || o === 0 || o === ''); // Infinity fails
+return (L.isObject(o) || L.isString(o) || L.isNumber(o) || L.isBoolean(o));
+    };
+
+}, "3.0.0pr2");
+
+
+/*
+ * Array utilities
+ * @module yui
+ * @submodule array
+ */
+
+/**
+ * YUI core
+ * @module yui
+ */
+
+YUI.add("array", function(Y) {
+
+    var L = Y.Lang, Native = Array.prototype;
+
+    /**
+     * Adds the following array utilities to the YUI instance
+     * @class YUI~array
+     */
+
+    /** 
+     * Y.Array(o) returns an array:
+     * - Arrays are return unmodified unless the start position is specified.
+     * - "Array-like" collections (@see Array.test) are converted to arrays
+     * - For everything else, a new array is created with the input as the sole item
+     * - The start position is used if the input is or is like an array to return
+     *   a subset of the collection.
+     *
+     *   @TODO this will not automatically convert elements that are also collections
+     *   such as forms and selects.  Passing true as the third param will
+     *   force a conversion.
+     *
+     * @method Array
+     * @static
+     *   @param o the item to arrayify
+     *   @param i {int} if an array or array-like, this is the start index
+     *   @param al {boolean} if true, it forces the array-like fork.  This
+     *   can be used to avoid multiple array.test calls.
+     *   @return {Array} the resulting array
+     */
+    Y.Array = function(o, i, al) {
+        var t = (al) ? 2 : Y.Array.test(o);
+
+        // switch (t) {
+        //     case 1:
+        //         // return (i) ? o.slice(i) : o;
+        //     case 2:
+        //         return Native.slice.call(o, i || 0);
+        //     default:
+        //         return [o];
+        // }
+
+        if (t) {
+            return Native.slice.call(o, i || 0);
+        } else {
+            return [o];
+        }
+
+    };
+
+    var A = Y.Array;
+    
+    /** 
+     * Evaluates the input to determine if it is an array, array-like, or 
+     * something else.  This is used to handle the arguments collection 
+     * available within functions, and HTMLElement collections
+     *
+     * @method Array.test
+     * @static
+     *
+     * @todo current implementation (intenionally) will not implicitly 
+     * handle html elements that are array-like (forms, selects, etc).  
+     *
+     * @return {int} a number indicating the results:
+     * 0: Not an array or an array-like collection
+     * 1: A real array. 
+     * 2: array-like collection.
+     */
+    A.test = function(o) {
+        var r = 0;
+        if (L.isObject(o, true)) {
+            if (L.isArray(o)) {
+                r = 1; 
+            } else {
+                try {
+                    // indexed, but no tagName (element) or alert (window)
+                    if ("length" in o && 
+                        !("tagName" in o) && 
+                        !("alert" in o) && 
+                        (!Y.Lang.isFunction(o.size) || o.size() > 1)) {
+                            r = 2;
+                    }
+                        
+                } catch(ex) {}
+            }
+        }
+        return r;
+    };
+
+    /**
+     * Executes the supplied function on each item in the array.
+     * @method Array.each
+     * @param a {Array} the array to iterate
+     * @param f {Function} the function to execute on each item
+     * @param o Optional context object
+     * @static
+     * @return {YUI} the YUI instance
+     */
+    A.each = (Native.forEach) ?
+        function (a, f, o) { 
+            Native.forEach.call(a, f, o || Y);
+            return Y;
+        } :
+        function (a, f, o) { 
+            var l = a.length, i;
+            for (i = 0; i < l; i=i+1) {
+                f.call(o || Y, a[i], i, a);
+            }
+            return Y;
+        };
+
+    /**
+     * Executes the supplied function on each item in the array.
+     * Returning true from the processing function will stop the 
+     * processing of the remaining
+     * items.
+     * @method Array.some
+     * @param a {Array} the array to iterate
+     * @param f {Function} the function to execute on each item
+     * @param o Optional context object
+     * @static
+     * @return {boolean} true if the 
+     */
+     A.some = (Native.forEach) ?
+        function (a, f, o) { 
+            Native.some.call(a, f, o || Y);
+            return Y;
+        } :
+        function (a, f, o) {
+            var l = a.length;
+            for (var i = 0; i < l; i=i+1) {
+                if (f.call(o, a[i], i, a)) {
+                    return true;
+                }
+            }
+            return false;
+        };
+
+    /**
+     * Returns an object using the first array as keys, and
+     * the second as values.  If the second array is not
+     * provided the value is set to true for each.
+     * @method Array.hash
+     * @static
+     * @param k {Array} keyset
+     * @param v {Array} optional valueset
+     * @return {object} the hash
+     */
+    A.hash = function(k, v) {
+        var o = {}, l = k.length, vl = v && v.length, i;
+        for (i=0; i<l; i=i+1) {
+            o[k[i]] = (vl && vl > i) ? v[i] : true;
+        }
+
+        return o;
+    };
+
+
+    /**
+     * Returns the index of the first item in the array
+     * that contains the specified value, -1 if the
+     * value isn't found.
+     * @TODO use native method if avail
+     * @method Array.indexOf
+     * @static
+     * @param a {Array} the array to search
+     * @param val the value to search for
+     * @return {int} the index of the item that contains the value or -1
+     */
+    A.indexOf = function(a, val) {
+        for (var i=0; i<a.length; i=i+1) {
+            if (a[i] === val) {
+                return i;
+            }
+        }
+
+        return -1;
+    };
+
+}, "3.0.0pr2");
+/*
+ * YUI core utilities
+ * @module yui
+ * @submodule core
+ */
+// requires lang
+YUI.add("core", function(Y) {
+
+    var L = Y.Lang, 
+    A = Y.Array,
+    OP = Object.prototype, 
+    IEF = ["toString", "valueOf"], 
+    PROTO = 'prototype',
+
+    /**
+     * IE will not enumerate native functions in a derived object even if the
+     * function was overridden.  This is a workaround for specific functions 
+     * we care about on the Object prototype. 
+     * @property _iefix
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param w a whitelist object (the keys are the valid items to reference)
+     * @private
+     * @for YUI
+     */
+    _iefix = (Y.UA && Y.UA.ie) ?
+        function(r, s, w) {
+            for (var i=0, a=IEF; i<a.length; i=i+1) {
+                var n = a[i], f = s[n];
+                if (L.isFunction(f) && f != OP[n]) {
+                    if (!w || (n in w)) {
+                        r[n]=f;
+                    }
+                }
+            }
+        } : function() {};
+   
+
+    /**
+     * Returns a new object containing all of the properties of
+     * all the supplied objects.  The properties from later objects
+     * will overwrite those in earlier objects.  Passing in a
+     * single object will create a shallow copy of it.  For a deep
+     * copy, use clone.
+     * @method merge
+     * @param arguments {Object*} the objects to merge
+     * @return {object} the new merged object
+     */
+    Y.merge = function() {
+        // var o={}, a=arguments;
+        // for (var i=0, l=a.length; i<l; i=i+1) {
+        //var a=arguments, o=Y.Object(a[0]);
+        var a=arguments, o={};
+        for (var i=0, l=a.length; i<l; i=i+1) {
+            Y.mix(o, a[i], true);
+        }
+        return o;
+    };
+       
+    /**
+     * Applies the supplier's properties to the receiver.  By default
+     * all prototype and static propertes on the supplier are applied
+     * to the corresponding spot on the receiver.  By default all
+     * properties are applied, and a property that is already on the
+     * reciever will not be overwritten.  The default behavior can
+     * be modified by supplying the appropriate parameters.
+     *
+     * @TODO add constants for the modes
+     *
+     * @method mix
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param ov {boolean} if true, properties already on the receiver
+     * will be overwritten if found on the supplier.
+     * @param wl {string[]} a whitelist.  If supplied, only properties in 
+     * this list will be applied to the receiver.
+     * @param {int} mode what should be copies, and to where
+     *        default(0): object to object
+     *        1: prototype to prototype (old augment)
+     *        2: prototype to prototype and object props (new augment)
+     *        3: prototype to object
+     *        4: object to prototype
+     * @param merge {boolean} merge objects instead of overwriting/ignoring
+     * Used by Y.aggregate
+     * @return {object} the augmented object
+     * @TODO review for PR2
+     */
+    Y.mix = function(r, s, ov, wl, mode, merge) {
+
+        if (!s||!r) {
+            return Y;
+        }
+
+        var w = (wl && wl.length) ? A.hash(wl) : null, m = merge,
+
+            f = function(fr, fs, proto, iwl) {
+
+                var arr = m && L.isArray(fr);
+
+                for (var i in fs) { 
+
+                    if (fs.hasOwnProperty(i)) {
+
+                        // We never want to overwrite the prototype
+                        // if (PROTO === i) {
+                        if (PROTO === i || '_yuid' === i) {
+                            continue;
+                        }
+
+                        // @TODO deal with the hasownprop issue
+
+                        // check white list if it was supplied
+                        if (!w || iwl || (i in w)) {
+                            // if the receiver has this property, it is an object,
+                            // and merge is specified, merge the two objects.
+                            if (m && L.isObject(fr[i], true)) {
+                                // console.log('aggregate RECURSE: ' + i);
+                                // @TODO recursive or no?
+                                // Y.mix(fr[i], fs[i]); // not recursive
+                                f(fr[i], fs[i], proto, true); // recursive
+                            // otherwise apply the property only if overwrite
+                            // is specified or the receiver doesn't have one.
+                            // @TODO make sure the 'arr' check isn't desructive
+                            } else if (!arr && (ov || !(i in fr))) {
+                                // console.log('hash: ' + i);
+                                fr[i] = fs[i];
+                            // if merge is specified and the receiver is an array,
+                            // append the array item
+                            } else if (arr) {
+                                // console.log('array: ' + i);
+                                // @TODO probably will need to remove dups
+                                fr.push(fs[i]);
+                            }
+                        }
+                    }
+                }
+
+                _iefix(fr, fs, w);
+            };
+
+        var rp = r.prototype, sp = s.prototype;
+
+        switch (mode) {
+            case 1: // proto to proto
+                f(rp, sp, true);
+                break;
+            case 2: // object to object and proto to proto
+                f(r, s);
+                f(rp, sp, true);
+                break;
+            case 3: // proto to static
+                f(r, sp, true);
+                break;
+            case 4: // static to proto
+                f(rp, s);
+                break;
+            default:  // object to object
+                f(r, s);
+        }
+
+        return r;
+    };
+
+    
+
+}, "3.0.0pr2");
+/*
+ * YUI object utilities
+ * @module yui
+ * @submodule object
+ */
+YUI.add("object", function(Y) {
+
+    /**
+     * Adds the following Object utilities to the YUI instance
+     * @class YUI~object
+     */
+
+    /**
+     * Y.Object(o) returns a new object based upon the supplied object.  
+     * @method Object
+     * @static
+     * @param o the supplier object
+     * @return {object} the new object
+     */
+    Y.Object = function(o) {
+        var F = function() {};
+        F.prototype = o;
+        return new F();
+    }; 
+
+    var O = Y.Object, L = Y.Lang;
+
+    /**
+     * Determines whether or not the property was added
+     * to the object instance.  Returns false if the property is not present
+     * in the object, or was inherited from the prototype.
+     *
+     * @deprecated Safari 1.x support has been removed, so this is simply a 
+     * wrapper for the native implementation.  Use the native implementation
+     * directly instead.
+     *
+     * @TODO Remove in PR2
+     *
+     * @method Object.owns
+     * @static
+     * @param o {any} The object being testing
+     * @param p {string} the property to look for
+     * @return {boolean} true if the object has the property on the instance
+     */
+    O.owns = function(o, p) {
+        return (o && o.hasOwnProperty) ? o.hasOwnProperty(p) : false;
+    };
+
+    /**
+     * Returns an array containing the object's keys
+     * @method Object.keys
+     * @static
+     * @param o an object
+     * @return {string[]} the keys
+     */
+    O.keys = function(o) {
+        var a=[], i;
+        for (i in o) {
+            if (o.hasOwnProperty(i)) {
+                a.push(i);
+            }
+        }
+
+        return a;
+    };
+
+    /**
+     * Executes a function on each item. The function
+     * receives the value, the key, and the object
+     * as paramters (in that order).
+     * @method Object.each
+     * @static
+     * @param o the object to iterate
+     * @param f {function} the function to execute
+     * @param c the execution context
+     * @param proto {boolean} include proto
+     * @return {YUI} the YUI instance
+     */
+    O.each = function (o, f, c, proto) {
+        var s = c || Y;
+
+        for (var i in o) {
+            if (proto || o.hasOwnProperty(i)) {
+                f.call(s, o[i], i, o);
+            }
+        }
+        return Y;
+    };
+}, "3.0.0pr2");
+/*
+ * YUI user agent detection
+ * @module yui
+ * @submodule ua
+ */
+YUI.add("ua", function(Y) {
+
+    /**
+     * Browser/platform detection
+     * @class UA
+     * @static
+     */
+    Y.UA = function() {
+
+        var o={
+
+            /**
+             * Internet Explorer version number or 0.  Example: 6
+             * @property ie
+             * @type float
+             * @static
+             */
+            ie:0,
+
+            /**
+             * Opera version number or 0.  Example: 9.2
+             * @property opera
+             * @type float
+             * @static
+             */
+            opera:0,
+
+            /**
+             * Gecko engine revision number.  Will evaluate to 1 if Gecko 
+             * is detected but the revision could not be found. Other browsers
+             * will be 0.  Example: 1.8
+             * <pre>
+             * Firefox 1.0.0.4: 1.7.8   <-- Reports 1.7
+             * Firefox 1.5.0.9: 1.8.0.9 <-- Reports 1.8
+             * Firefox 2.0.0.3: 1.8.1.3 <-- Reports 1.8
+             * Firefox 3 alpha: 1.9a4   <-- Reports 1.9
+             * </pre>
+             * @property gecko
+             * @type float
+             * @static
+             */
+            gecko:0,
+
+            /**
+             * AppleWebKit version.  KHTML browsers that are not WebKit browsers 
+             * will evaluate to 1, other browsers 0.  Example: 418.9.1
+             * <pre>
+             * Safari 1.3.2 (312.6): 312.8.1 <-- Reports 312.8 -- currently the 
+             *                                   latest available for Mac OSX 10.3.
+             * Safari 2.0.2:         416     <-- hasOwnProperty introduced
+             * Safari 2.0.4:         418     <-- preventDefault fixed
+             * Safari 2.0.4 (419.3): 418.9.1 <-- One version of Safari may run
+             *                                   different versions of webkit
+             * Safari 2.0.4 (419.3): 419     <-- Tiger installations that have been
+             *                                   updated, but not updated
+             *                                   to the latest patch.
+             * Webkit 212 nightly:   522+    <-- Safari 3.0 precursor (with native SVG
+             *                                   and many major issues fixed).
+             * Safari 3.0.4 (523.12) 523.12  <-- First Tiger release - automatic update
+             *                                   from 2.x via the 10.4.11 OS patch
+             *                                   
+             * </pre>
+             * http://developer.apple.com/internet/safari/uamatrix.html
+             * @property webkit
+             * @type float
+             * @static
+             */
+            webkit:0,
+
+            /**
+             * The mobile property will be set to a string containing any relevant
+             * user agent information when a modern mobile browser is detected.
+             * Currently limited to Safari on the iPhone/iPod Touch, Nokia N-series
+             * devices with the WebKit-based browser, and Opera Mini.  
+             * @property mobile 
+             * @type string
+             * @static
+             */
+            mobile: null 
+        };
+
+        var ua=navigator.userAgent, m;
+
+        // Modern KHTML browsers should qualify as Safari X-Grade
+        if ((/KHTML/).test(ua)) {
+            o.webkit=1;
+        }
+        // Modern WebKit browsers are at least X-Grade
+        m=ua.match(/AppleWebKit\/([^\s]*)/);
+        if (m&&m[1]) {
+            o.webkit=parseFloat(m[1]);
+
+            // Mobile browser check
+            if (/ Mobile\//.test(ua)) {
+                o.mobile = "Apple"; // iPhone or iPod Touch
+            } else {
+                m=ua.match(/NokiaN[^\/]*/);
+                if (m) {
+                    o.mobile = m[0]; // Nokia N-series, ex: NokiaN95
+                }
+            }
+
+        }
+
+        if (!o.webkit) { // not webkit
+            // @todo check Opera/8.01 (J2ME/MIDP; Opera Mini/2.0.4509/1316; fi; U; ssr)
+            m=ua.match(/Opera[\s\/]([^\s]*)/);
+            if (m&&m[1]) {
+                o.opera=parseFloat(m[1]);
+                m=ua.match(/Opera Mini[^;]*/);
+                if (m) {
+                    o.mobile = m[0]; // ex: Opera Mini/2.0.4509/1316
+                }
+            } else { // not opera or webkit
+                m=ua.match(/MSIE\s([^;]*)/);
+                if (m&&m[1]) {
+                    o.ie=parseFloat(m[1]);
+                } else { // not opera, webkit, or ie
+                    m=ua.match(/Gecko\/([^\s]*)/);
+                    if (m) {
+                        o.gecko=1; // Gecko detected, look for revision
+                        m=ua.match(/rv:([^\s\)]*)/);
+                        if (m&&m[1]) {
+                            o.gecko=parseFloat(m[1]);
+                        }
+                    }
+                }
+            }
+        }
+        
+        return o;
+    }();
+}, "3.0.0pr2");
+/*
+ * YUI setTimeout/setInterval abstraction
+ * @module yui
+ * @submodule later
+ */
+YUI.add("later", function(Y) {
+
+    var L = Y.Lang;
+
+    /**
+     * Executes the supplied function in the context of the supplied 
+     * object 'when' milliseconds later.  Executes the function a 
+     * single time unless periodic is set to true.
+     * @method later
+     * @for YUI
+     * @param when {int} the number of milliseconds to wait until the fn 
+     * is executed.
+     * @param o the context object.
+     * @param fn {Function|String} the function to execute or the name of 
+     * the method in the 'o' object to execute.
+     * @param data [Array] data that is provided to the function.  This accepts
+     * either a single item or an array.  If an array is provided, the
+     * function is executed with one parameter for each array item.  If
+     * you need to pass a single array parameter, it needs to be wrapped in
+     * an array [myarray].
+     * @param periodic {boolean} if true, executes continuously at supplied 
+     * interval until canceled.
+     * @return {object} a timer object. Call the cancel() method on this object to 
+     * stop the timer.
+     */
+    var later = function(when, o, fn, data, periodic) {
+        when = when || 0; 
+        o = o || {};
+        var m=fn, d=data, f, r;
+
+        if (L.isString(fn)) {
+            m = o[fn];
+        }
+
+        if (!m) {
+            Y.fail("method undefined");
+        }
+
+        if (!L.isArray(d)) {
+            d = [data];
+        }
+
+        f = function() {
+            m.apply(o, d);
+        };
+
+        r = (periodic) ? setInterval(f, when) : setTimeout(f, when);
+
+        return {
+            interval: periodic,
+            cancel: function() {
+                if (this.interval) {
+                    clearInterval(r);
+                } else {
+                    clearTimeout(r);
+                }
+            }
+        };
+    };
+
+    Y.later = later;
+    L.later = later;
+
+}, "3.0.0pr2");
+/*
+ * YUI initializer
+ * @module yui
+ * @submodule init
+ */
+(function() {
+
+    var min = ['yui-base', 'log', 'lang', 'array', 'core'], core,
+
+    M = function(Y) {
+
+        var C = Y.config;
+
+        // apply the minimal required functionality
+        Y.use.apply(Y, min);
+
+
+        if (C.core) {
+
+            core = C.core;
+
+        } else {
+
+            core = ["object", "ua", "later"];
+
+            core.push(
+              "get", 
+              "loader");
+        }
+
+        Y.use.apply(Y, core);
+
+    };
+     
+    YUI.add("yui", M, "3.0.0pr2");
+    
+    // {
+        // the following will be bound automatically when this code is loaded
+      //   use: core
+    // });
+
+})();

=== added file 'loggerhead/static/javascript/yui/build/yui/README'
--- loggerhead/static/javascript/yui/build/yui/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yui/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,21 @@
+The YUI Global
+    Provides core YUI functionality, including module registration and consumption utils,
+    language/array/object utilities, browser detection, a setTimout/setInterval wrapper,
+    and dynamic loading of script and css files.
+
+    The yui module is a rollup of the following modules:
+        yui-base
+        get
+        loader
+
+
+3.0.0pr2
+    - The initial dependency calculation should not allow automatic rollup.
+    - Y.fail with throw/rethrow errors by default (throwFail is now true).
+    - Y.namespace reverted to scrub YAHOO out if included as the first
+      level of the namespace.
+    - Added Array.some
+    - 'useConsole' config changed to useBrowserConsole
+
+3.0.0pr1
+    Inital release

=== added file 'loggerhead/static/javascript/yui/build/yui/yui-debug.js'
--- loggerhead/static/javascript/yui/build/yui/yui-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yui/yui-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,4048 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * YUI core
+ * @module yui
+ */
+(function() {
+
+    var _instances = {},
+
+// @TODO: this needs to be created at build time from module metadata
+
+        _APPLY_TO_WHITE_LIST = {
+            'io.xdrReady': 1,
+            'io.start': 1,
+            'io.success': 1,
+            'io.failure': 1,
+            'io.abort': 1
+        };
+        
+
+if (typeof YUI === 'undefined' || !YUI) {
+
+    /**
+     * The YUI global namespace object.  If YUI is already defined, the
+     * existing YUI object will not be overwritten so that defined
+     * namespaces are preserved.  
+     *
+     * @class YUI
+     * @constructor
+     * @global
+     * @uses Event.Target
+     * @param o Optional configuration object.  Options:
+     * <ul>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>Global:</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>debug:
+     *  Turn debug statements on or off</li>
+     *  <li>useBrowserConsole:
+     *  Log to the browser console if debug is on and the console is available</li>
+     *  <li>logInclude:
+     *  A hash of log sources that should be logged.  If specified, only log messages from these sources will be logged.
+     *  
+     *  </li>
+     *  <li>logExclude:
+     *  A hash of log sources that should be not be logged.  If specified, all sources are logged if not on this list.</li>
+     *  <li>throwFail:
+     *  If throwFail is set, Y.fail will generate or re-throw a JS error.  Otherwise the failure is logged.
+     *  <li>win:
+     *  The target window/frame</li>
+     *  <li>core:
+     *  A list of modules that defines the YUI core (overrides the default)</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>For event and get:</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>pollInterval:
+     *  The default poll interval</li>
+     *  <li>-------------------------------------------------------------------------</li>
+     *  <li>For loader:</li>
+     *  <li>-------------------------------------------------------------------------</li>
+     *  <li>base:
+     *  The base dir</li>
+     *  <li>secureBase:
+     *  The secure base dir (not implemented)</li>
+     *  <li>comboBase:
+     *  The YUI combo service base dir. Ex: http://yui.yahooapis.com/combo?</li>
+     *  <li>root:
+     *  The root path to prepend to module names for the combo service. Ex: 2.5.2/build/</li>
+     *  <li>filter:
+     *  
+     * A filter to apply to result urls.  This filter will modify the default
+     * path for all modules.  The default path for the YUI library is the
+     * minified version of the files (e.g., event-min.js).  The filter property
+     * can be a predefined filter or a custom filter.  The valid predefined 
+     * filters are:
+     * <dl>
+     *  <dt>DEBUG</dt>
+     *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+     *      This option will automatically include the logger widget</dd>
+     *  <dt>RAW</dt>
+     *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+     * </dl>
+     * You can also define a custom filter, which must be an object literal 
+     * containing a search expression and a replace string:
+     * <pre>
+     *  myFilter: &#123; 
+     *      'searchExp': "-min\\.js", 
+     *      'replaceStr': "-debug.js"
+     *  &#125;
+     * </pre>
+     *
+     *  </li>
+     *  <li>combine:
+     *  Use the YUI combo service to reduce the number of http connections required to load your dependencies</li>
+     *  <li>ignore:
+     *  A list of modules that should never be dynamically loaded</li>
+     *  <li>force:
+     *  A list of modules that should always be loaded when required, even if already present on the page</li>
+     *  <li>insertBefore:
+     *  Node or id for a node that should be used as the insertion point for new nodes</li>
+     *  <li>charset:
+     *  charset for dynamic nodes</li>
+     *  <li>timeout:
+     *  number of milliseconds before a timeout occurs when dynamically loading nodes.  in not set, there is no timeout</li>
+     *  <li>context:
+     *  execution context for all callbacks</li>
+     *  <li>onSuccess:
+     *  callback for the 'success' event</li>
+     *  <li>onFailure:
+     *  callback for the 'failure' event</li>
+     *  <li>onTimeout:
+     *  callback for the 'timeout' event</li>
+     *  <li>onProgress:
+     *  callback executed each time a script or css file is loaded</li>
+     *  <li>modules:
+     *  A list of module definitions.  See Loader.addModule for the supported module metadata</li>
+     * </ul>
+     */
+
+    /*global YUI*/
+    YUI = function(o) {
+        var Y = this;
+
+        // Allow instantiation without the new operator
+        if (!(Y instanceof YUI)) {
+            return new YUI(o);
+        } else {
+            // set up the core environment
+            Y._init(o);
+
+            // bind the specified additional modules for this instance
+            Y._setup();
+
+            return Y;
+        }
+    };
+}
+
+// The prototype contains the functions that are required to allow the external
+// modules to be registered and for the instance to be initialized.
+YUI.prototype = {
+
+    /**
+     * Initialize this YUI instance
+     * @param o config options
+     * @private
+     */
+    _init: function(o) {
+        
+
+        o = o || {};
+
+        // find targeted window and @TODO create facades
+        var w = (o.win) ? (o.win.contentWindow) : o.win  || window;
+        o.win = w;
+        o.doc = w.document;
+        o.debug = ('debug' in o) ? o.debug : true;
+        o.useBrowserConsole = ('useBrowserConsole' in o) ? o.useBrowserConsole : true;
+        o.throwFail = ('throwFail' in o) ? o.throwFail : true;
+    
+        // add a reference to o for anything that needs it
+        // before _setup is called.
+        this.config = o;
+
+        this.Env = {
+            // @todo expand the new module metadata
+            mods: {},
+            _idx: 0,
+            _pre: 'yuid',
+            _used: {},
+            _attached: {},
+            _yidx: 0,
+            _uidx: 0
+        };
+
+        if (YUI.Env) {
+            this.Env._yidx = ++YUI.Env._idx;
+            this.id = this.stamp(this);
+            _instances[this.id] = this;
+        }
+
+        this.constructor = YUI;
+
+        this.log(this.id + ') init ');
+    },
+    
+    /**
+     * Finishes the instance setup. Attaches whatever modules were defined
+     * when the yui modules was registered.
+     * @method _setup
+     * @private
+     */
+    _setup: function(o) {
+        this.use("yui");
+        // @TODO eval the need to copy the config
+        this.config = this.merge(this.config);
+    },
+
+    /**
+     * Executes a method on a YUI instance with
+     * the specified id if the specified method is whitelisted.
+     * @method applyTo
+     * @param id {string} the YUI instance id
+     * @param method {string} the name of the method to exectute.
+     * Ex: 'Object.keys'
+     * @param args {Array} the arguments to apply to the method
+     * @return {object} the return value from the applied method or null
+     */
+    applyTo: function(id, method, args) {
+
+        if (!(method in _APPLY_TO_WHITE_LIST)) {
+            this.fail(method + ': applyTo not allowed');
+            return null;
+        }
+
+        var instance = _instances[id];
+
+        if (instance) {
+
+            var nest = method.split('.'), m = instance;
+
+            for (var i=0; i<nest.length; i=i+1) {
+
+                m = m[nest[i]];
+
+                if (!m) {
+                    this.fail('applyTo not found: ' + method);
+                }
+            }
+
+            return m.apply(instance, args);
+        }
+
+        return null;
+    }, 
+
+    /**
+     * Register a module
+     * @method add
+     * @param name {string} module name
+     * @param fn {Function} entry point into the module that
+     * is used to bind module to the YUI instance
+     * @param version {string} version string
+     * @return {YUI} the YUI instance
+     *
+     * requires   - features that should be present before loading
+     * optional   - optional features that should be present if load optional defined
+     * use  - features that should be attached automatically
+     * skinnable  -
+     * rollup
+     * omit - features that should not be loaded if this module is present
+     */
+    add: function(name, fn, version, details) {
+
+        // this.log('Adding a new component ' + name);
+
+        // @todo expand this to include version mapping
+        
+        // @todo allow requires/supersedes
+
+        // @todo may want to restore the build property
+        
+        // @todo fire moduleAvailable event
+        
+        var m = {
+            name: name, 
+            fn: fn,
+            version: version,
+            details: details || {}
+        };
+
+        YUI.Env.mods[name] = m;
+
+        return this; // chain support
+    },
+
+    _attach: function(r, fromLoader) {
+
+        var mods = YUI.Env.mods,
+            attached = this.Env._attached;
+
+        for (var i=0, l=r.length; i<l; i=i+1) {
+            var name = r[i], m = mods[name], mm;
+            if (!attached[name] && m) {
+
+                attached[name] = true;
+
+                var d = m.details, req = d.requires, use = d.use;
+
+                if (req) {
+                    this._attach(this.Array(req));
+                }
+
+                this.log('attaching ' + name, 'info', 'YUI');
+
+                if (m.fn) {
+                    m.fn(this);
+                }
+
+                if (use) {
+                    this._attach(this.Array(use));
+                }
+            }
+        }
+
+    },
+
+    /**
+     * Bind a module to a YUI instance
+     * @param modules* {string} 1-n modules to bind (uses arguments array)
+     * @param *callback {function} callback function executed when 
+     * the instance has the required functionality.  If included, it
+     * must be the last parameter.
+     *
+     * @TODO 
+     * Implement versioning?  loader can load different versions?
+     * Should sub-modules/plugins be normal modules, or do
+     * we add syntax for specifying these?
+     *
+     * YUI().use('dragdrop')
+     * YUI().use('dragdrop:2.4.0'); // specific version
+     * YUI().use('dragdrop:2.4.0-'); // at least this version
+     * YUI().use('dragdrop:2.4.0-2.9999.9999'); // version range
+     * YUI().use('*'); // use all available modules
+     * YUI().use('lang+dump+substitute'); // use lang and some plugins
+     * YUI().use('lang+*'); // use lang and all known plugins
+     *
+     *
+     * @return {YUI} the YUI instance
+     */
+    use: function() {
+
+        var Y = this, 
+            a=Array.prototype.slice.call(arguments, 0), 
+            mods = YUI.Env.mods, 
+            used = Y.Env._used,
+            loader, 
+            firstArg = a[0], 
+            dynamic = false,
+            callback = a[a.length-1];
+
+        // Y.log(Y.id + ': use called: ' + a + ' :: ' + callback);
+
+        // The last argument supplied to use can be a load complete callback
+        if (typeof callback === 'function') {
+            a.pop();
+            Y.Env._callback = callback;
+        } else {
+            callback = null;
+        }
+
+        // YUI().use('*'); // bind everything available
+        if (firstArg === "*") {
+            a = [];
+            for (var k in mods) {
+                if (mods.hasOwnProperty(k)) {
+                    a.push(k);
+                }
+            }
+
+            return Y.use.apply(Y, a);
+
+        }
+        // Y.log('loader before: ' + a.join(','));
+       
+
+        // use loader to expand dependencies and sort the 
+        // requirements if it is available.
+        if (Y.Loader) {
+            dynamic = true;
+            loader = new Y.Loader(Y.config);
+            loader.require(a);
+            loader.ignoreRegistered = true;
+            loader.allowRollup = false;
+            loader.calculate();
+            a = loader.sorted;
+        }
+
+        // Y.log('loader after: ' + a.join(','));
+
+        var missing = [], r = [], f = function(name) {
+
+            // only attach a module once
+            if (used[name]) {
+                // Y.log(name + ' already used');
+                return;
+            }
+
+            var m = mods[name], j, req, use;
+
+            if (m) {
+                used[name] = true;
+
+                // Y.log('found ' + name);
+                req = m.details.requires;
+                use = m.details.use;
+            } else {
+                Y.log('module not found: ' + name, 'info', 'yui');
+                missing.push(name);
+            }
+
+            // make sure requirements are attached
+            if (req) {
+                if (Y.Lang.isString(req)) {
+                    f(req);
+                } else {
+                    for (j = 0; j < req.length; j = j + 1) {
+                        f(req[j]);
+                    }
+                }
+            }
+
+            // add this module to full list of things to attach
+            // Y.log('using ' + name);
+            r.push(name);
+
+        };
+
+        // process each requirement and any additional requirements 
+        // the module metadata specifies
+        for (var i=0, l=a.length; i<l; i=i+1) {
+            f(a[i]);
+        }
+
+        // Y.log('all reqs: ' + r + ' --- missing: ' + missing);
+
+        var onComplete = function(fromLoader) {
+
+            // Y.log('Use complete');
+
+            fromLoader = fromLoader || {
+                success: true,
+                msg: 'not dynamic'
+            };
+
+            if (Y.Env._callback) {
+
+                var cb = Y.Env._callback;
+                Y.Env._callback = null;
+                cb(Y, fromLoader);
+            }
+
+            if (Y.fire) {
+                Y.fire('yui:load', Y, fromLoader);
+            }
+        };
+
+
+        // dynamic load
+        if (Y.Loader && missing.length) {
+            Y.log('Attempting to dynamically load the missing modules ' + missing, 'info', 'yui');
+            loader = new Y.Loader(Y.config);
+            loader.onSuccess = onComplete;
+            loader.onFailure = onComplete;
+            loader.onTimeout = onComplete;
+            loader.attaching = a;
+            loader.require(missing);
+            loader.insert();
+        } else {
+            Y._attach(r);
+            onComplete();
+        }
+
+        return Y; // chain support var yui = YUI().use('dragdrop');
+    },
+
+
+    /**
+     * Returns the namespace specified and creates it if it doesn't exist
+     * <pre>
+     * YUI.namespace("property.package");
+     * YUI.namespace("YAHOO.property.package");
+     * </pre>
+     * Either of the above would create YAHOO.property, then
+     * YUI.property.package
+     *
+     * Be careful when naming packages. Reserved words may work in some browsers
+     * and not others. For instance, the following will fail in Safari:
+     * <pre>
+     * YUI.namespace("really.long.nested.namespace");
+     * </pre>
+     * This fails because "long" is a future reserved word in ECMAScript
+     *
+     * @method namespace
+     * @param  {string*} arguments 1-n namespaces to create 
+     * @return {object}  A reference to the last namespace object created
+     */
+    namespace: function() {
+        var a=arguments, o=null, i, j, d;
+        for (i=0; i<a.length; i=i+1) {
+            d = a[i].split(".");
+            o = this;
+            for (j=(d[0] == "YAHOO") ? 1 : 0; j<d.length; j=j+1) {
+                o[d[j]] = o[d[j]] || {};
+                o = o[d[j]];
+            }
+        }
+        return o;
+    },
+
+    // this is replaced if the log module is included
+    log: function() {
+
+    },
+
+    /**
+     * Report an error.  The reporting mechanism is controled by
+     * the 'throwFail' configuration attribute.  If throwFail is
+     * not specified, the message is written to the logger, otherwise
+     * a JS error is thrown
+     * @method fail
+     * @param msg {string} the failure message
+     * @param e {Error} Optional JS error that was caught.  If supplied
+     * and throwFail is specified, this error will be re-thrown.
+     * @return {YUI} this YUI instance
+     */
+    fail: function(msg, e) {
+        if (this.config.throwFail) {
+            throw (e || new Error(msg)); 
+        } else {
+            var instance = this;
+            instance.log(msg, "error"); // don't scrub this one
+        }
+
+        return this;
+    },
+
+    /**
+     * Generate an id that is unique among all YUI instances
+     * @method guid
+     * @param pre {string} optional guid prefix
+     * @return {string} the guid
+     */
+    guid: function(pre) {
+        var e = this.Env, p = (pre) || e._pre;
+        return p +'-' + e._yidx + '-' + e._uidx++;
+    },
+
+    /**
+     * Stamps an object with a guid.  If the object already
+     * has one, a new one is not created
+     * @method stamp
+     * @param o The object to stamp
+     * @return {string} The object's guid
+     */
+    stamp: function(o) {
+
+        if (!o) {
+            return o;
+        }
+
+        var uid = (typeof o === 'string') ? o : o._yuid;
+
+        if (!uid) {
+            uid = this.guid();
+            o._yuid = uid;
+        }
+
+        return uid;
+    }
+};
+
+// Give the YUI global the same properties as an instance.
+// This makes it so that the YUI global can be used like the YAHOO
+// global was used prior to 3.x.  More importantly, the YUI global
+// provides global metadata, so env needs to be configured.
+// @TODO review
+
+    var Y = YUI, p = Y.prototype, i;
+
+    // inheritance utilities are not available yet
+    for (i in p) {
+        if (true) {
+            Y[i] = p[i];
+        }
+    }
+
+    // set up the environment
+    Y._init();
+
+
+})();
+/**
+ * YUI stub
+ * @module yui
+ * @submodule yui-base
+ */
+// This is just a stub to for dependency processing
+YUI.add("yui-base", null, "3.0.0pr2");
+/*
+ * YUI console logger
+ * @module yui
+ * @submodule log
+ */
+YUI.add("log", function(instance) {
+
+    /**
+     * If the 'debug' config is true, a 'yui:log' event will be
+     * dispatched, which the logger widget and anything else
+     * can consume.  If the 'useBrowserConsole' config is true, it will
+     * write to the browser console if available.
+     *
+     * @method log
+     * @for YUI
+     * @param  {String}  msg  The message to log.
+     * @param  {String}  cat  The log category for the message.  Default
+     *                        categories are "info", "warn", "error", time".
+     *                        Custom categories can be used as well. (opt)
+     * @param  {String}  src  The source of the the message (opt)
+     * @param  {boolean} silent If true, the log event won't fire
+     * @return {YUI}      YUI instance
+     */
+    instance.log = function(msg, cat, src, silent) {
+
+        var Y = instance, c = Y.config, es = Y.Env._eventstack,
+            // bail = (es && es.logging);
+            bail = false; 
+
+        // suppress log message if the config is off or the event stack
+        // or the event call stack contains a consumer of the yui:log event
+        if (c.debug && !bail) {
+
+            // apply source filters
+            if (src) {
+
+                var exc = c.logExclude, inc = c.logInclude;
+
+                // console.log('checking src filter: ' + src + ', inc: ' + inc + ', exc: ' + exc);
+
+                if (inc && !(src in inc)) {
+                    // console.log('bail: inc list found, but src is not in list: ' + src);
+                    bail = true;
+                } else if (exc && (src in exc)) {
+                    // console.log('bail: exc list found, and src is in it: ' + src);
+                    bail = true;
+                }
+            }
+
+            if (!bail) {
+
+                if (c.useBrowserConsole) {
+                    var m = (src) ? src + ': ' + msg : msg;
+                    if (typeof console != 'undefined') {
+                        var f = (cat && console[cat]) ? cat : 'log';
+                        console[f](m);
+                    } else if (typeof opera != 'undefined') {
+                        opera.postError(m);
+                    }
+                }
+
+                if (Y.fire && !bail && !silent) {
+                    Y.fire('yui:log', msg, cat, src);
+                }
+            }
+        }
+
+        return Y;
+    };
+
+}, "3.0.0pr2");
+/*
+ * YUI lang utils
+ * @module yui
+ * @submodule lang
+ */
+YUI.add("lang", function(Y) {
+
+    /**
+     * Provides the language utilites and extensions used by the library
+     * @class Lang
+     * @static
+     */
+    Y.Lang = Y.Lang || {};
+
+    var L = Y.Lang, 
+
+    ARRAY_TOSTRING = '[object Array]',
+    FUNCTION_TOSTRING = '[object Function]',
+    STRING = 'string',
+    OBJECT = 'object',
+    BOOLEAN = 'boolean',
+    UNDEFINED = 'undefined',
+    OP = Object.prototype;
+
+    /**
+     * Determines whether or not the provided object is an array.
+     * Testing typeof/instanceof/constructor of arrays across frame 
+     * boundaries isn't possible in Safari unless you have a reference
+     * to the other frame to test against its Array prototype.  To
+     * handle this case, we test well-known array properties instead.
+     * properties.
+     * @TODO can we kill this cross frame hack?
+     * @method isArray
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is an array
+     */
+    L.isArray = function(o) { 
+        return OP.toString.apply(o) === ARRAY_TOSTRING;
+    };
+
+    /**
+     * Determines whether or not the provided object is a boolean
+     * @method isBoolean
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a boolean
+     */
+    L.isBoolean = function(o) {
+        return typeof o === BOOLEAN;
+    };
+    
+    /**
+     * Determines whether or not the provided object is a function
+     * Note: Internet Explorer thinks certain functions are objects:
+     *
+     * var obj = document.createElement("object");
+     * Y.Lang.isFunction(obj.getAttribute) // reports false in IE
+     *
+     * var input = document.createElement("input"); // append to body
+     * Y.Lang.isFunction(input.focus) // reports false in IE
+     *
+     * You will have to implement additional tests if these functions
+     * matter to you.
+     *
+     * @method isFunction
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a function
+     */
+    L.isFunction = function(o) {
+        return OP.toString.apply(o) === FUNCTION_TOSTRING;
+    };
+        
+    /**
+     * Determines whether or not the supplied object is a date instance
+     * @method isDate
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a date
+     */
+    L.isDate = function(o) {
+        return o instanceof Date;
+    };
+
+    /**
+     * Determines whether or not the provided object is null
+     * @method isNull
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is null
+     */
+    L.isNull = function(o) {
+        return o === null;
+    };
+        
+    /**
+     * Determines whether or not the provided object is a legal number
+     * @method isNumber
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a number
+     */
+    L.isNumber = function(o) {
+        return typeof o === 'number' && isFinite(o);
+    };
+      
+    /**
+     * Determines whether or not the provided object is of type object
+     * or function
+     * @method isObject
+     * @static
+     * @param o The object to test
+     * @param failfn {boolean} fail if the input is a function
+     * @return {boolean} true if o is an object
+     */  
+    L.isObject = function(o, failfn) {
+return (o && (typeof o === OBJECT || (!failfn && L.isFunction(o)))) || false;
+    };
+        
+    /**
+     * Determines whether or not the provided object is a string
+     * @method isString
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a string
+     */
+    L.isString = function(o) {
+        return typeof o === STRING;
+    };
+        
+    /**
+     * Determines whether or not the provided object is undefined
+     * @method isUndefined
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is undefined
+     */
+    L.isUndefined = function(o) {
+        return typeof o === UNDEFINED;
+    };
+    
+    /**
+     * Returns a string without any leading or trailing whitespace.  If 
+     * the input is not a string, the input will be returned untouched.
+     * @method trim
+     * @static
+     * @param s {string} the string to trim
+     * @return {string} the trimmed string
+     */
+    L.trim = function(s){
+        try {
+            return s.replace(/^\s+|\s+$/g, "");
+        } catch(e) {
+            return s;
+        }
+    };
+
+    /**
+     * A convenience method for detecting a legitimate non-null value.
+     * Returns false for null/undefined/NaN, true for other values, 
+     * including 0/false/''
+     * @method isValue
+     * @static
+     * @param o The item to test
+     * @return {boolean} true if it is not null/undefined/NaN || false
+     */
+    L.isValue = function(o) {
+// return (o || o === false || o === 0 || o === ''); // Infinity fails
+return (L.isObject(o) || L.isString(o) || L.isNumber(o) || L.isBoolean(o));
+    };
+
+}, "3.0.0pr2");
+
+
+/*
+ * Array utilities
+ * @module yui
+ * @submodule array
+ */
+
+/**
+ * YUI core
+ * @module yui
+ */
+
+YUI.add("array", function(Y) {
+
+    var L = Y.Lang, Native = Array.prototype;
+
+    /**
+     * Adds the following array utilities to the YUI instance
+     * @class YUI~array
+     */
+
+    /** 
+     * Y.Array(o) returns an array:
+     * - Arrays are return unmodified unless the start position is specified.
+     * - "Array-like" collections (@see Array.test) are converted to arrays
+     * - For everything else, a new array is created with the input as the sole item
+     * - The start position is used if the input is or is like an array to return
+     *   a subset of the collection.
+     *
+     *   @TODO this will not automatically convert elements that are also collections
+     *   such as forms and selects.  Passing true as the third param will
+     *   force a conversion.
+     *
+     * @method Array
+     * @static
+     *   @param o the item to arrayify
+     *   @param i {int} if an array or array-like, this is the start index
+     *   @param al {boolean} if true, it forces the array-like fork.  This
+     *   can be used to avoid multiple array.test calls.
+     *   @return {Array} the resulting array
+     */
+    Y.Array = function(o, i, al) {
+        var t = (al) ? 2 : Y.Array.test(o);
+
+        // switch (t) {
+        //     case 1:
+        //         // return (i) ? o.slice(i) : o;
+        //     case 2:
+        //         return Native.slice.call(o, i || 0);
+        //     default:
+        //         return [o];
+        // }
+
+        if (t) {
+            return Native.slice.call(o, i || 0);
+        } else {
+            return [o];
+        }
+
+    };
+
+    var A = Y.Array;
+    
+    /** 
+     * Evaluates the input to determine if it is an array, array-like, or 
+     * something else.  This is used to handle the arguments collection 
+     * available within functions, and HTMLElement collections
+     *
+     * @method Array.test
+     * @static
+     *
+     * @todo current implementation (intenionally) will not implicitly 
+     * handle html elements that are array-like (forms, selects, etc).  
+     *
+     * @return {int} a number indicating the results:
+     * 0: Not an array or an array-like collection
+     * 1: A real array. 
+     * 2: array-like collection.
+     */
+    A.test = function(o) {
+        var r = 0;
+        if (L.isObject(o, true)) {
+            if (L.isArray(o)) {
+                r = 1; 
+            } else {
+                try {
+                    // indexed, but no tagName (element) or alert (window)
+                    if ("length" in o && 
+                        !("tagName" in o) && 
+                        !("alert" in o) && 
+                        (!Y.Lang.isFunction(o.size) || o.size() > 1)) {
+                            r = 2;
+                    }
+                        
+                } catch(ex) {}
+            }
+        }
+        return r;
+    };
+
+    /**
+     * Executes the supplied function on each item in the array.
+     * @method Array.each
+     * @param a {Array} the array to iterate
+     * @param f {Function} the function to execute on each item
+     * @param o Optional context object
+     * @static
+     * @return {YUI} the YUI instance
+     */
+    A.each = (Native.forEach) ?
+        function (a, f, o) { 
+            Native.forEach.call(a, f, o || Y);
+            return Y;
+        } :
+        function (a, f, o) { 
+            var l = a.length, i;
+            for (i = 0; i < l; i=i+1) {
+                f.call(o || Y, a[i], i, a);
+            }
+            return Y;
+        };
+
+    /**
+     * Executes the supplied function on each item in the array.
+     * Returning true from the processing function will stop the 
+     * processing of the remaining
+     * items.
+     * @method Array.some
+     * @param a {Array} the array to iterate
+     * @param f {Function} the function to execute on each item
+     * @param o Optional context object
+     * @static
+     * @return {boolean} true if the 
+     */
+     A.some = (Native.forEach) ?
+        function (a, f, o) { 
+            Native.some.call(a, f, o || Y);
+            return Y;
+        } :
+        function (a, f, o) {
+            var l = a.length;
+            for (var i = 0; i < l; i=i+1) {
+                if (f.call(o, a[i], i, a)) {
+                    return true;
+                }
+            }
+            return false;
+        };
+
+    /**
+     * Returns an object using the first array as keys, and
+     * the second as values.  If the second array is not
+     * provided the value is set to true for each.
+     * @method Array.hash
+     * @static
+     * @param k {Array} keyset
+     * @param v {Array} optional valueset
+     * @return {object} the hash
+     */
+    A.hash = function(k, v) {
+        var o = {}, l = k.length, vl = v && v.length, i;
+        for (i=0; i<l; i=i+1) {
+            o[k[i]] = (vl && vl > i) ? v[i] : true;
+        }
+
+        return o;
+    };
+
+
+    /**
+     * Returns the index of the first item in the array
+     * that contains the specified value, -1 if the
+     * value isn't found.
+     * @TODO use native method if avail
+     * @method Array.indexOf
+     * @static
+     * @param a {Array} the array to search
+     * @param val the value to search for
+     * @return {int} the index of the item that contains the value or -1
+     */
+    A.indexOf = function(a, val) {
+        for (var i=0; i<a.length; i=i+1) {
+            if (a[i] === val) {
+                return i;
+            }
+        }
+
+        return -1;
+    };
+
+}, "3.0.0pr2");
+/*
+ * YUI core utilities
+ * @module yui
+ * @submodule core
+ */
+// requires lang
+YUI.add("core", function(Y) {
+
+    var L = Y.Lang, 
+    A = Y.Array,
+    OP = Object.prototype, 
+    IEF = ["toString", "valueOf"], 
+    PROTO = 'prototype',
+
+    /**
+     * IE will not enumerate native functions in a derived object even if the
+     * function was overridden.  This is a workaround for specific functions 
+     * we care about on the Object prototype. 
+     * @property _iefix
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param w a whitelist object (the keys are the valid items to reference)
+     * @private
+     * @for YUI
+     */
+    _iefix = (Y.UA && Y.UA.ie) ?
+        function(r, s, w) {
+            for (var i=0, a=IEF; i<a.length; i=i+1) {
+                var n = a[i], f = s[n];
+                if (L.isFunction(f) && f != OP[n]) {
+                    if (!w || (n in w)) {
+                        r[n]=f;
+                    }
+                }
+            }
+        } : function() {};
+   
+
+    /**
+     * Returns a new object containing all of the properties of
+     * all the supplied objects.  The properties from later objects
+     * will overwrite those in earlier objects.  Passing in a
+     * single object will create a shallow copy of it.  For a deep
+     * copy, use clone.
+     * @method merge
+     * @param arguments {Object*} the objects to merge
+     * @return {object} the new merged object
+     */
+    Y.merge = function() {
+        // var o={}, a=arguments;
+        // for (var i=0, l=a.length; i<l; i=i+1) {
+        //var a=arguments, o=Y.Object(a[0]);
+        var a=arguments, o={};
+        for (var i=0, l=a.length; i<l; i=i+1) {
+            Y.mix(o, a[i], true);
+        }
+        return o;
+    };
+       
+    /**
+     * Applies the supplier's properties to the receiver.  By default
+     * all prototype and static propertes on the supplier are applied
+     * to the corresponding spot on the receiver.  By default all
+     * properties are applied, and a property that is already on the
+     * reciever will not be overwritten.  The default behavior can
+     * be modified by supplying the appropriate parameters.
+     *
+     * @TODO add constants for the modes
+     *
+     * @method mix
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param ov {boolean} if true, properties already on the receiver
+     * will be overwritten if found on the supplier.
+     * @param wl {string[]} a whitelist.  If supplied, only properties in 
+     * this list will be applied to the receiver.
+     * @param {int} mode what should be copies, and to where
+     *        default(0): object to object
+     *        1: prototype to prototype (old augment)
+     *        2: prototype to prototype and object props (new augment)
+     *        3: prototype to object
+     *        4: object to prototype
+     * @param merge {boolean} merge objects instead of overwriting/ignoring
+     * Used by Y.aggregate
+     * @return {object} the augmented object
+     * @TODO review for PR2
+     */
+    Y.mix = function(r, s, ov, wl, mode, merge) {
+
+        if (!s||!r) {
+            return Y;
+        }
+
+        var w = (wl && wl.length) ? A.hash(wl) : null, m = merge,
+
+            f = function(fr, fs, proto, iwl) {
+
+                var arr = m && L.isArray(fr);
+
+                for (var i in fs) { 
+
+                    if (fs.hasOwnProperty(i)) {
+
+                        // We never want to overwrite the prototype
+                        // if (PROTO === i) {
+                        if (PROTO === i || '_yuid' === i) {
+                            continue;
+                        }
+
+                        // Y.log('i: ' + i + ", " + fs[i]);
+                        // @TODO deal with the hasownprop issue
+
+                        // check white list if it was supplied
+                        if (!w || iwl || (i in w)) {
+                            // if the receiver has this property, it is an object,
+                            // and merge is specified, merge the two objects.
+                            if (m && L.isObject(fr[i], true)) {
+                                // console.log('aggregate RECURSE: ' + i);
+                                // @TODO recursive or no?
+                                // Y.mix(fr[i], fs[i]); // not recursive
+                                f(fr[i], fs[i], proto, true); // recursive
+                            // otherwise apply the property only if overwrite
+                            // is specified or the receiver doesn't have one.
+                            // @TODO make sure the 'arr' check isn't desructive
+                            } else if (!arr && (ov || !(i in fr))) {
+                                // console.log('hash: ' + i);
+                                fr[i] = fs[i];
+                            // if merge is specified and the receiver is an array,
+                            // append the array item
+                            } else if (arr) {
+                                // console.log('array: ' + i);
+                                // @TODO probably will need to remove dups
+                                fr.push(fs[i]);
+                            }
+                        }
+                    }
+                }
+
+                _iefix(fr, fs, w);
+            };
+
+        var rp = r.prototype, sp = s.prototype;
+
+        switch (mode) {
+            case 1: // proto to proto
+                f(rp, sp, true);
+                break;
+            case 2: // object to object and proto to proto
+                f(r, s);
+                f(rp, sp, true);
+                break;
+            case 3: // proto to static
+                f(r, sp, true);
+                break;
+            case 4: // static to proto
+                f(rp, s);
+                break;
+            default:  // object to object
+                f(r, s);
+        }
+
+        return r;
+    };
+
+    
+
+}, "3.0.0pr2");
+/*
+ * YUI object utilities
+ * @module yui
+ * @submodule object
+ */
+YUI.add("object", function(Y) {
+
+    /**
+     * Adds the following Object utilities to the YUI instance
+     * @class YUI~object
+     */
+
+    /**
+     * Y.Object(o) returns a new object based upon the supplied object.  
+     * @method Object
+     * @static
+     * @param o the supplier object
+     * @return {object} the new object
+     */
+    Y.Object = function(o) {
+        var F = function() {};
+        F.prototype = o;
+        return new F();
+    }; 
+
+    var O = Y.Object, L = Y.Lang;
+
+    /**
+     * Determines whether or not the property was added
+     * to the object instance.  Returns false if the property is not present
+     * in the object, or was inherited from the prototype.
+     *
+     * @deprecated Safari 1.x support has been removed, so this is simply a 
+     * wrapper for the native implementation.  Use the native implementation
+     * directly instead.
+     *
+     * @TODO Remove in PR2
+     *
+     * @method Object.owns
+     * @static
+     * @param o {any} The object being testing
+     * @param p {string} the property to look for
+     * @return {boolean} true if the object has the property on the instance
+     */
+    O.owns = function(o, p) {
+        return (o && o.hasOwnProperty) ? o.hasOwnProperty(p) : false;
+    };
+
+    /**
+     * Returns an array containing the object's keys
+     * @method Object.keys
+     * @static
+     * @param o an object
+     * @return {string[]} the keys
+     */
+    O.keys = function(o) {
+        var a=[], i;
+        for (i in o) {
+            if (o.hasOwnProperty(i)) {
+                a.push(i);
+            }
+        }
+
+        return a;
+    };
+
+    /**
+     * Executes a function on each item. The function
+     * receives the value, the key, and the object
+     * as paramters (in that order).
+     * @method Object.each
+     * @static
+     * @param o the object to iterate
+     * @param f {function} the function to execute
+     * @param c the execution context
+     * @param proto {boolean} include proto
+     * @return {YUI} the YUI instance
+     */
+    O.each = function (o, f, c, proto) {
+        var s = c || Y;
+
+        for (var i in o) {
+            if (proto || o.hasOwnProperty(i)) {
+                f.call(s, o[i], i, o);
+            }
+        }
+        return Y;
+    };
+}, "3.0.0pr2");
+/*
+ * YUI user agent detection
+ * @module yui
+ * @submodule ua
+ */
+YUI.add("ua", function(Y) {
+
+    /**
+     * Browser/platform detection
+     * @class UA
+     * @static
+     */
+    Y.UA = function() {
+
+        var o={
+
+            /**
+             * Internet Explorer version number or 0.  Example: 6
+             * @property ie
+             * @type float
+             * @static
+             */
+            ie:0,
+
+            /**
+             * Opera version number or 0.  Example: 9.2
+             * @property opera
+             * @type float
+             * @static
+             */
+            opera:0,
+
+            /**
+             * Gecko engine revision number.  Will evaluate to 1 if Gecko 
+             * is detected but the revision could not be found. Other browsers
+             * will be 0.  Example: 1.8
+             * <pre>
+             * Firefox 1.0.0.4: 1.7.8   <-- Reports 1.7
+             * Firefox 1.5.0.9: 1.8.0.9 <-- Reports 1.8
+             * Firefox 2.0.0.3: 1.8.1.3 <-- Reports 1.8
+             * Firefox 3 alpha: 1.9a4   <-- Reports 1.9
+             * </pre>
+             * @property gecko
+             * @type float
+             * @static
+             */
+            gecko:0,
+
+            /**
+             * AppleWebKit version.  KHTML browsers that are not WebKit browsers 
+             * will evaluate to 1, other browsers 0.  Example: 418.9.1
+             * <pre>
+             * Safari 1.3.2 (312.6): 312.8.1 <-- Reports 312.8 -- currently the 
+             *                                   latest available for Mac OSX 10.3.
+             * Safari 2.0.2:         416     <-- hasOwnProperty introduced
+             * Safari 2.0.4:         418     <-- preventDefault fixed
+             * Safari 2.0.4 (419.3): 418.9.1 <-- One version of Safari may run
+             *                                   different versions of webkit
+             * Safari 2.0.4 (419.3): 419     <-- Tiger installations that have been
+             *                                   updated, but not updated
+             *                                   to the latest patch.
+             * Webkit 212 nightly:   522+    <-- Safari 3.0 precursor (with native SVG
+             *                                   and many major issues fixed).
+             * Safari 3.0.4 (523.12) 523.12  <-- First Tiger release - automatic update
+             *                                   from 2.x via the 10.4.11 OS patch
+             *                                   
+             * </pre>
+             * http://developer.apple.com/internet/safari/uamatrix.html
+             * @property webkit
+             * @type float
+             * @static
+             */
+            webkit:0,
+
+            /**
+             * The mobile property will be set to a string containing any relevant
+             * user agent information when a modern mobile browser is detected.
+             * Currently limited to Safari on the iPhone/iPod Touch, Nokia N-series
+             * devices with the WebKit-based browser, and Opera Mini.  
+             * @property mobile 
+             * @type string
+             * @static
+             */
+            mobile: null 
+        };
+
+        var ua=navigator.userAgent, m;
+
+        // Modern KHTML browsers should qualify as Safari X-Grade
+        if ((/KHTML/).test(ua)) {
+            o.webkit=1;
+        }
+        // Modern WebKit browsers are at least X-Grade
+        m=ua.match(/AppleWebKit\/([^\s]*)/);
+        if (m&&m[1]) {
+            o.webkit=parseFloat(m[1]);
+
+            // Mobile browser check
+            if (/ Mobile\//.test(ua)) {
+                o.mobile = "Apple"; // iPhone or iPod Touch
+            } else {
+                m=ua.match(/NokiaN[^\/]*/);
+                if (m) {
+                    o.mobile = m[0]; // Nokia N-series, ex: NokiaN95
+                }
+            }
+
+        }
+
+        if (!o.webkit) { // not webkit
+            // @todo check Opera/8.01 (J2ME/MIDP; Opera Mini/2.0.4509/1316; fi; U; ssr)
+            m=ua.match(/Opera[\s\/]([^\s]*)/);
+            if (m&&m[1]) {
+                o.opera=parseFloat(m[1]);
+                m=ua.match(/Opera Mini[^;]*/);
+                if (m) {
+                    o.mobile = m[0]; // ex: Opera Mini/2.0.4509/1316
+                }
+            } else { // not opera or webkit
+                m=ua.match(/MSIE\s([^;]*)/);
+                if (m&&m[1]) {
+                    o.ie=parseFloat(m[1]);
+                } else { // not opera, webkit, or ie
+                    m=ua.match(/Gecko\/([^\s]*)/);
+                    if (m) {
+                        o.gecko=1; // Gecko detected, look for revision
+                        m=ua.match(/rv:([^\s\)]*)/);
+                        if (m&&m[1]) {
+                            o.gecko=parseFloat(m[1]);
+                        }
+                    }
+                }
+            }
+        }
+        
+        return o;
+    }();
+}, "3.0.0pr2");
+/*
+ * YUI setTimeout/setInterval abstraction
+ * @module yui
+ * @submodule later
+ */
+YUI.add("later", function(Y) {
+
+    var L = Y.Lang;
+
+    /**
+     * Executes the supplied function in the context of the supplied 
+     * object 'when' milliseconds later.  Executes the function a 
+     * single time unless periodic is set to true.
+     * @method later
+     * @for YUI
+     * @param when {int} the number of milliseconds to wait until the fn 
+     * is executed.
+     * @param o the context object.
+     * @param fn {Function|String} the function to execute or the name of 
+     * the method in the 'o' object to execute.
+     * @param data [Array] data that is provided to the function.  This accepts
+     * either a single item or an array.  If an array is provided, the
+     * function is executed with one parameter for each array item.  If
+     * you need to pass a single array parameter, it needs to be wrapped in
+     * an array [myarray].
+     * @param periodic {boolean} if true, executes continuously at supplied 
+     * interval until canceled.
+     * @return {object} a timer object. Call the cancel() method on this object to 
+     * stop the timer.
+     */
+    var later = function(when, o, fn, data, periodic) {
+        when = when || 0; 
+        o = o || {};
+        var m=fn, d=data, f, r;
+
+        if (L.isString(fn)) {
+            m = o[fn];
+        }
+
+        if (!m) {
+            Y.fail("method undefined");
+        }
+
+        if (!L.isArray(d)) {
+            d = [data];
+        }
+
+        f = function() {
+            m.apply(o, d);
+        };
+
+        r = (periodic) ? setInterval(f, when) : setTimeout(f, when);
+
+        return {
+            interval: periodic,
+            cancel: function() {
+                if (this.interval) {
+                    clearInterval(r);
+                } else {
+                    clearTimeout(r);
+                }
+            }
+        };
+    };
+
+    Y.later = later;
+    L.later = later;
+
+}, "3.0.0pr2");
+
+YUI.add("get", function(Y) {
+    
+        var ua=Y.UA, 
+        L=Y.Lang;
+
+/**
+ * Provides a mechanism to fetch remote resources and
+ * insert them into a document.
+ * @module yui
+ * @submodule get
+ */
+
+/**
+ * Fetches and inserts one or more script or link nodes into the document 
+ * @class Get
+ * @static
+ */
+Y.Get = function() {
+
+    /**
+     * hash of queues to manage multiple requests
+     * @property queues
+     * @private
+     */
+    var queues={}, 
+        
+    /**
+     * queue index used to generate transaction ids
+     * @property qidx
+     * @type int
+     * @private
+     */
+        qidx=0, 
+        
+    /**
+     * node index used to generate unique node ids
+     * @property nidx
+     * @type int
+     * @private
+     */
+        nidx=0, 
+
+        // ridx=0,
+
+        // sandboxFrame=null,
+
+    /**
+     * interal property used to prevent multiple simultaneous purge 
+     * processes
+     * @property purging
+     * @type boolean
+     * @private
+     */
+        purging=false;
+
+    
+    /** 
+     * Generates an HTML element, this is not appended to a document
+     * @method _node
+     * @param type {string} the type of element
+     * @param attr {string} the attributes
+     * @param win {Window} optional window to create the element in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _node = function(type, attr, win) {
+        var w = win || Y.config.win, d=w.document, n=d.createElement(type);
+
+        for (var i in attr) {
+            if (attr[i] && Y.Object.owns(attr, i)) {
+                n.setAttribute(i, attr[i]);
+            }
+        }
+
+        return n;
+    };
+
+    /**
+     * Generates a link node
+     * @method _linkNode
+     * @param url {string} the url for the css file
+     * @param win {Window} optional window to create the node in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _linkNode = function(url, win, charset) {
+        var c = charset || "utf-8";
+        return _node("link", {
+                "id":      "yui__dyn_" + (nidx++),
+                "type":    "text/css",
+                "charset": c,
+                "rel":     "stylesheet",
+                "href":    url
+            }, win);
+    };
+
+    /**
+     * Generates a script node
+     * @method _scriptNode
+     * @param url {string} the url for the script file
+     * @param win {Window} optional window to create the node in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _scriptNode = function(url, win, charset) {
+        var c = charset || "utf-8";
+        return _node("script", {
+                "id":      "yui__dyn_" + (nidx++),
+                "type":    "text/javascript",
+                "charset": c,
+                "src":     url
+            }, win);
+    };
+
+    /**
+     * Removes the nodes for the specified queue
+     * @method _purge
+     * @private
+     */
+    var _purge = function(tId) {
+        var q=queues[tId];
+        if (q) {
+            var n=q.nodes, l=n.length, d=q.win.document, 
+                h=d.getElementsByTagName("head")[0];
+
+            if (q.insertBefore) {
+                var s = _get(q.insertBefore, tId);
+                if (s) {
+                    h = s.parentNode;
+                }
+            }
+
+            for (var i=0; i<l; i=i+1) {
+                h.removeChild(n[i]);
+            }
+        }
+        q.nodes = [];
+    };
+
+    /**
+     * Returns the data payload for callback functions
+     * @method _returnData
+     * @private
+     */
+    var _returnData = function(q, msg) {
+        return {
+                tId: q.tId,
+                win: q.win,
+                data: q.data,
+                nodes: q.nodes,
+                msg: msg,
+                purge: function() {
+                    _purge(this.tId);
+                }
+            };
+    };
+
+    /*
+     * The request failed, execute fail handler with whatever
+     * was accomplished.  There isn't a failure case at the
+     * moment unless you count aborted transactions
+     * @method _fail
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _fail = function(id, msg) {
+
+        Y.log("get failure: " + msg, "warn", "get");
+
+        var q = queues[id];
+        if (q.timer) {
+            q.timer.cancel();
+        }
+
+        // execute failure callback
+        if (q.onFailure) {
+            var sc=q.context || q;
+            q.onFailure.call(sc, _returnData(q, msg));
+        }
+    };
+
+    var _get = function(nId, tId) {
+        var q = queues[tId],
+            n = (L.isString(nId)) ? q.win.document.getElementById(nId) : nId;
+        if (!n) {
+            _fail(tId, "target node not found: " + nId);
+        }
+
+        return n;
+    };
+
+
+    /**
+     * The request is complete, so executing the requester's callback
+     * @method _finish
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _finish = function(id) {
+        Y.log("Finishing transaction " + id, "info", "get");
+        var q = queues[id];
+        if (q.timer) {
+            q.timer.cancel();
+        }
+        q.finished = true;
+
+        if (q.aborted) {
+            var msg = "transaction " + id + " was aborted";
+            _fail(id, msg);
+            return;
+        }
+
+        // execute success callback
+        if (q.onSuccess) {
+            var sc=q.context || q;
+            q.onSuccess.call(sc, _returnData(q));
+        }
+    };
+
+    /**
+     * Timeout detected
+     * @method _timeout
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _timeout = function(id) {
+        Y.log("Timeout " + id, "info", "get");
+        var q = queues[id];
+        if (q.onTimeout) {
+            var sc=q.context || q;
+            q.onTimeout.call(sc, _returnData(q));
+        }
+    };
+
+    /**
+     * Loads the next item for a given request
+     * @method _next
+     * @param id {string} the id of the request
+     * @param loaded {string} the url that was just loaded, if any
+     * @private
+     */
+    var _next = function(id, loaded) {
+        Y.log("_next: " + id + ", loaded: " + loaded, "info", "get");
+
+        var q = queues[id];
+
+        if (q.timer) {
+            // Y.log('cancel timer');
+            q.timer.cancel();
+        }
+
+        if (q.aborted) {
+            var msg = "transaction " + id + " was aborted";
+            _fail(id, msg);
+            return;
+        }
+
+        if (loaded) {
+            q.url.shift(); 
+            if (q.varName) {
+                q.varName.shift(); 
+            }
+        } else {
+            // This is the first pass: make sure the url is an array
+            q.url = (L.isString(q.url)) ? [q.url] : q.url;
+            if (q.varName) {
+                q.varName = (L.isString(q.varName)) ? [q.varName] : q.varName;
+            }
+        }
+
+        var w=q.win, d=w.document, h=d.getElementsByTagName("head")[0], n;
+
+        if (q.url.length === 0) {
+            _finish(id);
+            return;
+        } 
+
+        var url = q.url[0];
+
+        // if the url is undefined, this is probably a trailing comma problem in IE
+        if (!url) {
+            q.url.shift(); 
+            Y.log('skipping empty url');
+            return _next(id);
+        }
+
+        Y.log("attempting to load " + url, "info", "get");
+
+        if (q.timeout) {
+            // Y.log('create timer');
+            q.timer = L.later(q.timeout, q, _timeout, id);
+        }
+
+        if (q.type === "script") {
+            n = _scriptNode(url, w, q.charset);
+        } else {
+            n = _linkNode(url, w, q.charset);
+        }
+
+        // track this node's load progress
+        _track(q.type, n, id, url, w, q.url.length);
+
+        // add the node to the queue so we can return it to the user supplied callback
+        q.nodes.push(n);
+
+        // add it to the head or insert it before 'insertBefore'
+        if (q.insertBefore) {
+            var s = _get(q.insertBefore, id);
+            if (s) {
+                s.parentNode.insertBefore(n, s);
+            }
+        } else {
+            h.appendChild(n);
+        }
+        
+        Y.log("Appending node: " + url, "info", "get");
+
+        // FireFox does not support the onload event for link nodes, so there is
+        // no way to make the css requests synchronous. This means that the css 
+        // rules in multiple files could be applied out of order in this browser
+        // if a later request returns before an earlier one.  Safari too.
+        if ((ua.webkit || ua.gecko) && q.type === "css") {
+            _next(id, url);
+        }
+    };
+
+    /**
+     * Removes processed queues and corresponding nodes
+     * @method _autoPurge
+     * @private
+     */
+    var _autoPurge = function() {
+
+        if (purging) {
+            return;
+        }
+
+        purging = true;
+        for (var i in queues) {
+            if (queues.hasOwnProperty(i)) {
+                var q = queues[i];
+                if (q.autopurge && q.finished) {
+                    _purge(q.tId);
+                    delete queues[i];
+                }
+            }
+        }
+
+        purging = false;
+    };
+
+    /**
+     * Saves the state for the request and begins loading
+     * the requested urls
+     * @method queue
+     * @param type {string} the type of node to insert
+     * @param url {string} the url to load
+     * @param opts the hash of options for this request
+     * @private
+     */
+    var _queue = function(type, url, opts) {
+
+        var id = "q" + (qidx++);
+        opts = opts || {};
+
+        if (qidx % Y.Get.PURGE_THRESH === 0) {
+            _autoPurge();
+        }
+
+        queues[id] = Y.merge(opts, {
+            tId: id,
+            type: type,
+            url: url,
+            finished: false,
+            nodes: []
+        });
+
+        var q = queues[id];
+        q.win = q.win || Y.config.win;
+        q.context = q.context || q;
+        q.autopurge = ("autopurge" in q) ? q.autopurge : 
+                      (type === "script") ? true : false;
+
+        L.later(0, q, _next, id);
+
+        return {
+            tId: id
+        };
+    };
+
+    /**
+     * Detects when a node has been loaded.  In the case of
+     * script nodes, this does not guarantee that contained
+     * script is ready to use.
+     * @method _track
+     * @param type {string} the type of node to track
+     * @param n {HTMLElement} the node to track
+     * @param id {string} the id of the request
+     * @param url {string} the url that is being loaded
+     * @param win {Window} the targeted window
+     * @param qlength the number of remaining items in the queue,
+     * including this one
+     * @param trackfn {Function} function to execute when finished
+     * the default is _next
+     * @private
+     */
+    var _track = function(type, n, id, url, win, qlength, trackfn) {
+        var f = trackfn || _next;
+
+        // IE supports the readystatechange event for script and css nodes
+        // Opera only for script nodes.  Opera support onload for script
+        // nodes, but this doesn't fire when there is a load failure.
+        // The onreadystatechange appears to be a better way to respond
+        // to both success and failure.
+        if (ua.ie) {
+            n.onreadystatechange = function() {
+                var rs = this.readyState;
+                if ("loaded" === rs || "complete" === rs) {
+                    Y.log(id + " onreadstatechange " + url, "info", "get");
+                    n.onreadystatechange = null;
+                    f(id, url);
+                }
+            };
+
+        // webkit prior to 3.x is no longer supported
+        } else if (ua.webkit) {
+
+            if (type === "script") {
+                // Safari 3.x supports the load event for script nodes (DOM2)
+                n.addEventListener("load", function() {
+                    Y.log(id + " DOM2 onload " + url, "info", "get");
+                    f(id, url);
+                });
+            } 
+
+        // FireFox and Opera support onload (but not DOM2 in FF) handlers for
+        // script nodes.  Opera, but not FF, supports the onload event for link
+        // nodes.
+        } else { 
+
+            n.onload = function() {
+                Y.log(id + " onload " + url, "info", "get");
+                f(id, url);
+            };
+
+            n.onerror = function(e) {
+                _fail(id, e + ": " + url);
+            };
+        }
+    };
+
+    return {
+
+        /**
+         * The number of request required before an automatic purge.
+         * property PURGE_THRESH
+         * @static
+         * @type int
+         * @default 20
+         */
+        PURGE_THRESH: 20,
+
+        /**
+         * Called by the the helper for detecting script load in Safari
+         * @method _finalize
+         * @static
+         * @param id {string} the transaction id
+         * @private
+         */
+        _finalize: function(id) {
+            Y.log(id + " finalized ", "info", "get");
+            L.later(0, null, _finish, id);
+        },
+
+        /**
+         * Abort a transaction
+         * @method abort
+         * @static
+         * @param o {string|object} Either the tId or the object returned from
+         * script() or css()
+         */
+        abort: function(o) {
+            var id = (L.isString(o)) ? o : o.tId;
+            var q = queues[id];
+            if (q) {
+                Y.log("Aborting " + id, "info", "get");
+                q.aborted = true;
+            }
+        }, 
+
+        /**
+         * Fetches and inserts one or more script nodes into the head
+         * of the current document or the document in a specified window.
+         *
+         * @method script
+         * @static
+         * @param url {string|string[]} the url or urls to the script(s)
+         * @param opts {object} Options: 
+         * <dl>
+         * <dt>onSuccess</dt>
+         * <dd>
+         * callback to execute when the script(s) are finished loading
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>onTimeout</dt>
+         * <dd>
+         * callback to execute when a timeout occurs.
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>onFailure</dt>
+         * <dd>
+         * callback to execute when the script load operation fails
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted successfully</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove any nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>context</dt>
+         * <dd>the execution context for the callbacks</dd>
+         * <dt>win</dt>
+         * <dd>a window other than the one the utility occupies</dd>
+         * <dt>autopurge</dt>
+         * <dd>
+         * setting to true will let the utilities cleanup routine purge 
+         * the script once loaded
+         * </dd>
+         * <dt>data</dt>
+         * <dd>
+         * data that is supplied to the callback when the script(s) are
+         * loaded.
+         * </dd>
+         * <dt>insertBefore</dt>
+         * <dd>node or node id that will become the new node's nextSibling</dd>
+         * </dl>
+         * <dt>charset</dt>
+         * <dd>Node charset, default utf-8</dd>
+         * <dt>timeout</dt>
+         * <dd>Number of milliseconds to wait before aborting and firing the timeout event</dd>
+         * <pre>
+         * &nbsp;&nbsp;Y.Get.script(
+         * &nbsp;&nbsp;["http://yui.yahooapis.com/2.5.2/build/yahoo/yahoo-min.js",
+         * &nbsp;&nbsp;&nbsp;"http://yui.yahooapis.com/2.5.2/build/event/event-min.js"], &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;onSuccess: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;this.log("won't cause error because Y is the context");
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Y.log(o.data); // foo
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Y.log(o.nodes.length === 2) // true
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;// o.purge(); // optionally remove the script nodes immediately
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;onFailure: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Y.log("transaction failed");
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;onTimeout: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Y.log("transaction timed out");
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;data: "foo",
+         * &nbsp;&nbsp;&nbsp;&nbsp;timeout: 10000, // 10 second timeout
+         * &nbsp;&nbsp;&nbsp;&nbsp;context: Y, // make the YUI instance
+         * &nbsp;&nbsp;&nbsp;&nbsp;// win: otherframe // target another window/frame
+         * &nbsp;&nbsp;&nbsp;&nbsp;autopurge: true // allow the utility to choose when to remove the nodes
+         * &nbsp;&nbsp;&#125;);
+         * </pre>
+         * @return {tId: string} an object containing info about the transaction
+         */
+        script: function(url, opts) { 
+            return _queue("script", url, opts); 
+        },
+
+        /**
+         * Fetches and inserts one or more css link nodes into the 
+         * head of the current document or the document in a specified
+         * window.
+         * @method css
+         * @static
+         * @param url {string} the url or urls to the css file(s)
+         * @param opts Options: 
+         * <dl>
+         * <dt>onSuccess</dt>
+         * <dd>
+         * callback to execute when the css file(s) are finished loading
+         * The callback receives an object back with the following
+         * data:
+         * <dl>win</dl>
+         * <dd>the window the link nodes(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>context</dt>
+         * <dd>the execution context for the callbacks</dd>
+         * <dt>win</dt>
+         * <dd>a window other than the one the utility occupies</dd>
+         * <dt>data</dt>
+         * <dd>
+         * data that is supplied to the callbacks when the nodes(s) are
+         * loaded.
+         * </dd>
+         * <dt>insertBefore</dt>
+         * <dd>node or node id that will become the new node's nextSibling</dd>
+         * <dt>charset</dt>
+         * <dd>Node charset, default utf-8</dd>
+         * </dl>
+         * <pre>
+         *      Y.Get.css("http://yui.yahooapis.com/2.3.1/build/menu/assets/skins/sam/menu.css");
+         * </pre>
+         * <pre>
+         * &nbsp;&nbsp;Y.Get.css(
+         * &nbsp;&nbsp;["http://yui.yahooapis.com/2.3.1/build/menu/assets/skins/sam/menu.css",
+         * &nbsp;&nbsp;&nbsp;"http://yui.yahooapis.com/2.3.1/build/logger/assets/skins/sam/logger.css"], &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;insertBefore: 'custom-styles' // nodes will be inserted before the specified node
+         * &nbsp;&nbsp;&#125;);
+         * </pre>
+         * @return {tId: string} an object containing info about the transaction
+         */
+        css: function(url, opts) {
+            return _queue("css", url, opts); 
+        }
+    };
+}();
+
+}, "3.0.0pr2");
+/**
+ * Loader dynamically loads script and css files.  It includes the dependency
+ * info for the version of the library in use, and will automatically pull in
+ * dependencies for the modules requested.  It supports rollup files and will
+ * automatically use these when appropriate in order to minimize the number of
+ * http connections required to load all of the dependencies.  It can load the
+ * files from the Yahoo! CDN, and it can utilize the combo service provided on
+ * this network to reduce the number of http connections required to download 
+ * YUI files.
+ *
+ * @module yui
+ * @submodule loader
+ */
+
+/**
+ * Loader dynamically loads script and css files.  It includes the dependency
+ * info for the version of the library in use, and will automatically pull in
+ * dependencies for the modules requested.  It supports rollup files and will
+ * automatically use these when appropriate in order to minimize the number of
+ * http connections required to load all of the dependencies.  It can load the
+ * files from the Yahoo! CDN, and it can utilize the combo service provided on
+ * this network to reduce the number of http connections required to download 
+ * YUI files.
+ * @class Loader
+ * @constructor
+ * @param o an optional set of configuration options.  Valid options:
+ * <ul>
+ *  <li>base:
+ *  The base dir</li>
+ *  <li>secureBase:
+ *  The secure base dir (not implemented)</li>
+ *  <li>comboBase:
+ *  The YUI combo service base dir. Ex: http://yui.yahooapis.com/combo?</li>
+ *  <li>root:
+ *  The root path to prepend to module names for the combo service. Ex: 2.5.2/build/</li>
+ *  <li>filter:
+ *  
+ * A filter to apply to result urls.  This filter will modify the default
+ * path for all modules.  The default path for the YUI library is the
+ * minified version of the files (e.g., event-min.js).  The filter property
+ * can be a predefined filter or a custom filter.  The valid predefined 
+ * filters are:
+ * <dl>
+ *  <dt>DEBUG</dt>
+ *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+ *      This option will automatically include the logger widget</dd>
+ *  <dt>RAW</dt>
+ *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+ * </dl>
+ * You can also define a custom filter, which must be an object literal 
+ * containing a search expression and a replace string:
+ * <pre>
+ *  myFilter: &#123; 
+ *      'searchExp': "-min\\.js", 
+ *      'replaceStr': "-debug.js"
+ *  &#125;
+ * </pre>
+ *
+ *  </li>
+ *  <li>combine:
+ *  Use the YUI combo service to reduce the number of http connections required to load your dependencies</li>
+ *  <li>ignore:
+ *  A list of modules that should never be dynamically loaded</li>
+ *  <li>force:
+ *  A list of modules that should always be loaded when required, even if already present on the page</li>
+ *  <li>insertBefore:
+ *  Node or id for a node that should be used as the insertion point for new nodes</li>
+ *  <li>charset:
+ *  charset for dynamic nodes</li>
+ *  <li>timeout:
+ *  number of milliseconds before a timeout occurs when dynamically loading nodes.  in not set, there is no timeout</li>
+ *  <li>context:
+ *  execution context for all callbacks</li>
+ *  <li>onSuccess:
+ *  callback for the 'success' event</li>
+ *  <li>onFailure:
+ *  callback for the 'failure' event</li>
+ *  <li>onTimeout:
+ *  callback for the 'timeout' event</li>
+ *  <li>onProgress:
+ *  callback executed each time a script or css file is loaded</li>
+ *  <li>modules:
+ *  A list of module definitions.  See Loader.addModule for the supported module metadata</li>
+ * </ul>
+ */
+
+// @TODO backed out the custom event changes so that the event system
+// isn't required in the seed build.  If needed, we may want to 
+// add them back if the event system is detected.
+
+/*
+ * Executed when the loader successfully completes an insert operation
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onSuccess config option.
+ * @event success
+ */
+
+/*
+ * Executed when the loader fails to complete an insert operation.
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onFailure config option.
+ *
+ * @event failure
+ */
+
+/*
+ * Executed when a Get operation times out.
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onTimeout config option.
+ *
+ * @event timeout
+ */
+
+// http://yui.yahooapis.com/combo?2.5.2/build/yahoo/yahoo-min.js&2.5.2/build/dom/dom-min.js&2.5.2/build/event/event-min.js&2.5.2/build/autocomplete/autocomplete-min.js"
+
+YUI.add("loader", function(Y) {
+
+var BASE = 'base', 
+    CSS = 'css',
+    JS = 'js',
+    CSSRESET = 'cssreset',
+    CSSFONTS = 'cssfonts',
+    CSSGRIDS = 'cssgrids',
+    CSSBASE = 'cssbase',
+    CSS_AFTER = [CSSRESET, CSSFONTS, CSSGRIDS, 'cssreset-context', 'cssfonts-context', 'cssgrids-context'],
+    YUI_CSS = ['reset', 'fonts', 'grids', 'base'],
+    VERSION = '3.0.0pr2',
+    ROOT = VERSION + '/build/',
+    CONTEXT = '-context',
+    META = {
+
+    version: VERSION,
+
+    root: ROOT,
+
+    base: 'http://yui.yahooapis.com/' + ROOT,
+
+    comboBase: 'http://yui.yahooapis.com/combo?',
+
+    skin: {
+        defaultSkin: 'sam',
+        base: 'assets/skins/',
+        path: 'skin.css',
+        after: ['reset', 'fonts', 'grids', 'base']
+        //rollup: 3
+    },
+
+    modules: {
+
+       dom: {
+            requires: ['event'],
+            submodules: {
+                'dom-base': {
+                    requires: ['event']
+                },
+                'dom-style': {
+                    requires: ['dom-base']
+
+                },
+                'dom-screen': {
+                    requires: ['dom-base', 'dom-style']
+                },
+                selector: {
+                    requires: ['dom-base']
+                }
+            }
+        },
+
+        node: {
+            requires: ['dom'],
+            submodules: {
+                'node-base': {
+                    requires: ['dom-base', 'selector']
+                },
+                'node-style': {
+                    requires: ['dom-style', 'node-base']
+                },
+                'node-screen': {
+                    requires: ['dom-screen', 'node-base']
+                },
+                'node-event-simulate': {
+                    requires: ['node-base']
+                }
+            }
+        },
+
+        anim: {
+            requires: [BASE, 'node'],
+            submodules: {
+                'anim-base': {
+                    requires: ['base', 'node-style']
+                },
+                'anim-color': {
+                    requires: ['anim-base']
+                },
+                'anim-curve': {
+                    requires: ['anim-xy']
+                },
+                'anim-easing': {
+                },
+                'anim-scroll': {
+                    requires: ['anim-base']
+                },
+                'anim-xy': {
+                    requires: ['anim-base', 'node-screen']
+                },
+                'anim-node-plugin': {
+                     requires: ['node', 'anim-base']
+                }
+            }
+        },
+
+        attribute: { 
+            requires: ['event']
+        },
+
+        base: {
+            requires: ['attribute']
+        },
+        
+        compat: { 
+            requires: ['node', 'dump', 'substitute']
+        },
+
+        classnamemanager: { },
+
+        console: {
+            requires: ['widget', 'substitute'],
+            skinnable: true
+        },
+        
+        cookie: { },
+
+        // Note: CSS attributes are modified programmatically to reduce metadata size
+        // cssbase: {
+        //     after: CSS_AFTER
+        // },
+
+        // cssgrids: {
+        //     requires: [CSSFONTS],
+        //     optional: [CSSRESET]
+        // },
+
+        dd:{
+            submodules: {
+                'dd-ddm-base': {
+                    requires: ['node', BASE]
+                }, 
+                'dd-ddm':{
+                    requires: ['dd-ddm-base']
+                }, 
+                'dd-ddm-drop':{
+                    requires: ['dd-ddm']
+                }, 
+                'dd-drag':{
+                    requires: ['dd-ddm-base']
+                }, 
+                'dd-drop':{
+                    requires: ['dd-ddm-drop']
+                }, 
+                'dd-proxy':{
+                    requires: ['dd-drag']
+                }, 
+                'dd-constrain':{
+                    requires: ['dd-drag', 'dd-proxy']
+                }, 
+                'dd-plugin':{
+                    requires: ['dd-drag'],
+                    optional: ['dd-constrain', 'dd-proxy']
+                },
+                'dd-drop-plugin':{
+                    requires: ['dd-drop']
+                }
+            }
+        },
+
+        dump: { },
+
+        event: { 
+            requires: ['oop']
+        },
+
+        get: { 
+            requires: ['yui-base']
+        },
+        
+        io:{
+            submodules: {
+
+                'io-base': {
+                    requires: ['node']
+                }, 
+
+                'io-xdr': {
+                    requires: ['io-base']
+                }, 
+
+                'io-form': {
+                    requires: ['io-base']
+                }, 
+
+                'io-upload-iframe': {
+                    requires: ['io-base']
+                },
+
+                'io-queue': {
+                    requires: ['io-base']
+                }
+            }
+        },
+
+        json: {
+            submodules: {
+                'json-parse': {
+                },
+
+                'json-stringify': {
+                }
+            }
+        },
+
+        loader: { 
+            requires: ['get']
+        },
+
+        'node-menunav': {
+            requires: ['node', 'classnamemanager'],
+            skinnable: true
+        },
+        
+        oop: { 
+            requires: ['yui-base']
+        },
+
+        overlay: {
+            requires: ['widget', 'widget-position', 'widget-position-ext', 'widget-stack', 'widget-stdmod'],
+            skinnable: true
+        },
+
+        plugin: { 
+            requires: ['base']
+        },
+
+        profiler: { },
+
+        queue: {
+            requires: ['node']
+        },
+
+        slider: {
+            requires: ['widget', 'dd-constrain'],
+            skinnable: true
+        },
+
+        stylesheet: { },
+
+        substitute: {
+            optional: ['dump']
+        },
+
+        widget: {
+            requires: ['base', 'node', 'classnamemanager'],
+            plugins: {
+                'widget-position': { },
+                'widget-position-ext': {
+                    requires: ['widget-position']
+                },
+                'widget-stack': {
+                    skinnable: true
+                },
+                'widget-stdmod': { }
+            },
+            skinnable: true
+        },
+
+        // Since YUI is required for everything else, it should not be specified as
+        // a dependency.
+        yui: {
+            supersedes: ['yui-base', 'get', 'loader']
+        },
+
+        'yui-base': { },
+
+        yuitest: {                                                                                                                                                        
+            requires: ['substitute', 'node', 'json']                                                                                                                     
+        }  
+
+    }
+};
+
+var _path = function(dir, file, type) {
+    return dir + '/' + file + '-min.' + (type || CSS);
+};
+
+var _cssmeta = function() {
+    var mods = META.modules;
+    // modify the meta info for YUI CSS
+    for (var i=0; i<YUI_CSS.length; i=i+1) {
+        var bname = YUI_CSS[i],
+            mname = CSS + bname;
+
+        mods[mname] = {
+            type: CSS,
+            path: _path(mname, bname)
+        };
+
+        // define -context module
+        var contextname = mname + CONTEXT;
+        bname = bname + CONTEXT;
+
+        mods[contextname] = {
+            type: CSS,
+            path: _path(mname, bname)
+        };
+
+        if (mname == CSSGRIDS) {
+            mods[mname].requires = [CSSFONTS];
+            mods[mname].optional = [CSSRESET];
+            mods[contextname].requires = [CSSFONTS + CONTEXT];
+            mods[contextname].optional = [CSSRESET + CONTEXT];
+        } else if (mname == CSSBASE) {
+            mods[mname].after = CSS_AFTER;
+            mods[contextname].after = CSS_AFTER;
+        }
+    }
+}();
+
+Y.Env.meta = META;
+
+
+    var L=Y.Lang, env=Y.Env,
+        PROV = "_provides", SUPER = "_supersedes",
+        REQ = "expanded";
+
+    Y.Loader = function(o) {
+
+        /**
+         * Internal callback to handle multiple internal insert() calls
+         * so that css is inserted prior to js
+         * @property _internalCallback
+         * @private
+         */
+        this._internalCallback = null;
+
+        /**
+         * Use the YUI environment listener to detect script load.  This
+         * is only switched on for Safari 2.x and below.
+         * @property _useYahooListener
+         * @private
+         */
+        this._useYahooListener = false;
+
+        /**
+         * Callback that will be executed when the loader is finished
+         * with an insert
+         * @method onSuccess
+         * @type function
+         */
+        this.onSuccess = null;
+
+        /**
+         * Callback that will be executed if there is a failure
+         * @method onFailure
+         * @type function
+         */
+        this.onFailure = null;
+
+        /**
+         * Callback executed each time a script or css file is loaded
+         * @method onProgress
+         * @type function
+         */
+        this.onProgress = null;
+
+        /**
+         * Callback that will be executed if a timeout occurs
+         * @method onTimeout
+         * @type function
+         */
+        this.onTimeout = null;
+
+        /**
+         * The execution context for all callbacks
+         * @property context
+         * @default {YUI} the YUI instance
+         */
+        this.context = Y;
+
+        /**
+         * Data that is passed to all callbacks
+         * @property data
+         */
+        this.data = null;
+
+        /**
+         * Node reference or id where new nodes should be inserted before
+         * @property insertBefore
+         * @type string|HTMLElement
+         */
+        this.insertBefore = null;
+
+        /**
+         * The charset attribute for inserted nodes
+         * @property charset
+         * @type string
+         * @default utf-8
+         */
+        this.charset = null;
+
+        /**
+         * The base directory.
+         * @property base
+         * @type string
+         * @default http://yui.yahooapis.com/[YUI VERSION]/build/
+         */
+        this.base = Y.Env.meta.base;
+
+        /**
+         * Base path for the combo service
+         * @property comboBase
+         * @type string
+         * @default http://yui.yahooapis.com/combo?
+         */
+        this.comboBase = Y.Env.meta.comboBase;
+
+        /**
+         * If configured, YUI JS resources will use the combo
+         * handler
+         * @property combine
+         * @type boolean
+         * @default true if a base dir isn't in the config
+         */
+        this.combine = (!(BASE in o));
+
+        /**
+         * Ignore modules registered on the YUI global
+         * @property ignoreRegistered
+         * @default false
+         */
+        this.ignoreRegistered = false;
+
+        /**
+         * Root path to prepend to module path for the combo
+         * service
+         * @property root
+         * @type string
+         * @default [YUI VERSION]/build/
+         */
+        this.root = Y.Env.meta.root;
+
+        /**
+         * Timeout value in milliseconds.  If set, this value will be used by
+         * the get utility.  the timeout event will fire if
+         * a timeout occurs.
+         * @property timeout
+         * @type int
+         */
+        this.timeout = 0;
+
+        /**
+         * A list of modules that should not be loaded, even if
+         * they turn up in the dependency tree
+         * @property ignore
+         * @type string[]
+         */
+        this.ignore = null;
+
+        /**
+         * A list of modules that should always be loaded, even
+         * if they have already been inserted into the page.
+         * @property force
+         * @type string[]
+         */
+        this.force = null;
+
+        /**
+         * Should we allow rollups
+         * @property allowRollup
+         * @type boolean
+         * @default true
+         */
+        this.allowRollup = true;
+
+        /**
+         * A filter to apply to result urls.  This filter will modify the default
+         * path for all modules.  The default path for the YUI library is the
+         * minified version of the files (e.g., event-min.js).  The filter property
+         * can be a predefined filter or a custom filter.  The valid predefined 
+         * filters are:
+         * <dl>
+         *  <dt>DEBUG</dt>
+         *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+         *      This option will automatically include the logger widget</dd>
+         *  <dt>RAW</dt>
+         *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+         * </dl>
+         * You can also define a custom filter, which must be an object literal 
+         * containing a search expression and a replace string:
+         * <pre>
+         *  myFilter: &#123; 
+         *      'searchExp': "-min\\.js", 
+         *      'replaceStr': "-debug.js"
+         *  &#125;
+         * </pre>
+         * @property filter
+         * @type string|{searchExp: string, replaceStr: string}
+         */
+        this.filter = null;
+
+        /**
+         * The list of requested modules
+         * @property required
+         * @type {string: boolean}
+         */
+        this.required = {};
+
+        /**
+         * The library metadata
+         * @property moduleInfo
+         */
+        // this.moduleInfo = Y.merge(Y.Env.meta.moduleInfo);
+        this.moduleInfo = {};
+
+        /**
+         * Provides the information used to skin the skinnable components.
+         * The following skin definition would result in 'skin1' and 'skin2'
+         * being loaded for calendar (if calendar was requested), and
+         * 'sam' for all other skinnable components:
+         *
+         *   <code>
+         *   skin: {
+         *
+         *      // The default skin, which is automatically applied if not
+         *      // overriden by a component-specific skin definition.
+         *      // Change this in to apply a different skin globally
+         *      defaultSkin: 'sam', 
+         *
+         *      // This is combined with the loader base property to get
+         *      // the default root directory for a skin. ex:
+         *      // http://yui.yahooapis.com/2.3.0/build/assets/skins/sam/
+         *      base: 'assets/skins/',
+         *
+         *      // The name of the rollup css file for the skin
+         *      path: 'skin.css',
+         *
+         *      // The number of skinnable components requested that are
+         *      // required before using the rollup file rather than the
+         *      // individual component css files
+         *      rollup: 3,
+         *
+         *      // Any component-specific overrides can be specified here,
+         *      // making it possible to load different skins for different
+         *      // components.  It is possible to load more than one skin
+         *      // for a given component as well.
+         *      overrides: {
+         *          calendar: ['skin1', 'skin2']
+         *      }
+         *   }
+         *   </code>
+         *   @property skin
+         */
+         this.skin = Y.merge(Y.Env.meta.skin);
+        
+        var defaults = Y.Env.meta.modules;
+
+        for (var i in defaults) {
+            if (defaults.hasOwnProperty(i)) {
+                this._internal = true;
+                this.addModule(defaults[i], i);
+                this._internal = false;
+            }
+        }
+
+        /**
+         * List of rollup files found in the library metadata
+         * @property rollups
+         */
+        this.rollups = null;
+
+        /**
+         * Whether or not to load optional dependencies for 
+         * the requested modules
+         * @property loadOptional
+         * @type boolean
+         * @default false
+         */
+        this.loadOptional = false;
+
+        /**
+         * All of the derived dependencies in sorted order, which
+         * will be populated when either calculate() or insert()
+         * is called
+         * @property sorted
+         * @type string[]
+         */
+        this.sorted = [];
+
+        /**
+         * Set when beginning to compute the dependency tree. 
+         * Composed of what YUI reports to be loaded combined
+         * with what has been loaded by the tool
+         * @propery loaded
+         * @type {string: boolean}
+         */
+        this.loaded = {};
+
+        /**
+         * A list of modules to attach to the YUI instance when complete.
+         * If not supplied, the sorted list of dependencies are applied.
+         * @property attaching
+         */
+        this.attaching = null;
+
+        /**
+         * Flag to indicate the dependency tree needs to be recomputed
+         * if insert is called again.
+         * @property dirty
+         * @type boolean
+         * @default true
+         */
+        this.dirty = true;
+
+        /**
+         * List of modules inserted by the utility
+         * @property inserted
+         * @type {string: boolean}
+         */
+        this.inserted = {};
+
+        this.skipped = {};
+
+
+        // Y.on('yui:load', this.loadNext, this);
+
+        this._config(o);
+
+    };
+
+    Y.Loader.prototype = {
+
+        FILTERS: {
+            RAW: { 
+                'searchExp': "-min\\.js", 
+                'replaceStr': ".js"
+            },
+            DEBUG: { 
+                'searchExp': "-min\\.js", 
+                'replaceStr': "-debug.js"
+            }
+        },
+
+        SKIN_PREFIX: "skin-",
+
+        _config: function(o) {
+
+            // apply config values
+            if (o) {
+                for (var i in o) {
+                    if (o.hasOwnProperty(i)) {
+                        var val = o[i];
+                        if (i == 'require') {
+                            this.require(val);
+                        } else if (i == 'modules') {
+
+                            // add a hash of module definitions
+                            for (var j in val) {
+                                if (val.hasOwnProperty(j)) {
+                                    this.addModule(val[j], j);
+                                }
+                            }
+
+                        } else {
+                            this[i] = val;
+                        }
+                    }
+                }
+            }
+
+            // fix filter
+            var f = this.filter;
+
+            if (L.isString(f)) {
+                f = f.toUpperCase();
+                this.filterName = f;
+                this.filter = this.FILTERS[f];
+            }
+
+        },
+
+        /**
+         * Returns the skin module name for the specified skin name.  If a
+         * module name is supplied, the returned skin module name is 
+         * specific to the module passed in.
+         * @method formatSkin
+         * @param skin {string} the name of the skin
+         * @param mod {string} optional: the name of a module to skin
+         * @return {string} the full skin module name
+         */
+        formatSkin: function(skin, mod) {
+            var s = this.SKIN_PREFIX + skin;
+            if (mod) {
+                s = s + "-" + mod;
+            }
+
+            return s;
+        },
+
+        /**
+         * Reverses <code>formatSkin</code>, providing the skin name and
+         * module name if the string matches the pattern for skins.
+         * @method parseSkin
+         * @param mod {string} the module name to parse
+         * @return {skin: string, module: string} the parsed skin name 
+         * and module name, or null if the supplied string does not match
+         * the skin pattern
+         */
+        parseSkin: function(mod) {
+            
+            if (mod.indexOf(this.SKIN_PREFIX) === 0) {
+                var a = mod.split("-");
+                return {skin: a[1], module: a[2]};
+            } 
+
+            return null;
+        },
+
+        /**
+         * Adds the skin def to the module info
+         * @method _addSkin
+         * @param skin {string} the name of the skin
+         * @param mod {string} the name of the module
+         * @param parent {string} parent module if this is a skin of a
+         * submodule or plugin
+         * @return {string} the module name for the skin
+         * @private
+         */
+        _addSkin: function(skin, mod, parent) {
+
+            var name = this.formatSkin(skin), info = this.moduleInfo,
+                sinf = this.skin, ext = info[mod] && info[mod].ext;
+
+            /*
+            // Add a module definition for the skin rollup css
+            // Y.log('ext? ' + mod + ": " + ext);
+            if (!info[name]) {
+                // Y.log('adding skin ' + name);
+                this.addModule({
+                    'name': name,
+                    'type': 'css',
+                    'path': sinf.base + skin + '/' + sinf.path,
+                    //'supersedes': '*',
+                    'after': sinf.after,
+                    'rollup': sinf.rollup,
+                    'ext': ext
+                });
+            }
+            */
+
+            // Add a module definition for the module-specific skin css
+            if (mod) {
+                name = this.formatSkin(skin, mod);
+                if (!info[name]) {
+                    var mdef = info[mod], pkg = mdef.pkg || mod;
+                    // Y.log('adding skin ' + name);
+                    this.addModule({
+                        'name': name,
+                        'type': 'css',
+                        'after': sinf.after,
+                        'path': (parent || pkg) + '/' + sinf.base + skin + '/' + mod + '.css',
+                        'ext': ext
+                    });
+                }
+            }
+
+            return name;
+        },
+
+        /** Add a new module to the component metadata.         
+         * <dl>
+         *     <dt>name:</dt>       <dd>required, the component name</dd>
+         *     <dt>type:</dt>       <dd>required, the component type (js or css)</dd>
+         *     <dt>path:</dt>       <dd>required, the path to the script from "base"</dd>
+         *     <dt>requires:</dt>   <dd>array of modules required by this component</dd>
+         *     <dt>optional:</dt>   <dd>array of optional modules for this component</dd>
+         *     <dt>supersedes:</dt> <dd>array of the modules this component replaces</dd>
+         *     <dt>after:</dt>      <dd>array of modules the components which, if present, should be sorted above this one</dd>
+         *     <dt>rollup:</dt>     <dd>the number of superseded modules required for automatic rollup</dd>
+         *     <dt>fullpath:</dt>   <dd>If fullpath is specified, this is used instead of the configured base + path</dd>
+         *     <dt>skinnable:</dt>  <dd>flag to determine if skin assets should automatically be pulled in</dd>
+         *     <dt>submodules:</dt> <dd>a has of submodules</dd>
+         * </dl>
+         * @method addModule
+         * @param o An object containing the module data
+         * @param name the module name (optional), required if not in the module data
+         * @return {boolean} true if the module was added, false if 
+         * the object passed in did not provide all required attributes
+         */
+        addModule: function(o, name) {
+
+            name = name || o.name;
+            o.name = name;
+
+            if (!o || !o.name) {
+                return false;
+            }
+
+            if (!o.type) {
+                o.type = JS;
+            }
+
+            if (!o.path && !o.fullpath) {
+                // o.path = name + "/" + name + "-min." + o.type;
+                o.path = _path(name, name, o.type);
+            }
+
+            o.ext = ('ext' in o) ? o.ext : (this._internal) ? false : true;
+            o.requires = o.requires || [];
+
+            // Y.log('New module ' + name);
+
+            this.moduleInfo[name] = o;
+
+            // Handle submodule logic
+            var subs = o.submodules, i;
+            if (subs) {
+                var sup = [], l=0;
+
+                for (i in subs) {
+                    if (subs.hasOwnProperty(i)) {
+                        var s = subs[i];
+                        s.path = _path(name, i, o.type);
+                        this.addModule(s, i);
+                        sup.push(i);
+
+                        if (o.skinnable) {
+                            var smod = this._addSkin(this.skin.defaultSkin, i, name);
+                            sup.push(smod.name);
+                        }
+
+                        l++;
+                    }
+                }
+
+                o.supersedes = sup;
+                o.rollup = Math.min(l-1, 4);
+            }
+
+            var plugins = o.plugins;
+            if (plugins) {
+                for (i in plugins) {
+                    if (plugins.hasOwnProperty(i)) {
+                        var plug = plugins[i];
+                        plug.path = _path(name, i, o.type);
+                        plug.requires = plug.requires || [];
+                        plug.requires.push(name);
+                        this.addModule(plug, i);
+                        if (o.skinnable) {
+                            this._addSkin(this.skin.defaultSkin, i, name);
+                        }
+                    }
+                }
+            }
+
+            this.dirty = true;
+
+            return o;
+        },
+
+        /**
+         * Add a requirement for one or more module
+         * @method require
+         * @param what {string[] | string*} the modules to load
+         */
+        require: function(what) {
+            var a = (typeof what === "string") ? arguments : what;
+            this.dirty = true;
+            Y.mix(this.required, Y.Array.hash(a));
+        },
+
+        /**
+         * Returns an object containing properties for all modules required
+         * in order to load the requested module
+         * @method getRequires
+         * @param mod The module definition from moduleInfo
+         */
+        getRequires: function(mod) {
+
+            if (!mod) {
+                // Y.log('getRequires, no module');
+                return [];
+            }
+
+            if (!this.dirty && mod.expanded) {
+                // Y.log('already expanded');
+                return mod.expanded;
+            }
+
+            var i, d=[], r=mod.requires, o=mod.optional, 
+                info=this.moduleInfo, m, j, add;
+
+            for (i=0; i<r.length; i=i+1) {
+                // Y.log(mod.name + ' requiring ' + r[i]);
+                d.push(r[i]);
+                m = this.getModule(r[i]);
+                add = this.getRequires(m);
+                for (j=0;j<add.length;j=j+1) {
+                    d.push(add[j]);
+                }
+            }
+
+            // get the requirements from superseded modules, if any
+            r=mod.supersedes;
+            if (r) {
+                for (i=0; i<r.length; i=i+1) {
+                    // Y.log(mod.name + ' requiring ' + r[i]);
+                    d.push(r[i]);
+                    m = this.getModule(r[i]);
+                    add = this.getRequires(m);
+                    for (j=0;j<add.length;j=j+1) {
+                        d.push(add[j]);
+                    }
+                }
+            }
+
+            if (o && this.loadOptional) {
+                for (i=0; i<o.length; i=i+1) {
+                    d.push(o[i]);
+                    add = this.getRequires(info[o[i]]);
+                    for (j=0;j<add.length;j=j+1) {
+                        d.push(add[j]);
+                    }
+                }
+            }
+
+            mod.expanded = Y.Object.keys(Y.Array.hash(d));
+
+            // Y.log(mod.expanded);
+
+            return mod.expanded;
+        },
+
+
+        /**
+         * Returns an object literal of the modules the supplied module satisfies
+         * @method getProvides
+         * @param name{string} The name of the module
+         * @param notMe {string} don't add this module name, only include superseded modules
+         * @return what this module provides
+         */
+        getProvides: function(name, notMe) {
+            var addMe = !(notMe), ckey = (addMe) ? PROV : SUPER,
+                m = this.getModule(name), o = {};
+
+            if (!m) {
+                return o;
+            }
+
+            if (m[ckey]) {
+// Y.log('cached: ' + name + ' ' + ckey + ' ' + L.dump(this.moduleInfo[name][ckey], 0));
+                return m[ckey];
+            }
+
+            var s = m.supersedes, done={}, me = this;
+
+            // use worker to break cycles
+            var add = function(mm) {
+                if (!done[mm]) {
+                    // Y.log(name + ' provides worker trying: ' + mm);
+                    done[mm] = true;
+                    // we always want the return value normal behavior 
+                    // (provides) for superseded modules.
+                    Y.mix(o, me.getProvides(mm));
+                } 
+                
+                // else {
+                // Y.log(name + ' provides worker skipping done: ' + mm);
+                // }
+            };
+
+            // calculate superseded modules
+            if (s) {
+                for (var i=0; i<s.length; i=i+1) {
+                    add(s[i]);
+                }
+            }
+
+            // supersedes cache
+            m[SUPER] = o;
+            // provides cache
+            m[PROV] = Y.merge(o);
+            m[PROV][name] = true;
+
+// Y.log(name + " supersedes " + L.dump(m[SUPER], 0));
+// Y.log(name + " provides " + L.dump(m[PROV], 0));
+
+            return m[ckey];
+        },
+
+
+        /**
+         * Calculates the dependency tree, the result is stored in the sorted 
+         * property
+         * @method calculate
+         * @param o optional options object
+         */
+        calculate: function(o) {
+            if (o || this.dirty) {
+                this._config(o);
+                this._setup();
+                this._explode();
+                if (this.allowRollup) {
+                    this._rollup();
+                }
+                this._reduce();
+                this._sort();
+
+                // Y.log("after calculate: " + this.sorted);
+
+                this.dirty = false;
+            }
+        },
+
+        /**
+         * Investigates the current YUI configuration on the page.  By default,
+         * modules already detected will not be loaded again unless a force
+         * option is encountered.  Called by calculate()
+         * @method _setup
+         * @private
+         */
+        _setup: function() {
+
+            var info = this.moduleInfo, name, i, j;
+
+            // Create skin modules
+            for (name in info) {
+                if (info.hasOwnProperty(name)) {
+                    var m = info[name];
+                    if (m && m.skinnable) {
+                        // Y.log("skinning: " + name);
+                        var o=this.skin.overrides, smod;
+                        if (o && o[name]) {
+                            for (i=0; i<o[name].length; i=i+1) {
+                                smod = this._addSkin(o[name][i], name);
+                            }
+                        } else {
+                            smod = this._addSkin(this.skin.defaultSkin, name);
+                        }
+
+                        m.requires.push(smod);
+                    }
+                }
+            }
+
+            var l = Y.merge(this.inserted); // shallow clone
+
+            // available modules
+            if (!this.ignoreRegistered) {
+                Y.mix(l, YUI.Env.mods);
+            }
+            
+            // Y.log("Already loaded stuff: " + L.dump(l, 0));
+
+            // add the ignore list to the list of loaded packages
+            if (this.ignore) {
+                // OU.appendArray(l, this.ignore);
+                Y.mix(l, Y.Array.hash(this.ignore));
+            }
+
+            // expand the list to include superseded modules
+            for (j in l) {
+                // Y.log("expanding: " + j);
+                if (l.hasOwnProperty(j)) {
+                    Y.mix(l, this.getProvides(j));
+                }
+            }
+
+            // remove modules on the force list from the loaded list
+            if (this.force) {
+                for (i=0; i<this.force.length; i=i+1) {
+                    if (this.force[i] in l) {
+                        delete l[this.force[i]];
+                    }
+                }
+            }
+
+            // Y.log("loaded expanded: " + L.dump(l, 0));
+
+            this.loaded = l;
+
+        },
+        
+
+        /**
+         * Inspects the required modules list looking for additional 
+         * dependencies.  Expands the required list to include all 
+         * required modules.  Called by calculate()
+         * @method _explode
+         * @private
+         */
+        _explode: function() {
+
+            var r=this.required, i, mod;
+
+            for (i in r) {
+                if (r.hasOwnProperty(i)) {
+                    mod = this.getModule(i);
+                    // Y.log('exploding ' + i);
+
+                    var req = this.getRequires(mod);
+
+                    if (req) {
+                        // Y.log('via explode: ' + req);
+                        Y.mix(r, Y.Array.hash(req));
+                    }
+                }
+            }
+        },
+
+        getModule: function(name) {
+
+            var m = this.moduleInfo[name];
+
+            // create the default module
+            // if (!m) {
+                // Y.log('Module does not exist: ' + name + ', creating with defaults');
+                // m = this.addModule({ext: false}, name);
+            // }
+
+            return m;
+        },
+
+        /**
+         * Look for rollup packages to determine if all of the modules a
+         * rollup supersedes are required.  If so, include the rollup to
+         * help reduce the total number of connections required.  Called
+         * by calculate()
+         * @method _rollup
+         * @private
+         */
+        _rollup: function() {
+            var i, j, m, s, rollups={}, r=this.required, roll,
+                info = this.moduleInfo;
+
+            // find and cache rollup modules
+            if (this.dirty || !this.rollups) {
+                for (i in info) {
+                    if (info.hasOwnProperty(i)) {
+                        m = this.getModule(i);
+                        // if (m && m.rollup && m.supersedes) {
+                        if (m && m.rollup) {
+                            rollups[i] = m;
+                        }
+                    }
+                }
+
+                this.rollups = rollups;
+            }
+
+            // make as many passes as needed to pick up rollup rollups
+            for (;;) {
+                var rolled = false;
+
+                // go through the rollup candidates
+                for (i in rollups) { 
+
+                    if (rollups.hasOwnProperty(i)) {
+
+                        // there can be only one
+                        if (!r[i] && !this.loaded[i]) {
+                            m =this.getModule(i); s = m.supersedes ||[]; roll=false;
+
+                            if (!m.rollup) {
+                                continue;
+                            }
+
+                            var c=0;
+
+                            // check the threshold
+                            for (j=0;j<s.length;j=j+1) {
+
+                                // if the superseded module is loaded, we can't load the rollup
+                                // if (this.loaded[s[j]] && (!_Y.dupsAllowed[s[j]])) {
+                                if (this.loaded[s[j]]) {
+                                    roll = false;
+                                    break;
+                                // increment the counter if this module is required.  if we are
+                                // beyond the rollup threshold, we will use the rollup module
+                                } else if (r[s[j]]) {
+                                    c++;
+                                    roll = (c >= m.rollup);
+                                    if (roll) {
+                                        // Y.log("over thresh " + c + ", " + L.dump(r));
+                                        break;
+                                    }
+                                }
+                            }
+
+                            if (roll) {
+                                // Y.log("rollup: " +  i + ", " + L.dump(this, 1));
+                                // add the rollup
+                                r[i] = true;
+                                rolled = true;
+
+                                // expand the rollup's dependencies
+                                this.getRequires(m);
+                            }
+                        }
+                    }
+                }
+
+                // if we made it here w/o rolling up something, we are done
+                if (!rolled) {
+                    break;
+                }
+            }
+        },
+
+        /**
+         * Remove superceded modules and loaded modules.  Called by
+         * calculate() after we have the mega list of all dependencies
+         * @method _reduce
+         * @private
+         */
+        _reduce: function() {
+
+            var i, j, s, m, r=this.required;
+            for (i in r) {
+
+                if (r.hasOwnProperty(i)) {
+
+                    // remove if already loaded
+                    if (i in this.loaded) { 
+                        delete r[i];
+
+                    // remove anything this module supersedes
+                    } else {
+
+                         m = this.getModule(i);
+                         s = m && m.supersedes;
+                         if (s) {
+                             for (j=0; j<s.length; j=j+1) {
+                                 if (s[j] in r) {
+                                     delete r[s[j]];
+                                 }
+                             }
+                         }
+                    }
+                }
+            }
+        },
+
+        _attach: function() {
+
+            // this is the full list of items the YUI needs attached,
+            // which is needed if some dependencies are already on
+            // the page without their dependencies.
+            if (this.attaching) {
+                Y.log('attaching Y supplied deps: ' + this.attaching, "info", "loader");
+                Y._attach(this.attaching);
+            } else {
+                Y.log('attaching sorted list: ' + this.sorted, "info", "loader");
+                Y._attach(this.sorted);
+            }
+
+            this._pushEvents();
+
+        },
+
+        _onSuccess: function() {
+
+            this._attach();
+
+            var skipped = this.skipped;
+
+            for (var i in skipped) {
+                if (skipped.hasOwnProperty(i)) {
+                    delete this.inserted[i];
+                }
+            }
+
+            this.skipped = {};
+
+            // this.fire('success', {
+            //     data: this.data
+            // });
+
+            var f = this.onSuccess;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'success',
+                    data: this.data,
+                    success: true
+                });
+            }
+
+        },
+
+        _onFailure: function(msg) {
+            this._attach();
+            // this.fire('failure', {
+            //     msg: 'operation failed: ' + msg,
+            //     data: this.data
+            // });
+
+            var f = this.onFailure;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'failure: ' + msg,
+                    data: this.data,
+                    success: false
+                });
+            }
+        },
+
+        _onTimeout: function() {
+            this._attach();
+
+            // this.fire('timeout', {
+            //     data: this.data
+            // });
+
+            var f = this.onTimeout;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'timeout',
+                    data: this.data,
+                    success: false
+                });
+            }
+        },
+        
+        /**
+         * Sorts the dependency tree.  The last step of calculate()
+         * @method _sort
+         * @private
+         */
+        _sort: function() {
+            // create an indexed list
+            var s=Y.Object.keys(this.required), info=this.moduleInfo, loaded=this.loaded,
+                me = this;
+
+            // returns true if b is not loaded, and is required
+            // directly or by means of modules it supersedes.
+            var requires = function(aa, bb) {
+
+                var mm=info[aa];
+
+                if (loaded[bb] || !mm) {
+                    return false;
+                }
+
+                var ii, rr = mm.expanded, 
+                    after = mm.after, other=info[bb];
+
+                // check if this module requires the other directly
+                if (rr && Y.Array.indexOf(rr, bb) > -1) {
+                    return true;
+                }
+
+                // check if this module should be sorted after the other
+                if (after && Y.Array.indexOf(after, bb) > -1) {
+                    return true;
+                }
+
+                // check if this module requires one the other supersedes
+                var ss=info[bb] && info[bb].supersedes;
+                if (ss) {
+                    for (ii=0; ii<ss.length; ii=ii+1) {
+                        if (requires(aa, ss[ii])) {
+                            return true;
+                        }
+                    }
+                }
+
+                // external css files should be sorted below yui css
+                if (mm.ext && mm.type == CSS && !other.ext && other.type == CSS) {
+                    return true;
+                }
+
+                return false;
+            };
+
+            // pointer to the first unsorted item
+            var p=0; 
+
+            // keep going until we make a pass without moving anything
+            for (;;) {
+               
+                var l=s.length, a, b, j, k, moved=false;
+
+                // start the loop after items that are already sorted
+                for (j=p; j<l; j=j+1) {
+
+                    // check the next module on the list to see if its
+                    // dependencies have been met
+                    a = s[j];
+
+                    // check everything below current item and move if we
+                    // find a requirement for the current item
+                    for (k=j+1; k<l; k=k+1) {
+                        if (requires(a, s[k])) {
+
+                            // extract the dependency so we can move it up
+                            b = s.splice(k, 1);
+
+                            // insert the dependency above the item that 
+                            // requires it
+                            s.splice(j, 0, b[0]);
+
+                            moved = true;
+                            break;
+                        }
+                    }
+
+                    // jump out of loop if we moved something
+                    if (moved) {
+                        break;
+                    // this item is sorted, move our pointer and keep going
+                    } else {
+                        p = p + 1;
+                    }
+                }
+
+                // when we make it here and moved is false, we are 
+                // finished sorting
+                if (!moved) {
+                    break;
+                }
+
+            }
+
+            this.sorted = s;
+        },
+
+        /**
+         * inserts the requested modules and their dependencies.  
+         * <code>type</code> can be "js" or "css".  Both script and 
+         * css are inserted if type is not provided.
+         * @method insert
+         * @param o optional options object
+         * @param type {string} the type of dependency to insert
+         */
+        insert: function(o, type) {
+
+            Y.log('Insert() ' + (type || ''), "info", "loader");
+
+            // build the dependency list
+            this.calculate(o);
+
+            if (!type) {
+                // Y.log("trying to load css first");
+                var self = this;
+                this._internalCallback = function() {
+                            self._internalCallback = null;
+                            self.insert(null, JS);
+                        };
+                this.insert(null, CSS);
+                return;
+            }
+
+            // set a flag to indicate the load has started
+            this._loading = true;
+
+            // flag to indicate we are done with the combo service
+            // and any additional files will need to be loaded
+            // individually
+            this._combineComplete = {};
+
+            // keep the loadType (js, css or undefined) cached
+            this.loadType = type;
+
+            // start the load
+            this.loadNext();
+
+        },
+
+        /**
+         * Executed every time a module is loaded, and if we are in a load
+         * cycle, we attempt to load the next script.  Public so that it
+         * is possible to call this if using a method other than
+         * Y.register to determine when scripts are fully loaded
+         * @method loadNext
+         * @param mname {string} optional the name of the module that has
+         * been loaded (which is usually why it is time to load the next
+         * one)
+         */
+        loadNext: function(mname) {
+
+            // It is possible that this function is executed due to something
+            // else one the page loading a YUI module.  Only react when we
+            // are actively loading something
+            if (!this._loading) {
+                return;
+            }
+
+            var s, len, i, m, url, self=this, type=this.loadType, fn;
+
+            // @TODO this will need to handle the two phase insert when
+            // CSS support is added
+            if (this.combine && (!this._combineComplete[type])) {
+
+                this._combining = []; 
+                s=this.sorted;
+                len=s.length;
+                url=this.comboBase;
+
+                for (i=0; i<len; i=i+1) {
+                    m = this.getModule(s[i]);
+// @TODO we can't combine CSS yet until we deliver files with absolute paths to the assets
+                    // Do not try to combine non-yui JS
+                    if (m && m.type === this.loadType && !m.ext) {
+                        url += this.root + m.path;
+                        if (i < len-1) {
+                            url += '&';
+                        }
+
+                        this._combining.push(s[i]);
+                    }
+                }
+
+                if (this._combining.length) {
+
+Y.log('Attempting to combine: ' + this._combining, "info", "loader");
+
+                    var callback=function(o) {
+                        Y.log('Combo complete: ' + o.data, "info", "loader");
+                        this._combineComplete[type] = true;
+
+
+                        var c=this._combining, len=c.length, i, m;
+                        for (i=0; i<len; i=i+1) {
+                            this.inserted[c[i]] = true;
+                        }
+
+                        this.loadNext(o.data);
+                    };
+
+                    fn =(type === CSS) ? Y.Get.css : Y.Get.script;
+
+                    // @TODO get rid of the redundant Get code
+                    fn(this._filter(url), {
+                        data: this._loading,
+                        onSuccess: callback,
+                        onFailure: this._onFailure,
+                        onTimeout: this._onTimeout,
+                        insertBefore: this.insertBefore,
+                        charset: this.charset,
+                        timeout: this.timeout,
+                        context: self 
+                    });
+
+                    return;
+
+                } else {
+                    this._combineComplete[type] = true;
+                }
+            }
+
+            if (mname) {
+
+                // if the module that was just loaded isn't what we were expecting,
+                // continue to wait
+                if (mname !== this._loading) {
+                    return;
+                }
+
+Y.log("loadNext executing, just loaded " + mname || "", "info", "loader");
+
+                // The global handler that is called when each module is loaded
+                // will pass that module name to this function.  Storing this
+                // data to avoid loading the same module multiple times
+                this.inserted[mname] = true;
+
+                // this.fire('progress', {
+                //     name: mname,
+                //     data: this.data
+                // });
+                if (this.onProgress) {
+                    this.onProgress.call(this.context, {
+                            name: mname,
+                            data: this.data
+                        });
+                }
+
+
+            }
+
+            s=this.sorted;
+            len=s.length;
+
+            for (i=0; i<len; i=i+1) {
+
+                // this.inserted keeps track of what the loader has loaded.
+                // move on if this item is done.
+                if (s[i] in this.inserted) {
+                    // Y.log(s[i] + " alread loaded ");
+                    continue;
+                }
+
+                // Because rollups will cause multiple load notifications
+                // from Y, loadNext may be called multiple times for
+                // the same module when loading a rollup.  We can safely
+                // skip the subsequent requests
+                if (s[i] === this._loading) {
+                    Y.log("still loading " + s[i] + ", waiting", "info", "loader");
+                    return;
+                }
+
+                // log("inserting " + s[i]);
+                m = this.getModule(s[i]);
+
+                if (!m) {
+
+                    var msg = "Undefined module " + s[i] + " skipped";
+                    Y.log(msg, 'warn', 'loader');
+                    this.inserted[s[i]] = true;
+                    this.skipped[s[i]] = true;
+                    continue;
+
+                    // this.fire('failure', {
+                        // msg: msg,
+                        // data: this.data
+                    // });
+                }
+
+
+                // The load type is stored to offer the possibility to load
+                // the css separately from the script.
+                if (!type || type === m.type) {
+                    this._loading = s[i];
+                    Y.log("attempting to load " + s[i] + ", " + this.base, "info", "loader");
+
+                    fn = (m.type === CSS) ? Y.Get.css : Y.Get.script;
+
+                    var onsuccess=function(o) {
+                            // Y.log('loading next, just loaded' + o.data);
+                            self.loadNext(o.data);
+                        };
+                        
+                    url = (m.fullpath) ? this._filter(m.fullpath) : this._url(m.path, s[i]);
+
+                    self = this; 
+
+                    fn(url, {
+                        data: s[i],
+                        onSuccess: onsuccess,
+                        insertBefore: this.insertBefore,
+                        charset: this.charset,
+                        onFailure: this._onFailure,
+                        onTimeout: this._onTimeout,
+                        timeout: this.timeout,
+                        context: self 
+                    });
+
+                    return;
+                }
+            }
+
+            // we are finished
+            this._loading = null;
+
+            fn = this._internalCallback;
+
+            // internal callback for loading css first
+            if (fn) {
+                // Y.log('loader internal');
+                this._internalCallback = null;
+                fn.call(this);
+
+            // } else if (this.onSuccess) {
+            } else {
+                // Y.log('loader complete');
+                // call Y.use passing this instance. Y will use the sorted
+                // dependency list.
+                this._onSuccess();
+            }
+
+        },
+
+        /**
+         * In IE, the onAvailable/onDOMReady events need help when Event is
+         * loaded dynamically
+         * @method _pushEvents
+         * @param {Function} optional function reference
+         * @private
+         */
+        _pushEvents: function() {
+            if (Y.Event) {
+                Y.Event._load();
+            }
+        },
+
+        /**
+         * Apply filter defined for this instance to a url/path
+         * method _filter
+         * @param u {string} the string to filter
+         * @return {string} the filtered string
+         * @private
+         */
+        _filter: function(u) {
+
+            Y.log('filter ' + u);
+
+            var f = this.filter;
+
+            if (u && f) {
+                var useFilter = true;
+
+                if (this.filterName == "DEBUG") {
+                
+                    var exc = this.logExclude,
+                        inc = this.logInclude;
+                    if (inc && !(name in inc)) {
+                        useFilter = false;
+                    } else if (exc && (name in exc)) {
+                        useFilter = false;
+                    }
+
+                }
+                
+                if (useFilter) {
+                    u = u.replace(new RegExp(f.searchExp, 'g'), f.replaceStr);
+                }
+            }
+
+            return u;
+
+        },
+
+        /**
+         * Generates the full url for a module
+         * method _url
+         * @param path {string} the path fragment
+         * @return {string} the full url
+         * @private
+         */
+        _url: function(path, name) {
+            return this._filter((this.base || "") + path);
+        }
+
+    };
+
+    // Y.augment(Y.Loader, Y.Event.Target);
+
+}, "3.0.0pr2");
+/*
+ * YUI initializer
+ * @module yui
+ * @submodule init
+ */
+(function() {
+
+    var min = ['yui-base', 'log', 'lang', 'array', 'core'], core,
+
+    M = function(Y) {
+
+        var C = Y.config;
+
+        // apply the minimal required functionality
+        Y.use.apply(Y, min);
+
+        Y.log(Y.id + ' initialized', 'info', 'yui');
+
+        if (C.core) {
+
+            core = C.core;
+
+        } else {
+
+            core = ["object", "ua", "later"];
+
+            core.push(
+              "get", 
+              "loader");
+        }
+
+        Y.use.apply(Y, core);
+
+    };
+     
+    YUI.add("yui", M, "3.0.0pr2");
+    
+    // {
+        // the following will be bound automatically when this code is loaded
+      //   use: core
+    // });
+
+})();

=== added file 'loggerhead/static/javascript/yui/build/yui/yui-min.js'
--- loggerhead/static/javascript/yui/build/yui/yui-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yui/yui-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,10 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+(function(){var D={},B={"io.xdrReady":1,"io.start":1,"io.success":1,"io.failure":1,"io.abort":1};if(typeof YUI==="undefined"||!YUI){YUI=function(G){var F=this;if(!(F instanceof YUI)){return new YUI(G);}else{F._init(G);F._setup();return F;}};}YUI.prototype={_init:function(G){G=G||{};var F=(G.win)?(G.win.contentWindow):G.win||window;G.win=F;G.doc=F.document;G.debug=("debug" in G)?G.debug:true;G.useBrowserConsole=("useBrowserConsole" in G)?G.useBrowserConsole:true;G.throwFail=("throwFail" in G)?G.throwFail:true;this.config=G;this.Env={mods:{},_idx:0,_pre:"yuid",_used:{},_attached:{},_yidx:0,_uidx:0};if(YUI.Env){this.Env._yidx=++YUI.Env._idx;this.id=this.stamp(this);D[this.id]=this;}this.constructor=YUI;},_setup:function(F){this.use("yui");this.config=this.merge(this.config);},applyTo:function(L,K,H){if(!(K in B)){this.fail(K+": applyTo not allowed");return null;}var G=D[L];if(G){var J=K.split("."),F=G;for(var I=0;I<J.length;I=I+1){F=F[J[I]];if(!F){this.fail("applyTo not found: "+K);}}return F.apply(G,H);}return null;},add:function(H,J,G,I){var F={name:H,fn:J,version:G,details:I||{}};YUI.Env.mods[H]=F;return this;},_attach:function(G,K){var Q=YUI.Env.mods,H=this.Env._attached;for(var N=0,L=G.length;N<L;N=N+1){var I=G[N],J=Q[I],M;if(!H[I]&&J){H[I]=true;var O=J.details,P=O.requires,F=O.use;if(P){this._attach(this.Array(P));}if(J.fn){J.fn(this);}if(F){this._attach(this.Array(F));}}}},use:function(){var G=this,P=Array.prototype.slice.call(arguments,0),S=YUI.Env.mods,T=G.Env._used,Q,K=P[0],I=false,R=P[P.length-1];if(typeof R==="function"){P.pop();G.Env._callback=R;}else{R=null;}if(K==="*"){P=[];for(var L in S){if(S.hasOwnProperty(L)){P.push(L);}}return G.use.apply(G,P);}if(G.Loader){I=true;Q=new G.Loader(G.config);Q.require(P);Q.ignoreRegistered=true;Q.allowRollup=false;Q.calculate();P=Q.sorted;}var N=[],F=[],O=function(X){if(T[X]){return;}var U=S[X],W,Y,V;if(U){T[X]=true;Y=U.details.requires;V=U.details.use;}else{N.push(X);}if(Y){if(G.Lang.isString(Y)){O(Y);}else{for(W=0;W<Y.length;W=W+1){O(Y[W]);}}}F.push(X);};for(var M=0,J=P.length;M<J;M=M+1){O(P[M]);}var H=function(V){V=V||{success:true,msg:"not dynamic"};if(G.Env._callback){var U=G.Env._callback;G.Env._callback=null;U(G,V);}if(G.fire){G.fire("yui:load",G,V);}};if(G.Loader&&N.length){Q=new G.Loader(G.config);Q.onSuccess=H;Q.onFailure=H;Q.onTimeout=H;Q.attaching=P;Q.require(N);Q.insert();}else{G._attach(F);H();}return G;},namespace:function(){var F=arguments,J=null,H,G,I;for(H=0;H<F.length;H=H+1){I=F[H].split(".");J=this;for(G=(I[0]=="YAHOO")?1:0;G<I.length;G=G+1){J[I[G]]=J[I[G]]||{};J=J[I[G]];}}return J;},log:function(){},fail:function(H,G){if(this.config.throwFail){throw (G||new Error(H));}else{var F=this;F.log(H,"error");}return this;},guid:function(H){var G=this.Env,F=(H)||G._pre;return F+"-"+G._yidx+"-"+G._uidx++;},stamp:function(G){if(!G){return G;}var F=(typeof G==="string")?G:G._yuid;if(!F){F=this.guid();G._yuid=F;}return F;}};var E=YUI,C=E.prototype,A;for(A in C){if(true){E[A]=C[A];}}E._init();})();YUI.add("yui-base",null,"3.0.0pr2");YUI.add("log",function(A){A.log=function(D,K,B,I){var C=A,J=C.config,L=C.Env._eventstack,G=false;if(J.debug&&!G){if(B){var M=J.logExclude,F=J.logInclude;if(F&&!(B in F)){G=true;}else{if(M&&(B in M)){G=true;}}}if(!G){if(J.useBrowserConsole){var E=(B)?B+": "+D:D;if(typeof console!="undefined"){var H=(K&&console[K])?K:"log";console[H](E);}else{if(typeof opera!="undefined"){opera.postError(E);}}}if(C.fire&&!G&&!I){C.fire("yui:log",D,K,B);}}}return C;};},"3.0.0pr2");YUI.add("lang",function(B){B.Lang=B.Lang||{};var H=B.Lang,E="[object Array]",I="[object Function]",F="string",C="object",D="boolean",G="undefined",A=Object.prototype;H.isArray=function(J){return A.toString.apply(J)===E;};H.isBoolean=function(J){return typeof J===D;};H.isFunction=function(J){return A.toString.apply(J)===I;};H.isDate=function(J){return J instanceof Date;};H.isNull=function(J){return J===null;};H.isNumber=function(J){return typeof J==="number"&&isFinite(J);};H.isObject=function(K,J){return(K&&(typeof K===C||(!J&&H.isFunction(K))))||false;};H.isString=function(J){return typeof J===F;};H.isUndefined=function(J){return typeof J===G;};H.trim=function(J){try{return J.replace(/^\s+|\s+$/g,"");}catch(K){return J;}};H.isValue=function(J){return(H.isObject(J)||H.isString(J)||H.isNumber(J)||H.isBoolean(J));};},"3.0.0pr2");YUI.add("array",function(E){var C=E.Lang,D=Array.prototype;E.Array=function(H,F,G){var A=(G)?2:E.Array.test(H);if(A){return D.slice.call(H,F||0);}else{return[H];}};var B=E.Array;B.test=function(G){var F=0;if(C.isObject(G,true)){if(C.isArray(G)){F=1;}else{try{if("length" in G&&!("tagName" in G)&&!("alert" in G)&&(!E.Lang.isFunction(G.size)||G.size()>1)){F=2;}}catch(A){}}}return F;};B.each=(D.forEach)?function(A,F,G){D.forEach.call(A,F,G||E);return E;}:function(F,H,I){var A=F.length,G;for(G=0;G<A;G=G+1){H.call(I||E,F[G],G,F);}return E;};B.some=(D.forEach)?function(A,F,G){D.some.call(A,F,G||E);return E;}:function(F,H,I){var A=F.length;for(var G=0;G<A;G=G+1){if(H.call(I,F[G],G,F)){return true;}}return false;};B.hash=function(G,F){var J={},A=G.length,I=F&&F.length,H;for(H=0;H<A;H=H+1){J[G[H]]=(I&&I>H)?F[H]:true;}return J;};B.indexOf=function(A,G){for(var F=0;F<A.length;F=F+1){if(A[F]===G){return F;}}return -1;};},"3.0.0pr2");YUI.add("core",function(H){var D=H.Lang,C=H.Array,B=Object.prototype,G=["toString","valueOf"],F="prototype",E=(H.UA&&H.UA.ie)?function(L,K,I){for(var J=0,A=G;J<A.length;J=J+1){var N=A[J],M=K[N];if(D.isFunction(M)&&M!=B[N]){if(!I||(N in I)){L[N]=M;}}}}:function(){};H.merge=function(){var I=arguments,K={};for(var J=0,A=I.length;J<A;J=J+1){H.mix(K,I[J],true);}return K;};H.mix=function(A,R,J,Q,M,O){if(!R||!A){return H;}var P=(Q&&Q.length)?C.hash(Q):null,K=O,N=function(U,T,X,W){var S=K&&D.isArray(U);for(var V in T){if(T.hasOwnProperty(V)){if(F===V||"_yuid"===V){continue;}if(!P||W||(V in P)){if(K&&D.isObject(U[V],true)){N(U[V],T[V],X,true);}else{if(!S&&(J||!(V in U))){U[V]=T[V];}else{if(S){U.push(T[V]);}}}}}}E(U,T,P);
+};var L=A.prototype,I=R.prototype;switch(M){case 1:N(L,I,true);break;case 2:N(A,R);N(L,I,true);break;case 3:N(A,I,true);break;case 4:N(L,R);break;default:N(A,R);}return A;};},"3.0.0pr2");YUI.add("object",function(C){C.Object=function(E){var D=function(){};D.prototype=E;return new D();};var B=C.Object,A=C.Lang;B.owns=function(E,D){return(E&&E.hasOwnProperty)?E.hasOwnProperty(D):false;};B.keys=function(F){var D=[],E;for(E in F){if(F.hasOwnProperty(E)){D.push(E);}}return D;};B.each=function(H,G,I,F){var E=I||C;for(var D in H){if(F||H.hasOwnProperty(D)){G.call(E,H[D],D,H);}}return C;};},"3.0.0pr2");YUI.add("ua",function(A){A.UA=function(){var D={ie:0,opera:0,gecko:0,webkit:0,mobile:null};var C=navigator.userAgent,B;if((/KHTML/).test(C)){D.webkit=1;}B=C.match(/AppleWebKit\/([^\s]*)/);if(B&&B[1]){D.webkit=parseFloat(B[1]);if(/ Mobile\//.test(C)){D.mobile="Apple";}else{B=C.match(/NokiaN[^\/]*/);if(B){D.mobile=B[0];}}}if(!D.webkit){B=C.match(/Opera[\s\/]([^\s]*)/);if(B&&B[1]){D.opera=parseFloat(B[1]);B=C.match(/Opera Mini[^;]*/);if(B){D.mobile=B[0];}}else{B=C.match(/MSIE\s([^;]*)/);if(B&&B[1]){D.ie=parseFloat(B[1]);}else{B=C.match(/Gecko\/([^\s]*)/);if(B){D.gecko=1;B=C.match(/rv:([^\s\)]*)/);if(B&&B[1]){D.gecko=parseFloat(B[1]);}}}}}return D;}();},"3.0.0pr2");YUI.add("later",function(C){var A=C.Lang;var B=function(K,E,L,G,H){K=K||0;E=E||{};var F=L,J=G,I,D;if(A.isString(L)){F=E[L];}if(!F){C.fail("method undefined");}if(!A.isArray(J)){J=[G];}I=function(){F.apply(E,J);};D=(H)?setInterval(I,K):setTimeout(I,K);return{interval:H,cancel:function(){if(this.interval){clearInterval(D);}else{clearTimeout(D);}}};};C.later=B;A.later=B;},"3.0.0pr2");YUI.add("get",function(C){var B=C.UA,A=C.Lang;C.Get=function(){var K={},I=0,D=0,R=false;var T=function(X,U,Y){var V=Y||C.config.win,Z=V.document,a=Z.createElement(X);for(var W in U){if(U[W]&&C.Object.owns(U,W)){a.setAttribute(W,U[W]);}}return a;};var Q=function(U,V,X){var W=X||"utf-8";return T("link",{"id":"yui__dyn_"+(D++),"type":"text/css","charset":W,"rel":"stylesheet","href":U},V);};var P=function(U,V,X){var W=X||"utf-8";return T("script",{"id":"yui__dyn_"+(D++),"type":"text/javascript","charset":W,"src":U},V);};var L=function(b){var Y=K[b];if(Y){var a=Y.nodes,U=a.length,Z=Y.win.document,X=Z.getElementsByTagName("head")[0];if(Y.insertBefore){var W=J(Y.insertBefore,b);if(W){X=W.parentNode;}}for(var V=0;V<U;V=V+1){X.removeChild(a[V]);}}Y.nodes=[];};var M=function(U,V){return{tId:U.tId,win:U.win,data:U.data,nodes:U.nodes,msg:V,purge:function(){L(this.tId);}};};var S=function(X,W){var U=K[X];if(U.timer){U.timer.cancel();}if(U.onFailure){var V=U.context||U;U.onFailure.call(V,M(U,W));}};var J=function(U,X){var V=K[X],W=(A.isString(U))?V.win.document.getElementById(U):U;if(!W){S(X,"target node not found: "+U);}return W;};var G=function(X){var U=K[X];if(U.timer){U.timer.cancel();}U.finished=true;if(U.aborted){var W="transaction "+X+" was aborted";S(X,W);return;}if(U.onSuccess){var V=U.context||U;U.onSuccess.call(V,M(U));}};var N=function(W){var U=K[W];if(U.onTimeout){var V=U.context||U;U.onTimeout.call(V,M(U));}};var F=function(W,Z){var V=K[W];if(V.timer){V.timer.cancel();}if(V.aborted){var Y="transaction "+W+" was aborted";S(W,Y);return;}if(Z){V.url.shift();if(V.varName){V.varName.shift();}}else{V.url=(A.isString(V.url))?[V.url]:V.url;if(V.varName){V.varName=(A.isString(V.varName))?[V.varName]:V.varName;}}var c=V.win,b=c.document,a=b.getElementsByTagName("head")[0],X;if(V.url.length===0){G(W);return;}var U=V.url[0];if(!U){V.url.shift();return F(W);}if(V.timeout){V.timer=A.later(V.timeout,V,N,W);}if(V.type==="script"){X=P(U,c,V.charset);}else{X=Q(U,c,V.charset);}H(V.type,X,W,U,c,V.url.length);V.nodes.push(X);if(V.insertBefore){var e=J(V.insertBefore,W);if(e){e.parentNode.insertBefore(X,e);}}else{a.appendChild(X);}if((B.webkit||B.gecko)&&V.type==="css"){F(W,U);}};var E=function(){if(R){return;}R=true;for(var U in K){if(K.hasOwnProperty(U)){var V=K[U];if(V.autopurge&&V.finished){L(V.tId);delete K[U];}}}R=false;};var O=function(V,U,W){var Y="q"+(I++);W=W||{};if(I%C.Get.PURGE_THRESH===0){E();}K[Y]=C.merge(W,{tId:Y,type:V,url:U,finished:false,nodes:[]});var X=K[Y];X.win=X.win||C.config.win;X.context=X.context||X;X.autopurge=("autopurge" in X)?X.autopurge:(V==="script")?true:false;A.later(0,X,F,Y);return{tId:Y};};var H=function(W,b,a,V,Z,Y,U){var X=U||F;if(B.ie){b.onreadystatechange=function(){var c=this.readyState;if("loaded"===c||"complete"===c){b.onreadystatechange=null;X(a,V);}};}else{if(B.webkit){if(W==="script"){b.addEventListener("load",function(){X(a,V);});}}else{b.onload=function(){X(a,V);};b.onerror=function(c){S(a,c+": "+V);};}}};return{PURGE_THRESH:20,_finalize:function(U){A.later(0,null,G,U);},abort:function(V){var W=(A.isString(V))?V:V.tId;var U=K[W];if(U){U.aborted=true;}},script:function(U,V){return O("script",U,V);},css:function(U,V){return O("css",U,V);}};}();},"3.0.0pr2");YUI.add("loader",function(C){var P="base",O="css",M="js",G="cssreset",Q="cssfonts",N="cssgrids",B="cssbase",E=[G,Q,N,"cssreset-context","cssfonts-context","cssgrids-context"],J=["reset","fonts","grids","base"],T="3.0.0pr2",A=T+"/build/",R="-context",U={version:T,root:A,base:"http://yui.yahooapis.com/"+A,comboBase:"http://yui.yahooapis.com/combo?",skin:{defaultSkin:"sam",base:"assets/skins/",path:"skin.css",after:["reset","fonts","grids","base"]},modules:{dom:{requires:["event"],submodules:{"dom-base":{requires:["event"]},"dom-style":{requires:["dom-base"]},"dom-screen":{requires:["dom-base","dom-style"]},selector:{requires:["dom-base"]}}},node:{requires:["dom"],submodules:{"node-base":{requires:["dom-base","selector"]},"node-style":{requires:["dom-style","node-base"]},"node-screen":{requires:["dom-screen","node-base"]},"node-event-simulate":{requires:["node-base"]}}},anim:{requires:[P,"node"],submodules:{"anim-base":{requires:["base","node-style"]},"anim-color":{requires:["anim-base"]},"anim-curve":{requires:["anim-xy"]},"anim-easing":{},"anim-scroll":{requires:["anim-base"]},"anim-xy":{requires:["anim-base","node-screen"]},"anim-node-plugin":{requires:["node","anim-base"]}}},attribute:{requires:["event"]},base:{requires:["attribute"]},compat:{requires:["node","dump","substitute"]},classnamemanager:{},console:{requires:["widget","substitute"],skinnable:true},cookie:{},dd:{submodules:{"dd-ddm-base":{requires:["node",P]},"dd-ddm":{requires:["dd-ddm-base"]},"dd-ddm-drop":{requires:["dd-ddm"]},"dd-drag":{requires:["dd-ddm-base"]},"dd-drop":{requires:["dd-ddm-drop"]},"dd-proxy":{requires:["dd-drag"]},"dd-constrain":{requires:["dd-drag","dd-proxy"]},"dd-plugin":{requires:["dd-drag"],optional:["dd-constrain","dd-proxy"]},"dd-drop-plugin":{requires:["dd-drop"]}}},dump:{},event:{requires:["oop"]},get:{requires:["yui-base"]},io:{submodules:{"io-base":{requires:["node"]},"io-xdr":{requires:["io-base"]},"io-form":{requires:["io-base"]},"io-upload-iframe":{requires:["io-base"]},"io-queue":{requires:["io-base"]}}},json:{submodules:{"json-parse":{},"json-stringify":{}}},loader:{requires:["get"]},"node-menunav":{requires:["node","classnamemanager"],skinnable:true},oop:{requires:["yui-base"]},overlay:{requires:["widget","widget-position","widget-position-ext","widget-stack","widget-stdmod"],skinnable:true},plugin:{requires:["base"]},profiler:{},queue:{requires:["node"]},slider:{requires:["widget","dd-constrain"],skinnable:true},stylesheet:{},substitute:{optional:["dump"]},widget:{requires:["base","node","classnamemanager"],plugins:{"widget-position":{},"widget-position-ext":{requires:["widget-position"]},"widget-stack":{skinnable:true},"widget-stdmod":{}},skinnable:true},yui:{supersedes:["yui-base","get","loader"]},"yui-base":{},yuitest:{requires:["substitute","node","json"]}}};
+var H=function(L,W,X){return L+"/"+W+"-min."+(X||O);};var F=function(){var X=U.modules;for(var W=0;W<J.length;W=W+1){var Z=J[W],Y=O+Z;X[Y]={type:O,path:H(Y,Z)};var L=Y+R;Z=Z+R;X[L]={type:O,path:H(Y,Z)};if(Y==N){X[Y].requires=[Q];X[Y].optional=[G];X[L].requires=[Q+R];X[L].optional=[G+R];}else{if(Y==B){X[Y].after=E;X[L].after=E;}}}}();C.Env.meta=U;var K=C.Lang,S=C.Env,I="_provides",V="_supersedes",D="expanded";C.Loader=function(X){this._internalCallback=null;this._useYahooListener=false;this.onSuccess=null;this.onFailure=null;this.onProgress=null;this.onTimeout=null;this.context=C;this.data=null;this.insertBefore=null;this.charset=null;this.base=C.Env.meta.base;this.comboBase=C.Env.meta.comboBase;this.combine=(!(P in X));this.ignoreRegistered=false;this.root=C.Env.meta.root;this.timeout=0;this.ignore=null;this.force=null;this.allowRollup=true;this.filter=null;this.required={};this.moduleInfo={};this.skin=C.merge(C.Env.meta.skin);var W=C.Env.meta.modules;for(var L in W){if(W.hasOwnProperty(L)){this._internal=true;this.addModule(W[L],L);this._internal=false;}}this.rollups=null;this.loadOptional=false;this.sorted=[];this.loaded={};this.attaching=null;this.dirty=true;this.inserted={};this.skipped={};this._config(X);};C.Loader.prototype={FILTERS:{RAW:{"searchExp":"-min\\.js","replaceStr":".js"},DEBUG:{"searchExp":"-min\\.js","replaceStr":"-debug.js"}},SKIN_PREFIX:"skin-",_config:function(Z){if(Z){for(var W in Z){if(Z.hasOwnProperty(W)){var Y=Z[W];if(W=="require"){this.require(Y);}else{if(W=="modules"){for(var L in Y){if(Y.hasOwnProperty(L)){this.addModule(Y[L],L);}}}else{this[W]=Y;}}}}}var X=this.filter;if(K.isString(X)){X=X.toUpperCase();this.filterName=X;this.filter=this.FILTERS[X];}},formatSkin:function(X,L){var W=this.SKIN_PREFIX+X;if(L){W=W+"-"+L;}return W;},parseSkin:function(W){if(W.indexOf(this.SKIN_PREFIX)===0){var L=W.split("-");return{skin:L[1],module:L[2]};}return null;},_addSkin:function(d,b,c){var L=this.formatSkin(d),Y=this.moduleInfo,W=this.skin,X=Y[b]&&Y[b].ext;if(b){L=this.formatSkin(d,b);if(!Y[L]){var a=Y[b],Z=a.pkg||b;this.addModule({"name":L,"type":"css","after":W.after,"path":(c||Z)+"/"+W.base+d+"/"+b+".css","ext":X});}}return L;},addModule:function(X,W){W=W||X.name;X.name=W;if(!X||!X.name){return false;}if(!X.type){X.type=M;}if(!X.path&&!X.fullpath){X.path=H(W,W,X.type);}X.ext=("ext" in X)?X.ext:(this._internal)?false:true;X.requires=X.requires||[];this.moduleInfo[W]=X;var a=X.submodules,b;if(a){var c=[],Y=0;for(b in a){if(a.hasOwnProperty(b)){var e=a[b];e.path=H(W,b,X.type);this.addModule(e,b);c.push(b);if(X.skinnable){var d=this._addSkin(this.skin.defaultSkin,b,W);c.push(d.name);}Y++;}}X.supersedes=c;X.rollup=Math.min(Y-1,4);}var Z=X.plugins;if(Z){for(b in Z){if(Z.hasOwnProperty(b)){var L=Z[b];L.path=H(W,b,X.type);L.requires=L.requires||[];L.requires.push(W);this.addModule(L,b);if(X.skinnable){this._addSkin(this.skin.defaultSkin,b,W);}}}}this.dirty=true;return X;},require:function(W){var L=(typeof W==="string")?arguments:W;this.dirty=true;C.mix(this.required,C.Array.hash(L));},getRequires:function(c){if(!c){return[];}if(!this.dirty&&c.expanded){return c.expanded;}var a,b=[],L=c.requires,W=c.optional,X=this.moduleInfo,Y,Z,e;for(a=0;a<L.length;a=a+1){b.push(L[a]);Y=this.getModule(L[a]);e=this.getRequires(Y);for(Z=0;Z<e.length;Z=Z+1){b.push(e[Z]);}}L=c.supersedes;if(L){for(a=0;a<L.length;a=a+1){b.push(L[a]);Y=this.getModule(L[a]);e=this.getRequires(Y);for(Z=0;Z<e.length;Z=Z+1){b.push(e[Z]);}}}if(W&&this.loadOptional){for(a=0;a<W.length;a=a+1){b.push(W[a]);e=this.getRequires(X[W[a]]);for(Z=0;Z<e.length;Z=Z+1){b.push(e[Z]);}}}c.expanded=C.Object.keys(C.Array.hash(b));return c.expanded;},getProvides:function(X,c){var W=!(c),L=(W)?I:V,Z=this.getModule(X),Y={};if(!Z){return Y;}if(Z[L]){return Z[L];}var f=Z.supersedes,a={},d=this;var e=function(g){if(!a[g]){a[g]=true;C.mix(Y,d.getProvides(g));}};if(f){for(var b=0;b<f.length;b=b+1){e(f[b]);}}Z[V]=Y;Z[I]=C.merge(Y);Z[I][X]=true;return Z[L];},calculate:function(L){if(L||this.dirty){this._config(L);this._setup();this._explode();if(this.allowRollup){this._rollup();}this._reduce();this._sort();this.dirty=false;}},_setup:function(){var b=this.moduleInfo,Z,a,Y;for(Z in b){if(b.hasOwnProperty(Z)){var W=b[Z];if(W&&W.skinnable){var c=this.skin.overrides,L;if(c&&c[Z]){for(a=0;a<c[Z].length;a=a+1){L=this._addSkin(c[Z][a],Z);}}else{L=this._addSkin(this.skin.defaultSkin,Z);}W.requires.push(L);}}}var X=C.merge(this.inserted);if(!this.ignoreRegistered){C.mix(X,YUI.Env.mods);}if(this.ignore){C.mix(X,C.Array.hash(this.ignore));}for(Y in X){if(X.hasOwnProperty(Y)){C.mix(X,this.getProvides(Y));}}if(this.force){for(a=0;a<this.force.length;a=a+1){if(this.force[a] in X){delete X[this.force[a]];}}}this.loaded=X;},_explode:function(){var Y=this.required,W,L;for(W in Y){if(Y.hasOwnProperty(W)){L=this.getModule(W);var X=this.getRequires(L);if(X){C.mix(Y,C.Array.hash(X));}}}},getModule:function(W){var L=this.moduleInfo[W];return L;},_rollup:function(){var b,a,Z,f,e={},L=this.required,X,Y=this.moduleInfo;if(this.dirty||!this.rollups){for(b in Y){if(Y.hasOwnProperty(b)){Z=this.getModule(b);if(Z&&Z.rollup){e[b]=Z;}}}this.rollups=e;}for(;;){var W=false;for(b in e){if(e.hasOwnProperty(b)){if(!L[b]&&!this.loaded[b]){Z=this.getModule(b);f=Z.supersedes||[];X=false;if(!Z.rollup){continue;}var d=0;for(a=0;a<f.length;a=a+1){if(this.loaded[f[a]]){X=false;break;}else{if(L[f[a]]){d++;X=(d>=Z.rollup);if(X){break;}}}}if(X){L[b]=true;W=true;this.getRequires(Z);}}}}if(!W){break;}}},_reduce:function(){var X,W,Y,L,Z=this.required;for(X in Z){if(Z.hasOwnProperty(X)){if(X in this.loaded){delete Z[X];}else{L=this.getModule(X);Y=L&&L.supersedes;if(Y){for(W=0;W<Y.length;W=W+1){if(Y[W] in Z){delete Z[Y[W]];}}}}}}},_attach:function(){if(this.attaching){C._attach(this.attaching);}else{C._attach(this.sorted);}this._pushEvents();},_onSuccess:function(){this._attach();var L=this.skipped;for(var W in L){if(L.hasOwnProperty(W)){delete this.inserted[W];}}this.skipped={};var X=this.onSuccess;
+if(X){X.call(this.context,{msg:"success",data:this.data,success:true});}},_onFailure:function(W){this._attach();var L=this.onFailure;if(L){L.call(this.context,{msg:"failure: "+W,data:this.data,success:false});}},_onTimeout:function(){this._attach();var L=this.onTimeout;if(L){L.call(this.context,{msg:"timeout",data:this.data,success:false});}},_sort:function(){var h=C.Object.keys(this.required),W=this.moduleInfo,c=this.loaded,d=this;var i=function(l,o){var n=W[l];if(c[o]||!n){return false;}var k,b=n.expanded,m=n.after,a=W[o];if(b&&C.Array.indexOf(b,o)>-1){return true;}if(m&&C.Array.indexOf(m,o)>-1){return true;}var j=W[o]&&W[o].supersedes;if(j){for(k=0;k<j.length;k=k+1){if(i(l,j[k])){return true;}}}if(n.ext&&n.type==O&&!a.ext&&a.type==O){return true;}return false;};var L=0;for(;;){var X=h.length,g,f,Z,Y,e=false;for(Z=L;Z<X;Z=Z+1){g=h[Z];for(Y=Z+1;Y<X;Y=Y+1){if(i(g,h[Y])){f=h.splice(Y,1);h.splice(Z,0,f[0]);e=true;break;}}if(e){break;}else{L=L+1;}}if(!e){break;}}this.sorted=h;},insert:function(X,W){this.calculate(X);if(!W){var L=this;this._internalCallback=function(){L._internalCallback=null;L.insert(null,M);};this.insert(null,O);return;}this._loading=true;this._combineComplete={};this.loadType=W;this.loadNext();},loadNext:function(a){if(!this._loading){return;}var g,Z,Y,X,L,f=this,b=this.loadType,c;if(this.combine&&(!this._combineComplete[b])){this._combining=[];g=this.sorted;Z=g.length;L=this.comboBase;for(Y=0;Y<Z;Y=Y+1){X=this.getModule(g[Y]);if(X&&X.type===this.loadType&&!X.ext){L+=this.root+X.path;if(Y<Z-1){L+="&";}this._combining.push(g[Y]);}}if(this._combining.length){var d=function(l){this._combineComplete[b]=true;var n=this._combining,j=n.length,k,h;for(k=0;k<j;k=k+1){this.inserted[n[k]]=true;}this.loadNext(l.data);};c=(b===O)?C.Get.css:C.Get.script;c(this._filter(L),{data:this._loading,onSuccess:d,onFailure:this._onFailure,onTimeout:this._onTimeout,insertBefore:this.insertBefore,charset:this.charset,timeout:this.timeout,context:f});return;}else{this._combineComplete[b]=true;}}if(a){if(a!==this._loading){return;}this.inserted[a]=true;if(this.onProgress){this.onProgress.call(this.context,{name:a,data:this.data});}}g=this.sorted;Z=g.length;for(Y=0;Y<Z;Y=Y+1){if(g[Y] in this.inserted){continue;}if(g[Y]===this._loading){return;}X=this.getModule(g[Y]);if(!X){var W="Undefined module "+g[Y]+" skipped";this.inserted[g[Y]]=true;this.skipped[g[Y]]=true;continue;}if(!b||b===X.type){this._loading=g[Y];c=(X.type===O)?C.Get.css:C.Get.script;var e=function(h){f.loadNext(h.data);};L=(X.fullpath)?this._filter(X.fullpath):this._url(X.path,g[Y]);f=this;c(L,{data:g[Y],onSuccess:e,insertBefore:this.insertBefore,charset:this.charset,onFailure:this._onFailure,onTimeout:this._onTimeout,timeout:this.timeout,context:f});return;}}this._loading=null;c=this._internalCallback;if(c){this._internalCallback=null;c.call(this);}else{this._onSuccess();}},_pushEvents:function(){if(C.Event){C.Event._load();}},_filter:function(X){var Y=this.filter;if(X&&Y){var W=true;if(this.filterName=="DEBUG"){var L=this.logExclude,Z=this.logInclude;if(Z&&!(name in Z)){W=false;}else{if(L&&(name in L)){W=false;}}}if(W){X=X.replace(new RegExp(Y.searchExp,"g"),Y.replaceStr);}}return X;},_url:function(W,L){return this._filter((this.base||"")+W);}};},"3.0.0pr2");(function(){var B=["yui-base","log","lang","array","core"],A,C=function(E){var D=E.config;E.use.apply(E,B);if(D.core){A=D.core;}else{A=["object","ua","later"];A.push("get","loader");}E.use.apply(E,A);};YUI.add("yui",C,"3.0.0pr2");})();
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/yui/yui.js'
--- loggerhead/static/javascript/yui/build/yui/yui.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yui/yui.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,3974 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+/**
+ * YUI core
+ * @module yui
+ */
+(function() {
+
+    var _instances = {},
+
+// @TODO: this needs to be created at build time from module metadata
+
+        _APPLY_TO_WHITE_LIST = {
+            'io.xdrReady': 1,
+            'io.start': 1,
+            'io.success': 1,
+            'io.failure': 1,
+            'io.abort': 1
+        };
+        
+
+if (typeof YUI === 'undefined' || !YUI) {
+
+    /**
+     * The YUI global namespace object.  If YUI is already defined, the
+     * existing YUI object will not be overwritten so that defined
+     * namespaces are preserved.  
+     *
+     * @class YUI
+     * @constructor
+     * @global
+     * @uses Event.Target
+     * @param o Optional configuration object.  Options:
+     * <ul>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>Global:</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>debug:
+     *  Turn debug statements on or off</li>
+     *  <li>useBrowserConsole:
+     *  Log to the browser console if debug is on and the console is available</li>
+     *  <li>logInclude:
+     *  A hash of log sources that should be logged.  If specified, only log messages from these sources will be logged.
+     *  
+     *  </li>
+     *  <li>logExclude:
+     *  A hash of log sources that should be not be logged.  If specified, all sources are logged if not on this list.</li>
+     *  <li>throwFail:
+     *  If throwFail is set, Y.fail will generate or re-throw a JS error.  Otherwise the failure is logged.
+     *  <li>win:
+     *  The target window/frame</li>
+     *  <li>core:
+     *  A list of modules that defines the YUI core (overrides the default)</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>For event and get:</li>
+     *  <li>------------------------------------------------------------------------</li>
+     *  <li>pollInterval:
+     *  The default poll interval</li>
+     *  <li>-------------------------------------------------------------------------</li>
+     *  <li>For loader:</li>
+     *  <li>-------------------------------------------------------------------------</li>
+     *  <li>base:
+     *  The base dir</li>
+     *  <li>secureBase:
+     *  The secure base dir (not implemented)</li>
+     *  <li>comboBase:
+     *  The YUI combo service base dir. Ex: http://yui.yahooapis.com/combo?</li>
+     *  <li>root:
+     *  The root path to prepend to module names for the combo service. Ex: 2.5.2/build/</li>
+     *  <li>filter:
+     *  
+     * A filter to apply to result urls.  This filter will modify the default
+     * path for all modules.  The default path for the YUI library is the
+     * minified version of the files (e.g., event-min.js).  The filter property
+     * can be a predefined filter or a custom filter.  The valid predefined 
+     * filters are:
+     * <dl>
+     *  <dt>DEBUG</dt>
+     *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+     *      This option will automatically include the logger widget</dd>
+     *  <dt>RAW</dt>
+     *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+     * </dl>
+     * You can also define a custom filter, which must be an object literal 
+     * containing a search expression and a replace string:
+     * <pre>
+     *  myFilter: &#123; 
+     *      'searchExp': "-min\\.js", 
+     *      'replaceStr': "-debug.js"
+     *  &#125;
+     * </pre>
+     *
+     *  </li>
+     *  <li>combine:
+     *  Use the YUI combo service to reduce the number of http connections required to load your dependencies</li>
+     *  <li>ignore:
+     *  A list of modules that should never be dynamically loaded</li>
+     *  <li>force:
+     *  A list of modules that should always be loaded when required, even if already present on the page</li>
+     *  <li>insertBefore:
+     *  Node or id for a node that should be used as the insertion point for new nodes</li>
+     *  <li>charset:
+     *  charset for dynamic nodes</li>
+     *  <li>timeout:
+     *  number of milliseconds before a timeout occurs when dynamically loading nodes.  in not set, there is no timeout</li>
+     *  <li>context:
+     *  execution context for all callbacks</li>
+     *  <li>onSuccess:
+     *  callback for the 'success' event</li>
+     *  <li>onFailure:
+     *  callback for the 'failure' event</li>
+     *  <li>onTimeout:
+     *  callback for the 'timeout' event</li>
+     *  <li>onProgress:
+     *  callback executed each time a script or css file is loaded</li>
+     *  <li>modules:
+     *  A list of module definitions.  See Loader.addModule for the supported module metadata</li>
+     * </ul>
+     */
+
+    /*global YUI*/
+    YUI = function(o) {
+        var Y = this;
+
+        // Allow instantiation without the new operator
+        if (!(Y instanceof YUI)) {
+            return new YUI(o);
+        } else {
+            // set up the core environment
+            Y._init(o);
+
+            // bind the specified additional modules for this instance
+            Y._setup();
+
+            return Y;
+        }
+    };
+}
+
+// The prototype contains the functions that are required to allow the external
+// modules to be registered and for the instance to be initialized.
+YUI.prototype = {
+
+    /**
+     * Initialize this YUI instance
+     * @param o config options
+     * @private
+     */
+    _init: function(o) {
+        
+
+        o = o || {};
+
+        // find targeted window and @TODO create facades
+        var w = (o.win) ? (o.win.contentWindow) : o.win  || window;
+        o.win = w;
+        o.doc = w.document;
+        o.debug = ('debug' in o) ? o.debug : true;
+        o.useBrowserConsole = ('useBrowserConsole' in o) ? o.useBrowserConsole : true;
+        o.throwFail = ('throwFail' in o) ? o.throwFail : true;
+    
+        // add a reference to o for anything that needs it
+        // before _setup is called.
+        this.config = o;
+
+        this.Env = {
+            // @todo expand the new module metadata
+            mods: {},
+            _idx: 0,
+            _pre: 'yuid',
+            _used: {},
+            _attached: {},
+            _yidx: 0,
+            _uidx: 0
+        };
+
+        if (YUI.Env) {
+            this.Env._yidx = ++YUI.Env._idx;
+            this.id = this.stamp(this);
+            _instances[this.id] = this;
+        }
+
+        this.constructor = YUI;
+
+    },
+    
+    /**
+     * Finishes the instance setup. Attaches whatever modules were defined
+     * when the yui modules was registered.
+     * @method _setup
+     * @private
+     */
+    _setup: function(o) {
+        this.use("yui");
+        // @TODO eval the need to copy the config
+        this.config = this.merge(this.config);
+    },
+
+    /**
+     * Executes a method on a YUI instance with
+     * the specified id if the specified method is whitelisted.
+     * @method applyTo
+     * @param id {string} the YUI instance id
+     * @param method {string} the name of the method to exectute.
+     * Ex: 'Object.keys'
+     * @param args {Array} the arguments to apply to the method
+     * @return {object} the return value from the applied method or null
+     */
+    applyTo: function(id, method, args) {
+
+        if (!(method in _APPLY_TO_WHITE_LIST)) {
+            this.fail(method + ': applyTo not allowed');
+            return null;
+        }
+
+        var instance = _instances[id];
+
+        if (instance) {
+
+            var nest = method.split('.'), m = instance;
+
+            for (var i=0; i<nest.length; i=i+1) {
+
+                m = m[nest[i]];
+
+                if (!m) {
+                    this.fail('applyTo not found: ' + method);
+                }
+            }
+
+            return m.apply(instance, args);
+        }
+
+        return null;
+    }, 
+
+    /**
+     * Register a module
+     * @method add
+     * @param name {string} module name
+     * @param fn {Function} entry point into the module that
+     * is used to bind module to the YUI instance
+     * @param version {string} version string
+     * @return {YUI} the YUI instance
+     *
+     * requires   - features that should be present before loading
+     * optional   - optional features that should be present if load optional defined
+     * use  - features that should be attached automatically
+     * skinnable  -
+     * rollup
+     * omit - features that should not be loaded if this module is present
+     */
+    add: function(name, fn, version, details) {
+
+
+        // @todo expand this to include version mapping
+        
+        // @todo allow requires/supersedes
+
+        // @todo may want to restore the build property
+        
+        // @todo fire moduleAvailable event
+        
+        var m = {
+            name: name, 
+            fn: fn,
+            version: version,
+            details: details || {}
+        };
+
+        YUI.Env.mods[name] = m;
+
+        return this; // chain support
+    },
+
+    _attach: function(r, fromLoader) {
+
+        var mods = YUI.Env.mods,
+            attached = this.Env._attached;
+
+        for (var i=0, l=r.length; i<l; i=i+1) {
+            var name = r[i], m = mods[name], mm;
+            if (!attached[name] && m) {
+
+                attached[name] = true;
+
+                var d = m.details, req = d.requires, use = d.use;
+
+                if (req) {
+                    this._attach(this.Array(req));
+                }
+
+
+                if (m.fn) {
+                    m.fn(this);
+                }
+
+                if (use) {
+                    this._attach(this.Array(use));
+                }
+            }
+        }
+
+    },
+
+    /**
+     * Bind a module to a YUI instance
+     * @param modules* {string} 1-n modules to bind (uses arguments array)
+     * @param *callback {function} callback function executed when 
+     * the instance has the required functionality.  If included, it
+     * must be the last parameter.
+     *
+     * @TODO 
+     * Implement versioning?  loader can load different versions?
+     * Should sub-modules/plugins be normal modules, or do
+     * we add syntax for specifying these?
+     *
+     * YUI().use('dragdrop')
+     * YUI().use('dragdrop:2.4.0'); // specific version
+     * YUI().use('dragdrop:2.4.0-'); // at least this version
+     * YUI().use('dragdrop:2.4.0-2.9999.9999'); // version range
+     * YUI().use('*'); // use all available modules
+     * YUI().use('lang+dump+substitute'); // use lang and some plugins
+     * YUI().use('lang+*'); // use lang and all known plugins
+     *
+     *
+     * @return {YUI} the YUI instance
+     */
+    use: function() {
+
+        var Y = this, 
+            a=Array.prototype.slice.call(arguments, 0), 
+            mods = YUI.Env.mods, 
+            used = Y.Env._used,
+            loader, 
+            firstArg = a[0], 
+            dynamic = false,
+            callback = a[a.length-1];
+
+
+        // The last argument supplied to use can be a load complete callback
+        if (typeof callback === 'function') {
+            a.pop();
+            Y.Env._callback = callback;
+        } else {
+            callback = null;
+        }
+
+        // YUI().use('*'); // bind everything available
+        if (firstArg === "*") {
+            a = [];
+            for (var k in mods) {
+                if (mods.hasOwnProperty(k)) {
+                    a.push(k);
+                }
+            }
+
+            return Y.use.apply(Y, a);
+
+        }
+       
+
+        // use loader to expand dependencies and sort the 
+        // requirements if it is available.
+        if (Y.Loader) {
+            dynamic = true;
+            loader = new Y.Loader(Y.config);
+            loader.require(a);
+            loader.ignoreRegistered = true;
+            loader.allowRollup = false;
+            loader.calculate();
+            a = loader.sorted;
+        }
+
+
+        var missing = [], r = [], f = function(name) {
+
+            // only attach a module once
+            if (used[name]) {
+                return;
+            }
+
+            var m = mods[name], j, req, use;
+
+            if (m) {
+                used[name] = true;
+
+                req = m.details.requires;
+                use = m.details.use;
+            } else {
+                missing.push(name);
+            }
+
+            // make sure requirements are attached
+            if (req) {
+                if (Y.Lang.isString(req)) {
+                    f(req);
+                } else {
+                    for (j = 0; j < req.length; j = j + 1) {
+                        f(req[j]);
+                    }
+                }
+            }
+
+            // add this module to full list of things to attach
+            r.push(name);
+
+        };
+
+        // process each requirement and any additional requirements 
+        // the module metadata specifies
+        for (var i=0, l=a.length; i<l; i=i+1) {
+            f(a[i]);
+        }
+
+
+        var onComplete = function(fromLoader) {
+
+
+            fromLoader = fromLoader || {
+                success: true,
+                msg: 'not dynamic'
+            };
+
+            if (Y.Env._callback) {
+
+                var cb = Y.Env._callback;
+                Y.Env._callback = null;
+                cb(Y, fromLoader);
+            }
+
+            if (Y.fire) {
+                Y.fire('yui:load', Y, fromLoader);
+            }
+        };
+
+
+        // dynamic load
+        if (Y.Loader && missing.length) {
+            loader = new Y.Loader(Y.config);
+            loader.onSuccess = onComplete;
+            loader.onFailure = onComplete;
+            loader.onTimeout = onComplete;
+            loader.attaching = a;
+            loader.require(missing);
+            loader.insert();
+        } else {
+            Y._attach(r);
+            onComplete();
+        }
+
+        return Y; // chain support var yui = YUI().use('dragdrop');
+    },
+
+
+    /**
+     * Returns the namespace specified and creates it if it doesn't exist
+     * <pre>
+     * YUI.namespace("property.package");
+     * YUI.namespace("YAHOO.property.package");
+     * </pre>
+     * Either of the above would create YAHOO.property, then
+     * YUI.property.package
+     *
+     * Be careful when naming packages. Reserved words may work in some browsers
+     * and not others. For instance, the following will fail in Safari:
+     * <pre>
+     * YUI.namespace("really.long.nested.namespace");
+     * </pre>
+     * This fails because "long" is a future reserved word in ECMAScript
+     *
+     * @method namespace
+     * @param  {string*} arguments 1-n namespaces to create 
+     * @return {object}  A reference to the last namespace object created
+     */
+    namespace: function() {
+        var a=arguments, o=null, i, j, d;
+        for (i=0; i<a.length; i=i+1) {
+            d = a[i].split(".");
+            o = this;
+            for (j=(d[0] == "YAHOO") ? 1 : 0; j<d.length; j=j+1) {
+                o[d[j]] = o[d[j]] || {};
+                o = o[d[j]];
+            }
+        }
+        return o;
+    },
+
+    // this is replaced if the log module is included
+    log: function() {
+
+    },
+
+    /**
+     * Report an error.  The reporting mechanism is controled by
+     * the 'throwFail' configuration attribute.  If throwFail is
+     * not specified, the message is written to the logger, otherwise
+     * a JS error is thrown
+     * @method fail
+     * @param msg {string} the failure message
+     * @param e {Error} Optional JS error that was caught.  If supplied
+     * and throwFail is specified, this error will be re-thrown.
+     * @return {YUI} this YUI instance
+     */
+    fail: function(msg, e) {
+        if (this.config.throwFail) {
+            throw (e || new Error(msg)); 
+        } else {
+            var instance = this;
+            instance.log(msg, "error"); // don't scrub this one
+        }
+
+        return this;
+    },
+
+    /**
+     * Generate an id that is unique among all YUI instances
+     * @method guid
+     * @param pre {string} optional guid prefix
+     * @return {string} the guid
+     */
+    guid: function(pre) {
+        var e = this.Env, p = (pre) || e._pre;
+        return p +'-' + e._yidx + '-' + e._uidx++;
+    },
+
+    /**
+     * Stamps an object with a guid.  If the object already
+     * has one, a new one is not created
+     * @method stamp
+     * @param o The object to stamp
+     * @return {string} The object's guid
+     */
+    stamp: function(o) {
+
+        if (!o) {
+            return o;
+        }
+
+        var uid = (typeof o === 'string') ? o : o._yuid;
+
+        if (!uid) {
+            uid = this.guid();
+            o._yuid = uid;
+        }
+
+        return uid;
+    }
+};
+
+// Give the YUI global the same properties as an instance.
+// This makes it so that the YUI global can be used like the YAHOO
+// global was used prior to 3.x.  More importantly, the YUI global
+// provides global metadata, so env needs to be configured.
+// @TODO review
+
+    var Y = YUI, p = Y.prototype, i;
+
+    // inheritance utilities are not available yet
+    for (i in p) {
+        if (true) {
+            Y[i] = p[i];
+        }
+    }
+
+    // set up the environment
+    Y._init();
+
+
+})();
+/**
+ * YUI stub
+ * @module yui
+ * @submodule yui-base
+ */
+// This is just a stub to for dependency processing
+YUI.add("yui-base", null, "3.0.0pr2");
+/*
+ * YUI console logger
+ * @module yui
+ * @submodule log
+ */
+YUI.add("log", function(instance) {
+
+    /**
+     * If the 'debug' config is true, a 'yui:log' event will be
+     * dispatched, which the logger widget and anything else
+     * can consume.  If the 'useBrowserConsole' config is true, it will
+     * write to the browser console if available.
+     *
+     * @method log
+     * @for YUI
+     * @param  {String}  msg  The message to log.
+     * @param  {String}  cat  The log category for the message.  Default
+     *                        categories are "info", "warn", "error", time".
+     *                        Custom categories can be used as well. (opt)
+     * @param  {String}  src  The source of the the message (opt)
+     * @param  {boolean} silent If true, the log event won't fire
+     * @return {YUI}      YUI instance
+     */
+    instance.log = function(msg, cat, src, silent) {
+
+        var Y = instance, c = Y.config, es = Y.Env._eventstack,
+            // bail = (es && es.logging);
+            bail = false; 
+
+        // suppress log message if the config is off or the event stack
+        // or the event call stack contains a consumer of the yui:log event
+        if (c.debug && !bail) {
+
+            // apply source filters
+            if (src) {
+
+                var exc = c.logExclude, inc = c.logInclude;
+
+                // console.log('checking src filter: ' + src + ', inc: ' + inc + ', exc: ' + exc);
+
+                if (inc && !(src in inc)) {
+                    // console.log('bail: inc list found, but src is not in list: ' + src);
+                    bail = true;
+                } else if (exc && (src in exc)) {
+                    // console.log('bail: exc list found, and src is in it: ' + src);
+                    bail = true;
+                }
+            }
+
+            if (!bail) {
+
+                if (c.useBrowserConsole) {
+                    var m = (src) ? src + ': ' + msg : msg;
+                    if (typeof console != 'undefined') {
+                        var f = (cat && console[cat]) ? cat : 'log';
+                        console[f](m);
+                    } else if (typeof opera != 'undefined') {
+                        opera.postError(m);
+                    }
+                }
+
+                if (Y.fire && !bail && !silent) {
+                    Y.fire('yui:log', msg, cat, src);
+                }
+            }
+        }
+
+        return Y;
+    };
+
+}, "3.0.0pr2");
+/*
+ * YUI lang utils
+ * @module yui
+ * @submodule lang
+ */
+YUI.add("lang", function(Y) {
+
+    /**
+     * Provides the language utilites and extensions used by the library
+     * @class Lang
+     * @static
+     */
+    Y.Lang = Y.Lang || {};
+
+    var L = Y.Lang, 
+
+    ARRAY_TOSTRING = '[object Array]',
+    FUNCTION_TOSTRING = '[object Function]',
+    STRING = 'string',
+    OBJECT = 'object',
+    BOOLEAN = 'boolean',
+    UNDEFINED = 'undefined',
+    OP = Object.prototype;
+
+    /**
+     * Determines whether or not the provided object is an array.
+     * Testing typeof/instanceof/constructor of arrays across frame 
+     * boundaries isn't possible in Safari unless you have a reference
+     * to the other frame to test against its Array prototype.  To
+     * handle this case, we test well-known array properties instead.
+     * properties.
+     * @TODO can we kill this cross frame hack?
+     * @method isArray
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is an array
+     */
+    L.isArray = function(o) { 
+        return OP.toString.apply(o) === ARRAY_TOSTRING;
+    };
+
+    /**
+     * Determines whether or not the provided object is a boolean
+     * @method isBoolean
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a boolean
+     */
+    L.isBoolean = function(o) {
+        return typeof o === BOOLEAN;
+    };
+    
+    /**
+     * Determines whether or not the provided object is a function
+     * Note: Internet Explorer thinks certain functions are objects:
+     *
+     * var obj = document.createElement("object");
+     * Y.Lang.isFunction(obj.getAttribute) // reports false in IE
+     *
+     * var input = document.createElement("input"); // append to body
+     * Y.Lang.isFunction(input.focus) // reports false in IE
+     *
+     * You will have to implement additional tests if these functions
+     * matter to you.
+     *
+     * @method isFunction
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a function
+     */
+    L.isFunction = function(o) {
+        return OP.toString.apply(o) === FUNCTION_TOSTRING;
+    };
+        
+    /**
+     * Determines whether or not the supplied object is a date instance
+     * @method isDate
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a date
+     */
+    L.isDate = function(o) {
+        return o instanceof Date;
+    };
+
+    /**
+     * Determines whether or not the provided object is null
+     * @method isNull
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is null
+     */
+    L.isNull = function(o) {
+        return o === null;
+    };
+        
+    /**
+     * Determines whether or not the provided object is a legal number
+     * @method isNumber
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a number
+     */
+    L.isNumber = function(o) {
+        return typeof o === 'number' && isFinite(o);
+    };
+      
+    /**
+     * Determines whether or not the provided object is of type object
+     * or function
+     * @method isObject
+     * @static
+     * @param o The object to test
+     * @param failfn {boolean} fail if the input is a function
+     * @return {boolean} true if o is an object
+     */  
+    L.isObject = function(o, failfn) {
+return (o && (typeof o === OBJECT || (!failfn && L.isFunction(o)))) || false;
+    };
+        
+    /**
+     * Determines whether or not the provided object is a string
+     * @method isString
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is a string
+     */
+    L.isString = function(o) {
+        return typeof o === STRING;
+    };
+        
+    /**
+     * Determines whether or not the provided object is undefined
+     * @method isUndefined
+     * @static
+     * @param o The object to test
+     * @return {boolean} true if o is undefined
+     */
+    L.isUndefined = function(o) {
+        return typeof o === UNDEFINED;
+    };
+    
+    /**
+     * Returns a string without any leading or trailing whitespace.  If 
+     * the input is not a string, the input will be returned untouched.
+     * @method trim
+     * @static
+     * @param s {string} the string to trim
+     * @return {string} the trimmed string
+     */
+    L.trim = function(s){
+        try {
+            return s.replace(/^\s+|\s+$/g, "");
+        } catch(e) {
+            return s;
+        }
+    };
+
+    /**
+     * A convenience method for detecting a legitimate non-null value.
+     * Returns false for null/undefined/NaN, true for other values, 
+     * including 0/false/''
+     * @method isValue
+     * @static
+     * @param o The item to test
+     * @return {boolean} true if it is not null/undefined/NaN || false
+     */
+    L.isValue = function(o) {
+// return (o || o === false || o === 0 || o === ''); // Infinity fails
+return (L.isObject(o) || L.isString(o) || L.isNumber(o) || L.isBoolean(o));
+    };
+
+}, "3.0.0pr2");
+
+
+/*
+ * Array utilities
+ * @module yui
+ * @submodule array
+ */
+
+/**
+ * YUI core
+ * @module yui
+ */
+
+YUI.add("array", function(Y) {
+
+    var L = Y.Lang, Native = Array.prototype;
+
+    /**
+     * Adds the following array utilities to the YUI instance
+     * @class YUI~array
+     */
+
+    /** 
+     * Y.Array(o) returns an array:
+     * - Arrays are return unmodified unless the start position is specified.
+     * - "Array-like" collections (@see Array.test) are converted to arrays
+     * - For everything else, a new array is created with the input as the sole item
+     * - The start position is used if the input is or is like an array to return
+     *   a subset of the collection.
+     *
+     *   @TODO this will not automatically convert elements that are also collections
+     *   such as forms and selects.  Passing true as the third param will
+     *   force a conversion.
+     *
+     * @method Array
+     * @static
+     *   @param o the item to arrayify
+     *   @param i {int} if an array or array-like, this is the start index
+     *   @param al {boolean} if true, it forces the array-like fork.  This
+     *   can be used to avoid multiple array.test calls.
+     *   @return {Array} the resulting array
+     */
+    Y.Array = function(o, i, al) {
+        var t = (al) ? 2 : Y.Array.test(o);
+
+        // switch (t) {
+        //     case 1:
+        //         // return (i) ? o.slice(i) : o;
+        //     case 2:
+        //         return Native.slice.call(o, i || 0);
+        //     default:
+        //         return [o];
+        // }
+
+        if (t) {
+            return Native.slice.call(o, i || 0);
+        } else {
+            return [o];
+        }
+
+    };
+
+    var A = Y.Array;
+    
+    /** 
+     * Evaluates the input to determine if it is an array, array-like, or 
+     * something else.  This is used to handle the arguments collection 
+     * available within functions, and HTMLElement collections
+     *
+     * @method Array.test
+     * @static
+     *
+     * @todo current implementation (intenionally) will not implicitly 
+     * handle html elements that are array-like (forms, selects, etc).  
+     *
+     * @return {int} a number indicating the results:
+     * 0: Not an array or an array-like collection
+     * 1: A real array. 
+     * 2: array-like collection.
+     */
+    A.test = function(o) {
+        var r = 0;
+        if (L.isObject(o, true)) {
+            if (L.isArray(o)) {
+                r = 1; 
+            } else {
+                try {
+                    // indexed, but no tagName (element) or alert (window)
+                    if ("length" in o && 
+                        !("tagName" in o) && 
+                        !("alert" in o) && 
+                        (!Y.Lang.isFunction(o.size) || o.size() > 1)) {
+                            r = 2;
+                    }
+                        
+                } catch(ex) {}
+            }
+        }
+        return r;
+    };
+
+    /**
+     * Executes the supplied function on each item in the array.
+     * @method Array.each
+     * @param a {Array} the array to iterate
+     * @param f {Function} the function to execute on each item
+     * @param o Optional context object
+     * @static
+     * @return {YUI} the YUI instance
+     */
+    A.each = (Native.forEach) ?
+        function (a, f, o) { 
+            Native.forEach.call(a, f, o || Y);
+            return Y;
+        } :
+        function (a, f, o) { 
+            var l = a.length, i;
+            for (i = 0; i < l; i=i+1) {
+                f.call(o || Y, a[i], i, a);
+            }
+            return Y;
+        };
+
+    /**
+     * Executes the supplied function on each item in the array.
+     * Returning true from the processing function will stop the 
+     * processing of the remaining
+     * items.
+     * @method Array.some
+     * @param a {Array} the array to iterate
+     * @param f {Function} the function to execute on each item
+     * @param o Optional context object
+     * @static
+     * @return {boolean} true if the 
+     */
+     A.some = (Native.forEach) ?
+        function (a, f, o) { 
+            Native.some.call(a, f, o || Y);
+            return Y;
+        } :
+        function (a, f, o) {
+            var l = a.length;
+            for (var i = 0; i < l; i=i+1) {
+                if (f.call(o, a[i], i, a)) {
+                    return true;
+                }
+            }
+            return false;
+        };
+
+    /**
+     * Returns an object using the first array as keys, and
+     * the second as values.  If the second array is not
+     * provided the value is set to true for each.
+     * @method Array.hash
+     * @static
+     * @param k {Array} keyset
+     * @param v {Array} optional valueset
+     * @return {object} the hash
+     */
+    A.hash = function(k, v) {
+        var o = {}, l = k.length, vl = v && v.length, i;
+        for (i=0; i<l; i=i+1) {
+            o[k[i]] = (vl && vl > i) ? v[i] : true;
+        }
+
+        return o;
+    };
+
+
+    /**
+     * Returns the index of the first item in the array
+     * that contains the specified value, -1 if the
+     * value isn't found.
+     * @TODO use native method if avail
+     * @method Array.indexOf
+     * @static
+     * @param a {Array} the array to search
+     * @param val the value to search for
+     * @return {int} the index of the item that contains the value or -1
+     */
+    A.indexOf = function(a, val) {
+        for (var i=0; i<a.length; i=i+1) {
+            if (a[i] === val) {
+                return i;
+            }
+        }
+
+        return -1;
+    };
+
+}, "3.0.0pr2");
+/*
+ * YUI core utilities
+ * @module yui
+ * @submodule core
+ */
+// requires lang
+YUI.add("core", function(Y) {
+
+    var L = Y.Lang, 
+    A = Y.Array,
+    OP = Object.prototype, 
+    IEF = ["toString", "valueOf"], 
+    PROTO = 'prototype',
+
+    /**
+     * IE will not enumerate native functions in a derived object even if the
+     * function was overridden.  This is a workaround for specific functions 
+     * we care about on the Object prototype. 
+     * @property _iefix
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param w a whitelist object (the keys are the valid items to reference)
+     * @private
+     * @for YUI
+     */
+    _iefix = (Y.UA && Y.UA.ie) ?
+        function(r, s, w) {
+            for (var i=0, a=IEF; i<a.length; i=i+1) {
+                var n = a[i], f = s[n];
+                if (L.isFunction(f) && f != OP[n]) {
+                    if (!w || (n in w)) {
+                        r[n]=f;
+                    }
+                }
+            }
+        } : function() {};
+   
+
+    /**
+     * Returns a new object containing all of the properties of
+     * all the supplied objects.  The properties from later objects
+     * will overwrite those in earlier objects.  Passing in a
+     * single object will create a shallow copy of it.  For a deep
+     * copy, use clone.
+     * @method merge
+     * @param arguments {Object*} the objects to merge
+     * @return {object} the new merged object
+     */
+    Y.merge = function() {
+        // var o={}, a=arguments;
+        // for (var i=0, l=a.length; i<l; i=i+1) {
+        //var a=arguments, o=Y.Object(a[0]);
+        var a=arguments, o={};
+        for (var i=0, l=a.length; i<l; i=i+1) {
+            Y.mix(o, a[i], true);
+        }
+        return o;
+    };
+       
+    /**
+     * Applies the supplier's properties to the receiver.  By default
+     * all prototype and static propertes on the supplier are applied
+     * to the corresponding spot on the receiver.  By default all
+     * properties are applied, and a property that is already on the
+     * reciever will not be overwritten.  The default behavior can
+     * be modified by supplying the appropriate parameters.
+     *
+     * @TODO add constants for the modes
+     *
+     * @method mix
+     * @param {Function} r  the object to receive the augmentation
+     * @param {Function} s  the object that supplies the properties to augment
+     * @param ov {boolean} if true, properties already on the receiver
+     * will be overwritten if found on the supplier.
+     * @param wl {string[]} a whitelist.  If supplied, only properties in 
+     * this list will be applied to the receiver.
+     * @param {int} mode what should be copies, and to where
+     *        default(0): object to object
+     *        1: prototype to prototype (old augment)
+     *        2: prototype to prototype and object props (new augment)
+     *        3: prototype to object
+     *        4: object to prototype
+     * @param merge {boolean} merge objects instead of overwriting/ignoring
+     * Used by Y.aggregate
+     * @return {object} the augmented object
+     * @TODO review for PR2
+     */
+    Y.mix = function(r, s, ov, wl, mode, merge) {
+
+        if (!s||!r) {
+            return Y;
+        }
+
+        var w = (wl && wl.length) ? A.hash(wl) : null, m = merge,
+
+            f = function(fr, fs, proto, iwl) {
+
+                var arr = m && L.isArray(fr);
+
+                for (var i in fs) { 
+
+                    if (fs.hasOwnProperty(i)) {
+
+                        // We never want to overwrite the prototype
+                        // if (PROTO === i) {
+                        if (PROTO === i || '_yuid' === i) {
+                            continue;
+                        }
+
+                        // @TODO deal with the hasownprop issue
+
+                        // check white list if it was supplied
+                        if (!w || iwl || (i in w)) {
+                            // if the receiver has this property, it is an object,
+                            // and merge is specified, merge the two objects.
+                            if (m && L.isObject(fr[i], true)) {
+                                // console.log('aggregate RECURSE: ' + i);
+                                // @TODO recursive or no?
+                                // Y.mix(fr[i], fs[i]); // not recursive
+                                f(fr[i], fs[i], proto, true); // recursive
+                            // otherwise apply the property only if overwrite
+                            // is specified or the receiver doesn't have one.
+                            // @TODO make sure the 'arr' check isn't desructive
+                            } else if (!arr && (ov || !(i in fr))) {
+                                // console.log('hash: ' + i);
+                                fr[i] = fs[i];
+                            // if merge is specified and the receiver is an array,
+                            // append the array item
+                            } else if (arr) {
+                                // console.log('array: ' + i);
+                                // @TODO probably will need to remove dups
+                                fr.push(fs[i]);
+                            }
+                        }
+                    }
+                }
+
+                _iefix(fr, fs, w);
+            };
+
+        var rp = r.prototype, sp = s.prototype;
+
+        switch (mode) {
+            case 1: // proto to proto
+                f(rp, sp, true);
+                break;
+            case 2: // object to object and proto to proto
+                f(r, s);
+                f(rp, sp, true);
+                break;
+            case 3: // proto to static
+                f(r, sp, true);
+                break;
+            case 4: // static to proto
+                f(rp, s);
+                break;
+            default:  // object to object
+                f(r, s);
+        }
+
+        return r;
+    };
+
+    
+
+}, "3.0.0pr2");
+/*
+ * YUI object utilities
+ * @module yui
+ * @submodule object
+ */
+YUI.add("object", function(Y) {
+
+    /**
+     * Adds the following Object utilities to the YUI instance
+     * @class YUI~object
+     */
+
+    /**
+     * Y.Object(o) returns a new object based upon the supplied object.  
+     * @method Object
+     * @static
+     * @param o the supplier object
+     * @return {object} the new object
+     */
+    Y.Object = function(o) {
+        var F = function() {};
+        F.prototype = o;
+        return new F();
+    }; 
+
+    var O = Y.Object, L = Y.Lang;
+
+    /**
+     * Determines whether or not the property was added
+     * to the object instance.  Returns false if the property is not present
+     * in the object, or was inherited from the prototype.
+     *
+     * @deprecated Safari 1.x support has been removed, so this is simply a 
+     * wrapper for the native implementation.  Use the native implementation
+     * directly instead.
+     *
+     * @TODO Remove in PR2
+     *
+     * @method Object.owns
+     * @static
+     * @param o {any} The object being testing
+     * @param p {string} the property to look for
+     * @return {boolean} true if the object has the property on the instance
+     */
+    O.owns = function(o, p) {
+        return (o && o.hasOwnProperty) ? o.hasOwnProperty(p) : false;
+    };
+
+    /**
+     * Returns an array containing the object's keys
+     * @method Object.keys
+     * @static
+     * @param o an object
+     * @return {string[]} the keys
+     */
+    O.keys = function(o) {
+        var a=[], i;
+        for (i in o) {
+            if (o.hasOwnProperty(i)) {
+                a.push(i);
+            }
+        }
+
+        return a;
+    };
+
+    /**
+     * Executes a function on each item. The function
+     * receives the value, the key, and the object
+     * as paramters (in that order).
+     * @method Object.each
+     * @static
+     * @param o the object to iterate
+     * @param f {function} the function to execute
+     * @param c the execution context
+     * @param proto {boolean} include proto
+     * @return {YUI} the YUI instance
+     */
+    O.each = function (o, f, c, proto) {
+        var s = c || Y;
+
+        for (var i in o) {
+            if (proto || o.hasOwnProperty(i)) {
+                f.call(s, o[i], i, o);
+            }
+        }
+        return Y;
+    };
+}, "3.0.0pr2");
+/*
+ * YUI user agent detection
+ * @module yui
+ * @submodule ua
+ */
+YUI.add("ua", function(Y) {
+
+    /**
+     * Browser/platform detection
+     * @class UA
+     * @static
+     */
+    Y.UA = function() {
+
+        var o={
+
+            /**
+             * Internet Explorer version number or 0.  Example: 6
+             * @property ie
+             * @type float
+             * @static
+             */
+            ie:0,
+
+            /**
+             * Opera version number or 0.  Example: 9.2
+             * @property opera
+             * @type float
+             * @static
+             */
+            opera:0,
+
+            /**
+             * Gecko engine revision number.  Will evaluate to 1 if Gecko 
+             * is detected but the revision could not be found. Other browsers
+             * will be 0.  Example: 1.8
+             * <pre>
+             * Firefox 1.0.0.4: 1.7.8   <-- Reports 1.7
+             * Firefox 1.5.0.9: 1.8.0.9 <-- Reports 1.8
+             * Firefox 2.0.0.3: 1.8.1.3 <-- Reports 1.8
+             * Firefox 3 alpha: 1.9a4   <-- Reports 1.9
+             * </pre>
+             * @property gecko
+             * @type float
+             * @static
+             */
+            gecko:0,
+
+            /**
+             * AppleWebKit version.  KHTML browsers that are not WebKit browsers 
+             * will evaluate to 1, other browsers 0.  Example: 418.9.1
+             * <pre>
+             * Safari 1.3.2 (312.6): 312.8.1 <-- Reports 312.8 -- currently the 
+             *                                   latest available for Mac OSX 10.3.
+             * Safari 2.0.2:         416     <-- hasOwnProperty introduced
+             * Safari 2.0.4:         418     <-- preventDefault fixed
+             * Safari 2.0.4 (419.3): 418.9.1 <-- One version of Safari may run
+             *                                   different versions of webkit
+             * Safari 2.0.4 (419.3): 419     <-- Tiger installations that have been
+             *                                   updated, but not updated
+             *                                   to the latest patch.
+             * Webkit 212 nightly:   522+    <-- Safari 3.0 precursor (with native SVG
+             *                                   and many major issues fixed).
+             * Safari 3.0.4 (523.12) 523.12  <-- First Tiger release - automatic update
+             *                                   from 2.x via the 10.4.11 OS patch
+             *                                   
+             * </pre>
+             * http://developer.apple.com/internet/safari/uamatrix.html
+             * @property webkit
+             * @type float
+             * @static
+             */
+            webkit:0,
+
+            /**
+             * The mobile property will be set to a string containing any relevant
+             * user agent information when a modern mobile browser is detected.
+             * Currently limited to Safari on the iPhone/iPod Touch, Nokia N-series
+             * devices with the WebKit-based browser, and Opera Mini.  
+             * @property mobile 
+             * @type string
+             * @static
+             */
+            mobile: null 
+        };
+
+        var ua=navigator.userAgent, m;
+
+        // Modern KHTML browsers should qualify as Safari X-Grade
+        if ((/KHTML/).test(ua)) {
+            o.webkit=1;
+        }
+        // Modern WebKit browsers are at least X-Grade
+        m=ua.match(/AppleWebKit\/([^\s]*)/);
+        if (m&&m[1]) {
+            o.webkit=parseFloat(m[1]);
+
+            // Mobile browser check
+            if (/ Mobile\//.test(ua)) {
+                o.mobile = "Apple"; // iPhone or iPod Touch
+            } else {
+                m=ua.match(/NokiaN[^\/]*/);
+                if (m) {
+                    o.mobile = m[0]; // Nokia N-series, ex: NokiaN95
+                }
+            }
+
+        }
+
+        if (!o.webkit) { // not webkit
+            // @todo check Opera/8.01 (J2ME/MIDP; Opera Mini/2.0.4509/1316; fi; U; ssr)
+            m=ua.match(/Opera[\s\/]([^\s]*)/);
+            if (m&&m[1]) {
+                o.opera=parseFloat(m[1]);
+                m=ua.match(/Opera Mini[^;]*/);
+                if (m) {
+                    o.mobile = m[0]; // ex: Opera Mini/2.0.4509/1316
+                }
+            } else { // not opera or webkit
+                m=ua.match(/MSIE\s([^;]*)/);
+                if (m&&m[1]) {
+                    o.ie=parseFloat(m[1]);
+                } else { // not opera, webkit, or ie
+                    m=ua.match(/Gecko\/([^\s]*)/);
+                    if (m) {
+                        o.gecko=1; // Gecko detected, look for revision
+                        m=ua.match(/rv:([^\s\)]*)/);
+                        if (m&&m[1]) {
+                            o.gecko=parseFloat(m[1]);
+                        }
+                    }
+                }
+            }
+        }
+        
+        return o;
+    }();
+}, "3.0.0pr2");
+/*
+ * YUI setTimeout/setInterval abstraction
+ * @module yui
+ * @submodule later
+ */
+YUI.add("later", function(Y) {
+
+    var L = Y.Lang;
+
+    /**
+     * Executes the supplied function in the context of the supplied 
+     * object 'when' milliseconds later.  Executes the function a 
+     * single time unless periodic is set to true.
+     * @method later
+     * @for YUI
+     * @param when {int} the number of milliseconds to wait until the fn 
+     * is executed.
+     * @param o the context object.
+     * @param fn {Function|String} the function to execute or the name of 
+     * the method in the 'o' object to execute.
+     * @param data [Array] data that is provided to the function.  This accepts
+     * either a single item or an array.  If an array is provided, the
+     * function is executed with one parameter for each array item.  If
+     * you need to pass a single array parameter, it needs to be wrapped in
+     * an array [myarray].
+     * @param periodic {boolean} if true, executes continuously at supplied 
+     * interval until canceled.
+     * @return {object} a timer object. Call the cancel() method on this object to 
+     * stop the timer.
+     */
+    var later = function(when, o, fn, data, periodic) {
+        when = when || 0; 
+        o = o || {};
+        var m=fn, d=data, f, r;
+
+        if (L.isString(fn)) {
+            m = o[fn];
+        }
+
+        if (!m) {
+            Y.fail("method undefined");
+        }
+
+        if (!L.isArray(d)) {
+            d = [data];
+        }
+
+        f = function() {
+            m.apply(o, d);
+        };
+
+        r = (periodic) ? setInterval(f, when) : setTimeout(f, when);
+
+        return {
+            interval: periodic,
+            cancel: function() {
+                if (this.interval) {
+                    clearInterval(r);
+                } else {
+                    clearTimeout(r);
+                }
+            }
+        };
+    };
+
+    Y.later = later;
+    L.later = later;
+
+}, "3.0.0pr2");
+
+YUI.add("get", function(Y) {
+    
+        var ua=Y.UA, 
+        L=Y.Lang;
+
+/**
+ * Provides a mechanism to fetch remote resources and
+ * insert them into a document.
+ * @module yui
+ * @submodule get
+ */
+
+/**
+ * Fetches and inserts one or more script or link nodes into the document 
+ * @class Get
+ * @static
+ */
+Y.Get = function() {
+
+    /**
+     * hash of queues to manage multiple requests
+     * @property queues
+     * @private
+     */
+    var queues={}, 
+        
+    /**
+     * queue index used to generate transaction ids
+     * @property qidx
+     * @type int
+     * @private
+     */
+        qidx=0, 
+        
+    /**
+     * node index used to generate unique node ids
+     * @property nidx
+     * @type int
+     * @private
+     */
+        nidx=0, 
+
+        // ridx=0,
+
+        // sandboxFrame=null,
+
+    /**
+     * interal property used to prevent multiple simultaneous purge 
+     * processes
+     * @property purging
+     * @type boolean
+     * @private
+     */
+        purging=false;
+
+    
+    /** 
+     * Generates an HTML element, this is not appended to a document
+     * @method _node
+     * @param type {string} the type of element
+     * @param attr {string} the attributes
+     * @param win {Window} optional window to create the element in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _node = function(type, attr, win) {
+        var w = win || Y.config.win, d=w.document, n=d.createElement(type);
+
+        for (var i in attr) {
+            if (attr[i] && Y.Object.owns(attr, i)) {
+                n.setAttribute(i, attr[i]);
+            }
+        }
+
+        return n;
+    };
+
+    /**
+     * Generates a link node
+     * @method _linkNode
+     * @param url {string} the url for the css file
+     * @param win {Window} optional window to create the node in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _linkNode = function(url, win, charset) {
+        var c = charset || "utf-8";
+        return _node("link", {
+                "id":      "yui__dyn_" + (nidx++),
+                "type":    "text/css",
+                "charset": c,
+                "rel":     "stylesheet",
+                "href":    url
+            }, win);
+    };
+
+    /**
+     * Generates a script node
+     * @method _scriptNode
+     * @param url {string} the url for the script file
+     * @param win {Window} optional window to create the node in
+     * @return {HTMLElement} the generated node
+     * @private
+     */
+    var _scriptNode = function(url, win, charset) {
+        var c = charset || "utf-8";
+        return _node("script", {
+                "id":      "yui__dyn_" + (nidx++),
+                "type":    "text/javascript",
+                "charset": c,
+                "src":     url
+            }, win);
+    };
+
+    /**
+     * Removes the nodes for the specified queue
+     * @method _purge
+     * @private
+     */
+    var _purge = function(tId) {
+        var q=queues[tId];
+        if (q) {
+            var n=q.nodes, l=n.length, d=q.win.document, 
+                h=d.getElementsByTagName("head")[0];
+
+            if (q.insertBefore) {
+                var s = _get(q.insertBefore, tId);
+                if (s) {
+                    h = s.parentNode;
+                }
+            }
+
+            for (var i=0; i<l; i=i+1) {
+                h.removeChild(n[i]);
+            }
+        }
+        q.nodes = [];
+    };
+
+    /**
+     * Returns the data payload for callback functions
+     * @method _returnData
+     * @private
+     */
+    var _returnData = function(q, msg) {
+        return {
+                tId: q.tId,
+                win: q.win,
+                data: q.data,
+                nodes: q.nodes,
+                msg: msg,
+                purge: function() {
+                    _purge(this.tId);
+                }
+            };
+    };
+
+    /*
+     * The request failed, execute fail handler with whatever
+     * was accomplished.  There isn't a failure case at the
+     * moment unless you count aborted transactions
+     * @method _fail
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _fail = function(id, msg) {
+
+
+        var q = queues[id];
+        if (q.timer) {
+            q.timer.cancel();
+        }
+
+        // execute failure callback
+        if (q.onFailure) {
+            var sc=q.context || q;
+            q.onFailure.call(sc, _returnData(q, msg));
+        }
+    };
+
+    var _get = function(nId, tId) {
+        var q = queues[tId],
+            n = (L.isString(nId)) ? q.win.document.getElementById(nId) : nId;
+        if (!n) {
+            _fail(tId, "target node not found: " + nId);
+        }
+
+        return n;
+    };
+
+
+    /**
+     * The request is complete, so executing the requester's callback
+     * @method _finish
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _finish = function(id) {
+        var q = queues[id];
+        if (q.timer) {
+            q.timer.cancel();
+        }
+        q.finished = true;
+
+        if (q.aborted) {
+            var msg = "transaction " + id + " was aborted";
+            _fail(id, msg);
+            return;
+        }
+
+        // execute success callback
+        if (q.onSuccess) {
+            var sc=q.context || q;
+            q.onSuccess.call(sc, _returnData(q));
+        }
+    };
+
+    /**
+     * Timeout detected
+     * @method _timeout
+     * @param id {string} the id of the request
+     * @private
+     */
+    var _timeout = function(id) {
+        var q = queues[id];
+        if (q.onTimeout) {
+            var sc=q.context || q;
+            q.onTimeout.call(sc, _returnData(q));
+        }
+    };
+
+    /**
+     * Loads the next item for a given request
+     * @method _next
+     * @param id {string} the id of the request
+     * @param loaded {string} the url that was just loaded, if any
+     * @private
+     */
+    var _next = function(id, loaded) {
+
+        var q = queues[id];
+
+        if (q.timer) {
+            q.timer.cancel();
+        }
+
+        if (q.aborted) {
+            var msg = "transaction " + id + " was aborted";
+            _fail(id, msg);
+            return;
+        }
+
+        if (loaded) {
+            q.url.shift(); 
+            if (q.varName) {
+                q.varName.shift(); 
+            }
+        } else {
+            // This is the first pass: make sure the url is an array
+            q.url = (L.isString(q.url)) ? [q.url] : q.url;
+            if (q.varName) {
+                q.varName = (L.isString(q.varName)) ? [q.varName] : q.varName;
+            }
+        }
+
+        var w=q.win, d=w.document, h=d.getElementsByTagName("head")[0], n;
+
+        if (q.url.length === 0) {
+            _finish(id);
+            return;
+        } 
+
+        var url = q.url[0];
+
+        // if the url is undefined, this is probably a trailing comma problem in IE
+        if (!url) {
+            q.url.shift(); 
+            return _next(id);
+        }
+
+
+        if (q.timeout) {
+            q.timer = L.later(q.timeout, q, _timeout, id);
+        }
+
+        if (q.type === "script") {
+            n = _scriptNode(url, w, q.charset);
+        } else {
+            n = _linkNode(url, w, q.charset);
+        }
+
+        // track this node's load progress
+        _track(q.type, n, id, url, w, q.url.length);
+
+        // add the node to the queue so we can return it to the user supplied callback
+        q.nodes.push(n);
+
+        // add it to the head or insert it before 'insertBefore'
+        if (q.insertBefore) {
+            var s = _get(q.insertBefore, id);
+            if (s) {
+                s.parentNode.insertBefore(n, s);
+            }
+        } else {
+            h.appendChild(n);
+        }
+        
+
+        // FireFox does not support the onload event for link nodes, so there is
+        // no way to make the css requests synchronous. This means that the css 
+        // rules in multiple files could be applied out of order in this browser
+        // if a later request returns before an earlier one.  Safari too.
+        if ((ua.webkit || ua.gecko) && q.type === "css") {
+            _next(id, url);
+        }
+    };
+
+    /**
+     * Removes processed queues and corresponding nodes
+     * @method _autoPurge
+     * @private
+     */
+    var _autoPurge = function() {
+
+        if (purging) {
+            return;
+        }
+
+        purging = true;
+        for (var i in queues) {
+            if (queues.hasOwnProperty(i)) {
+                var q = queues[i];
+                if (q.autopurge && q.finished) {
+                    _purge(q.tId);
+                    delete queues[i];
+                }
+            }
+        }
+
+        purging = false;
+    };
+
+    /**
+     * Saves the state for the request and begins loading
+     * the requested urls
+     * @method queue
+     * @param type {string} the type of node to insert
+     * @param url {string} the url to load
+     * @param opts the hash of options for this request
+     * @private
+     */
+    var _queue = function(type, url, opts) {
+
+        var id = "q" + (qidx++);
+        opts = opts || {};
+
+        if (qidx % Y.Get.PURGE_THRESH === 0) {
+            _autoPurge();
+        }
+
+        queues[id] = Y.merge(opts, {
+            tId: id,
+            type: type,
+            url: url,
+            finished: false,
+            nodes: []
+        });
+
+        var q = queues[id];
+        q.win = q.win || Y.config.win;
+        q.context = q.context || q;
+        q.autopurge = ("autopurge" in q) ? q.autopurge : 
+                      (type === "script") ? true : false;
+
+        L.later(0, q, _next, id);
+
+        return {
+            tId: id
+        };
+    };
+
+    /**
+     * Detects when a node has been loaded.  In the case of
+     * script nodes, this does not guarantee that contained
+     * script is ready to use.
+     * @method _track
+     * @param type {string} the type of node to track
+     * @param n {HTMLElement} the node to track
+     * @param id {string} the id of the request
+     * @param url {string} the url that is being loaded
+     * @param win {Window} the targeted window
+     * @param qlength the number of remaining items in the queue,
+     * including this one
+     * @param trackfn {Function} function to execute when finished
+     * the default is _next
+     * @private
+     */
+    var _track = function(type, n, id, url, win, qlength, trackfn) {
+        var f = trackfn || _next;
+
+        // IE supports the readystatechange event for script and css nodes
+        // Opera only for script nodes.  Opera support onload for script
+        // nodes, but this doesn't fire when there is a load failure.
+        // The onreadystatechange appears to be a better way to respond
+        // to both success and failure.
+        if (ua.ie) {
+            n.onreadystatechange = function() {
+                var rs = this.readyState;
+                if ("loaded" === rs || "complete" === rs) {
+                    n.onreadystatechange = null;
+                    f(id, url);
+                }
+            };
+
+        // webkit prior to 3.x is no longer supported
+        } else if (ua.webkit) {
+
+            if (type === "script") {
+                // Safari 3.x supports the load event for script nodes (DOM2)
+                n.addEventListener("load", function() {
+                    f(id, url);
+                });
+            } 
+
+        // FireFox and Opera support onload (but not DOM2 in FF) handlers for
+        // script nodes.  Opera, but not FF, supports the onload event for link
+        // nodes.
+        } else { 
+
+            n.onload = function() {
+                f(id, url);
+            };
+
+            n.onerror = function(e) {
+                _fail(id, e + ": " + url);
+            };
+        }
+    };
+
+    return {
+
+        /**
+         * The number of request required before an automatic purge.
+         * property PURGE_THRESH
+         * @static
+         * @type int
+         * @default 20
+         */
+        PURGE_THRESH: 20,
+
+        /**
+         * Called by the the helper for detecting script load in Safari
+         * @method _finalize
+         * @static
+         * @param id {string} the transaction id
+         * @private
+         */
+        _finalize: function(id) {
+            L.later(0, null, _finish, id);
+        },
+
+        /**
+         * Abort a transaction
+         * @method abort
+         * @static
+         * @param o {string|object} Either the tId or the object returned from
+         * script() or css()
+         */
+        abort: function(o) {
+            var id = (L.isString(o)) ? o : o.tId;
+            var q = queues[id];
+            if (q) {
+                q.aborted = true;
+            }
+        }, 
+
+        /**
+         * Fetches and inserts one or more script nodes into the head
+         * of the current document or the document in a specified window.
+         *
+         * @method script
+         * @static
+         * @param url {string|string[]} the url or urls to the script(s)
+         * @param opts {object} Options: 
+         * <dl>
+         * <dt>onSuccess</dt>
+         * <dd>
+         * callback to execute when the script(s) are finished loading
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>onTimeout</dt>
+         * <dd>
+         * callback to execute when a timeout occurs.
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>onFailure</dt>
+         * <dd>
+         * callback to execute when the script load operation fails
+         * The callback receives an object back with the following
+         * data:
+         * <dl>
+         * <dt>win</dt>
+         * <dd>the window the script(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted successfully</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove any nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>context</dt>
+         * <dd>the execution context for the callbacks</dd>
+         * <dt>win</dt>
+         * <dd>a window other than the one the utility occupies</dd>
+         * <dt>autopurge</dt>
+         * <dd>
+         * setting to true will let the utilities cleanup routine purge 
+         * the script once loaded
+         * </dd>
+         * <dt>data</dt>
+         * <dd>
+         * data that is supplied to the callback when the script(s) are
+         * loaded.
+         * </dd>
+         * <dt>insertBefore</dt>
+         * <dd>node or node id that will become the new node's nextSibling</dd>
+         * </dl>
+         * <dt>charset</dt>
+         * <dd>Node charset, default utf-8</dd>
+         * <dt>timeout</dt>
+         * <dd>Number of milliseconds to wait before aborting and firing the timeout event</dd>
+         * <pre>
+         * &nbsp;&nbsp;Y.Get.script(
+         * &nbsp;&nbsp;["http://yui.yahooapis.com/2.5.2/build/yahoo/yahoo-min.js",
+         * &nbsp;&nbsp;&nbsp;"http://yui.yahooapis.com/2.5.2/build/event/event-min.js"], &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;onSuccess: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;onFailure: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;onTimeout: function(o) &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;&#125;,
+         * &nbsp;&nbsp;&nbsp;&nbsp;data: "foo",
+         * &nbsp;&nbsp;&nbsp;&nbsp;timeout: 10000, // 10 second timeout
+         * &nbsp;&nbsp;&nbsp;&nbsp;context: Y, // make the YUI instance
+         * &nbsp;&nbsp;&nbsp;&nbsp;// win: otherframe // target another window/frame
+         * &nbsp;&nbsp;&nbsp;&nbsp;autopurge: true // allow the utility to choose when to remove the nodes
+         * &nbsp;&nbsp;&#125;);
+         * </pre>
+         * @return {tId: string} an object containing info about the transaction
+         */
+        script: function(url, opts) { 
+            return _queue("script", url, opts); 
+        },
+
+        /**
+         * Fetches and inserts one or more css link nodes into the 
+         * head of the current document or the document in a specified
+         * window.
+         * @method css
+         * @static
+         * @param url {string} the url or urls to the css file(s)
+         * @param opts Options: 
+         * <dl>
+         * <dt>onSuccess</dt>
+         * <dd>
+         * callback to execute when the css file(s) are finished loading
+         * The callback receives an object back with the following
+         * data:
+         * <dl>win</dl>
+         * <dd>the window the link nodes(s) were inserted into</dd>
+         * <dt>data</dt>
+         * <dd>the data object passed in when the request was made</dd>
+         * <dt>nodes</dt>
+         * <dd>An array containing references to the nodes that were
+         * inserted</dd>
+         * <dt>purge</dt>
+         * <dd>A function that, when executed, will remove the nodes
+         * that were inserted</dd>
+         * <dt>
+         * </dl>
+         * </dd>
+         * <dt>context</dt>
+         * <dd>the execution context for the callbacks</dd>
+         * <dt>win</dt>
+         * <dd>a window other than the one the utility occupies</dd>
+         * <dt>data</dt>
+         * <dd>
+         * data that is supplied to the callbacks when the nodes(s) are
+         * loaded.
+         * </dd>
+         * <dt>insertBefore</dt>
+         * <dd>node or node id that will become the new node's nextSibling</dd>
+         * <dt>charset</dt>
+         * <dd>Node charset, default utf-8</dd>
+         * </dl>
+         * <pre>
+         *      Y.Get.css("http://yui.yahooapis.com/2.3.1/build/menu/assets/skins/sam/menu.css");
+         * </pre>
+         * <pre>
+         * &nbsp;&nbsp;Y.Get.css(
+         * &nbsp;&nbsp;["http://yui.yahooapis.com/2.3.1/build/menu/assets/skins/sam/menu.css",
+         * &nbsp;&nbsp;&nbsp;"http://yui.yahooapis.com/2.3.1/build/logger/assets/skins/sam/logger.css"], &#123;
+         * &nbsp;&nbsp;&nbsp;&nbsp;insertBefore: 'custom-styles' // nodes will be inserted before the specified node
+         * &nbsp;&nbsp;&#125;);
+         * </pre>
+         * @return {tId: string} an object containing info about the transaction
+         */
+        css: function(url, opts) {
+            return _queue("css", url, opts); 
+        }
+    };
+}();
+
+}, "3.0.0pr2");
+/**
+ * Loader dynamically loads script and css files.  It includes the dependency
+ * info for the version of the library in use, and will automatically pull in
+ * dependencies for the modules requested.  It supports rollup files and will
+ * automatically use these when appropriate in order to minimize the number of
+ * http connections required to load all of the dependencies.  It can load the
+ * files from the Yahoo! CDN, and it can utilize the combo service provided on
+ * this network to reduce the number of http connections required to download 
+ * YUI files.
+ *
+ * @module yui
+ * @submodule loader
+ */
+
+/**
+ * Loader dynamically loads script and css files.  It includes the dependency
+ * info for the version of the library in use, and will automatically pull in
+ * dependencies for the modules requested.  It supports rollup files and will
+ * automatically use these when appropriate in order to minimize the number of
+ * http connections required to load all of the dependencies.  It can load the
+ * files from the Yahoo! CDN, and it can utilize the combo service provided on
+ * this network to reduce the number of http connections required to download 
+ * YUI files.
+ * @class Loader
+ * @constructor
+ * @param o an optional set of configuration options.  Valid options:
+ * <ul>
+ *  <li>base:
+ *  The base dir</li>
+ *  <li>secureBase:
+ *  The secure base dir (not implemented)</li>
+ *  <li>comboBase:
+ *  The YUI combo service base dir. Ex: http://yui.yahooapis.com/combo?</li>
+ *  <li>root:
+ *  The root path to prepend to module names for the combo service. Ex: 2.5.2/build/</li>
+ *  <li>filter:
+ *  
+ * A filter to apply to result urls.  This filter will modify the default
+ * path for all modules.  The default path for the YUI library is the
+ * minified version of the files (e.g., event-min.js).  The filter property
+ * can be a predefined filter or a custom filter.  The valid predefined 
+ * filters are:
+ * <dl>
+ *  <dt>DEBUG</dt>
+ *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+ *      This option will automatically include the logger widget</dd>
+ *  <dt>RAW</dt>
+ *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+ * </dl>
+ * You can also define a custom filter, which must be an object literal 
+ * containing a search expression and a replace string:
+ * <pre>
+ *  myFilter: &#123; 
+ *      'searchExp': "-min\\.js", 
+ *      'replaceStr': "-debug.js"
+ *  &#125;
+ * </pre>
+ *
+ *  </li>
+ *  <li>combine:
+ *  Use the YUI combo service to reduce the number of http connections required to load your dependencies</li>
+ *  <li>ignore:
+ *  A list of modules that should never be dynamically loaded</li>
+ *  <li>force:
+ *  A list of modules that should always be loaded when required, even if already present on the page</li>
+ *  <li>insertBefore:
+ *  Node or id for a node that should be used as the insertion point for new nodes</li>
+ *  <li>charset:
+ *  charset for dynamic nodes</li>
+ *  <li>timeout:
+ *  number of milliseconds before a timeout occurs when dynamically loading nodes.  in not set, there is no timeout</li>
+ *  <li>context:
+ *  execution context for all callbacks</li>
+ *  <li>onSuccess:
+ *  callback for the 'success' event</li>
+ *  <li>onFailure:
+ *  callback for the 'failure' event</li>
+ *  <li>onTimeout:
+ *  callback for the 'timeout' event</li>
+ *  <li>onProgress:
+ *  callback executed each time a script or css file is loaded</li>
+ *  <li>modules:
+ *  A list of module definitions.  See Loader.addModule for the supported module metadata</li>
+ * </ul>
+ */
+
+// @TODO backed out the custom event changes so that the event system
+// isn't required in the seed build.  If needed, we may want to 
+// add them back if the event system is detected.
+
+/*
+ * Executed when the loader successfully completes an insert operation
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onSuccess config option.
+ * @event success
+ */
+
+/*
+ * Executed when the loader fails to complete an insert operation.
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onFailure config option.
+ *
+ * @event failure
+ */
+
+/*
+ * Executed when a Get operation times out.
+ * This can be subscribed to normally, or a listener can be passed
+ * as an onTimeout config option.
+ *
+ * @event timeout
+ */
+
+// http://yui.yahooapis.com/combo?2.5.2/build/yahoo/yahoo-min.js&2.5.2/build/dom/dom-min.js&2.5.2/build/event/event-min.js&2.5.2/build/autocomplete/autocomplete-min.js"
+
+YUI.add("loader", function(Y) {
+
+var BASE = 'base', 
+    CSS = 'css',
+    JS = 'js',
+    CSSRESET = 'cssreset',
+    CSSFONTS = 'cssfonts',
+    CSSGRIDS = 'cssgrids',
+    CSSBASE = 'cssbase',
+    CSS_AFTER = [CSSRESET, CSSFONTS, CSSGRIDS, 'cssreset-context', 'cssfonts-context', 'cssgrids-context'],
+    YUI_CSS = ['reset', 'fonts', 'grids', 'base'],
+    VERSION = '3.0.0pr2',
+    ROOT = VERSION + '/build/',
+    CONTEXT = '-context',
+    META = {
+
+    version: VERSION,
+
+    root: ROOT,
+
+    base: 'http://yui.yahooapis.com/' + ROOT,
+
+    comboBase: 'http://yui.yahooapis.com/combo?',
+
+    skin: {
+        defaultSkin: 'sam',
+        base: 'assets/skins/',
+        path: 'skin.css',
+        after: ['reset', 'fonts', 'grids', 'base']
+        //rollup: 3
+    },
+
+    modules: {
+
+       dom: {
+            requires: ['event'],
+            submodules: {
+                'dom-base': {
+                    requires: ['event']
+                },
+                'dom-style': {
+                    requires: ['dom-base']
+
+                },
+                'dom-screen': {
+                    requires: ['dom-base', 'dom-style']
+                },
+                selector: {
+                    requires: ['dom-base']
+                }
+            }
+        },
+
+        node: {
+            requires: ['dom'],
+            submodules: {
+                'node-base': {
+                    requires: ['dom-base', 'selector']
+                },
+                'node-style': {
+                    requires: ['dom-style', 'node-base']
+                },
+                'node-screen': {
+                    requires: ['dom-screen', 'node-base']
+                },
+                'node-event-simulate': {
+                    requires: ['node-base']
+                }
+            }
+        },
+
+        anim: {
+            requires: [BASE, 'node'],
+            submodules: {
+                'anim-base': {
+                    requires: ['base', 'node-style']
+                },
+                'anim-color': {
+                    requires: ['anim-base']
+                },
+                'anim-curve': {
+                    requires: ['anim-xy']
+                },
+                'anim-easing': {
+                },
+                'anim-scroll': {
+                    requires: ['anim-base']
+                },
+                'anim-xy': {
+                    requires: ['anim-base', 'node-screen']
+                },
+                'anim-node-plugin': {
+                     requires: ['node', 'anim-base']
+                }
+            }
+        },
+
+        attribute: { 
+            requires: ['event']
+        },
+
+        base: {
+            requires: ['attribute']
+        },
+        
+        compat: { 
+            requires: ['node', 'dump', 'substitute']
+        },
+
+        classnamemanager: { },
+
+        console: {
+            requires: ['widget', 'substitute'],
+            skinnable: true
+        },
+        
+        cookie: { },
+
+        // Note: CSS attributes are modified programmatically to reduce metadata size
+        // cssbase: {
+        //     after: CSS_AFTER
+        // },
+
+        // cssgrids: {
+        //     requires: [CSSFONTS],
+        //     optional: [CSSRESET]
+        // },
+
+        dd:{
+            submodules: {
+                'dd-ddm-base': {
+                    requires: ['node', BASE]
+                }, 
+                'dd-ddm':{
+                    requires: ['dd-ddm-base']
+                }, 
+                'dd-ddm-drop':{
+                    requires: ['dd-ddm']
+                }, 
+                'dd-drag':{
+                    requires: ['dd-ddm-base']
+                }, 
+                'dd-drop':{
+                    requires: ['dd-ddm-drop']
+                }, 
+                'dd-proxy':{
+                    requires: ['dd-drag']
+                }, 
+                'dd-constrain':{
+                    requires: ['dd-drag', 'dd-proxy']
+                }, 
+                'dd-plugin':{
+                    requires: ['dd-drag'],
+                    optional: ['dd-constrain', 'dd-proxy']
+                },
+                'dd-drop-plugin':{
+                    requires: ['dd-drop']
+                }
+            }
+        },
+
+        dump: { },
+
+        event: { 
+            requires: ['oop']
+        },
+
+        get: { 
+            requires: ['yui-base']
+        },
+        
+        io:{
+            submodules: {
+
+                'io-base': {
+                    requires: ['node']
+                }, 
+
+                'io-xdr': {
+                    requires: ['io-base']
+                }, 
+
+                'io-form': {
+                    requires: ['io-base']
+                }, 
+
+                'io-upload-iframe': {
+                    requires: ['io-base']
+                },
+
+                'io-queue': {
+                    requires: ['io-base']
+                }
+            }
+        },
+
+        json: {
+            submodules: {
+                'json-parse': {
+                },
+
+                'json-stringify': {
+                }
+            }
+        },
+
+        loader: { 
+            requires: ['get']
+        },
+
+        'node-menunav': {
+            requires: ['node', 'classnamemanager'],
+            skinnable: true
+        },
+        
+        oop: { 
+            requires: ['yui-base']
+        },
+
+        overlay: {
+            requires: ['widget', 'widget-position', 'widget-position-ext', 'widget-stack', 'widget-stdmod'],
+            skinnable: true
+        },
+
+        plugin: { 
+            requires: ['base']
+        },
+
+        profiler: { },
+
+        queue: {
+            requires: ['node']
+        },
+
+        slider: {
+            requires: ['widget', 'dd-constrain'],
+            skinnable: true
+        },
+
+        stylesheet: { },
+
+        substitute: {
+            optional: ['dump']
+        },
+
+        widget: {
+            requires: ['base', 'node', 'classnamemanager'],
+            plugins: {
+                'widget-position': { },
+                'widget-position-ext': {
+                    requires: ['widget-position']
+                },
+                'widget-stack': {
+                    skinnable: true
+                },
+                'widget-stdmod': { }
+            },
+            skinnable: true
+        },
+
+        // Since YUI is required for everything else, it should not be specified as
+        // a dependency.
+        yui: {
+            supersedes: ['yui-base', 'get', 'loader']
+        },
+
+        'yui-base': { },
+
+        yuitest: {                                                                                                                                                        
+            requires: ['substitute', 'node', 'json']                                                                                                                     
+        }  
+
+    }
+};
+
+var _path = function(dir, file, type) {
+    return dir + '/' + file + '-min.' + (type || CSS);
+};
+
+var _cssmeta = function() {
+    var mods = META.modules;
+    // modify the meta info for YUI CSS
+    for (var i=0; i<YUI_CSS.length; i=i+1) {
+        var bname = YUI_CSS[i],
+            mname = CSS + bname;
+
+        mods[mname] = {
+            type: CSS,
+            path: _path(mname, bname)
+        };
+
+        // define -context module
+        var contextname = mname + CONTEXT;
+        bname = bname + CONTEXT;
+
+        mods[contextname] = {
+            type: CSS,
+            path: _path(mname, bname)
+        };
+
+        if (mname == CSSGRIDS) {
+            mods[mname].requires = [CSSFONTS];
+            mods[mname].optional = [CSSRESET];
+            mods[contextname].requires = [CSSFONTS + CONTEXT];
+            mods[contextname].optional = [CSSRESET + CONTEXT];
+        } else if (mname == CSSBASE) {
+            mods[mname].after = CSS_AFTER;
+            mods[contextname].after = CSS_AFTER;
+        }
+    }
+}();
+
+Y.Env.meta = META;
+
+
+    var L=Y.Lang, env=Y.Env,
+        PROV = "_provides", SUPER = "_supersedes",
+        REQ = "expanded";
+
+    Y.Loader = function(o) {
+
+        /**
+         * Internal callback to handle multiple internal insert() calls
+         * so that css is inserted prior to js
+         * @property _internalCallback
+         * @private
+         */
+        this._internalCallback = null;
+
+        /**
+         * Use the YUI environment listener to detect script load.  This
+         * is only switched on for Safari 2.x and below.
+         * @property _useYahooListener
+         * @private
+         */
+        this._useYahooListener = false;
+
+        /**
+         * Callback that will be executed when the loader is finished
+         * with an insert
+         * @method onSuccess
+         * @type function
+         */
+        this.onSuccess = null;
+
+        /**
+         * Callback that will be executed if there is a failure
+         * @method onFailure
+         * @type function
+         */
+        this.onFailure = null;
+
+        /**
+         * Callback executed each time a script or css file is loaded
+         * @method onProgress
+         * @type function
+         */
+        this.onProgress = null;
+
+        /**
+         * Callback that will be executed if a timeout occurs
+         * @method onTimeout
+         * @type function
+         */
+        this.onTimeout = null;
+
+        /**
+         * The execution context for all callbacks
+         * @property context
+         * @default {YUI} the YUI instance
+         */
+        this.context = Y;
+
+        /**
+         * Data that is passed to all callbacks
+         * @property data
+         */
+        this.data = null;
+
+        /**
+         * Node reference or id where new nodes should be inserted before
+         * @property insertBefore
+         * @type string|HTMLElement
+         */
+        this.insertBefore = null;
+
+        /**
+         * The charset attribute for inserted nodes
+         * @property charset
+         * @type string
+         * @default utf-8
+         */
+        this.charset = null;
+
+        /**
+         * The base directory.
+         * @property base
+         * @type string
+         * @default http://yui.yahooapis.com/[YUI VERSION]/build/
+         */
+        this.base = Y.Env.meta.base;
+
+        /**
+         * Base path for the combo service
+         * @property comboBase
+         * @type string
+         * @default http://yui.yahooapis.com/combo?
+         */
+        this.comboBase = Y.Env.meta.comboBase;
+
+        /**
+         * If configured, YUI JS resources will use the combo
+         * handler
+         * @property combine
+         * @type boolean
+         * @default true if a base dir isn't in the config
+         */
+        this.combine = (!(BASE in o));
+
+        /**
+         * Ignore modules registered on the YUI global
+         * @property ignoreRegistered
+         * @default false
+         */
+        this.ignoreRegistered = false;
+
+        /**
+         * Root path to prepend to module path for the combo
+         * service
+         * @property root
+         * @type string
+         * @default [YUI VERSION]/build/
+         */
+        this.root = Y.Env.meta.root;
+
+        /**
+         * Timeout value in milliseconds.  If set, this value will be used by
+         * the get utility.  the timeout event will fire if
+         * a timeout occurs.
+         * @property timeout
+         * @type int
+         */
+        this.timeout = 0;
+
+        /**
+         * A list of modules that should not be loaded, even if
+         * they turn up in the dependency tree
+         * @property ignore
+         * @type string[]
+         */
+        this.ignore = null;
+
+        /**
+         * A list of modules that should always be loaded, even
+         * if they have already been inserted into the page.
+         * @property force
+         * @type string[]
+         */
+        this.force = null;
+
+        /**
+         * Should we allow rollups
+         * @property allowRollup
+         * @type boolean
+         * @default true
+         */
+        this.allowRollup = true;
+
+        /**
+         * A filter to apply to result urls.  This filter will modify the default
+         * path for all modules.  The default path for the YUI library is the
+         * minified version of the files (e.g., event-min.js).  The filter property
+         * can be a predefined filter or a custom filter.  The valid predefined 
+         * filters are:
+         * <dl>
+         *  <dt>DEBUG</dt>
+         *  <dd>Selects the debug versions of the library (e.g., event-debug.js).
+         *      This option will automatically include the logger widget</dd>
+         *  <dt>RAW</dt>
+         *  <dd>Selects the non-minified version of the library (e.g., event.js).</dd>
+         * </dl>
+         * You can also define a custom filter, which must be an object literal 
+         * containing a search expression and a replace string:
+         * <pre>
+         *  myFilter: &#123; 
+         *      'searchExp': "-min\\.js", 
+         *      'replaceStr': "-debug.js"
+         *  &#125;
+         * </pre>
+         * @property filter
+         * @type string|{searchExp: string, replaceStr: string}
+         */
+        this.filter = null;
+
+        /**
+         * The list of requested modules
+         * @property required
+         * @type {string: boolean}
+         */
+        this.required = {};
+
+        /**
+         * The library metadata
+         * @property moduleInfo
+         */
+        // this.moduleInfo = Y.merge(Y.Env.meta.moduleInfo);
+        this.moduleInfo = {};
+
+        /**
+         * Provides the information used to skin the skinnable components.
+         * The following skin definition would result in 'skin1' and 'skin2'
+         * being loaded for calendar (if calendar was requested), and
+         * 'sam' for all other skinnable components:
+         *
+         *   <code>
+         *   skin: {
+         *
+         *      // The default skin, which is automatically applied if not
+         *      // overriden by a component-specific skin definition.
+         *      // Change this in to apply a different skin globally
+         *      defaultSkin: 'sam', 
+         *
+         *      // This is combined with the loader base property to get
+         *      // the default root directory for a skin. ex:
+         *      // http://yui.yahooapis.com/2.3.0/build/assets/skins/sam/
+         *      base: 'assets/skins/',
+         *
+         *      // The name of the rollup css file for the skin
+         *      path: 'skin.css',
+         *
+         *      // The number of skinnable components requested that are
+         *      // required before using the rollup file rather than the
+         *      // individual component css files
+         *      rollup: 3,
+         *
+         *      // Any component-specific overrides can be specified here,
+         *      // making it possible to load different skins for different
+         *      // components.  It is possible to load more than one skin
+         *      // for a given component as well.
+         *      overrides: {
+         *          calendar: ['skin1', 'skin2']
+         *      }
+         *   }
+         *   </code>
+         *   @property skin
+         */
+         this.skin = Y.merge(Y.Env.meta.skin);
+        
+        var defaults = Y.Env.meta.modules;
+
+        for (var i in defaults) {
+            if (defaults.hasOwnProperty(i)) {
+                this._internal = true;
+                this.addModule(defaults[i], i);
+                this._internal = false;
+            }
+        }
+
+        /**
+         * List of rollup files found in the library metadata
+         * @property rollups
+         */
+        this.rollups = null;
+
+        /**
+         * Whether or not to load optional dependencies for 
+         * the requested modules
+         * @property loadOptional
+         * @type boolean
+         * @default false
+         */
+        this.loadOptional = false;
+
+        /**
+         * All of the derived dependencies in sorted order, which
+         * will be populated when either calculate() or insert()
+         * is called
+         * @property sorted
+         * @type string[]
+         */
+        this.sorted = [];
+
+        /**
+         * Set when beginning to compute the dependency tree. 
+         * Composed of what YUI reports to be loaded combined
+         * with what has been loaded by the tool
+         * @propery loaded
+         * @type {string: boolean}
+         */
+        this.loaded = {};
+
+        /**
+         * A list of modules to attach to the YUI instance when complete.
+         * If not supplied, the sorted list of dependencies are applied.
+         * @property attaching
+         */
+        this.attaching = null;
+
+        /**
+         * Flag to indicate the dependency tree needs to be recomputed
+         * if insert is called again.
+         * @property dirty
+         * @type boolean
+         * @default true
+         */
+        this.dirty = true;
+
+        /**
+         * List of modules inserted by the utility
+         * @property inserted
+         * @type {string: boolean}
+         */
+        this.inserted = {};
+
+        this.skipped = {};
+
+
+        // Y.on('yui:load', this.loadNext, this);
+
+        this._config(o);
+
+    };
+
+    Y.Loader.prototype = {
+
+        FILTERS: {
+            RAW: { 
+                'searchExp': "-min\\.js", 
+                'replaceStr': ".js"
+            },
+            DEBUG: { 
+                'searchExp': "-min\\.js", 
+                'replaceStr': "-debug.js"
+            }
+        },
+
+        SKIN_PREFIX: "skin-",
+
+        _config: function(o) {
+
+            // apply config values
+            if (o) {
+                for (var i in o) {
+                    if (o.hasOwnProperty(i)) {
+                        var val = o[i];
+                        if (i == 'require') {
+                            this.require(val);
+                        } else if (i == 'modules') {
+
+                            // add a hash of module definitions
+                            for (var j in val) {
+                                if (val.hasOwnProperty(j)) {
+                                    this.addModule(val[j], j);
+                                }
+                            }
+
+                        } else {
+                            this[i] = val;
+                        }
+                    }
+                }
+            }
+
+            // fix filter
+            var f = this.filter;
+
+            if (L.isString(f)) {
+                f = f.toUpperCase();
+                this.filterName = f;
+                this.filter = this.FILTERS[f];
+            }
+
+        },
+
+        /**
+         * Returns the skin module name for the specified skin name.  If a
+         * module name is supplied, the returned skin module name is 
+         * specific to the module passed in.
+         * @method formatSkin
+         * @param skin {string} the name of the skin
+         * @param mod {string} optional: the name of a module to skin
+         * @return {string} the full skin module name
+         */
+        formatSkin: function(skin, mod) {
+            var s = this.SKIN_PREFIX + skin;
+            if (mod) {
+                s = s + "-" + mod;
+            }
+
+            return s;
+        },
+
+        /**
+         * Reverses <code>formatSkin</code>, providing the skin name and
+         * module name if the string matches the pattern for skins.
+         * @method parseSkin
+         * @param mod {string} the module name to parse
+         * @return {skin: string, module: string} the parsed skin name 
+         * and module name, or null if the supplied string does not match
+         * the skin pattern
+         */
+        parseSkin: function(mod) {
+            
+            if (mod.indexOf(this.SKIN_PREFIX) === 0) {
+                var a = mod.split("-");
+                return {skin: a[1], module: a[2]};
+            } 
+
+            return null;
+        },
+
+        /**
+         * Adds the skin def to the module info
+         * @method _addSkin
+         * @param skin {string} the name of the skin
+         * @param mod {string} the name of the module
+         * @param parent {string} parent module if this is a skin of a
+         * submodule or plugin
+         * @return {string} the module name for the skin
+         * @private
+         */
+        _addSkin: function(skin, mod, parent) {
+
+            var name = this.formatSkin(skin), info = this.moduleInfo,
+                sinf = this.skin, ext = info[mod] && info[mod].ext;
+
+            /*
+            // Add a module definition for the skin rollup css
+            if (!info[name]) {
+                this.addModule({
+                    'name': name,
+                    'type': 'css',
+                    'path': sinf.base + skin + '/' + sinf.path,
+                    //'supersedes': '*',
+                    'after': sinf.after,
+                    'rollup': sinf.rollup,
+                    'ext': ext
+                });
+            }
+            */
+
+            // Add a module definition for the module-specific skin css
+            if (mod) {
+                name = this.formatSkin(skin, mod);
+                if (!info[name]) {
+                    var mdef = info[mod], pkg = mdef.pkg || mod;
+                    this.addModule({
+                        'name': name,
+                        'type': 'css',
+                        'after': sinf.after,
+                        'path': (parent || pkg) + '/' + sinf.base + skin + '/' + mod + '.css',
+                        'ext': ext
+                    });
+                }
+            }
+
+            return name;
+        },
+
+        /** Add a new module to the component metadata.         
+         * <dl>
+         *     <dt>name:</dt>       <dd>required, the component name</dd>
+         *     <dt>type:</dt>       <dd>required, the component type (js or css)</dd>
+         *     <dt>path:</dt>       <dd>required, the path to the script from "base"</dd>
+         *     <dt>requires:</dt>   <dd>array of modules required by this component</dd>
+         *     <dt>optional:</dt>   <dd>array of optional modules for this component</dd>
+         *     <dt>supersedes:</dt> <dd>array of the modules this component replaces</dd>
+         *     <dt>after:</dt>      <dd>array of modules the components which, if present, should be sorted above this one</dd>
+         *     <dt>rollup:</dt>     <dd>the number of superseded modules required for automatic rollup</dd>
+         *     <dt>fullpath:</dt>   <dd>If fullpath is specified, this is used instead of the configured base + path</dd>
+         *     <dt>skinnable:</dt>  <dd>flag to determine if skin assets should automatically be pulled in</dd>
+         *     <dt>submodules:</dt> <dd>a has of submodules</dd>
+         * </dl>
+         * @method addModule
+         * @param o An object containing the module data
+         * @param name the module name (optional), required if not in the module data
+         * @return {boolean} true if the module was added, false if 
+         * the object passed in did not provide all required attributes
+         */
+        addModule: function(o, name) {
+
+            name = name || o.name;
+            o.name = name;
+
+            if (!o || !o.name) {
+                return false;
+            }
+
+            if (!o.type) {
+                o.type = JS;
+            }
+
+            if (!o.path && !o.fullpath) {
+                // o.path = name + "/" + name + "-min." + o.type;
+                o.path = _path(name, name, o.type);
+            }
+
+            o.ext = ('ext' in o) ? o.ext : (this._internal) ? false : true;
+            o.requires = o.requires || [];
+
+
+            this.moduleInfo[name] = o;
+
+            // Handle submodule logic
+            var subs = o.submodules, i;
+            if (subs) {
+                var sup = [], l=0;
+
+                for (i in subs) {
+                    if (subs.hasOwnProperty(i)) {
+                        var s = subs[i];
+                        s.path = _path(name, i, o.type);
+                        this.addModule(s, i);
+                        sup.push(i);
+
+                        if (o.skinnable) {
+                            var smod = this._addSkin(this.skin.defaultSkin, i, name);
+                            sup.push(smod.name);
+                        }
+
+                        l++;
+                    }
+                }
+
+                o.supersedes = sup;
+                o.rollup = Math.min(l-1, 4);
+            }
+
+            var plugins = o.plugins;
+            if (plugins) {
+                for (i in plugins) {
+                    if (plugins.hasOwnProperty(i)) {
+                        var plug = plugins[i];
+                        plug.path = _path(name, i, o.type);
+                        plug.requires = plug.requires || [];
+                        plug.requires.push(name);
+                        this.addModule(plug, i);
+                        if (o.skinnable) {
+                            this._addSkin(this.skin.defaultSkin, i, name);
+                        }
+                    }
+                }
+            }
+
+            this.dirty = true;
+
+            return o;
+        },
+
+        /**
+         * Add a requirement for one or more module
+         * @method require
+         * @param what {string[] | string*} the modules to load
+         */
+        require: function(what) {
+            var a = (typeof what === "string") ? arguments : what;
+            this.dirty = true;
+            Y.mix(this.required, Y.Array.hash(a));
+        },
+
+        /**
+         * Returns an object containing properties for all modules required
+         * in order to load the requested module
+         * @method getRequires
+         * @param mod The module definition from moduleInfo
+         */
+        getRequires: function(mod) {
+
+            if (!mod) {
+                return [];
+            }
+
+            if (!this.dirty && mod.expanded) {
+                return mod.expanded;
+            }
+
+            var i, d=[], r=mod.requires, o=mod.optional, 
+                info=this.moduleInfo, m, j, add;
+
+            for (i=0; i<r.length; i=i+1) {
+                d.push(r[i]);
+                m = this.getModule(r[i]);
+                add = this.getRequires(m);
+                for (j=0;j<add.length;j=j+1) {
+                    d.push(add[j]);
+                }
+            }
+
+            // get the requirements from superseded modules, if any
+            r=mod.supersedes;
+            if (r) {
+                for (i=0; i<r.length; i=i+1) {
+                    d.push(r[i]);
+                    m = this.getModule(r[i]);
+                    add = this.getRequires(m);
+                    for (j=0;j<add.length;j=j+1) {
+                        d.push(add[j]);
+                    }
+                }
+            }
+
+            if (o && this.loadOptional) {
+                for (i=0; i<o.length; i=i+1) {
+                    d.push(o[i]);
+                    add = this.getRequires(info[o[i]]);
+                    for (j=0;j<add.length;j=j+1) {
+                        d.push(add[j]);
+                    }
+                }
+            }
+
+            mod.expanded = Y.Object.keys(Y.Array.hash(d));
+
+
+            return mod.expanded;
+        },
+
+
+        /**
+         * Returns an object literal of the modules the supplied module satisfies
+         * @method getProvides
+         * @param name{string} The name of the module
+         * @param notMe {string} don't add this module name, only include superseded modules
+         * @return what this module provides
+         */
+        getProvides: function(name, notMe) {
+            var addMe = !(notMe), ckey = (addMe) ? PROV : SUPER,
+                m = this.getModule(name), o = {};
+
+            if (!m) {
+                return o;
+            }
+
+            if (m[ckey]) {
+                return m[ckey];
+            }
+
+            var s = m.supersedes, done={}, me = this;
+
+            // use worker to break cycles
+            var add = function(mm) {
+                if (!done[mm]) {
+                    done[mm] = true;
+                    // we always want the return value normal behavior 
+                    // (provides) for superseded modules.
+                    Y.mix(o, me.getProvides(mm));
+                } 
+                
+                // else {
+                // }
+            };
+
+            // calculate superseded modules
+            if (s) {
+                for (var i=0; i<s.length; i=i+1) {
+                    add(s[i]);
+                }
+            }
+
+            // supersedes cache
+            m[SUPER] = o;
+            // provides cache
+            m[PROV] = Y.merge(o);
+            m[PROV][name] = true;
+
+
+            return m[ckey];
+        },
+
+
+        /**
+         * Calculates the dependency tree, the result is stored in the sorted 
+         * property
+         * @method calculate
+         * @param o optional options object
+         */
+        calculate: function(o) {
+            if (o || this.dirty) {
+                this._config(o);
+                this._setup();
+                this._explode();
+                if (this.allowRollup) {
+                    this._rollup();
+                }
+                this._reduce();
+                this._sort();
+
+
+                this.dirty = false;
+            }
+        },
+
+        /**
+         * Investigates the current YUI configuration on the page.  By default,
+         * modules already detected will not be loaded again unless a force
+         * option is encountered.  Called by calculate()
+         * @method _setup
+         * @private
+         */
+        _setup: function() {
+
+            var info = this.moduleInfo, name, i, j;
+
+            // Create skin modules
+            for (name in info) {
+                if (info.hasOwnProperty(name)) {
+                    var m = info[name];
+                    if (m && m.skinnable) {
+                        var o=this.skin.overrides, smod;
+                        if (o && o[name]) {
+                            for (i=0; i<o[name].length; i=i+1) {
+                                smod = this._addSkin(o[name][i], name);
+                            }
+                        } else {
+                            smod = this._addSkin(this.skin.defaultSkin, name);
+                        }
+
+                        m.requires.push(smod);
+                    }
+                }
+            }
+
+            var l = Y.merge(this.inserted); // shallow clone
+
+            // available modules
+            if (!this.ignoreRegistered) {
+                Y.mix(l, YUI.Env.mods);
+            }
+            
+
+            // add the ignore list to the list of loaded packages
+            if (this.ignore) {
+                // OU.appendArray(l, this.ignore);
+                Y.mix(l, Y.Array.hash(this.ignore));
+            }
+
+            // expand the list to include superseded modules
+            for (j in l) {
+                if (l.hasOwnProperty(j)) {
+                    Y.mix(l, this.getProvides(j));
+                }
+            }
+
+            // remove modules on the force list from the loaded list
+            if (this.force) {
+                for (i=0; i<this.force.length; i=i+1) {
+                    if (this.force[i] in l) {
+                        delete l[this.force[i]];
+                    }
+                }
+            }
+
+
+            this.loaded = l;
+
+        },
+        
+
+        /**
+         * Inspects the required modules list looking for additional 
+         * dependencies.  Expands the required list to include all 
+         * required modules.  Called by calculate()
+         * @method _explode
+         * @private
+         */
+        _explode: function() {
+
+            var r=this.required, i, mod;
+
+            for (i in r) {
+                if (r.hasOwnProperty(i)) {
+                    mod = this.getModule(i);
+
+                    var req = this.getRequires(mod);
+
+                    if (req) {
+                        Y.mix(r, Y.Array.hash(req));
+                    }
+                }
+            }
+        },
+
+        getModule: function(name) {
+
+            var m = this.moduleInfo[name];
+
+            // create the default module
+            // if (!m) {
+                // m = this.addModule({ext: false}, name);
+            // }
+
+            return m;
+        },
+
+        /**
+         * Look for rollup packages to determine if all of the modules a
+         * rollup supersedes are required.  If so, include the rollup to
+         * help reduce the total number of connections required.  Called
+         * by calculate()
+         * @method _rollup
+         * @private
+         */
+        _rollup: function() {
+            var i, j, m, s, rollups={}, r=this.required, roll,
+                info = this.moduleInfo;
+
+            // find and cache rollup modules
+            if (this.dirty || !this.rollups) {
+                for (i in info) {
+                    if (info.hasOwnProperty(i)) {
+                        m = this.getModule(i);
+                        // if (m && m.rollup && m.supersedes) {
+                        if (m && m.rollup) {
+                            rollups[i] = m;
+                        }
+                    }
+                }
+
+                this.rollups = rollups;
+            }
+
+            // make as many passes as needed to pick up rollup rollups
+            for (;;) {
+                var rolled = false;
+
+                // go through the rollup candidates
+                for (i in rollups) { 
+
+                    if (rollups.hasOwnProperty(i)) {
+
+                        // there can be only one
+                        if (!r[i] && !this.loaded[i]) {
+                            m =this.getModule(i); s = m.supersedes ||[]; roll=false;
+
+                            if (!m.rollup) {
+                                continue;
+                            }
+
+                            var c=0;
+
+                            // check the threshold
+                            for (j=0;j<s.length;j=j+1) {
+
+                                // if the superseded module is loaded, we can't load the rollup
+                                // if (this.loaded[s[j]] && (!_Y.dupsAllowed[s[j]])) {
+                                if (this.loaded[s[j]]) {
+                                    roll = false;
+                                    break;
+                                // increment the counter if this module is required.  if we are
+                                // beyond the rollup threshold, we will use the rollup module
+                                } else if (r[s[j]]) {
+                                    c++;
+                                    roll = (c >= m.rollup);
+                                    if (roll) {
+                                        break;
+                                    }
+                                }
+                            }
+
+                            if (roll) {
+                                // add the rollup
+                                r[i] = true;
+                                rolled = true;
+
+                                // expand the rollup's dependencies
+                                this.getRequires(m);
+                            }
+                        }
+                    }
+                }
+
+                // if we made it here w/o rolling up something, we are done
+                if (!rolled) {
+                    break;
+                }
+            }
+        },
+
+        /**
+         * Remove superceded modules and loaded modules.  Called by
+         * calculate() after we have the mega list of all dependencies
+         * @method _reduce
+         * @private
+         */
+        _reduce: function() {
+
+            var i, j, s, m, r=this.required;
+            for (i in r) {
+
+                if (r.hasOwnProperty(i)) {
+
+                    // remove if already loaded
+                    if (i in this.loaded) { 
+                        delete r[i];
+
+                    // remove anything this module supersedes
+                    } else {
+
+                         m = this.getModule(i);
+                         s = m && m.supersedes;
+                         if (s) {
+                             for (j=0; j<s.length; j=j+1) {
+                                 if (s[j] in r) {
+                                     delete r[s[j]];
+                                 }
+                             }
+                         }
+                    }
+                }
+            }
+        },
+
+        _attach: function() {
+
+            // this is the full list of items the YUI needs attached,
+            // which is needed if some dependencies are already on
+            // the page without their dependencies.
+            if (this.attaching) {
+                Y._attach(this.attaching);
+            } else {
+                Y._attach(this.sorted);
+            }
+
+            this._pushEvents();
+
+        },
+
+        _onSuccess: function() {
+
+            this._attach();
+
+            var skipped = this.skipped;
+
+            for (var i in skipped) {
+                if (skipped.hasOwnProperty(i)) {
+                    delete this.inserted[i];
+                }
+            }
+
+            this.skipped = {};
+
+            // this.fire('success', {
+            //     data: this.data
+            // });
+
+            var f = this.onSuccess;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'success',
+                    data: this.data,
+                    success: true
+                });
+            }
+
+        },
+
+        _onFailure: function(msg) {
+            this._attach();
+            // this.fire('failure', {
+            //     msg: 'operation failed: ' + msg,
+            //     data: this.data
+            // });
+
+            var f = this.onFailure;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'failure: ' + msg,
+                    data: this.data,
+                    success: false
+                });
+            }
+        },
+
+        _onTimeout: function() {
+            this._attach();
+
+            // this.fire('timeout', {
+            //     data: this.data
+            // });
+
+            var f = this.onTimeout;
+            if (f) {
+                f.call(this.context, {
+                    msg: 'timeout',
+                    data: this.data,
+                    success: false
+                });
+            }
+        },
+        
+        /**
+         * Sorts the dependency tree.  The last step of calculate()
+         * @method _sort
+         * @private
+         */
+        _sort: function() {
+            // create an indexed list
+            var s=Y.Object.keys(this.required), info=this.moduleInfo, loaded=this.loaded,
+                me = this;
+
+            // returns true if b is not loaded, and is required
+            // directly or by means of modules it supersedes.
+            var requires = function(aa, bb) {
+
+                var mm=info[aa];
+
+                if (loaded[bb] || !mm) {
+                    return false;
+                }
+
+                var ii, rr = mm.expanded, 
+                    after = mm.after, other=info[bb];
+
+                // check if this module requires the other directly
+                if (rr && Y.Array.indexOf(rr, bb) > -1) {
+                    return true;
+                }
+
+                // check if this module should be sorted after the other
+                if (after && Y.Array.indexOf(after, bb) > -1) {
+                    return true;
+                }
+
+                // check if this module requires one the other supersedes
+                var ss=info[bb] && info[bb].supersedes;
+                if (ss) {
+                    for (ii=0; ii<ss.length; ii=ii+1) {
+                        if (requires(aa, ss[ii])) {
+                            return true;
+                        }
+                    }
+                }
+
+                // external css files should be sorted below yui css
+                if (mm.ext && mm.type == CSS && !other.ext && other.type == CSS) {
+                    return true;
+                }
+
+                return false;
+            };
+
+            // pointer to the first unsorted item
+            var p=0; 
+
+            // keep going until we make a pass without moving anything
+            for (;;) {
+               
+                var l=s.length, a, b, j, k, moved=false;
+
+                // start the loop after items that are already sorted
+                for (j=p; j<l; j=j+1) {
+
+                    // check the next module on the list to see if its
+                    // dependencies have been met
+                    a = s[j];
+
+                    // check everything below current item and move if we
+                    // find a requirement for the current item
+                    for (k=j+1; k<l; k=k+1) {
+                        if (requires(a, s[k])) {
+
+                            // extract the dependency so we can move it up
+                            b = s.splice(k, 1);
+
+                            // insert the dependency above the item that 
+                            // requires it
+                            s.splice(j, 0, b[0]);
+
+                            moved = true;
+                            break;
+                        }
+                    }
+
+                    // jump out of loop if we moved something
+                    if (moved) {
+                        break;
+                    // this item is sorted, move our pointer and keep going
+                    } else {
+                        p = p + 1;
+                    }
+                }
+
+                // when we make it here and moved is false, we are 
+                // finished sorting
+                if (!moved) {
+                    break;
+                }
+
+            }
+
+            this.sorted = s;
+        },
+
+        /**
+         * inserts the requested modules and their dependencies.  
+         * <code>type</code> can be "js" or "css".  Both script and 
+         * css are inserted if type is not provided.
+         * @method insert
+         * @param o optional options object
+         * @param type {string} the type of dependency to insert
+         */
+        insert: function(o, type) {
+
+
+            // build the dependency list
+            this.calculate(o);
+
+            if (!type) {
+                var self = this;
+                this._internalCallback = function() {
+                            self._internalCallback = null;
+                            self.insert(null, JS);
+                        };
+                this.insert(null, CSS);
+                return;
+            }
+
+            // set a flag to indicate the load has started
+            this._loading = true;
+
+            // flag to indicate we are done with the combo service
+            // and any additional files will need to be loaded
+            // individually
+            this._combineComplete = {};
+
+            // keep the loadType (js, css or undefined) cached
+            this.loadType = type;
+
+            // start the load
+            this.loadNext();
+
+        },
+
+        /**
+         * Executed every time a module is loaded, and if we are in a load
+         * cycle, we attempt to load the next script.  Public so that it
+         * is possible to call this if using a method other than
+         * Y.register to determine when scripts are fully loaded
+         * @method loadNext
+         * @param mname {string} optional the name of the module that has
+         * been loaded (which is usually why it is time to load the next
+         * one)
+         */
+        loadNext: function(mname) {
+
+            // It is possible that this function is executed due to something
+            // else one the page loading a YUI module.  Only react when we
+            // are actively loading something
+            if (!this._loading) {
+                return;
+            }
+
+            var s, len, i, m, url, self=this, type=this.loadType, fn;
+
+            // @TODO this will need to handle the two phase insert when
+            // CSS support is added
+            if (this.combine && (!this._combineComplete[type])) {
+
+                this._combining = []; 
+                s=this.sorted;
+                len=s.length;
+                url=this.comboBase;
+
+                for (i=0; i<len; i=i+1) {
+                    m = this.getModule(s[i]);
+// @TODO we can't combine CSS yet until we deliver files with absolute paths to the assets
+                    // Do not try to combine non-yui JS
+                    if (m && m.type === this.loadType && !m.ext) {
+                        url += this.root + m.path;
+                        if (i < len-1) {
+                            url += '&';
+                        }
+
+                        this._combining.push(s[i]);
+                    }
+                }
+
+                if (this._combining.length) {
+
+
+                    var callback=function(o) {
+                        this._combineComplete[type] = true;
+
+
+                        var c=this._combining, len=c.length, i, m;
+                        for (i=0; i<len; i=i+1) {
+                            this.inserted[c[i]] = true;
+                        }
+
+                        this.loadNext(o.data);
+                    };
+
+                    fn =(type === CSS) ? Y.Get.css : Y.Get.script;
+
+                    // @TODO get rid of the redundant Get code
+                    fn(this._filter(url), {
+                        data: this._loading,
+                        onSuccess: callback,
+                        onFailure: this._onFailure,
+                        onTimeout: this._onTimeout,
+                        insertBefore: this.insertBefore,
+                        charset: this.charset,
+                        timeout: this.timeout,
+                        context: self 
+                    });
+
+                    return;
+
+                } else {
+                    this._combineComplete[type] = true;
+                }
+            }
+
+            if (mname) {
+
+                // if the module that was just loaded isn't what we were expecting,
+                // continue to wait
+                if (mname !== this._loading) {
+                    return;
+                }
+
+
+                // The global handler that is called when each module is loaded
+                // will pass that module name to this function.  Storing this
+                // data to avoid loading the same module multiple times
+                this.inserted[mname] = true;
+
+                // this.fire('progress', {
+                //     name: mname,
+                //     data: this.data
+                // });
+                if (this.onProgress) {
+                    this.onProgress.call(this.context, {
+                            name: mname,
+                            data: this.data
+                        });
+                }
+
+
+            }
+
+            s=this.sorted;
+            len=s.length;
+
+            for (i=0; i<len; i=i+1) {
+
+                // this.inserted keeps track of what the loader has loaded.
+                // move on if this item is done.
+                if (s[i] in this.inserted) {
+                    continue;
+                }
+
+                // Because rollups will cause multiple load notifications
+                // from Y, loadNext may be called multiple times for
+                // the same module when loading a rollup.  We can safely
+                // skip the subsequent requests
+                if (s[i] === this._loading) {
+                    return;
+                }
+
+                // log("inserting " + s[i]);
+                m = this.getModule(s[i]);
+
+                if (!m) {
+
+                    var msg = "Undefined module " + s[i] + " skipped";
+                    this.inserted[s[i]] = true;
+                    this.skipped[s[i]] = true;
+                    continue;
+
+                    // this.fire('failure', {
+                        // msg: msg,
+                        // data: this.data
+                    // });
+                }
+
+
+                // The load type is stored to offer the possibility to load
+                // the css separately from the script.
+                if (!type || type === m.type) {
+                    this._loading = s[i];
+
+                    fn = (m.type === CSS) ? Y.Get.css : Y.Get.script;
+
+                    var onsuccess=function(o) {
+                            self.loadNext(o.data);
+                        };
+                        
+                    url = (m.fullpath) ? this._filter(m.fullpath) : this._url(m.path, s[i]);
+
+                    self = this; 
+
+                    fn(url, {
+                        data: s[i],
+                        onSuccess: onsuccess,
+                        insertBefore: this.insertBefore,
+                        charset: this.charset,
+                        onFailure: this._onFailure,
+                        onTimeout: this._onTimeout,
+                        timeout: this.timeout,
+                        context: self 
+                    });
+
+                    return;
+                }
+            }
+
+            // we are finished
+            this._loading = null;
+
+            fn = this._internalCallback;
+
+            // internal callback for loading css first
+            if (fn) {
+                this._internalCallback = null;
+                fn.call(this);
+
+            // } else if (this.onSuccess) {
+            } else {
+                // call Y.use passing this instance. Y will use the sorted
+                // dependency list.
+                this._onSuccess();
+            }
+
+        },
+
+        /**
+         * In IE, the onAvailable/onDOMReady events need help when Event is
+         * loaded dynamically
+         * @method _pushEvents
+         * @param {Function} optional function reference
+         * @private
+         */
+        _pushEvents: function() {
+            if (Y.Event) {
+                Y.Event._load();
+            }
+        },
+
+        /**
+         * Apply filter defined for this instance to a url/path
+         * method _filter
+         * @param u {string} the string to filter
+         * @return {string} the filtered string
+         * @private
+         */
+        _filter: function(u) {
+
+
+            var f = this.filter;
+
+            if (u && f) {
+                var useFilter = true;
+
+                if (this.filterName == "DEBUG") {
+                
+                    var exc = this.logExclude,
+                        inc = this.logInclude;
+                    if (inc && !(name in inc)) {
+                        useFilter = false;
+                    } else if (exc && (name in exc)) {
+                        useFilter = false;
+                    }
+
+                }
+                
+                if (useFilter) {
+                    u = u.replace(new RegExp(f.searchExp, 'g'), f.replaceStr);
+                }
+            }
+
+            return u;
+
+        },
+
+        /**
+         * Generates the full url for a module
+         * method _url
+         * @param path {string} the path fragment
+         * @return {string} the full url
+         * @private
+         */
+        _url: function(path, name) {
+            return this._filter((this.base || "") + path);
+        }
+
+    };
+
+    // Y.augment(Y.Loader, Y.Event.Target);
+
+}, "3.0.0pr2");
+/*
+ * YUI initializer
+ * @module yui
+ * @submodule init
+ */
+(function() {
+
+    var min = ['yui-base', 'log', 'lang', 'array', 'core'], core,
+
+    M = function(Y) {
+
+        var C = Y.config;
+
+        // apply the minimal required functionality
+        Y.use.apply(Y, min);
+
+
+        if (C.core) {
+
+            core = C.core;
+
+        } else {
+
+            core = ["object", "ua", "later"];
+
+            core.push(
+              "get", 
+              "loader");
+        }
+
+        Y.use.apply(Y, core);
+
+    };
+     
+    YUI.add("yui", M, "3.0.0pr2");
+    
+    // {
+        // the following will be bound automatically when this code is loaded
+      //   use: core
+    // });
+
+})();

=== added directory 'loggerhead/static/javascript/yui/build/yuitest'
=== added file 'loggerhead/static/javascript/yui/build/yuitest/README'
--- loggerhead/static/javascript/yui/build/yuitest/README	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yuitest/README	2008-12-30 19:20:39 +0000
@@ -0,0 +1,28 @@
+YUI Library - YUITest - Release Notes
+
+2.3.0
+
+  * Beta release
+
+2.3.1
+
+  * No changes
+
+2.4.0
+
+  * Changed test running from synchronous to asynchronous.
+  * Added wait() and resume() methods to TestRunner to allow testing of asynchronous features.
+  
+2.5.0
+ 
+  * Updated test results format to include ignored tests, result types, and names.
+  * Introduced test result formats in JSON and XML.
+  * Introduced TestReporter object.
+  * Removed beta tag.
+  
+2.5.1
+
+  * Fixed ObjectAssert.hasProperty() so that is correctly identifies declared properties with a value of undefined.
+  * Fixed DateAssert documentation errors.
+  * Added ability to include framework assertion message in addition to custom assertion message.
+  * Fixed Assert.isUndefined() documentation error.
\ No newline at end of file

=== added directory 'loggerhead/static/javascript/yui/build/yuitest/assets'
=== added file 'loggerhead/static/javascript/yui/build/yuitest/assets/testlogger.css'
--- loggerhead/static/javascript/yui/build/yuitest/assets/testlogger.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yuitest/assets/testlogger.css	2008-12-30 19:20:39 +0000
@@ -0,0 +1,33 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+.yui-log {padding-top:3em;}
+/*
+.yui-log-container {position:relative;width:60em}
+.yui-log .yui-log-bd {height:auto; overflow:visible;}
+*/
+.yui-log-container {width:40em}
+.yui-log .yui-log-bd {height:60em}
+.yui-log .yui-log-btns {display:none;}
+.yui-log .yui-log-ft .yui-log-sourcefilters {visibility:hidden;}
+.yui-log .yui-log-hd {display:none;}
+.yui-log .yui-log-ft {position:absolute;top:0em;}
+
+.pass {
+    background-color: green;
+    font-weight: bold;
+    color: white;
+}
+.fail {
+    background-color: red;
+    font-weight: bold;
+    color: white;
+}
+.ignore {
+    background-color: #666;
+    font-weight: bold;
+    color: white;
+}

=== added file 'loggerhead/static/javascript/yui/build/yuitest/yuitest-debug.js'
--- loggerhead/static/javascript/yui/build/yuitest/yuitest-debug.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yuitest/yuitest-debug.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,2451 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('yuitest', function(Y) {
+
+    /**
+     * YUI JavaScript Testing Framework
+     *
+     * @module yuitest
+     */
+
+    
+    Y.namespace("Test");
+    
+    /**
+     * Test case containing various tests to run.
+     * @param template An object containing any number of test methods, other methods,
+     *                 an optional name, and anything else the test case needs.
+     * @class Case
+     * @namespace Test
+     * @constructor
+     */
+    Y.Test.Case = function (template /*:Object*/) {
+        
+        /**
+         * Special rules for the test case. Possible subobjects
+         * are fail, for tests that should fail, and error, for
+         * tests that should throw an error.
+         */
+        this._should /*:Object*/ = {};
+        
+        //copy over all properties from the template to this object
+        for (var prop in template) {
+            this[prop] = template[prop];
+        }    
+        
+        //check for a valid name
+        if (!Y.Lang.isString(this.name)){
+            /**
+             * Name for the test case.
+             */
+            this.name /*:String*/ = "testCase" + Y.guid();
+        }
+    
+    };
+            
+    Y.Test.Case.prototype = {  
+    
+        /**
+         * Resumes a paused test and runs the given function.
+         * @param {Function} segment (Optional) The function to run.
+         *      If omitted, the test automatically passes.
+         * @return {Void}
+         * @method resume
+         */
+        resume : function (segment /*:Function*/) /*:Void*/ {
+            Y.Test.Runner.resume(segment);
+        },
+    
+        /**
+         * Causes the test case to wait a specified amount of time and then
+         * continue executing the given code.
+         * @param {Function} segment (Optional) The function to run after the delay.
+         *      If omitted, the TestRunner will wait until resume() is called.
+         * @param {int} delay (Optional) The number of milliseconds to wait before running
+         *      the function. If omitted, defaults to zero.
+         * @return {Void}
+         * @method wait
+         */
+        wait : function (segment /*:Function*/, delay /*:int*/) /*:Void*/{
+            var args = arguments;
+            if (Y.Lang.isFunction(args[0])){
+                throw new Y.Test.Wait(args[0], args[1]);
+            } else {
+                throw new Y.Test.Wait(function(){
+                    Y.Assert.fail("Timeout: wait() called but resume() never called.");
+                }, (Y.Lang.isNumber(args[0]) ? args[0] : 10000));
+            }
+        },
+    
+        //-------------------------------------------------------------------------
+        // Stub Methods
+        //-------------------------------------------------------------------------
+    
+        /**
+         * Function to run before each test is executed.
+         * @return {Void}
+         * @method setUp
+         */
+        setUp : function () /*:Void*/ {
+        },
+        
+        /**
+         * Function to run after each test is executed.
+         * @return {Void}
+         * @method tearDown
+         */
+        tearDown: function () /*:Void*/ {    
+        }
+    };
+    
+    /**
+     * Represents a stoppage in test execution to wait for an amount of time before
+     * continuing.
+     * @param {Function} segment A function to run when the wait is over.
+     * @param {int} delay The number of milliseconds to wait before running the code.
+     * @class Wait
+     * @namespace Test
+     * @constructor
+     *
+     */
+    Y.Test.Wait = function (segment /*:Function*/, delay /*:int*/) {
+        
+        /**
+         * The segment of code to run when the wait is over.
+         * @type Function
+         * @property segment
+         */
+        this.segment /*:Function*/ = (Y.Lang.isFunction(segment) ? segment : null);
+    
+        /**
+         * The delay before running the segment of code.
+         * @type int
+         * @property delay
+         */
+        this.delay /*:int*/ = (Y.Lang.isNumber(delay) ? delay : 0);        
+    };
+
+
+        
+    Y.namespace("Test");
+    
+    /**
+     * A test suite that can contain a collection of TestCase and TestSuite objects.
+     * @param {String||Object} data The name of the test suite or an object containing
+     *      a name property as well as setUp and tearDown methods.
+     * @namespace Test
+     * @class Suite
+     * @constructor
+     */
+    Y.Test.Suite = function (data /*:String||Object*/) {
+    
+        /**
+         * The name of the test suite.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "";
+    
+        /**
+         * Array of test suites and
+         * @private
+         */
+        this.items /*:Array*/ = [];
+    
+        //initialize the properties
+        if (Y.Lang.isString(data)){
+            this.name = data;
+        } else if (Y.Lang.isObject(data)){
+            Y.mix(this, data, true);
+        }
+    
+        //double-check name
+        if (this.name === ""){
+            this.name = "testSuite" + Y.guid();
+        }
+    
+    };
+    
+    Y.Test.Suite.prototype = {
+        
+        /**
+         * Adds a test suite or test case to the test suite.
+         * @param {Y.Test.Suite||Y.Test.Case} testObject The test suite or test case to add.
+         * @return {Void}
+         * @method add
+         */
+        add : function (testObject /*:Y.Test.Suite*/) /*:Void*/ {
+            if (testObject instanceof Y.Test.Suite || testObject instanceof Y.Test.Case) {
+                this.items.push(testObject);
+            }
+        },
+        
+        //-------------------------------------------------------------------------
+        // Stub Methods
+        //-------------------------------------------------------------------------
+    
+        /**
+         * Function to run before each test is executed.
+         * @return {Void}
+         * @method setUp
+         */
+        setUp : function () /*:Void*/ {
+        },
+        
+        /**
+         * Function to run after each test is executed.
+         * @return {Void}
+         * @method tearDown
+         */
+        tearDown: function () /*:Void*/ {
+        }
+        
+    };
+
+    
+    /*
+     * Runs test suites and test cases, providing events to allowing for the
+     * interpretation of test results.
+     * @namespace Test
+     * @class Runner
+     * @static
+     */
+    Y.Test.Runner = (function(){
+    
+        /**
+         * A node in the test tree structure. May represent a TestSuite, TestCase, or
+         * test function.
+         * @param {Variant} testObject A TestSuite, TestCase, or the name of a test function.
+         * @class TestNode
+         * @constructor
+         * @private
+         */
+        function TestNode(testObject /*:Variant*/){
+        
+            /**
+             * The TestSuite, TestCase, or test function represented by this node.
+             * @type Variant
+             * @property testObject
+             */
+            this.testObject = testObject;
+            
+            /**
+             * Pointer to this node's first child.
+             * @type TestNode
+             * @property firstChild
+             */        
+            this.firstChild /*:TestNode*/ = null;
+            
+            /**
+             * Pointer to this node's last child.
+             * @type TestNode
+             * @property lastChild
+             */        
+            this.lastChild = null;
+            
+            /**
+             * Pointer to this node's parent.
+             * @type TestNode
+             * @property parent
+             */        
+            this.parent = null; 
+       
+            /**
+             * Pointer to this node's next sibling.
+             * @type TestNode
+             * @property next
+             */        
+            this.next = null;
+            
+            /**
+             * Test results for this test object.
+             * @type object
+             * @property results
+             */                
+            this.results /*:Object*/ = {
+                passed : 0,
+                failed : 0,
+                total : 0,
+                ignored : 0
+            };
+            
+            //initialize results
+            if (testObject instanceof Y.Test.Suite){
+                this.results.type = "testsuite";
+                this.results.name = testObject.name;
+            } else if (testObject instanceof Y.Test.Case){
+                this.results.type = "testcase";
+                this.results.name = testObject.name;
+            }
+           
+        }
+        
+        TestNode.prototype = {
+        
+            /**
+             * Appends a new test object (TestSuite, TestCase, or test function name) as a child
+             * of this node.
+             * @param {Variant} testObject A TestSuite, TestCase, or the name of a test function.
+             * @return {Void}
+             */
+            appendChild : function (testObject /*:Variant*/) /*:Void*/{
+                var node = new TestNode(testObject);
+                if (this.firstChild === null){
+                    this.firstChild = this.lastChild = node;
+                } else {
+                    this.lastChild.next = node;
+                    this.lastChild = node;
+                }
+                node.parent = this;
+                return node;
+            }       
+        };
+    
+        /**
+         * Runs test suites and test cases, providing events to allowing for the
+         * interpretation of test results.
+         * @namespace Test
+         * @class Runner
+         * @static
+         */
+        function TestRunner(){
+        
+            //inherit from EventProvider
+            TestRunner.superclass.constructor.apply(this,arguments);
+            
+            /**
+             * Suite on which to attach all TestSuites and TestCases to be run.
+             * @type Y.Test.Suite
+             * @property masterSuite
+             * @static
+             * @private
+             */
+            this.masterSuite /*:Y.Test.Suite*/ = new Y.Test.Suite("YUI Test Results");        
+    
+            /**
+             * Pointer to the current node in the test tree.
+             * @type TestNode
+             * @private
+             * @property _cur
+             * @static
+             */
+            this._cur = null;
+            
+            /**
+             * Pointer to the root node in the test tree.
+             * @type TestNode
+             * @private
+             * @property _root
+             * @static
+             */
+            this._root = null;
+            
+            /**
+             * Indicates if the TestRunner will log events or not.
+             * @type Boolean
+             * @property _log
+             * @private
+             * @static
+             */
+            this._log = true;
+            
+            //create events
+            var events = [
+                this.TEST_CASE_BEGIN_EVENT,
+                this.TEST_CASE_COMPLETE_EVENT,
+                this.TEST_SUITE_BEGIN_EVENT,
+                this.TEST_SUITE_COMPLETE_EVENT,
+                this.TEST_PASS_EVENT,
+                this.TEST_FAIL_EVENT,
+                this.TEST_IGNORE_EVENT,
+                this.COMPLETE_EVENT,
+                this.BEGIN_EVENT
+            ];
+            for (var i=0; i < events.length; i++){
+                this.subscribe(events[i], this._logEvent, this, true);
+            }      
+       
+        }
+        
+        Y.extend(TestRunner, Y.Event.Target, {
+        
+            //-------------------------------------------------------------------------
+            // Constants
+            //-------------------------------------------------------------------------
+             
+            /**
+             * Fires when a test case is opened but before the first 
+             * test is executed.
+             * @event testcasebegin
+             * @static
+             */         
+            TEST_CASE_BEGIN_EVENT /*:String*/ : "testcasebegin",
+            
+            /**
+             * Fires when all tests in a test case have been executed.
+             * @event testcasecomplete
+             * @static
+             */        
+            TEST_CASE_COMPLETE_EVENT /*:String*/ : "testcasecomplete",
+            
+            /**
+             * Fires when a test suite is opened but before the first 
+             * test is executed.
+             * @event testsuitebegin
+             * @static
+             */        
+            TEST_SUITE_BEGIN_EVENT /*:String*/ : "testsuitebegin",
+            
+            /**
+             * Fires when all test cases in a test suite have been
+             * completed.
+             * @event testsuitecomplete
+             * @static
+             */        
+            TEST_SUITE_COMPLETE_EVENT /*:String*/ : "testsuitecomplete",
+            
+            /**
+             * Fires when a test has passed.
+             * @event pass
+             * @static
+             */        
+            TEST_PASS_EVENT /*:String*/ : "pass",
+            
+            /**
+             * Fires when a test has failed.
+             * @event fail
+             * @static
+             */        
+            TEST_FAIL_EVENT /*:String*/ : "fail",
+            
+            /**
+             * Fires when a test has been ignored.
+             * @event ignore
+             * @static
+             */        
+            TEST_IGNORE_EVENT /*:String*/ : "ignore",
+            
+            /**
+             * Fires when all test suites and test cases have been completed.
+             * @event complete
+             * @static
+             */        
+            COMPLETE_EVENT /*:String*/ : "complete",
+            
+            /**
+             * Fires when the run() method is called.
+             * @event begin
+             * @static
+             */        
+            BEGIN_EVENT /*:String*/ : "begin",    
+            
+            //-------------------------------------------------------------------------
+            // Logging-Related Methods
+            //-------------------------------------------------------------------------
+    
+            
+            /**
+             * Disable logging via Y.log(). Test output will not be visible unless
+             * TestRunner events are subscribed to.
+             * @return {Void}
+             * @method disableLogging
+             * @static
+             */
+            disableLogging: function(){
+                this._log = false;
+            },    
+            
+            /**
+             * Enable logging via Y.log(). Test output is published and can be read via
+             * logreader.
+             * @return {Void}
+             * @method enableLogging
+             * @static
+             */
+            enableLogging: function(){
+                this._log = true;
+            },
+            
+            /**
+             * Logs TestRunner events using Y.log().
+             * @param {Object} event The event object for the event.
+             * @return {Void}
+             * @method _logEvent
+             * @private
+             * @static
+             */
+            _logEvent: function(event){
+                
+                //data variables
+                var message /*:String*/ = "";
+                var messageType /*:String*/ = "";
+                
+                switch(event.type){
+                    case this.BEGIN_EVENT:
+                        message = "Testing began at " + (new Date()).toString() + ".";
+                        messageType = "info";
+                        break;
+                        
+                    case this.COMPLETE_EVENT:
+                        message = "Testing completed at " + (new Date()).toString() + ".\nPassed:" + 
+                            event.results.passed + " Failed:" + event.results.failed + " Total:" + event.results.total;
+                        messageType = "info";
+                        break;
+                        
+                    case this.TEST_FAIL_EVENT:
+                        message = event.testName + ": " + event.error.getMessage();
+                        messageType = "fail";
+                        break;
+                        
+                    case this.TEST_IGNORE_EVENT:
+                        message = event.testName + ": ignored.";
+                        messageType = "ignore";
+                        break;
+                        
+                    case this.TEST_PASS_EVENT:
+                        message = event.testName + ": passed.";
+                        messageType = "pass";
+                        break;
+                        
+                    case this.TEST_SUITE_BEGIN_EVENT:
+                        message = "Test suite \"" + event.testSuite.name + "\" started.";
+                        messageType = "info";
+                        break;
+                        
+                    case this.TEST_SUITE_COMPLETE_EVENT:
+                        message = "Test suite \"" + event.testSuite.name + "\" completed.\nPassed:" + 
+                            event.results.passed + " Failed:" + event.results.failed + " Total:" + event.results.total;
+                        messageType = "info";
+                        break;
+                        
+                    case this.TEST_CASE_BEGIN_EVENT:
+                        message = "Test case \"" + event.testCase.name + "\" started.";
+                        messageType = "info";
+                        break;
+                        
+                    case this.TEST_CASE_COMPLETE_EVENT:
+                        message = "Test case \"" + event.testCase.name + "\" completed.\nPassed:" + 
+                            event.results.passed + " Failed:" + event.results.failed + " Total:" + event.results.total;
+                        messageType = "info";
+                        break;
+                    default:
+                        message = "Unexpected event " + event.type;
+                        message = "info";
+                }
+            
+                //only log if required
+                if (this._log){
+                    Y.log(message, messageType, "TestRunner");
+                }
+            },
+
+            //-------------------------------------------------------------------------
+            // Test Tree-Related Methods
+            //-------------------------------------------------------------------------
+    
+            /**
+             * Adds a test case to the test tree as a child of the specified node.
+             * @param {TestNode} parentNode The node to add the test case to as a child.
+             * @param {Y.Test.Case} testCase The test case to add.
+             * @return {Void}
+             * @static
+             * @private
+             * @method _addTestCaseToTestTree
+             */
+           _addTestCaseToTestTree : function (parentNode /*:TestNode*/, testCase /*:Y.Test.Case*/) /*:Void*/{
+                
+                //add the test suite
+                var node = parentNode.appendChild(testCase);
+                
+                //iterate over the items in the test case
+                for (var prop in testCase){
+                    if (prop.indexOf("test") === 0 && Y.Lang.isFunction(testCase[prop])){
+                        node.appendChild(prop);
+                    }
+                }
+             
+            },
+            
+            /**
+             * Adds a test suite to the test tree as a child of the specified node.
+             * @param {TestNode} parentNode The node to add the test suite to as a child.
+             * @param {Y.Test.Suite} testSuite The test suite to add.
+             * @return {Void}
+             * @static
+             * @private
+             * @method _addTestSuiteToTestTree
+             */
+            _addTestSuiteToTestTree : function (parentNode /*:TestNode*/, testSuite /*:Y.Test.Suite*/) /*:Void*/ {
+                
+                //add the test suite
+                var node = parentNode.appendChild(testSuite);
+                
+                //iterate over the items in the master suite
+                for (var i=0; i < testSuite.items.length; i++){
+                    if (testSuite.items[i] instanceof Y.Test.Suite) {
+                        this._addTestSuiteToTestTree(node, testSuite.items[i]);
+                    } else if (testSuite.items[i] instanceof Y.Test.Case) {
+                        this._addTestCaseToTestTree(node, testSuite.items[i]);
+                    }                   
+                }            
+            },
+            
+            /**
+             * Builds the test tree based on items in the master suite. The tree is a hierarchical
+             * representation of the test suites, test cases, and test functions. The resulting tree
+             * is stored in _root and the pointer _cur is set to the root initially.
+             * @return {Void}
+             * @static
+             * @private
+             * @method _buildTestTree
+             */
+            _buildTestTree : function () /*:Void*/ {
+            
+                this._root = new TestNode(this.masterSuite);
+                this._cur = this._root;
+                
+                //iterate over the items in the master suite
+                for (var i=0; i < this.masterSuite.items.length; i++){
+                    if (this.masterSuite.items[i] instanceof Y.Test.Suite) {
+                        this._addTestSuiteToTestTree(this._root, this.masterSuite.items[i]);
+                    } else if (this.masterSuite.items[i] instanceof Y.Test.Case) {
+                        this._addTestCaseToTestTree(this._root, this.masterSuite.items[i]);
+                    }                   
+                }            
+            
+            }, 
+        
+            //-------------------------------------------------------------------------
+            // Private Methods
+            //-------------------------------------------------------------------------
+            
+            /**
+             * Handles the completion of a test object's tests. Tallies test results 
+             * from one level up to the next.
+             * @param {TestNode} node The TestNode representing the test object.
+             * @return {Void}
+             * @method _handleTestObjectComplete
+             * @private
+             */
+            _handleTestObjectComplete : function (node /*:TestNode*/) /*:Void*/ {
+                if (Y.Lang.isObject(node.testObject)){
+                    node.parent.results.passed += node.results.passed;
+                    node.parent.results.failed += node.results.failed;
+                    node.parent.results.total += node.results.total;                
+                    node.parent.results.ignored += node.results.ignored;                
+                    node.parent.results[node.testObject.name] = node.results;
+                
+                    if (node.testObject instanceof Y.Test.Suite){
+                        node.testObject.tearDown();
+                        this.fire(this.TEST_SUITE_COMPLETE_EVENT, { testSuite: node.testObject, results: node.results});
+                    } else if (node.testObject instanceof Y.Test.Case){
+                        this.fire(this.TEST_CASE_COMPLETE_EVENT, { testCase: node.testObject, results: node.results});
+                    }      
+                } 
+            },                
+            
+            //-------------------------------------------------------------------------
+            // Navigation Methods
+            //-------------------------------------------------------------------------
+            
+            /**
+             * Retrieves the next node in the test tree.
+             * @return {TestNode} The next node in the test tree or null if the end is reached.
+             * @private
+             * @static
+             * @method _next
+             */
+            _next : function () /*:TestNode*/ {
+            
+                if (this._cur.firstChild) {
+                    this._cur = this._cur.firstChild;
+                } else if (this._cur.next) {
+                    this._cur = this._cur.next;            
+                } else {
+                    while (this._cur && !this._cur.next && this._cur !== this._root){
+                        this._handleTestObjectComplete(this._cur);
+                        this._cur = this._cur.parent;
+                    }
+                    
+                    if (this._cur == this._root){
+                        this._cur.results.type = "report";
+                        this._cur.results.timestamp = (new Date()).toLocaleString();
+                        this._cur.results.duration = (new Date()) - this._cur.results.duration;                            
+                        this.fire(this.COMPLETE_EVENT, { results: this._cur.results});
+                        this._cur = null;
+                    } else {
+                        this._handleTestObjectComplete(this._cur);               
+                        this._cur = this._cur.next;                
+                    }
+                }
+            
+                return this._cur;
+            },
+            
+            /**
+             * Runs a test case or test suite, returning the results.
+             * @param {Y.Test.Case|Y.Test.Suite} testObject The test case or test suite to run.
+             * @return {Object} Results of the execution with properties passed, failed, and total.
+             * @private
+             * @method _run
+             * @static
+             */
+            _run : function () /*:Void*/ {
+            
+                //flag to indicate if the TestRunner should wait before continuing
+                var shouldWait /*:Boolean*/ = false;
+                
+                //get the next test node
+                var node = this._next();
+                
+                if (node !== null) {
+                    var testObject = node.testObject;
+                    
+                    //figure out what to do
+                    if (Y.Lang.isObject(testObject)){
+                        if (testObject instanceof Y.Test.Suite){
+                            this.fire(this.TEST_SUITE_BEGIN_EVENT, { testSuite: testObject });
+                            testObject.setUp();
+                        } else if (testObject instanceof Y.Test.Case){
+                            this.fire(this.TEST_CASE_BEGIN_EVENT, { testCase: testObject });
+                        }
+                        
+                        //some environments don't support setTimeout
+                        if (typeof setTimeout != "undefined"){                    
+                            setTimeout(function(){
+                                Y.Test.Runner._run();
+                            }, 0);
+                        } else {
+                            this._run();
+                        }
+                    } else {
+                        this._runTest(node);
+                    }
+    
+                }
+            },
+            
+            _resumeTest : function (segment /*:Function*/) /*:Void*/ {
+            
+                //get relevant information
+                var node /*:TestNode*/ = this._cur;
+                
+                //if there's no node, it probably means a wait() was called after resume()
+                if (!node){
+                    //TODO: Handle in some way?
+                    //console.log("wait() called after resume()");
+                    //this.fire("error", { testCase: "(unknown)", test: "(unknown)", error: new Error("wait() called after resume()")} );
+                    return;
+                }
+                
+                var testName /*:String*/ = node.testObject;
+                var testCase /*:Y.Test.Case*/ = node.parent.testObject;
+            
+                //cancel other waits if available
+                if (testCase.__yui_wait){
+                    clearTimeout(testCase.__yui_wait);
+                    delete testCase.__yui_wait;
+                }
+
+                //get the "should" test cases
+                var shouldFail /*:Object*/ = (testCase._should.fail || {})[testName];
+                var shouldError /*:Object*/ = (testCase._should.error || {})[testName];
+                
+                //variable to hold whether or not the test failed
+                var failed /*:Boolean*/ = false;
+                var error /*:Error*/ = null;
+                    
+                //try the test
+                try {
+                
+                    //run the test
+                    segment.apply(testCase);
+                    
+                    //if it should fail, and it got here, then it's a fail because it didn't
+                    if (shouldFail){
+                        error = new Y.Assert.ShouldFail();
+                        failed = true;
+                    } else if (shouldError){
+                        error = new Y.Assert.ShouldError();
+                        failed = true;
+                    }
+                               
+                } catch (thrown /*:Error*/){
+
+                    //cancel any pending waits, the test already failed
+                    if (testCase.__yui_wait){
+                        clearTimeout(testCase.__yui_wait);
+                        delete testCase.__yui_wait;
+                    }                    
+                
+                    //figure out what type of error it was
+                    if (thrown instanceof Y.Assert.Error) {
+                        if (!shouldFail){
+                            error = thrown;
+                            failed = true;
+                        }
+                    } else if (thrown instanceof Y.Test.Wait){
+                    
+                        if (Y.Lang.isFunction(thrown.segment)){
+                            if (Y.Lang.isNumber(thrown.delay)){
+                            
+                                //some environments don't support setTimeout
+                                if (typeof setTimeout != "undefined"){
+                                    testCase.__yui_wait = setTimeout(function(){
+                                        Y.Test.Runner._resumeTest(thrown.segment);
+                                    }, thrown.delay);
+                                } else {
+                                    throw new Error("Asynchronous tests not supported in this environment.");
+                                }
+                            }
+                        }
+                        
+                        return;
+                    
+                    } else {
+                        //first check to see if it should error
+                        if (!shouldError) {                        
+                            error = new Y.Assert.UnexpectedError(thrown);
+                            failed = true;
+                        } else {
+                            //check to see what type of data we have
+                            if (Y.Lang.isString(shouldError)){
+                                
+                                //if it's a string, check the error message
+                                if (thrown.message != shouldError){
+                                    error = new Y.Assert.UnexpectedError(thrown);
+                                    failed = true;                                    
+                                }
+                            } else if (Y.Lang.isFunction(shouldError)){
+                            
+                                //if it's a function, see if the error is an instance of it
+                                if (!(thrown instanceof shouldError)){
+                                    error = new Y.Assert.UnexpectedError(thrown);
+                                    failed = true;
+                                }
+                            
+                            } else if (Y.Lang.isObject(shouldError)){
+                            
+                                //if it's an object, check the instance and message
+                                if (!(thrown instanceof shouldError.constructor) || 
+                                        thrown.message != shouldError.message){
+                                    error = new Y.Assert.UnexpectedError(thrown);
+                                    failed = true;                                    
+                                }
+                            
+                            }
+                        
+                        }
+                    }
+                    
+                }
+                
+                //fire appropriate event
+                if (failed) {
+                    this.fire(this.TEST_FAIL_EVENT, { testCase: testCase, testName: testName, error: error });
+                } else {
+                    this.fire(this.TEST_PASS_EVENT, { testCase: testCase, testName: testName });
+                }
+                
+                //run the tear down
+                testCase.tearDown();
+                
+                //update results
+                node.parent.results[testName] = { 
+                    result: failed ? "fail" : "pass",
+                    message: error ? error.getMessage() : "Test passed",
+                    type: "test",
+                    name: testName
+                };
+                
+                if (failed){
+                    node.parent.results.failed++;
+                } else {
+                    node.parent.results.passed++;
+                }
+                node.parent.results.total++;
+    
+                //set timeout not supported in all environments
+                if (typeof setTimeout != "undefined"){
+                    setTimeout(function(){
+                        Y.Test.Runner._run();
+                    }, 0);
+                } else {
+                    this._run();
+                }
+            
+            },
+                    
+            /**
+             * Runs a single test based on the data provided in the node.
+             * @param {TestNode} node The TestNode representing the test to run.
+             * @return {Void}
+             * @static
+             * @private
+             * @name _runTest
+             */
+            _runTest : function (node /*:TestNode*/) /*:Void*/ {
+            
+                //get relevant information
+                var testName /*:String*/ = node.testObject;
+                var testCase /*:Y.Test.Case*/ = node.parent.testObject;
+                var test /*:Function*/ = testCase[testName];
+                
+                //get the "should" test cases
+                var shouldIgnore /*:Object*/ = (testCase._should.ignore || {})[testName];
+                
+                //figure out if the test should be ignored or not
+                if (shouldIgnore){
+                
+                    //update results
+                    node.parent.results[testName] = { 
+                        result: "ignore",
+                        message: "Test ignored",
+                        type: "test",
+                        name: testName
+                    };
+                    
+                    node.parent.results.ignored++;
+                    node.parent.results.total++;
+                
+                    this.fire(this.TEST_IGNORE_EVENT, { testCase: testCase, testName: testName });
+                    
+                    //some environments don't support setTimeout
+                    if (typeof setTimeout != "undefined"){                    
+                        setTimeout(function(){
+                            Y.Test.Runner._run();
+                        }, 0);              
+                    } else {
+                        this._run();
+                    }
+    
+                } else {
+                
+                    //run the setup
+                    testCase.setUp();
+                    
+                    //now call the body of the test
+                    this._resumeTest(test);                
+                }
+    
+            },        
+            
+            //-------------------------------------------------------------------------
+            // Protected Methods
+            //-------------------------------------------------------------------------   
+        
+            /*
+             * Fires events for the TestRunner. This overrides the default fire()
+             * method from EventProvider to add the type property to the data that is
+             * passed through on each event call.
+             * @param {String} type The type of event to fire.
+             * @param {Object} data (Optional) Data for the event.
+             * @method fire
+             * @static
+             * @protected
+             */
+            fire : function (type /*:String*/, data /*:Object*/) /*:Void*/ {
+                data = data || {};
+                data.type = type;
+                TestRunner.superclass.fire.call(this, type, data);
+            },
+            
+            //-------------------------------------------------------------------------
+            // Public Methods
+            //-------------------------------------------------------------------------   
+        
+            /**
+             * Adds a test suite or test case to the list of test objects to run.
+             * @param testObject Either a TestCase or a TestSuite that should be run.
+             * @return {Void}
+             * @method add
+             * @static
+             */
+            add : function (testObject /*:Object*/) /*:Void*/ {
+                this.masterSuite.add(testObject);
+            },
+            
+            /**
+             * Removes all test objects from the runner.
+             * @return {Void}
+             * @method clear
+             * @static
+             */
+            clear : function () /*:Void*/ {
+                this.masterSuite.items = [];
+            },
+            
+            /**
+             * Resumes the TestRunner after wait() was called.
+             * @param {Function} segment The function to run as the rest
+             *      of the haulted test.
+             * @return {Void}
+             * @method resume
+             * @static
+             */
+            resume : function (segment /*:Function*/) /*:Void*/ {
+                this._resumeTest(segment || function(){});
+            },
+        
+            /**
+             * Runs the test suite.
+             * @return {Void}
+             * @method run
+             * @static
+             */
+            run : function (testObject /*:Object*/) /*:Void*/ {
+                
+                //pointer to runner to avoid scope issues 
+                var runner = Y.Test.Runner;
+    
+                //build the test tree
+                runner._buildTestTree();
+                            
+                //set when the test started
+                runner._root.results.duration = (new Date()).valueOf();
+                
+                //fire the begin event
+                runner.fire(runner.BEGIN_EVENT);
+           
+                //begin the testing
+                runner._run();
+            }    
+        });
+        
+        return new TestRunner();
+        
+    })();
+
+  
+    /**
+     * The Assert object provides functions to test JavaScript values against
+     * known and expected results. Whenever a comparison (assertion) fails,
+     * an error is thrown.
+     *
+     * @class Assert
+     * @static
+     */
+    Y.Assert = {
+    
+        //-------------------------------------------------------------------------
+        // Helper Methods
+        //-------------------------------------------------------------------------
+        
+        /**
+         * Formats a message so that it can contain the original assertion message
+         * in addition to the custom message.
+         * @param {String} customMessage The message passed in by the developer.
+         * @param {String} defaultMessage The message created by the error by default.
+         * @return {String} The final error message, containing either or both.
+         * @protected
+         * @static
+         * @method _formatMessage
+         */
+        _formatMessage : function (customMessage /*:String*/, defaultMessage /*:String*/) /*:String*/ {
+            var message = customMessage;
+            if (Y.Lang.isString(customMessage) && customMessage.length > 0){
+                return Y.Lang.substitute(customMessage, { message: defaultMessage });
+            } else {
+                return defaultMessage;
+            }        
+        },
+        
+        //-------------------------------------------------------------------------
+        // Generic Assertion Methods
+        //-------------------------------------------------------------------------
+        
+        /** 
+         * Forces an assertion error to occur.
+         * @param {String} message (Optional) The message to display with the failure.
+         * @method fail
+         * @static
+         */
+        fail : function (message /*:String*/) /*:Void*/ {
+            throw new Y.Assert.Error(Y.Assert._formatMessage(message, "Test force-failed."));
+        },       
+        
+        //-------------------------------------------------------------------------
+        // Equality Assertion Methods
+        //-------------------------------------------------------------------------    
+        
+        /**
+         * Asserts that a value is equal to another. This uses the double equals sign
+         * so type cohersion may occur.
+         * @param {Object} expected The expected value.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method areEqual
+         * @static
+         */
+        areEqual : function (expected /*:Object*/, actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (expected != actual) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Values should be equal."), expected, actual);
+            }
+        },
+        
+        /**
+         * Asserts that a value is not equal to another. This uses the double equals sign
+         * so type cohersion may occur.
+         * @param {Object} unexpected The unexpected value.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method areNotEqual
+         * @static
+         */
+        areNotEqual : function (unexpected /*:Object*/, actual /*:Object*/, 
+                             message /*:String*/) /*:Void*/ {
+            if (unexpected == actual) {
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Values should not be equal."), unexpected);
+            }
+        },
+        
+        /**
+         * Asserts that a value is not the same as another. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} unexpected The unexpected value.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method areNotSame
+         * @static
+         */
+        areNotSame : function (unexpected /*:Object*/, actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (unexpected === actual) {
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Values should not be the same."), unexpected);
+            }
+        },
+    
+        /**
+         * Asserts that a value is the same as another. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} expected The expected value.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method areSame
+         * @static
+         */
+        areSame : function (expected /*:Object*/, actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (expected !== actual) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Values should be the same."), expected, actual);
+            }
+        },    
+        
+        //-------------------------------------------------------------------------
+        // Boolean Assertion Methods
+        //-------------------------------------------------------------------------    
+        
+        /**
+         * Asserts that a value is false. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isFalse
+         * @static
+         */
+        isFalse : function (actual /*:Boolean*/, message /*:String*/) {
+            if (false !== actual) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be false."), false, actual);
+            }
+        },
+        
+        /**
+         * Asserts that a value is true. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isTrue
+         * @static
+         */
+        isTrue : function (actual /*:Boolean*/, message /*:String*/) /*:Void*/ {
+            if (true !== actual) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be true."), true, actual);
+            }
+    
+        },
+        
+        //-------------------------------------------------------------------------
+        // Special Value Assertion Methods
+        //-------------------------------------------------------------------------    
+        
+        /**
+         * Asserts that a value is not a number.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNaN
+         * @static
+         */
+        isNaN : function (actual /*:Object*/, message /*:String*/) /*:Void*/{
+            if (!isNaN(actual)){
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be NaN."), NaN, actual);
+            }    
+        },
+        
+        /**
+         * Asserts that a value is not the special NaN value.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNotNaN
+         * @static
+         */
+        isNotNaN : function (actual /*:Object*/, message /*:String*/) /*:Void*/{
+            if (isNaN(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Values should not be NaN."), NaN);
+            }    
+        },
+        
+        /**
+         * Asserts that a value is not null. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNotNull
+         * @static
+         */
+        isNotNull : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (Y.Lang.isNull(actual)) {
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Values should not be null."), null);
+            }
+        },
+    
+        /**
+         * Asserts that a value is not undefined. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNotUndefined
+         * @static
+         */
+        isNotUndefined : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (Y.Lang.isUndefined(actual)) {
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should not be undefined."), undefined);
+            }
+        },
+    
+        /**
+         * Asserts that a value is null. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNull
+         * @static
+         */
+        isNull : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isNull(actual)) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be null."), null, actual);
+            }
+        },
+            
+        /**
+         * Asserts that a value is undefined. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isUndefined
+         * @static
+         */
+        isUndefined : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isUndefined(actual)) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be undefined."), undefined, actual);
+            }
+        },    
+        
+        //--------------------------------------------------------------------------
+        // Instance Assertion Methods
+        //--------------------------------------------------------------------------    
+       
+        /**
+         * Asserts that a value is an array.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isArray
+         * @static
+         */
+        isArray : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isArray(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be an array."), actual);
+            }    
+        },
+       
+        /**
+         * Asserts that a value is a Boolean.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isBoolean
+         * @static
+         */
+        isBoolean : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isBoolean(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be a Boolean."), actual);
+            }    
+        },
+       
+        /**
+         * Asserts that a value is a function.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isFunction
+         * @static
+         */
+        isFunction : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isFunction(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be a function."), actual);
+            }    
+        },
+       
+        /**
+         * Asserts that a value is an instance of a particular object. This may return
+         * incorrect results when comparing objects from one frame to constructors in
+         * another frame. For best results, don't use in a cross-frame manner.
+         * @param {Function} expected The function that the object should be an instance of.
+         * @param {Object} actual The object to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isInstanceOf
+         * @static
+         */
+        isInstanceOf : function (expected /*:Function*/, actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!(actual instanceof expected)){
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value isn't an instance of expected type."), expected, actual);
+            }
+        },
+        
+        /**
+         * Asserts that a value is a number.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNumber
+         * @static
+         */
+        isNumber : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isNumber(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be a number."), actual);
+            }    
+        },    
+        
+        /**
+         * Asserts that a value is an object.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isObject
+         * @static
+         */
+        isObject : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isObject(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be an object."), actual);
+            }
+        },
+        
+        /**
+         * Asserts that a value is a string.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isString
+         * @static
+         */
+        isString : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isString(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be a string."), actual);
+            }
+        },
+        
+        /**
+         * Asserts that a value is of a particular type. 
+         * @param {String} expectedType The expected type of the variable.
+         * @param {Object} actualValue The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isTypeOf
+         * @static
+         */
+        isTypeOf : function (expectedType /*:String*/, actualValue /*:Object*/, message /*:String*/) /*:Void*/{
+            if (typeof actualValue != expectedType){
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be of type " + expectedType + "."), expected, typeof actualValue);
+            }
+        }
+    };
+    
+    //-----------------------------------------------------------------------------
+    // Assertion errors
+    //-----------------------------------------------------------------------------
+    
+    /**
+     * Error is thrown whenever an assertion fails. It provides methods
+     * to more easily get at error information and also provides a base class
+     * from which more specific assertion errors can be derived.
+     *
+     * @param {String} message The message to display when the error occurs.
+     * @namespace Assert
+     * @class Error
+     * @constructor
+     */ 
+    Y.Assert.Error = function (message /*:String*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, message);
+        
+        /*
+         * Error message. Must be duplicated to ensure browser receives it.
+         * @type String
+         * @property message
+         */
+        this.message /*:String*/ = message;
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "Assert Error";
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.Error, Error, {
+    
+        /**
+         * Returns a fully formatted error for an assertion failure. This should
+         * be overridden by all subclasses to provide specific information.
+         * @method getMessage
+         * @return {String} A string describing the error.
+         */
+        getMessage : function () /*:String*/ {
+            return this.message;
+        },
+        
+        /**
+         * Returns a string representation of the error.
+         * @method toString
+         * @return {String} A string representation of the error.
+         */
+        toString : function () /*:String*/ {
+            return this.name + ": " + this.getMessage();
+        },
+        
+        /**
+         * Returns a primitive value version of the error. Same as toString().
+         * @method valueOf
+         * @return {String} A primitive value version of the error.
+         */
+        valueOf : function () /*:String*/ {
+            return this.toString();
+        }
+    
+    });
+    
+    /**
+     * ComparisonFailure is subclass of Error that is thrown whenever
+     * a comparison between two values fails. It provides mechanisms to retrieve
+     * both the expected and actual value.
+     *
+     * @param {String} message The message to display when the error occurs.
+     * @param {Object} expected The expected value.
+     * @param {Object} actual The actual value that caused the assertion to fail.
+     * @namespace Assert 
+     * @extends Assert.Error
+     * @class ComparisonFailure
+     * @constructor
+     */ 
+    Y.Assert.ComparisonFailure = function (message /*:String*/, expected /*:Object*/, actual /*:Object*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, message);
+        
+        /**
+         * The expected value.
+         * @type Object
+         * @property expected
+         */
+        this.expected /*:Object*/ = expected;
+        
+        /**
+         * The actual value.
+         * @type Object
+         * @property actual
+         */
+        this.actual /*:Object*/ = actual;
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "ComparisonFailure";
+        
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.ComparisonFailure, Y.Assert.Error, {
+    
+        /**
+         * Returns a fully formatted error for an assertion failure. This message
+         * provides information about the expected and actual values.
+         * @method toString
+         * @return {String} A string describing the error.
+         */
+        getMessage : function () /*:String*/ {
+            return this.message + "\nExpected: " + this.expected + " (" + (typeof this.expected) + ")"  +
+                "\nActual:" + this.actual + " (" + (typeof this.actual) + ")";
+        }
+    
+    });
+    
+    /**
+     * UnexpectedValue is subclass of Error that is thrown whenever
+     * a value was unexpected in its scope. This typically means that a test
+     * was performed to determine that a value was *not* equal to a certain
+     * value.
+     *
+     * @param {String} message The message to display when the error occurs.
+     * @param {Object} unexpected The unexpected value.
+     * @namespace Assert
+     * @extends Assert.Error
+     * @class UnexpectedValue
+     * @constructor
+     */ 
+    Y.Assert.UnexpectedValue = function (message /*:String*/, unexpected /*:Object*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, message);
+        
+        /**
+         * The unexpected value.
+         * @type Object
+         * @property unexpected
+         */
+        this.unexpected /*:Object*/ = unexpected;
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "UnexpectedValue";
+        
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.UnexpectedValue, Y.Assert.Error, {
+    
+        /**
+         * Returns a fully formatted error for an assertion failure. The message
+         * contains information about the unexpected value that was encountered.
+         * @method getMessage
+         * @return {String} A string describing the error.
+         */
+        getMessage : function () /*:String*/ {
+            return this.message + "\nUnexpected: " + this.unexpected + " (" + (typeof this.unexpected) + ") ";
+        }
+    
+    });
+    
+    /**
+     * ShouldFail is subclass of Error that is thrown whenever
+     * a test was expected to fail but did not.
+     *
+     * @param {String} message The message to display when the error occurs.
+     * @namespace Assert
+     * @extends Assert.Error
+     * @class ShouldFail
+     * @constructor
+     */  
+    Y.Assert.ShouldFail = function (message /*:String*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, message || "This test should fail but didn't.");
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "ShouldFail";
+        
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.ShouldFail, Y.Assert.Error);
+    
+    /**
+     * ShouldError is subclass of Error that is thrown whenever
+     * a test is expected to throw an error but doesn't.
+     *
+     * @param {String} message The message to display when the error occurs.
+     * @namespace Assert
+     * @extends Assert.Error
+     * @class ShouldError
+     * @constructor
+     */  
+    Y.Assert.ShouldError = function (message /*:String*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, message || "This test should have thrown an error but didn't.");
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "ShouldError";
+        
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.ShouldError, Y.Assert.Error);
+    
+    /**
+     * UnexpectedError is subclass of Error that is thrown whenever
+     * an error occurs within the course of a test and the test was not expected
+     * to throw an error.
+     *
+     * @param {Error} cause The unexpected error that caused this error to be 
+     *                      thrown.
+     * @namespace Assert
+     * @extends Assert.Error
+     * @class UnexpectedError
+     * @constructor
+     */  
+    Y.Assert.UnexpectedError = function (cause /*:Object*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, "Unexpected error: " + cause.message);
+        
+        /**
+         * The unexpected error that occurred.
+         * @type Error
+         * @property cause
+         */
+        this.cause /*:Error*/ = cause;
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "UnexpectedError";
+        
+        /**
+         * Stack information for the error (if provided).
+         * @type String
+         * @property stack
+         */
+        this.stack /*:String*/ = cause.stack;
+        
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.UnexpectedError, Y.Assert.Error);
+    
+
+    
+    /**
+     * The ArrayAssert object provides functions to test JavaScript array objects
+     * for a variety of cases.
+     *
+     * @class ArrayAssert
+     * @static
+     */
+     
+    Y.ArrayAssert = {
+    
+        /**
+         * Asserts that a value is present in an array. This uses the triple equals 
+         * sign so no type cohersion may occur.
+         * @param {Object} needle The value that is expected in the array.
+         * @param {Array} haystack An array of values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method contains
+         * @static
+         */
+        contains : function (needle /*:Object*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+            
+            var found /*:Boolean*/ = false;
+            
+            //begin checking values
+            for (var i=0; i < haystack.length && !found; i++){
+                if (haystack[i] === needle) {
+                    found = true;
+                }
+            }
+            
+            if (!found){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Value " + needle + " (" + (typeof needle) + ") not found in array [" + haystack + "]."));
+            }
+        },
+    
+        /**
+         * Asserts that a set of values are present in an array. This uses the triple equals 
+         * sign so no type cohersion may occur. For this assertion to pass, all values must
+         * be found.
+         * @param {Object[]} needles An array of values that are expected in the array.
+         * @param {Array} haystack An array of values to check.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method containsItems
+         * @static
+         */
+        containsItems : function (needles /*:Object[]*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+    
+            //begin checking values
+            for (var i=0; i < needles.length; i++){
+                this.contains(needles[i], haystack, message);
+            }
+        },
+    
+        /**
+         * Asserts that a value matching some condition is present in an array. This uses
+         * a function to determine a match.
+         * @param {Function} matcher A function that returns true if the items matches or false if not.
+         * @param {Array} haystack An array of values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method containsMatch
+         * @static
+         */
+        containsMatch : function (matcher /*:Function*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+            
+            //check for valid matcher
+            if (typeof matcher != "function"){
+                throw new TypeError("ArrayAssert.containsMatch(): First argument must be a function.");
+            }
+            
+            var found /*:Boolean*/ = false;
+            
+            //begin checking values
+            for (var i=0; i < haystack.length && !found; i++){
+                if (matcher(haystack[i])) {
+                    found = true;
+                }
+            }
+            
+            if (!found){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "No match found in array [" + haystack + "]."));
+            }
+        },
+    
+        /**
+         * Asserts that a value is not present in an array. This uses the triple equals 
+         * Asserts that a value is not present in an array. This uses the triple equals 
+         * sign so no type cohersion may occur.
+         * @param {Object} needle The value that is expected in the array.
+         * @param {Array} haystack An array of values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method doesNotContain
+         * @static
+         */
+        doesNotContain : function (needle /*:Object*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+            
+            var found /*:Boolean*/ = false;
+            
+            //begin checking values
+            for (var i=0; i < haystack.length && !found; i++){
+                if (haystack[i] === needle) {
+                    found = true;
+                }
+            }
+            
+            if (found){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Value found in array [" + haystack + "]."));
+            }
+        },
+    
+        /**
+         * Asserts that a set of values are not present in an array. This uses the triple equals 
+         * sign so no type cohersion may occur. For this assertion to pass, all values must
+         * not be found.
+         * @param {Object[]} needles An array of values that are not expected in the array.
+         * @param {Array} haystack An array of values to check.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method doesNotContainItems
+         * @static
+         */
+        doesNotContainItems : function (needles /*:Object[]*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+    
+            for (var i=0; i < needles.length; i++){
+                this.doesNotContain(needles[i], haystack, message);
+            }
+    
+        },
+            
+        /**
+         * Asserts that no values matching a condition are present in an array. This uses
+         * a function to determine a match.
+         * @param {Function} matcher A function that returns true if the items matches or false if not.
+         * @param {Array} haystack An array of values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method doesNotContainMatch
+         * @static
+         */
+        doesNotContainMatch : function (matcher /*:Function*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+            
+            //check for valid matcher
+            if (typeof matcher != "function"){
+                throw new TypeError("ArrayAssert.doesNotContainMatch(): First argument must be a function.");
+            }
+    
+            var found /*:Boolean*/ = false;
+            
+            //begin checking values
+            for (var i=0; i < haystack.length && !found; i++){
+                if (matcher(haystack[i])) {
+                    found = true;
+                }
+            }
+            
+            if (found){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Value found in array [" + haystack + "]."));
+            }
+        },
+            
+        /**
+         * Asserts that the given value is contained in an array at the specified index.
+         * This uses the triple equals sign so no type cohersion will occur.
+         * @param {Object} needle The value to look for.
+         * @param {Array} haystack The array to search in.
+         * @param {int} index The index at which the value should exist.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method indexOf
+         * @static
+         */
+        indexOf : function (needle /*:Object*/, haystack /*:Array*/, index /*:int*/, message /*:String*/) /*:Void*/ {
+        
+            //try to find the value in the array
+            for (var i=0; i < haystack.length; i++){
+                if (haystack[i] === needle){
+                    Y.Assert.areEqual(index, i, message || "Value exists at index " + i + " but should be at index " + index + ".");
+                    return;
+                }
+            }
+            
+            //if it makes it here, it wasn't found at all
+            Y.Assert.fail(Y.Assert._formatMessage(message, "Value doesn't exist in array [" + haystack + "]."));
+        },
+            
+        /**
+         * Asserts that the values in an array are equal, and in the same position,
+         * as values in another array. This uses the double equals sign
+         * so type cohersion may occur. Note that the array objects themselves
+         * need not be the same for this test to pass.
+         * @param {Array} expected An array of the expected values.
+         * @param {Array} actual Any array of the actual values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method itemsAreEqual
+         * @static
+         */
+        itemsAreEqual : function (expected /*:Array*/, actual /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+            
+            //one may be longer than the other, so get the maximum length
+            var len /*:int*/ = Math.max(expected.length, actual.length);
+           
+            //begin checking values
+            for (var i=0; i < len; i++){
+                Y.Assert.areEqual(expected[i], actual[i], 
+                    Y.Assert._formatMessage(message, "Values in position " + i + " are not equal."));
+            }
+        },
+        
+        /**
+         * Asserts that the values in an array are equivalent, and in the same position,
+         * as values in another array. This uses a function to determine if the values
+         * are equivalent. Note that the array objects themselves
+         * need not be the same for this test to pass.
+         * @param {Array} expected An array of the expected values.
+         * @param {Array} actual Any array of the actual values.
+         * @param {Function} comparator A function that returns true if the values are equivalent
+         *      or false if not.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @return {Void}
+         * @method itemsAreEquivalent
+         * @static
+         */
+        itemsAreEquivalent : function (expected /*:Array*/, actual /*:Array*/, 
+                               comparator /*:Function*/, message /*:String*/) /*:Void*/ {
+            
+            //make sure the comparator is valid
+            if (typeof comparator != "function"){
+                throw new TypeError("ArrayAssert.itemsAreEquivalent(): Third argument must be a function.");
+            }
+            
+            //one may be longer than the other, so get the maximum length
+            var len /*:int*/ = Math.max(expected.length, actual.length);
+            
+            //begin checking values
+            for (var i=0; i < len; i++){
+                if (!comparator(expected[i], actual[i])){
+                    throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Values in position " + i + " are not equivalent."), expected[i], actual[i]);
+                }
+            }
+        },
+        
+        /**
+         * Asserts that an array is empty.
+         * @param {Array} actual The array to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isEmpty
+         * @static
+         */
+        isEmpty : function (actual /*:Array*/, message /*:String*/) /*:Void*/ {        
+            if (actual.length > 0){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Array should be empty."));
+            }
+        },    
+        
+        /**
+         * Asserts that an array is not empty.
+         * @param {Array} actual The array to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNotEmpty
+         * @static
+         */
+        isNotEmpty : function (actual /*:Array*/, message /*:String*/) /*:Void*/ {        
+            if (actual.length === 0){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Array should not be empty."));
+            }
+        },    
+        
+        /**
+         * Asserts that the values in an array are the same, and in the same position,
+         * as values in another array. This uses the triple equals sign
+         * so no type cohersion will occur. Note that the array objects themselves
+         * need not be the same for this test to pass.
+         * @param {Array} expected An array of the expected values.
+         * @param {Array} actual Any array of the actual values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method itemsAreSame
+         * @static
+         */
+        itemsAreSame : function (expected /*:Array*/, actual /*:Array*/, 
+                              message /*:String*/) /*:Void*/ {
+            
+            //one may be longer than the other, so get the maximum length
+            var len /*:int*/ = Math.max(expected.length, actual.length);
+            
+            //begin checking values
+            for (var i=0; i < len; i++){
+                Y.Assert.areSame(expected[i], actual[i], 
+                    Y.Assert._formatMessage(message, "Values in position " + i + " are not the same."));
+            }
+        },
+        
+        /**
+         * Asserts that the given value is contained in an array at the specified index,
+         * starting from the back of the array.
+         * This uses the triple equals sign so no type cohersion will occur.
+         * @param {Object} needle The value to look for.
+         * @param {Array} haystack The array to search in.
+         * @param {int} index The index at which the value should exist.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method lastIndexOf
+         * @static
+         */
+        lastIndexOf : function (needle /*:Object*/, haystack /*:Array*/, index /*:int*/, message /*:String*/) /*:Void*/ {
+        
+            //try to find the value in the array
+            for (var i=haystack.length; i >= 0; i--){
+                if (haystack[i] === needle){
+                    Y.Assert.areEqual(index, i, Y.Assert._formatMessage(message, "Value exists at index " + i + " but should be at index " + index + "."));
+                    return;
+                }
+            }
+            
+            //if it makes it here, it wasn't found at all
+            Y.Assert.fail(Y.Assert._formatMessage(message, "Value doesn't exist in array."));        
+        }
+        
+    };
+
+
+    /**
+     * The ObjectAssert object provides functions to test JavaScript objects
+     * for a variety of cases.
+     *
+     * @class ObjectAssert
+     * @static
+     */
+    Y.ObjectAssert = {
+    
+        areEqual: function(expected /*:Object*/, actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            Y.Object.each(expected, function(value, name){
+                Y.Assert.areEqual(expected[name], actual[name], Y.Assert._formatMessage(message, "Values should be equal for property " + name));
+            });            
+        },
+        
+        /**
+         * Asserts that an object has a property with the given name.
+         * @param {String} propertyName The name of the property to test.
+         * @param {Object} object The object to search.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method has
+         * @static
+         */    
+        has : function (propertyName /*:String*/, object /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!(propertyName in object)){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Property '" + propertyName + "' not found on object."));
+            }    
+        },
+        
+        /**
+         * Asserts that an object has all properties of a reference object.
+         * @param {Object} refObject The object whose properties should be on the object to test.
+         * @param {Object} object The object to search.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method hasAll
+         * @static
+         */    
+        hasAll : function (refObject /*:Object*/, object /*:Object*/, message /*:String*/) /*:Void*/ {
+            Y.Object.each(refObject, function(value, name){
+                if (!(name in object)){
+                    Y.Assert.fail(Y.Assert._formatMessage(message, "Property '" + name + "' not found on object."));
+                }    
+            });
+        },
+        
+        /**
+         * Asserts that a property with the given name exists on an object instance (not on its prototype).
+         * @param {String} propertyName The name of the property to test.
+         * @param {Object} object The object to search.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method owns
+         * @static
+         */    
+        owns : function (propertyName /*:String*/, object /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Object.owns(object, propertyName)){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Property '" + propertyName + "' not found on object instance."));
+            }     
+        },
+        
+        /**
+         * Asserts that all properties on a given object also exist on an object instance (not on its prototype).
+         * @param {Object} refObject The object whose properties should be owned by the object to test.
+         * @param {Object} object The object to search.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method ownsAll
+         * @static
+         */    
+        ownsAll : function (refObject /*:Object*/, object /*:Object*/, message /*:String*/) /*:Void*/ {
+            Y.Object.each(refObject, function(value, name){
+                if (!Y.Object.owns(object, name)){
+                    Y.Assert.fail(Y.Assert._formatMessage(message, "Property '" + name + "' not found on object instance."));
+                }     
+            });
+        }
+    };
+
+
+    
+    /**
+     * The DateAssert object provides functions to test JavaScript Date objects
+     * for a variety of cases.
+     *
+     * @class DateAssert
+     * @static
+     */
+     
+    Y.DateAssert = {
+    
+        /**
+         * Asserts that a date's month, day, and year are equal to another date's.
+         * @param {Date} expected The expected date.
+         * @param {Date} actual The actual date to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method datesAreEqual
+         * @static
+         */
+        datesAreEqual : function (expected /*:Date*/, actual /*:Date*/, message /*:String*/){
+            if (expected instanceof Date && actual instanceof Date){
+                Y.AssertareEqual(expected.getFullYear(), actual.getFullYear(), Y.Assert_formatMessage(message, "Years should be equal."));
+                Y.AssertareEqual(expected.getMonth(), actual.getMonth(), Y.Assert_formatMessage(message, "Months should be equal."));
+                Y.AssertareEqual(expected.getDate(), actual.getDate(), Y.Assert_formatMessage(message, "Day of month should be equal."));
+            } else {
+                throw new TypeError("DateY.AssertdatesAreEqual(): Expected and actual values must be Date objects.");
+            }
+        },
+    
+        /**
+         * Asserts that a date's hour, minutes, and seconds are equal to another date's.
+         * @param {Date} expected The expected date.
+         * @param {Date} actual The actual date to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method timesAreEqual
+         * @static
+         */
+        timesAreEqual : function (expected /*:Date*/, actual /*:Date*/, message /*:String*/){
+            if (expected instanceof Date && actual instanceof Date){
+                Y.AssertareEqual(expected.getHours(), actual.getHours(), Y.Assert_formatMessage(message, "Hours should be equal."));
+                Y.AssertareEqual(expected.getMinutes(), actual.getMinutes(), Y.Assert_formatMessage(message, "Minutes should be equal."));
+                Y.AssertareEqual(expected.getSeconds(), actual.getSeconds(), Y.Assert_formatMessage(message, "Seconds should be equal."));
+            } else {
+                throw new TypeError("DateY.AsserttimesAreEqual(): Expected and actual values must be Date objects.");
+            }
+        }
+        
+    };
+
+    
+    Y.namespace("Test.Format");
+    
+    /**
+     * Returns test results formatted as a JSON string. Requires JSON utility.
+     * @param {Object} result The results object created by TestRunner.
+     * @return {String} A JSON-formatted string of results.
+     * @namespace Test.Format
+     * @method JSON
+     * @static
+     */
+    Y.Test.Format.JSON = function(results /*:Object*/) /*:String*/ {
+        return Y.JSON.stringify(results);
+    };
+    
+    /**
+     * Returns test results formatted as an XML string.
+     * @param {Object} result The results object created by TestRunner.
+     * @return {String} An XML-formatted string of results.
+     * @namespace Test.Format
+     * @method XML
+     * @static
+     */
+    Y.Test.Format.XML = function(results /*:Object*/) /*:String*/ {
+    
+        var l = Y.Lang;
+        var xml /*:String*/ = "<" + results.type + " name=\"" + results.name.replace(/"/g, "&quot;").replace(/'/g, "&apos;") + "\"";
+        
+        if (results.type == "test"){
+            xml += " result=\"" + results.result + "\" message=\"" + results.message + "\">";
+        } else {
+            xml += " passed=\"" + results.passed + "\" failed=\"" + results.failed + "\" ignored=\"" + results.ignored + "\" total=\"" + results.total + "\">";
+            for (var prop in results) {
+                if (Y.Object.owns(results, prop) && l.isObject(results[prop]) && !l.isArray(results[prop])){
+                    xml += arguments.callee(results[prop]);
+                }
+            }        
+        }
+    
+        xml += "</" + results.type + ">";
+        
+        return xml;
+    
+    };
+
+
+    Y.namespace("Test");
+    
+    /**
+     * An object capable of sending test results to a server.
+     * @param {String} url The URL to submit the results to.
+     * @param {Function} format (Optiona) A function that outputs the results in a specific format.
+     *      Default is Y.Test.Format.XML.
+     * @constructor
+     * @namespace Test
+     * @class Reporter
+     */
+    Y.Test.Reporter = function(url /*:String*/, format /*:Function*/) {
+    
+        /**
+         * The URL to submit the data to.
+         * @type String
+         * @property url
+         */
+        this.url /*:String*/ = url;
+    
+        /**
+         * The formatting function to call when submitting the data.
+         * @type Function
+         * @property format
+         */
+        this.format /*:Function*/ = format || Y.Test.Format.XML;
+    
+        /**
+         * Extra fields to submit with the request.
+         * @type Object
+         * @property _fields
+         * @private
+         */
+        this._fields /*:Object*/ = new Object();
+        
+        /**
+         * The form element used to submit the results.
+         * @type HTMLFormElement
+         * @property _form
+         * @private
+         */
+        this._form /*:HTMLElement*/ = null;
+    
+        /**
+         * Iframe used as a target for form submission.
+         * @type HTMLIFrameElement
+         * @property _iframe
+         * @private
+         */
+        this._iframe /*:HTMLElement*/ = null;
+    };
+    
+    Y.Test.Reporter.prototype = {
+    
+        //restore missing constructor
+        constructor: Y.Test.Reporter,
+    
+        /**
+         * Adds a field to the form that submits the results.
+         * @param {String} name The name of the field.
+         * @param {Variant} value The value of the field.
+         * @return {Void}
+         * @method addField
+         */
+        addField : function (name /*:String*/, value /*:Variant*/) /*:Void*/{
+            this._fields[name] = value;    
+        },
+        
+        /**
+         * Removes all previous defined fields.
+         * @return {Void}
+         * @method addField
+         */
+        clearFields : function() /*:Void*/{
+            this._fields = new Object();
+        },
+    
+        /**
+         * Cleans up the memory associated with the TestReporter, removing DOM elements
+         * that were created.
+         * @return {Void}
+         * @method destroy
+         */
+        destroy : function() /*:Void*/ {
+            if (this._form){
+                this._form.parentNode.removeChild(this._form);
+                this._form = null;
+            }        
+            if (this._iframe){
+                this._iframe.parentNode.removeChild(this._iframe);
+                this._iframe = null;
+            }
+            this._fields = null;
+        },
+    
+        /**
+         * Sends the report to the server.
+         * @param {Object} results The results object created by TestRunner.
+         * @return {Void}
+         * @method report
+         */
+        report : function(results /*:Object*/) /*:Void*/{
+        
+            //if the form hasn't been created yet, create it
+            if (!this._form){
+                this._form = document.createElement("form");
+                this._form.method = "post";
+                this._form.style.visibility = "hidden";
+                this._form.style.position = "absolute";
+                this._form.style.top = 0;
+                document.body.appendChild(this._form);
+            
+                //IE won't let you assign a name using the DOM, must do it the hacky way
+                if (Y.UA.ie){
+                    this._iframe = document.createElement("<iframe name=\"yuiTestTarget\" />");
+                } else {
+                    this._iframe = document.createElement("iframe");
+                    this._iframe.name = "yuiTestTarget";
+                }
+    
+                this._iframe.src = "javascript:false";
+                this._iframe.style.visibility = "hidden";
+                this._iframe.style.position = "absolute";
+                this._iframe.style.top = 0;
+                document.body.appendChild(this._iframe);
+    
+                this._form.target = "yuiTestTarget";
+            }
+    
+            //set the form's action
+            this._form.action = this.url;
+        
+            //remove any existing fields
+            while(this._form.hasChildNodes()){
+                this._form.removeChild(this._form.lastChild);
+            }
+            
+            //create default fields
+            this._fields.results = this.format(results);
+            this._fields.useragent = navigator.userAgent;
+            this._fields.timestamp = (new Date()).toLocaleString();
+    
+            //add fields to the form
+            for (var prop in this._fields){
+                if (Y.Object.owns(this._fields, prop) && typeof this._fields[prop] != "function"){
+                    var input = document.createElement("input");
+                    input.type = "hidden";
+                    input.name = prop;
+                    input.value = this._fields[prop];
+                    this._form.appendChild(input);
+                }
+            }
+    
+            //remove default fields
+            delete this._fields.results;
+            delete this._fields.useragent;
+            delete this._fields.timestamp;
+            
+            if (arguments[1] !== false){
+                this._form.submit();
+            }
+        
+        }
+    
+    };
+
+    /**
+     * Creates a new mock object.
+     * @class Mock
+     * @constructor
+     * @param {Object} template (Optional) An object whose methods
+     *      should be stubbed out on the mock object.
+     */
+    Y.Mock = function(template){
+    
+        //use blank object is nothing is passed in
+        template = template || {};
+        
+        var mock = null;
+        
+        //try to create mock that keeps prototype chain intact
+        try {
+            mock = Y.Object(template);
+        } catch (ex) {
+            mock = {};
+            Y.log("Couldn't create mock with prototype.", "warn", "Mock");
+        }
+        
+        //create new versions of the methods so that they don't actually do anything
+        Y.Object.each(template, function(name){
+            if (Y.Lang.isFunction(template[name])){
+                mock[name] = function(){
+                    Y.Assert.fail("Method " + name + "() was called but was not expected to be.");
+                };
+            }
+        });
+        
+        //return it
+        return mock;    
+    };
+        
+    /**
+     * Assigns an expectation to a mock object. This is used to create
+     * methods and properties on the mock object that are monitored for
+     * calls and changes, respectively.
+     * @param {Object} mock The object to add the expectation to.
+     * @param {Object} expectation An object defining the expectation. For
+     *      a method, the keys "method" and "args" are required with
+     *      an optional "returns" key available. For properties, the keys
+     *      "property" and "value" are required.
+     * @return {void}
+     * @method expect
+     * @static
+     */ 
+    Y.Mock.expect = function(mock /*:Object*/, expectation /*:Object*/){
+
+        //make sure there's a place to store the expectations
+        if (!mock.__expectations) {
+            mock.__expectations = {};
+        }
+
+        //method expectation
+        if (expectation.method){
+            var name = expectation.method,
+                args = expectation.args || expectation.arguments || [],
+                result = expectation.returns,
+                callCount = Y.Lang.isNumber(expectation.callCount) ? expectation.callCount : 1,
+                error = expectation.error,
+                run = expectation.run || function(){};
+                
+            //save expectations
+            mock.__expectations[name] = expectation;
+            expectation.callCount = callCount;
+            expectation.actualCallCount = 0;
+                
+            //process arguments
+            Y.Array.each(args, function(arg, i, array){
+                if (!(array[i] instanceof Y.Mock.Value)){
+                    array[i] = Y.Mock.Value(Y.Assert.areSame, [arg], "Argument " + i + " of " + name + "() is incorrect.");
+                }
+            });
+        
+            //if the method is expected to be called
+            if (callCount > 0){
+                mock[name] = function(){   
+                    expectation.actualCallCount++;
+                    Y.Assert.areEqual(args.length, arguments.length, "Method " + name + "() passed incorrect number of arguments.");
+                    for (var i=0, len=args.length; i < len; i++){
+                        if (args[i]){
+                            args[i].verify(arguments[i]);
+                        } else {
+                            Y.Assert.fail("Argument " + i + " (" + arguments[i] + ") was not expected to be used.");
+                        }
+                        
+                    }                
+
+                    run.apply(this, arguments);
+                    
+                    if (error){
+                        throw error;
+                    }
+                    
+                    return result;
+                };
+            } else {
+            
+                //method should fail if called when not expected
+                mock[name] = function(){
+                    Y.Assert.fail("Method " + name + "() should not have been called.");
+                };
+            }
+        } else if (expectation.property){
+            //save expectations
+            mock.__expectations[name] = expectation;
+        }
+    };
+
+    /**
+     * Verifies that all expectations of a mock object have been met and
+     * throws an assertion error if not.
+     * @param {Object} mock The object to verify..
+     * @return {void}
+     * @method verify
+     * @static
+     */ 
+    Y.Mock.verify = function(mock /*:Object*/){    
+        Y.Object.each(mock.__expectations, function(expectation){
+            if (expectation.method) {
+                Y.Assert.areEqual(expectation.callCount, expectation.actualCallCount, "Method " + expectation.method + "() wasn't called the expected number of times.");
+            } else if (expectation.property){
+                Y.Assert.areEqual(expectation.value, mock[expectation.property], "Property " + expectation.property + " wasn't set to the correct value."); 
+            }
+        });    
+    };
+
+    Y.Mock.Value = function(method, args, message){
+        if (this instanceof Y.Mock.Value){
+            this.verify = function(value){
+                args = [].concat(args);
+                args.push(value);
+                args.push(message);
+                method.apply(null, args);
+            };
+        } else {
+            return new Y.Mock.Value(method, args, message);
+        }
+    };
+    
+    Y.Mock.Value.Any = Y.Mock.Value(function(){},[]);
+    Y.Mock.Value.Boolean = Y.Mock.Value(Y.Assert.isBoolean,[]);
+    Y.Mock.Value.Number = Y.Mock.Value(Y.Assert.isNumber,[]);
+    Y.Mock.Value.String = Y.Mock.Value(Y.Assert.isString,[]);
+    Y.Mock.Value.Object = Y.Mock.Value(Y.Assert.isObject,[]);
+    Y.Mock.Value.Function = Y.Mock.Value(Y.Assert.isFunction,[]);
+
+
+
+}, '3.0.0pr2' ,{requires:['substitute','event-custom','array','oop','event-target','event-simulate']});

=== added file 'loggerhead/static/javascript/yui/build/yuitest/yuitest-min.js'
--- loggerhead/static/javascript/yui/build/yuitest/yuitest-min.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yuitest/yuitest-min.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,10 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add("yuitest",function(A){A.namespace("Test");A.Test.Case=function(B){this._should={};for(var C in B){this[C]=B[C];}if(!A.Lang.isString(this.name)){this.name="testCase"+A.guid();}};A.Test.Case.prototype={resume:function(B){A.Test.Runner.resume(B);},wait:function(D,C){var B=arguments;if(A.Lang.isFunction(B[0])){throw new A.Test.Wait(B[0],B[1]);}else{throw new A.Test.Wait(function(){A.Assert.fail("Timeout: wait() called but resume() never called.");},(A.Lang.isNumber(B[0])?B[0]:10000));}},setUp:function(){},tearDown:function(){}};A.Test.Wait=function(C,B){this.segment=(A.Lang.isFunction(C)?C:null);this.delay=(A.Lang.isNumber(B)?B:0);};A.namespace("Test");A.Test.Suite=function(B){this.name="";this.items=[];if(A.Lang.isString(B)){this.name=B;}else{if(A.Lang.isObject(B)){A.mix(this,B,true);}}if(this.name===""){this.name="testSuite"+A.guid();}};A.Test.Suite.prototype={add:function(B){if(B instanceof A.Test.Suite||B instanceof A.Test.Case){this.items.push(B);}},setUp:function(){},tearDown:function(){}};A.Test.Runner=(function(){function C(D){this.testObject=D;this.firstChild=null;this.lastChild=null;this.parent=null;this.next=null;this.results={passed:0,failed:0,total:0,ignored:0};if(D instanceof A.Test.Suite){this.results.type="testsuite";this.results.name=D.name;}else{if(D instanceof A.Test.Case){this.results.type="testcase";this.results.name=D.name;}}}C.prototype={appendChild:function(D){var E=new C(D);if(this.firstChild===null){this.firstChild=this.lastChild=E;}else{this.lastChild.next=E;this.lastChild=E;}E.parent=this;return E;}};function B(){B.superclass.constructor.apply(this,arguments);this.masterSuite=new A.Test.Suite("YUI Test Results");this._cur=null;this._root=null;this._log=true;var E=[this.TEST_CASE_BEGIN_EVENT,this.TEST_CASE_COMPLETE_EVENT,this.TEST_SUITE_BEGIN_EVENT,this.TEST_SUITE_COMPLETE_EVENT,this.TEST_PASS_EVENT,this.TEST_FAIL_EVENT,this.TEST_IGNORE_EVENT,this.COMPLETE_EVENT,this.BEGIN_EVENT];for(var D=0;D<E.length;D++){this.subscribe(E[D],this._logEvent,this,true);}}A.extend(B,A.Event.Target,{TEST_CASE_BEGIN_EVENT:"testcasebegin",TEST_CASE_COMPLETE_EVENT:"testcasecomplete",TEST_SUITE_BEGIN_EVENT:"testsuitebegin",TEST_SUITE_COMPLETE_EVENT:"testsuitecomplete",TEST_PASS_EVENT:"pass",TEST_FAIL_EVENT:"fail",TEST_IGNORE_EVENT:"ignore",COMPLETE_EVENT:"complete",BEGIN_EVENT:"begin",disableLogging:function(){this._log=false;},enableLogging:function(){this._log=true;},_logEvent:function(F){var E="";var D="";switch(F.type){case this.BEGIN_EVENT:E="Testing began at "+(new Date()).toString()+".";D="info";break;case this.COMPLETE_EVENT:E="Testing completed at "+(new Date()).toString()+".\nPassed:"+F.results.passed+" Failed:"+F.results.failed+" Total:"+F.results.total;D="info";break;case this.TEST_FAIL_EVENT:E=F.testName+": "+F.error.getMessage();D="fail";break;case this.TEST_IGNORE_EVENT:E=F.testName+": ignored.";D="ignore";break;case this.TEST_PASS_EVENT:E=F.testName+": passed.";D="pass";break;case this.TEST_SUITE_BEGIN_EVENT:E='Test suite "'+F.testSuite.name+'" started.';D="info";break;case this.TEST_SUITE_COMPLETE_EVENT:E='Test suite "'+F.testSuite.name+'" completed.\nPassed:'+F.results.passed+" Failed:"+F.results.failed+" Total:"+F.results.total;D="info";break;case this.TEST_CASE_BEGIN_EVENT:E='Test case "'+F.testCase.name+'" started.';D="info";break;case this.TEST_CASE_COMPLETE_EVENT:E='Test case "'+F.testCase.name+'" completed.\nPassed:'+F.results.passed+" Failed:"+F.results.failed+" Total:"+F.results.total;D="info";break;default:E="Unexpected event "+F.type;E="info";}if(this._log){A.log(E,D,"TestRunner");}},_addTestCaseToTestTree:function(D,E){var F=D.appendChild(E);for(var G in E){if(G.indexOf("test")===0&&A.Lang.isFunction(E[G])){F.appendChild(G);}}},_addTestSuiteToTestTree:function(D,G){var F=D.appendChild(G);for(var E=0;E<G.items.length;E++){if(G.items[E] instanceof A.Test.Suite){this._addTestSuiteToTestTree(F,G.items[E]);}else{if(G.items[E] instanceof A.Test.Case){this._addTestCaseToTestTree(F,G.items[E]);}}}},_buildTestTree:function(){this._root=new C(this.masterSuite);this._cur=this._root;for(var D=0;D<this.masterSuite.items.length;D++){if(this.masterSuite.items[D] instanceof A.Test.Suite){this._addTestSuiteToTestTree(this._root,this.masterSuite.items[D]);}else{if(this.masterSuite.items[D] instanceof A.Test.Case){this._addTestCaseToTestTree(this._root,this.masterSuite.items[D]);}}}},_handleTestObjectComplete:function(D){if(A.Lang.isObject(D.testObject)){D.parent.results.passed+=D.results.passed;D.parent.results.failed+=D.results.failed;D.parent.results.total+=D.results.total;D.parent.results.ignored+=D.results.ignored;D.parent.results[D.testObject.name]=D.results;if(D.testObject instanceof A.Test.Suite){D.testObject.tearDown();this.fire(this.TEST_SUITE_COMPLETE_EVENT,{testSuite:D.testObject,results:D.results});}else{if(D.testObject instanceof A.Test.Case){this.fire(this.TEST_CASE_COMPLETE_EVENT,{testCase:D.testObject,results:D.results});}}}},_next:function(){if(this._cur.firstChild){this._cur=this._cur.firstChild;}else{if(this._cur.next){this._cur=this._cur.next;}else{while(this._cur&&!this._cur.next&&this._cur!==this._root){this._handleTestObjectComplete(this._cur);this._cur=this._cur.parent;}if(this._cur==this._root){this._cur.results.type="report";this._cur.results.timestamp=(new Date()).toLocaleString();this._cur.results.duration=(new Date())-this._cur.results.duration;this.fire(this.COMPLETE_EVENT,{results:this._cur.results});this._cur=null;}else{this._handleTestObjectComplete(this._cur);this._cur=this._cur.next;}}}return this._cur;},_run:function(){var F=false;var E=this._next();if(E!==null){var D=E.testObject;if(A.Lang.isObject(D)){if(D instanceof A.Test.Suite){this.fire(this.TEST_SUITE_BEGIN_EVENT,{testSuite:D});D.setUp();}else{if(D instanceof A.Test.Case){this.fire(this.TEST_CASE_BEGIN_EVENT,{testCase:D});}}if(typeof setTimeout!="undefined"){setTimeout(function(){A.Test.Runner._run();},0);}else{this._run();}}else{this._runTest(E);}}},_resumeTest:function(H){var D=this._cur;
+if(!D){return;}var I=D.testObject;var F=D.parent.testObject;if(F.__yui_wait){clearTimeout(F.__yui_wait);delete F.__yui_wait;}var L=(F._should.fail||{})[I];var E=(F._should.error||{})[I];var G=false;var J=null;try{H.apply(F);if(L){J=new A.Assert.ShouldFail();G=true;}else{if(E){J=new A.Assert.ShouldError();G=true;}}}catch(K){if(F.__yui_wait){clearTimeout(F.__yui_wait);delete F.__yui_wait;}if(K instanceof A.Assert.Error){if(!L){J=K;G=true;}}else{if(K instanceof A.Test.Wait){if(A.Lang.isFunction(K.segment)){if(A.Lang.isNumber(K.delay)){if(typeof setTimeout!="undefined"){F.__yui_wait=setTimeout(function(){A.Test.Runner._resumeTest(K.segment);},K.delay);}else{throw new Error("Asynchronous tests not supported in this environment.");}}}return;}else{if(!E){J=new A.Assert.UnexpectedError(K);G=true;}else{if(A.Lang.isString(E)){if(K.message!=E){J=new A.Assert.UnexpectedError(K);G=true;}}else{if(A.Lang.isFunction(E)){if(!(K instanceof E)){J=new A.Assert.UnexpectedError(K);G=true;}}else{if(A.Lang.isObject(E)){if(!(K instanceof E.constructor)||K.message!=E.message){J=new A.Assert.UnexpectedError(K);G=true;}}}}}}}}if(G){this.fire(this.TEST_FAIL_EVENT,{testCase:F,testName:I,error:J});}else{this.fire(this.TEST_PASS_EVENT,{testCase:F,testName:I});}F.tearDown();D.parent.results[I]={result:G?"fail":"pass",message:J?J.getMessage():"Test passed",type:"test",name:I};if(G){D.parent.results.failed++;}else{D.parent.results.passed++;}D.parent.results.total++;if(typeof setTimeout!="undefined"){setTimeout(function(){A.Test.Runner._run();},0);}else{this._run();}},_runTest:function(G){var D=G.testObject;var E=G.parent.testObject;var H=E[D];var F=(E._should.ignore||{})[D];if(F){G.parent.results[D]={result:"ignore",message:"Test ignored",type:"test",name:D};G.parent.results.ignored++;G.parent.results.total++;this.fire(this.TEST_IGNORE_EVENT,{testCase:E,testName:D});if(typeof setTimeout!="undefined"){setTimeout(function(){A.Test.Runner._run();},0);}else{this._run();}}else{E.setUp();this._resumeTest(H);}},fire:function(D,E){E=E||{};E.type=D;B.superclass.fire.call(this,D,E);},add:function(D){this.masterSuite.add(D);},clear:function(){this.masterSuite.items=[];},resume:function(D){this._resumeTest(D||function(){});},run:function(D){var E=A.Test.Runner;E._buildTestTree();E._root.results.duration=(new Date()).valueOf();E.fire(E.BEGIN_EVENT);E._run();}});return new B();})();A.Assert={_formatMessage:function(C,B){var D=C;if(A.Lang.isString(C)&&C.length>0){return A.Lang.substitute(C,{message:B});}else{return B;}},fail:function(B){throw new A.Assert.Error(A.Assert._formatMessage(B,"Test force-failed."));},areEqual:function(C,D,B){if(C!=D){throw new A.Assert.ComparisonFailure(A.Assert._formatMessage(B,"Values should be equal."),C,D);}},areNotEqual:function(B,D,C){if(B==D){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(C,"Values should not be equal."),B);}},areNotSame:function(B,D,C){if(B===D){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(C,"Values should not be the same."),B);}},areSame:function(C,D,B){if(C!==D){throw new A.Assert.ComparisonFailure(A.Assert._formatMessage(B,"Values should be the same."),C,D);}},isFalse:function(C,B){if(false!==C){throw new A.Assert.ComparisonFailure(A.Assert._formatMessage(B,"Value should be false."),false,C);}},isTrue:function(C,B){if(true!==C){throw new A.Assert.ComparisonFailure(A.Assert._formatMessage(B,"Value should be true."),true,C);}},isNaN:function(C,B){if(!isNaN(C)){throw new A.Assert.ComparisonFailure(A.Assert._formatMessage(B,"Value should be NaN."),NaN,C);}},isNotNaN:function(C,B){if(isNaN(C)){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(B,"Values should not be NaN."),NaN);}},isNotNull:function(C,B){if(A.Lang.isNull(C)){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(B,"Values should not be null."),null);}},isNotUndefined:function(C,B){if(A.Lang.isUndefined(C)){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(B,"Value should not be undefined."),undefined);}},isNull:function(C,B){if(!A.Lang.isNull(C)){throw new A.Assert.ComparisonFailure(A.Assert._formatMessage(B,"Value should be null."),null,C);}},isUndefined:function(C,B){if(!A.Lang.isUndefined(C)){throw new A.Assert.ComparisonFailure(A.Assert._formatMessage(B,"Value should be undefined."),undefined,C);}},isArray:function(C,B){if(!A.Lang.isArray(C)){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(B,"Value should be an array."),C);}},isBoolean:function(C,B){if(!A.Lang.isBoolean(C)){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(B,"Value should be a Boolean."),C);}},isFunction:function(C,B){if(!A.Lang.isFunction(C)){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(B,"Value should be a function."),C);}},isInstanceOf:function(C,D,B){if(!(D instanceof C)){throw new A.Assert.ComparisonFailure(A.Assert._formatMessage(B,"Value isn't an instance of expected type."),C,D);}},isNumber:function(C,B){if(!A.Lang.isNumber(C)){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(B,"Value should be a number."),C);}},isObject:function(C,B){if(!A.Lang.isObject(C)){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(B,"Value should be an object."),C);}},isString:function(C,B){if(!A.Lang.isString(C)){throw new A.Assert.UnexpectedValue(A.Assert._formatMessage(B,"Value should be a string."),C);}},isTypeOf:function(B,D,C){if(typeof D!=B){throw new A.Assert.ComparisonFailure(A.Assert._formatMessage(C,"Value should be of type "+B+"."),expected,typeof D);}}};A.Assert.Error=function(B){arguments.callee.superclass.constructor.call(this,B);this.message=B;this.name="Assert Error";};A.extend(A.Assert.Error,Error,{getMessage:function(){return this.message;},toString:function(){return this.name+": "+this.getMessage();},valueOf:function(){return this.toString();}});A.Assert.ComparisonFailure=function(C,B,D){arguments.callee.superclass.constructor.call(this,C);this.expected=B;this.actual=D;this.name="ComparisonFailure";};A.extend(A.Assert.ComparisonFailure,A.Assert.Error,{getMessage:function(){return this.message+"\nExpected: "+this.expected+" ("+(typeof this.expected)+")"+"\nActual:"+this.actual+" ("+(typeof this.actual)+")";
+}});A.Assert.UnexpectedValue=function(C,B){arguments.callee.superclass.constructor.call(this,C);this.unexpected=B;this.name="UnexpectedValue";};A.extend(A.Assert.UnexpectedValue,A.Assert.Error,{getMessage:function(){return this.message+"\nUnexpected: "+this.unexpected+" ("+(typeof this.unexpected)+") ";}});A.Assert.ShouldFail=function(B){arguments.callee.superclass.constructor.call(this,B||"This test should fail but didn't.");this.name="ShouldFail";};A.extend(A.Assert.ShouldFail,A.Assert.Error);A.Assert.ShouldError=function(B){arguments.callee.superclass.constructor.call(this,B||"This test should have thrown an error but didn't.");this.name="ShouldError";};A.extend(A.Assert.ShouldError,A.Assert.Error);A.Assert.UnexpectedError=function(B){arguments.callee.superclass.constructor.call(this,"Unexpected error: "+B.message);this.cause=B;this.name="UnexpectedError";this.stack=B.stack;};A.extend(A.Assert.UnexpectedError,A.Assert.Error);A.ArrayAssert={contains:function(F,E,C){var D=false;for(var B=0;B<E.length&&!D;B++){if(E[B]===F){D=true;}}if(!D){A.Assert.fail(A.Assert._formatMessage(C,"Value "+F+" ("+(typeof F)+") not found in array ["+E+"]."));}},containsItems:function(D,E,C){for(var B=0;B<D.length;B++){this.contains(D[B],E,C);}},containsMatch:function(F,E,C){if(typeof F!="function"){throw new TypeError("ArrayAssert.containsMatch(): First argument must be a function.");}var D=false;for(var B=0;B<E.length&&!D;B++){if(F(E[B])){D=true;}}if(!D){A.Assert.fail(A.Assert._formatMessage(C,"No match found in array ["+E+"]."));}},doesNotContain:function(F,E,C){var D=false;for(var B=0;B<E.length&&!D;B++){if(E[B]===F){D=true;}}if(D){A.Assert.fail(A.Assert._formatMessage(C,"Value found in array ["+E+"]."));}},doesNotContainItems:function(D,E,C){for(var B=0;B<D.length;B++){this.doesNotContain(D[B],E,C);}},doesNotContainMatch:function(F,E,C){if(typeof F!="function"){throw new TypeError("ArrayAssert.doesNotContainMatch(): First argument must be a function.");}var D=false;for(var B=0;B<E.length&&!D;B++){if(F(E[B])){D=true;}}if(D){A.Assert.fail(A.Assert._formatMessage(C,"Value found in array ["+E+"]."));}},indexOf:function(F,E,B,D){for(var C=0;C<E.length;C++){if(E[C]===F){A.Assert.areEqual(B,C,D||"Value exists at index "+C+" but should be at index "+B+".");return;}}A.Assert.fail(A.Assert._formatMessage(D,"Value doesn't exist in array ["+E+"]."));},itemsAreEqual:function(E,F,D){var B=Math.max(E.length,F.length);for(var C=0;C<B;C++){A.Assert.areEqual(E[C],F[C],A.Assert._formatMessage(D,"Values in position "+C+" are not equal."));}},itemsAreEquivalent:function(F,G,C,E){if(typeof C!="function"){throw new TypeError("ArrayAssert.itemsAreEquivalent(): Third argument must be a function.");}var B=Math.max(F.length,G.length);for(var D=0;D<B;D++){if(!C(F[D],G[D])){throw new A.Assert.ComparisonFailure(A.Assert._formatMessage(E,"Values in position "+D+" are not equivalent."),F[D],G[D]);}}},isEmpty:function(C,B){if(C.length>0){A.Assert.fail(A.Assert._formatMessage(B,"Array should be empty."));}},isNotEmpty:function(C,B){if(C.length===0){A.Assert.fail(A.Assert._formatMessage(B,"Array should not be empty."));}},itemsAreSame:function(E,F,D){var B=Math.max(E.length,F.length);for(var C=0;C<B;C++){A.Assert.areSame(E[C],F[C],A.Assert._formatMessage(D,"Values in position "+C+" are not the same."));}},lastIndexOf:function(F,E,B,D){for(var C=E.length;C>=0;C--){if(E[C]===F){A.Assert.areEqual(B,C,A.Assert._formatMessage(D,"Value exists at index "+C+" but should be at index "+B+"."));return;}}A.Assert.fail(A.Assert._formatMessage(D,"Value doesn't exist in array."));}};A.ObjectAssert={areEqual:function(C,D,B){A.Object.each(C,function(F,E){A.Assert.areEqual(C[E],D[E],A.Assert._formatMessage(B,"Values should be equal for property "+E));});},has:function(B,C,D){if(!(B in C)){A.Assert.fail(A.Assert._formatMessage(D,"Property '"+B+"' not found on object."));}},hasAll:function(D,B,C){A.Object.each(D,function(F,E){if(!(E in B)){A.Assert.fail(A.Assert._formatMessage(C,"Property '"+E+"' not found on object."));}});},owns:function(B,C,D){if(!A.Object.owns(C,B)){A.Assert.fail(A.Assert._formatMessage(D,"Property '"+B+"' not found on object instance."));}},ownsAll:function(D,B,C){A.Object.each(D,function(F,E){if(!A.Object.owns(B,E)){A.Assert.fail(A.Assert._formatMessage(C,"Property '"+E+"' not found on object instance."));}});}};A.DateAssert={datesAreEqual:function(C,D,B){if(C instanceof Date&&D instanceof Date){A.AssertareEqual(C.getFullYear(),D.getFullYear(),A.Assert_formatMessage(B,"Years should be equal."));A.AssertareEqual(C.getMonth(),D.getMonth(),A.Assert_formatMessage(B,"Months should be equal."));A.AssertareEqual(C.getDate(),D.getDate(),A.Assert_formatMessage(B,"Day of month should be equal."));}else{throw new TypeError("DateY.AssertdatesAreEqual(): Expected and actual values must be Date objects.");}},timesAreEqual:function(C,D,B){if(C instanceof Date&&D instanceof Date){A.AssertareEqual(C.getHours(),D.getHours(),A.Assert_formatMessage(B,"Hours should be equal."));A.AssertareEqual(C.getMinutes(),D.getMinutes(),A.Assert_formatMessage(B,"Minutes should be equal."));A.AssertareEqual(C.getSeconds(),D.getSeconds(),A.Assert_formatMessage(B,"Seconds should be equal."));}else{throw new TypeError("DateY.AsserttimesAreEqual(): Expected and actual values must be Date objects.");}}};A.namespace("Test.Format");A.Test.Format.JSON=function(B){return A.JSON.stringify(B);};A.Test.Format.XML=function(D){var B=A.Lang;var C="<"+D.type+' name="'+D.name.replace(/"/g,"&quot;").replace(/'/g,"&apos;")+'"';if(D.type=="test"){C+=' result="'+D.result+'" message="'+D.message+'">';}else{C+=' passed="'+D.passed+'" failed="'+D.failed+'" ignored="'+D.ignored+'" total="'+D.total+'">';for(var E in D){if(A.Object.owns(D,E)&&B.isObject(D[E])&&!B.isArray(D[E])){C+=arguments.callee(D[E]);}}}C+="</"+D.type+">";return C;};A.namespace("Test");A.Test.Reporter=function(B,C){this.url=B;this.format=C||A.Test.Format.XML;this._fields=new Object();this._form=null;this._iframe=null;};A.Test.Reporter.prototype={constructor:A.Test.Reporter,addField:function(B,C){this._fields[B]=C;
+},clearFields:function(){this._fields=new Object();},destroy:function(){if(this._form){this._form.parentNode.removeChild(this._form);this._form=null;}if(this._iframe){this._iframe.parentNode.removeChild(this._iframe);this._iframe=null;}this._fields=null;},report:function(C){if(!this._form){this._form=document.createElement("form");this._form.method="post";this._form.style.visibility="hidden";this._form.style.position="absolute";this._form.style.top=0;document.body.appendChild(this._form);if(A.UA.ie){this._iframe=document.createElement('<iframe name="yuiTestTarget" />');}else{this._iframe=document.createElement("iframe");this._iframe.name="yuiTestTarget";}this._iframe.src="javascript:false";this._iframe.style.visibility="hidden";this._iframe.style.position="absolute";this._iframe.style.top=0;document.body.appendChild(this._iframe);this._form.target="yuiTestTarget";}this._form.action=this.url;while(this._form.hasChildNodes()){this._form.removeChild(this._form.lastChild);}this._fields.results=this.format(C);this._fields.useragent=navigator.userAgent;this._fields.timestamp=(new Date()).toLocaleString();for(var D in this._fields){if(A.Object.owns(this._fields,D)&&typeof this._fields[D]!="function"){var B=document.createElement("input");B.type="hidden";B.name=D;B.value=this._fields[D];this._form.appendChild(B);}}delete this._fields.results;delete this._fields.useragent;delete this._fields.timestamp;if(arguments[1]!==false){this._form.submit();}}};A.Mock=function(D){D=D||{};var B=null;try{B=A.Object(D);}catch(C){B={};A.log("Couldn't create mock with prototype.","warn","Mock");}A.Object.each(D,function(E){if(A.Lang.isFunction(D[E])){B[E]=function(){A.Assert.fail("Method "+E+"() was called but was not expected to be.");};}});return B;};A.Mock.expect=function(C,G){if(!C.__expectations){C.__expectations={};}if(G.method){var F=G.method,E=G.args||G.arguments||[],B=G.returns,I=A.Lang.isNumber(G.callCount)?G.callCount:1,D=G.error,H=G.run||function(){};C.__expectations[F]=G;G.callCount=I;G.actualCallCount=0;A.Array.each(E,function(J,K,L){if(!(L[K] instanceof A.Mock.Value)){L[K]=A.Mock.Value(A.Assert.areSame,[J],"Argument "+K+" of "+F+"() is incorrect.");}});if(I>0){C[F]=function(){G.actualCallCount++;A.Assert.areEqual(E.length,arguments.length,"Method "+F+"() passed incorrect number of arguments.");for(var K=0,J=E.length;K<J;K++){if(E[K]){E[K].verify(arguments[K]);}else{A.Assert.fail("Argument "+K+" ("+arguments[K]+") was not expected to be used.");}}H.apply(this,arguments);if(D){throw D;}return B;};}else{C[F]=function(){A.Assert.fail("Method "+F+"() should not have been called.");};}}else{if(G.property){C.__expectations[F]=G;}}};A.Mock.verify=function(B){A.Object.each(B.__expectations,function(C){if(C.method){A.Assert.areEqual(C.callCount,C.actualCallCount,"Method "+C.method+"() wasn't called the expected number of times.");}else{if(C.property){A.Assert.areEqual(C.value,B[C.property],"Property "+C.property+" wasn't set to the correct value.");}}});};A.Mock.Value=function(D,B,C){if(this instanceof A.Mock.Value){this.verify=function(E){B=[].concat(B);B.push(E);B.push(C);D.apply(null,B);};}else{return new A.Mock.Value(D,B,C);}};A.Mock.Value.Any=A.Mock.Value(function(){},[]);A.Mock.Value.Boolean=A.Mock.Value(A.Assert.isBoolean,[]);A.Mock.Value.Number=A.Mock.Value(A.Assert.isNumber,[]);A.Mock.Value.String=A.Mock.Value(A.Assert.isString,[]);A.Mock.Value.Object=A.Mock.Value(A.Assert.isObject,[]);A.Mock.Value.Function=A.Mock.Value(A.Assert.isFunction,[]);},"3.0.0pr2",{requires:["substitute","event-custom","array","oop","event-target","event-simulate"]});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/yui/build/yuitest/yuitest.js'
--- loggerhead/static/javascript/yui/build/yuitest/yuitest.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/yui/build/yuitest/yuitest.js	2008-12-30 19:20:39 +0000
@@ -0,0 +1,2451 @@
+/*
+Copyright (c) 2008, Yahoo! Inc. All rights reserved.
+Code licensed under the BSD License:
+http://developer.yahoo.net/yui/license.txt
+version: 3.0.0pr2
+*/
+YUI.add('yuitest', function(Y) {
+
+    /**
+     * YUI JavaScript Testing Framework
+     *
+     * @module yuitest
+     */
+
+    
+    Y.namespace("Test");
+    
+    /**
+     * Test case containing various tests to run.
+     * @param template An object containing any number of test methods, other methods,
+     *                 an optional name, and anything else the test case needs.
+     * @class Case
+     * @namespace Test
+     * @constructor
+     */
+    Y.Test.Case = function (template /*:Object*/) {
+        
+        /**
+         * Special rules for the test case. Possible subobjects
+         * are fail, for tests that should fail, and error, for
+         * tests that should throw an error.
+         */
+        this._should /*:Object*/ = {};
+        
+        //copy over all properties from the template to this object
+        for (var prop in template) {
+            this[prop] = template[prop];
+        }    
+        
+        //check for a valid name
+        if (!Y.Lang.isString(this.name)){
+            /**
+             * Name for the test case.
+             */
+            this.name /*:String*/ = "testCase" + Y.guid();
+        }
+    
+    };
+            
+    Y.Test.Case.prototype = {  
+    
+        /**
+         * Resumes a paused test and runs the given function.
+         * @param {Function} segment (Optional) The function to run.
+         *      If omitted, the test automatically passes.
+         * @return {Void}
+         * @method resume
+         */
+        resume : function (segment /*:Function*/) /*:Void*/ {
+            Y.Test.Runner.resume(segment);
+        },
+    
+        /**
+         * Causes the test case to wait a specified amount of time and then
+         * continue executing the given code.
+         * @param {Function} segment (Optional) The function to run after the delay.
+         *      If omitted, the TestRunner will wait until resume() is called.
+         * @param {int} delay (Optional) The number of milliseconds to wait before running
+         *      the function. If omitted, defaults to zero.
+         * @return {Void}
+         * @method wait
+         */
+        wait : function (segment /*:Function*/, delay /*:int*/) /*:Void*/{
+            var args = arguments;
+            if (Y.Lang.isFunction(args[0])){
+                throw new Y.Test.Wait(args[0], args[1]);
+            } else {
+                throw new Y.Test.Wait(function(){
+                    Y.Assert.fail("Timeout: wait() called but resume() never called.");
+                }, (Y.Lang.isNumber(args[0]) ? args[0] : 10000));
+            }
+        },
+    
+        //-------------------------------------------------------------------------
+        // Stub Methods
+        //-------------------------------------------------------------------------
+    
+        /**
+         * Function to run before each test is executed.
+         * @return {Void}
+         * @method setUp
+         */
+        setUp : function () /*:Void*/ {
+        },
+        
+        /**
+         * Function to run after each test is executed.
+         * @return {Void}
+         * @method tearDown
+         */
+        tearDown: function () /*:Void*/ {    
+        }
+    };
+    
+    /**
+     * Represents a stoppage in test execution to wait for an amount of time before
+     * continuing.
+     * @param {Function} segment A function to run when the wait is over.
+     * @param {int} delay The number of milliseconds to wait before running the code.
+     * @class Wait
+     * @namespace Test
+     * @constructor
+     *
+     */
+    Y.Test.Wait = function (segment /*:Function*/, delay /*:int*/) {
+        
+        /**
+         * The segment of code to run when the wait is over.
+         * @type Function
+         * @property segment
+         */
+        this.segment /*:Function*/ = (Y.Lang.isFunction(segment) ? segment : null);
+    
+        /**
+         * The delay before running the segment of code.
+         * @type int
+         * @property delay
+         */
+        this.delay /*:int*/ = (Y.Lang.isNumber(delay) ? delay : 0);        
+    };
+
+
+        
+    Y.namespace("Test");
+    
+    /**
+     * A test suite that can contain a collection of TestCase and TestSuite objects.
+     * @param {String||Object} data The name of the test suite or an object containing
+     *      a name property as well as setUp and tearDown methods.
+     * @namespace Test
+     * @class Suite
+     * @constructor
+     */
+    Y.Test.Suite = function (data /*:String||Object*/) {
+    
+        /**
+         * The name of the test suite.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "";
+    
+        /**
+         * Array of test suites and
+         * @private
+         */
+        this.items /*:Array*/ = [];
+    
+        //initialize the properties
+        if (Y.Lang.isString(data)){
+            this.name = data;
+        } else if (Y.Lang.isObject(data)){
+            Y.mix(this, data, true);
+        }
+    
+        //double-check name
+        if (this.name === ""){
+            this.name = "testSuite" + Y.guid();
+        }
+    
+    };
+    
+    Y.Test.Suite.prototype = {
+        
+        /**
+         * Adds a test suite or test case to the test suite.
+         * @param {Y.Test.Suite||Y.Test.Case} testObject The test suite or test case to add.
+         * @return {Void}
+         * @method add
+         */
+        add : function (testObject /*:Y.Test.Suite*/) /*:Void*/ {
+            if (testObject instanceof Y.Test.Suite || testObject instanceof Y.Test.Case) {
+                this.items.push(testObject);
+            }
+        },
+        
+        //-------------------------------------------------------------------------
+        // Stub Methods
+        //-------------------------------------------------------------------------
+    
+        /**
+         * Function to run before each test is executed.
+         * @return {Void}
+         * @method setUp
+         */
+        setUp : function () /*:Void*/ {
+        },
+        
+        /**
+         * Function to run after each test is executed.
+         * @return {Void}
+         * @method tearDown
+         */
+        tearDown: function () /*:Void*/ {
+        }
+        
+    };
+
+    
+    /*
+     * Runs test suites and test cases, providing events to allowing for the
+     * interpretation of test results.
+     * @namespace Test
+     * @class Runner
+     * @static
+     */
+    Y.Test.Runner = (function(){
+    
+        /**
+         * A node in the test tree structure. May represent a TestSuite, TestCase, or
+         * test function.
+         * @param {Variant} testObject A TestSuite, TestCase, or the name of a test function.
+         * @class TestNode
+         * @constructor
+         * @private
+         */
+        function TestNode(testObject /*:Variant*/){
+        
+            /**
+             * The TestSuite, TestCase, or test function represented by this node.
+             * @type Variant
+             * @property testObject
+             */
+            this.testObject = testObject;
+            
+            /**
+             * Pointer to this node's first child.
+             * @type TestNode
+             * @property firstChild
+             */        
+            this.firstChild /*:TestNode*/ = null;
+            
+            /**
+             * Pointer to this node's last child.
+             * @type TestNode
+             * @property lastChild
+             */        
+            this.lastChild = null;
+            
+            /**
+             * Pointer to this node's parent.
+             * @type TestNode
+             * @property parent
+             */        
+            this.parent = null; 
+       
+            /**
+             * Pointer to this node's next sibling.
+             * @type TestNode
+             * @property next
+             */        
+            this.next = null;
+            
+            /**
+             * Test results for this test object.
+             * @type object
+             * @property results
+             */                
+            this.results /*:Object*/ = {
+                passed : 0,
+                failed : 0,
+                total : 0,
+                ignored : 0
+            };
+            
+            //initialize results
+            if (testObject instanceof Y.Test.Suite){
+                this.results.type = "testsuite";
+                this.results.name = testObject.name;
+            } else if (testObject instanceof Y.Test.Case){
+                this.results.type = "testcase";
+                this.results.name = testObject.name;
+            }
+           
+        }
+        
+        TestNode.prototype = {
+        
+            /**
+             * Appends a new test object (TestSuite, TestCase, or test function name) as a child
+             * of this node.
+             * @param {Variant} testObject A TestSuite, TestCase, or the name of a test function.
+             * @return {Void}
+             */
+            appendChild : function (testObject /*:Variant*/) /*:Void*/{
+                var node = new TestNode(testObject);
+                if (this.firstChild === null){
+                    this.firstChild = this.lastChild = node;
+                } else {
+                    this.lastChild.next = node;
+                    this.lastChild = node;
+                }
+                node.parent = this;
+                return node;
+            }       
+        };
+    
+        /**
+         * Runs test suites and test cases, providing events to allowing for the
+         * interpretation of test results.
+         * @namespace Test
+         * @class Runner
+         * @static
+         */
+        function TestRunner(){
+        
+            //inherit from EventProvider
+            TestRunner.superclass.constructor.apply(this,arguments);
+            
+            /**
+             * Suite on which to attach all TestSuites and TestCases to be run.
+             * @type Y.Test.Suite
+             * @property masterSuite
+             * @static
+             * @private
+             */
+            this.masterSuite /*:Y.Test.Suite*/ = new Y.Test.Suite("YUI Test Results");        
+    
+            /**
+             * Pointer to the current node in the test tree.
+             * @type TestNode
+             * @private
+             * @property _cur
+             * @static
+             */
+            this._cur = null;
+            
+            /**
+             * Pointer to the root node in the test tree.
+             * @type TestNode
+             * @private
+             * @property _root
+             * @static
+             */
+            this._root = null;
+            
+            /**
+             * Indicates if the TestRunner will log events or not.
+             * @type Boolean
+             * @property _log
+             * @private
+             * @static
+             */
+            this._log = true;
+            
+            //create events
+            var events = [
+                this.TEST_CASE_BEGIN_EVENT,
+                this.TEST_CASE_COMPLETE_EVENT,
+                this.TEST_SUITE_BEGIN_EVENT,
+                this.TEST_SUITE_COMPLETE_EVENT,
+                this.TEST_PASS_EVENT,
+                this.TEST_FAIL_EVENT,
+                this.TEST_IGNORE_EVENT,
+                this.COMPLETE_EVENT,
+                this.BEGIN_EVENT
+            ];
+            for (var i=0; i < events.length; i++){
+                this.subscribe(events[i], this._logEvent, this, true);
+            }      
+       
+        }
+        
+        Y.extend(TestRunner, Y.Event.Target, {
+        
+            //-------------------------------------------------------------------------
+            // Constants
+            //-------------------------------------------------------------------------
+             
+            /**
+             * Fires when a test case is opened but before the first 
+             * test is executed.
+             * @event testcasebegin
+             * @static
+             */         
+            TEST_CASE_BEGIN_EVENT /*:String*/ : "testcasebegin",
+            
+            /**
+             * Fires when all tests in a test case have been executed.
+             * @event testcasecomplete
+             * @static
+             */        
+            TEST_CASE_COMPLETE_EVENT /*:String*/ : "testcasecomplete",
+            
+            /**
+             * Fires when a test suite is opened but before the first 
+             * test is executed.
+             * @event testsuitebegin
+             * @static
+             */        
+            TEST_SUITE_BEGIN_EVENT /*:String*/ : "testsuitebegin",
+            
+            /**
+             * Fires when all test cases in a test suite have been
+             * completed.
+             * @event testsuitecomplete
+             * @static
+             */        
+            TEST_SUITE_COMPLETE_EVENT /*:String*/ : "testsuitecomplete",
+            
+            /**
+             * Fires when a test has passed.
+             * @event pass
+             * @static
+             */        
+            TEST_PASS_EVENT /*:String*/ : "pass",
+            
+            /**
+             * Fires when a test has failed.
+             * @event fail
+             * @static
+             */        
+            TEST_FAIL_EVENT /*:String*/ : "fail",
+            
+            /**
+             * Fires when a test has been ignored.
+             * @event ignore
+             * @static
+             */        
+            TEST_IGNORE_EVENT /*:String*/ : "ignore",
+            
+            /**
+             * Fires when all test suites and test cases have been completed.
+             * @event complete
+             * @static
+             */        
+            COMPLETE_EVENT /*:String*/ : "complete",
+            
+            /**
+             * Fires when the run() method is called.
+             * @event begin
+             * @static
+             */        
+            BEGIN_EVENT /*:String*/ : "begin",    
+            
+            //-------------------------------------------------------------------------
+            // Logging-Related Methods
+            //-------------------------------------------------------------------------
+    
+            
+            /**
+             * Disable logging via Y.log(). Test output will not be visible unless
+             * TestRunner events are subscribed to.
+             * @return {Void}
+             * @method disableLogging
+             * @static
+             */
+            disableLogging: function(){
+                this._log = false;
+            },    
+            
+            /**
+             * Enable logging via Y.log(). Test output is published and can be read via
+             * logreader.
+             * @return {Void}
+             * @method enableLogging
+             * @static
+             */
+            enableLogging: function(){
+                this._log = true;
+            },
+            
+            /**
+             * Logs TestRunner events using Y.log().
+             * @param {Object} event The event object for the event.
+             * @return {Void}
+             * @method _logEvent
+             * @private
+             * @static
+             */
+            _logEvent: function(event){
+                
+                //data variables
+                var message /*:String*/ = "";
+                var messageType /*:String*/ = "";
+                
+                switch(event.type){
+                    case this.BEGIN_EVENT:
+                        message = "Testing began at " + (new Date()).toString() + ".";
+                        messageType = "info";
+                        break;
+                        
+                    case this.COMPLETE_EVENT:
+                        message = "Testing completed at " + (new Date()).toString() + ".\nPassed:" + 
+                            event.results.passed + " Failed:" + event.results.failed + " Total:" + event.results.total;
+                        messageType = "info";
+                        break;
+                        
+                    case this.TEST_FAIL_EVENT:
+                        message = event.testName + ": " + event.error.getMessage();
+                        messageType = "fail";
+                        break;
+                        
+                    case this.TEST_IGNORE_EVENT:
+                        message = event.testName + ": ignored.";
+                        messageType = "ignore";
+                        break;
+                        
+                    case this.TEST_PASS_EVENT:
+                        message = event.testName + ": passed.";
+                        messageType = "pass";
+                        break;
+                        
+                    case this.TEST_SUITE_BEGIN_EVENT:
+                        message = "Test suite \"" + event.testSuite.name + "\" started.";
+                        messageType = "info";
+                        break;
+                        
+                    case this.TEST_SUITE_COMPLETE_EVENT:
+                        message = "Test suite \"" + event.testSuite.name + "\" completed.\nPassed:" + 
+                            event.results.passed + " Failed:" + event.results.failed + " Total:" + event.results.total;
+                        messageType = "info";
+                        break;
+                        
+                    case this.TEST_CASE_BEGIN_EVENT:
+                        message = "Test case \"" + event.testCase.name + "\" started.";
+                        messageType = "info";
+                        break;
+                        
+                    case this.TEST_CASE_COMPLETE_EVENT:
+                        message = "Test case \"" + event.testCase.name + "\" completed.\nPassed:" + 
+                            event.results.passed + " Failed:" + event.results.failed + " Total:" + event.results.total;
+                        messageType = "info";
+                        break;
+                    default:
+                        message = "Unexpected event " + event.type;
+                        message = "info";
+                }
+            
+                //only log if required
+                if (this._log){
+                    Y.log(message, messageType, "TestRunner");
+                }
+            },
+
+            //-------------------------------------------------------------------------
+            // Test Tree-Related Methods
+            //-------------------------------------------------------------------------
+    
+            /**
+             * Adds a test case to the test tree as a child of the specified node.
+             * @param {TestNode} parentNode The node to add the test case to as a child.
+             * @param {Y.Test.Case} testCase The test case to add.
+             * @return {Void}
+             * @static
+             * @private
+             * @method _addTestCaseToTestTree
+             */
+           _addTestCaseToTestTree : function (parentNode /*:TestNode*/, testCase /*:Y.Test.Case*/) /*:Void*/{
+                
+                //add the test suite
+                var node = parentNode.appendChild(testCase);
+                
+                //iterate over the items in the test case
+                for (var prop in testCase){
+                    if (prop.indexOf("test") === 0 && Y.Lang.isFunction(testCase[prop])){
+                        node.appendChild(prop);
+                    }
+                }
+             
+            },
+            
+            /**
+             * Adds a test suite to the test tree as a child of the specified node.
+             * @param {TestNode} parentNode The node to add the test suite to as a child.
+             * @param {Y.Test.Suite} testSuite The test suite to add.
+             * @return {Void}
+             * @static
+             * @private
+             * @method _addTestSuiteToTestTree
+             */
+            _addTestSuiteToTestTree : function (parentNode /*:TestNode*/, testSuite /*:Y.Test.Suite*/) /*:Void*/ {
+                
+                //add the test suite
+                var node = parentNode.appendChild(testSuite);
+                
+                //iterate over the items in the master suite
+                for (var i=0; i < testSuite.items.length; i++){
+                    if (testSuite.items[i] instanceof Y.Test.Suite) {
+                        this._addTestSuiteToTestTree(node, testSuite.items[i]);
+                    } else if (testSuite.items[i] instanceof Y.Test.Case) {
+                        this._addTestCaseToTestTree(node, testSuite.items[i]);
+                    }                   
+                }            
+            },
+            
+            /**
+             * Builds the test tree based on items in the master suite. The tree is a hierarchical
+             * representation of the test suites, test cases, and test functions. The resulting tree
+             * is stored in _root and the pointer _cur is set to the root initially.
+             * @return {Void}
+             * @static
+             * @private
+             * @method _buildTestTree
+             */
+            _buildTestTree : function () /*:Void*/ {
+            
+                this._root = new TestNode(this.masterSuite);
+                this._cur = this._root;
+                
+                //iterate over the items in the master suite
+                for (var i=0; i < this.masterSuite.items.length; i++){
+                    if (this.masterSuite.items[i] instanceof Y.Test.Suite) {
+                        this._addTestSuiteToTestTree(this._root, this.masterSuite.items[i]);
+                    } else if (this.masterSuite.items[i] instanceof Y.Test.Case) {
+                        this._addTestCaseToTestTree(this._root, this.masterSuite.items[i]);
+                    }                   
+                }            
+            
+            }, 
+        
+            //-------------------------------------------------------------------------
+            // Private Methods
+            //-------------------------------------------------------------------------
+            
+            /**
+             * Handles the completion of a test object's tests. Tallies test results 
+             * from one level up to the next.
+             * @param {TestNode} node The TestNode representing the test object.
+             * @return {Void}
+             * @method _handleTestObjectComplete
+             * @private
+             */
+            _handleTestObjectComplete : function (node /*:TestNode*/) /*:Void*/ {
+                if (Y.Lang.isObject(node.testObject)){
+                    node.parent.results.passed += node.results.passed;
+                    node.parent.results.failed += node.results.failed;
+                    node.parent.results.total += node.results.total;                
+                    node.parent.results.ignored += node.results.ignored;                
+                    node.parent.results[node.testObject.name] = node.results;
+                
+                    if (node.testObject instanceof Y.Test.Suite){
+                        node.testObject.tearDown();
+                        this.fire(this.TEST_SUITE_COMPLETE_EVENT, { testSuite: node.testObject, results: node.results});
+                    } else if (node.testObject instanceof Y.Test.Case){
+                        this.fire(this.TEST_CASE_COMPLETE_EVENT, { testCase: node.testObject, results: node.results});
+                    }      
+                } 
+            },                
+            
+            //-------------------------------------------------------------------------
+            // Navigation Methods
+            //-------------------------------------------------------------------------
+            
+            /**
+             * Retrieves the next node in the test tree.
+             * @return {TestNode} The next node in the test tree or null if the end is reached.
+             * @private
+             * @static
+             * @method _next
+             */
+            _next : function () /*:TestNode*/ {
+            
+                if (this._cur.firstChild) {
+                    this._cur = this._cur.firstChild;
+                } else if (this._cur.next) {
+                    this._cur = this._cur.next;            
+                } else {
+                    while (this._cur && !this._cur.next && this._cur !== this._root){
+                        this._handleTestObjectComplete(this._cur);
+                        this._cur = this._cur.parent;
+                    }
+                    
+                    if (this._cur == this._root){
+                        this._cur.results.type = "report";
+                        this._cur.results.timestamp = (new Date()).toLocaleString();
+                        this._cur.results.duration = (new Date()) - this._cur.results.duration;                            
+                        this.fire(this.COMPLETE_EVENT, { results: this._cur.results});
+                        this._cur = null;
+                    } else {
+                        this._handleTestObjectComplete(this._cur);               
+                        this._cur = this._cur.next;                
+                    }
+                }
+            
+                return this._cur;
+            },
+            
+            /**
+             * Runs a test case or test suite, returning the results.
+             * @param {Y.Test.Case|Y.Test.Suite} testObject The test case or test suite to run.
+             * @return {Object} Results of the execution with properties passed, failed, and total.
+             * @private
+             * @method _run
+             * @static
+             */
+            _run : function () /*:Void*/ {
+            
+                //flag to indicate if the TestRunner should wait before continuing
+                var shouldWait /*:Boolean*/ = false;
+                
+                //get the next test node
+                var node = this._next();
+                
+                if (node !== null) {
+                    var testObject = node.testObject;
+                    
+                    //figure out what to do
+                    if (Y.Lang.isObject(testObject)){
+                        if (testObject instanceof Y.Test.Suite){
+                            this.fire(this.TEST_SUITE_BEGIN_EVENT, { testSuite: testObject });
+                            testObject.setUp();
+                        } else if (testObject instanceof Y.Test.Case){
+                            this.fire(this.TEST_CASE_BEGIN_EVENT, { testCase: testObject });
+                        }
+                        
+                        //some environments don't support setTimeout
+                        if (typeof setTimeout != "undefined"){                    
+                            setTimeout(function(){
+                                Y.Test.Runner._run();
+                            }, 0);
+                        } else {
+                            this._run();
+                        }
+                    } else {
+                        this._runTest(node);
+                    }
+    
+                }
+            },
+            
+            _resumeTest : function (segment /*:Function*/) /*:Void*/ {
+            
+                //get relevant information
+                var node /*:TestNode*/ = this._cur;
+                
+                //if there's no node, it probably means a wait() was called after resume()
+                if (!node){
+                    //TODO: Handle in some way?
+                    //console.log("wait() called after resume()");
+                    //this.fire("error", { testCase: "(unknown)", test: "(unknown)", error: new Error("wait() called after resume()")} );
+                    return;
+                }
+                
+                var testName /*:String*/ = node.testObject;
+                var testCase /*:Y.Test.Case*/ = node.parent.testObject;
+            
+                //cancel other waits if available
+                if (testCase.__yui_wait){
+                    clearTimeout(testCase.__yui_wait);
+                    delete testCase.__yui_wait;
+                }
+
+                //get the "should" test cases
+                var shouldFail /*:Object*/ = (testCase._should.fail || {})[testName];
+                var shouldError /*:Object*/ = (testCase._should.error || {})[testName];
+                
+                //variable to hold whether or not the test failed
+                var failed /*:Boolean*/ = false;
+                var error /*:Error*/ = null;
+                    
+                //try the test
+                try {
+                
+                    //run the test
+                    segment.apply(testCase);
+                    
+                    //if it should fail, and it got here, then it's a fail because it didn't
+                    if (shouldFail){
+                        error = new Y.Assert.ShouldFail();
+                        failed = true;
+                    } else if (shouldError){
+                        error = new Y.Assert.ShouldError();
+                        failed = true;
+                    }
+                               
+                } catch (thrown /*:Error*/){
+
+                    //cancel any pending waits, the test already failed
+                    if (testCase.__yui_wait){
+                        clearTimeout(testCase.__yui_wait);
+                        delete testCase.__yui_wait;
+                    }                    
+                
+                    //figure out what type of error it was
+                    if (thrown instanceof Y.Assert.Error) {
+                        if (!shouldFail){
+                            error = thrown;
+                            failed = true;
+                        }
+                    } else if (thrown instanceof Y.Test.Wait){
+                    
+                        if (Y.Lang.isFunction(thrown.segment)){
+                            if (Y.Lang.isNumber(thrown.delay)){
+                            
+                                //some environments don't support setTimeout
+                                if (typeof setTimeout != "undefined"){
+                                    testCase.__yui_wait = setTimeout(function(){
+                                        Y.Test.Runner._resumeTest(thrown.segment);
+                                    }, thrown.delay);
+                                } else {
+                                    throw new Error("Asynchronous tests not supported in this environment.");
+                                }
+                            }
+                        }
+                        
+                        return;
+                    
+                    } else {
+                        //first check to see if it should error
+                        if (!shouldError) {                        
+                            error = new Y.Assert.UnexpectedError(thrown);
+                            failed = true;
+                        } else {
+                            //check to see what type of data we have
+                            if (Y.Lang.isString(shouldError)){
+                                
+                                //if it's a string, check the error message
+                                if (thrown.message != shouldError){
+                                    error = new Y.Assert.UnexpectedError(thrown);
+                                    failed = true;                                    
+                                }
+                            } else if (Y.Lang.isFunction(shouldError)){
+                            
+                                //if it's a function, see if the error is an instance of it
+                                if (!(thrown instanceof shouldError)){
+                                    error = new Y.Assert.UnexpectedError(thrown);
+                                    failed = true;
+                                }
+                            
+                            } else if (Y.Lang.isObject(shouldError)){
+                            
+                                //if it's an object, check the instance and message
+                                if (!(thrown instanceof shouldError.constructor) || 
+                                        thrown.message != shouldError.message){
+                                    error = new Y.Assert.UnexpectedError(thrown);
+                                    failed = true;                                    
+                                }
+                            
+                            }
+                        
+                        }
+                    }
+                    
+                }
+                
+                //fire appropriate event
+                if (failed) {
+                    this.fire(this.TEST_FAIL_EVENT, { testCase: testCase, testName: testName, error: error });
+                } else {
+                    this.fire(this.TEST_PASS_EVENT, { testCase: testCase, testName: testName });
+                }
+                
+                //run the tear down
+                testCase.tearDown();
+                
+                //update results
+                node.parent.results[testName] = { 
+                    result: failed ? "fail" : "pass",
+                    message: error ? error.getMessage() : "Test passed",
+                    type: "test",
+                    name: testName
+                };
+                
+                if (failed){
+                    node.parent.results.failed++;
+                } else {
+                    node.parent.results.passed++;
+                }
+                node.parent.results.total++;
+    
+                //set timeout not supported in all environments
+                if (typeof setTimeout != "undefined"){
+                    setTimeout(function(){
+                        Y.Test.Runner._run();
+                    }, 0);
+                } else {
+                    this._run();
+                }
+            
+            },
+                    
+            /**
+             * Runs a single test based on the data provided in the node.
+             * @param {TestNode} node The TestNode representing the test to run.
+             * @return {Void}
+             * @static
+             * @private
+             * @name _runTest
+             */
+            _runTest : function (node /*:TestNode*/) /*:Void*/ {
+            
+                //get relevant information
+                var testName /*:String*/ = node.testObject;
+                var testCase /*:Y.Test.Case*/ = node.parent.testObject;
+                var test /*:Function*/ = testCase[testName];
+                
+                //get the "should" test cases
+                var shouldIgnore /*:Object*/ = (testCase._should.ignore || {})[testName];
+                
+                //figure out if the test should be ignored or not
+                if (shouldIgnore){
+                
+                    //update results
+                    node.parent.results[testName] = { 
+                        result: "ignore",
+                        message: "Test ignored",
+                        type: "test",
+                        name: testName
+                    };
+                    
+                    node.parent.results.ignored++;
+                    node.parent.results.total++;
+                
+                    this.fire(this.TEST_IGNORE_EVENT, { testCase: testCase, testName: testName });
+                    
+                    //some environments don't support setTimeout
+                    if (typeof setTimeout != "undefined"){                    
+                        setTimeout(function(){
+                            Y.Test.Runner._run();
+                        }, 0);              
+                    } else {
+                        this._run();
+                    }
+    
+                } else {
+                
+                    //run the setup
+                    testCase.setUp();
+                    
+                    //now call the body of the test
+                    this._resumeTest(test);                
+                }
+    
+            },        
+            
+            //-------------------------------------------------------------------------
+            // Protected Methods
+            //-------------------------------------------------------------------------   
+        
+            /*
+             * Fires events for the TestRunner. This overrides the default fire()
+             * method from EventProvider to add the type property to the data that is
+             * passed through on each event call.
+             * @param {String} type The type of event to fire.
+             * @param {Object} data (Optional) Data for the event.
+             * @method fire
+             * @static
+             * @protected
+             */
+            fire : function (type /*:String*/, data /*:Object*/) /*:Void*/ {
+                data = data || {};
+                data.type = type;
+                TestRunner.superclass.fire.call(this, type, data);
+            },
+            
+            //-------------------------------------------------------------------------
+            // Public Methods
+            //-------------------------------------------------------------------------   
+        
+            /**
+             * Adds a test suite or test case to the list of test objects to run.
+             * @param testObject Either a TestCase or a TestSuite that should be run.
+             * @return {Void}
+             * @method add
+             * @static
+             */
+            add : function (testObject /*:Object*/) /*:Void*/ {
+                this.masterSuite.add(testObject);
+            },
+            
+            /**
+             * Removes all test objects from the runner.
+             * @return {Void}
+             * @method clear
+             * @static
+             */
+            clear : function () /*:Void*/ {
+                this.masterSuite.items = [];
+            },
+            
+            /**
+             * Resumes the TestRunner after wait() was called.
+             * @param {Function} segment The function to run as the rest
+             *      of the haulted test.
+             * @return {Void}
+             * @method resume
+             * @static
+             */
+            resume : function (segment /*:Function*/) /*:Void*/ {
+                this._resumeTest(segment || function(){});
+            },
+        
+            /**
+             * Runs the test suite.
+             * @return {Void}
+             * @method run
+             * @static
+             */
+            run : function (testObject /*:Object*/) /*:Void*/ {
+                
+                //pointer to runner to avoid scope issues 
+                var runner = Y.Test.Runner;
+    
+                //build the test tree
+                runner._buildTestTree();
+                            
+                //set when the test started
+                runner._root.results.duration = (new Date()).valueOf();
+                
+                //fire the begin event
+                runner.fire(runner.BEGIN_EVENT);
+           
+                //begin the testing
+                runner._run();
+            }    
+        });
+        
+        return new TestRunner();
+        
+    })();
+
+  
+    /**
+     * The Assert object provides functions to test JavaScript values against
+     * known and expected results. Whenever a comparison (assertion) fails,
+     * an error is thrown.
+     *
+     * @class Assert
+     * @static
+     */
+    Y.Assert = {
+    
+        //-------------------------------------------------------------------------
+        // Helper Methods
+        //-------------------------------------------------------------------------
+        
+        /**
+         * Formats a message so that it can contain the original assertion message
+         * in addition to the custom message.
+         * @param {String} customMessage The message passed in by the developer.
+         * @param {String} defaultMessage The message created by the error by default.
+         * @return {String} The final error message, containing either or both.
+         * @protected
+         * @static
+         * @method _formatMessage
+         */
+        _formatMessage : function (customMessage /*:String*/, defaultMessage /*:String*/) /*:String*/ {
+            var message = customMessage;
+            if (Y.Lang.isString(customMessage) && customMessage.length > 0){
+                return Y.Lang.substitute(customMessage, { message: defaultMessage });
+            } else {
+                return defaultMessage;
+            }        
+        },
+        
+        //-------------------------------------------------------------------------
+        // Generic Assertion Methods
+        //-------------------------------------------------------------------------
+        
+        /** 
+         * Forces an assertion error to occur.
+         * @param {String} message (Optional) The message to display with the failure.
+         * @method fail
+         * @static
+         */
+        fail : function (message /*:String*/) /*:Void*/ {
+            throw new Y.Assert.Error(Y.Assert._formatMessage(message, "Test force-failed."));
+        },       
+        
+        //-------------------------------------------------------------------------
+        // Equality Assertion Methods
+        //-------------------------------------------------------------------------    
+        
+        /**
+         * Asserts that a value is equal to another. This uses the double equals sign
+         * so type cohersion may occur.
+         * @param {Object} expected The expected value.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method areEqual
+         * @static
+         */
+        areEqual : function (expected /*:Object*/, actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (expected != actual) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Values should be equal."), expected, actual);
+            }
+        },
+        
+        /**
+         * Asserts that a value is not equal to another. This uses the double equals sign
+         * so type cohersion may occur.
+         * @param {Object} unexpected The unexpected value.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method areNotEqual
+         * @static
+         */
+        areNotEqual : function (unexpected /*:Object*/, actual /*:Object*/, 
+                             message /*:String*/) /*:Void*/ {
+            if (unexpected == actual) {
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Values should not be equal."), unexpected);
+            }
+        },
+        
+        /**
+         * Asserts that a value is not the same as another. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} unexpected The unexpected value.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method areNotSame
+         * @static
+         */
+        areNotSame : function (unexpected /*:Object*/, actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (unexpected === actual) {
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Values should not be the same."), unexpected);
+            }
+        },
+    
+        /**
+         * Asserts that a value is the same as another. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} expected The expected value.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method areSame
+         * @static
+         */
+        areSame : function (expected /*:Object*/, actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (expected !== actual) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Values should be the same."), expected, actual);
+            }
+        },    
+        
+        //-------------------------------------------------------------------------
+        // Boolean Assertion Methods
+        //-------------------------------------------------------------------------    
+        
+        /**
+         * Asserts that a value is false. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isFalse
+         * @static
+         */
+        isFalse : function (actual /*:Boolean*/, message /*:String*/) {
+            if (false !== actual) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be false."), false, actual);
+            }
+        },
+        
+        /**
+         * Asserts that a value is true. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isTrue
+         * @static
+         */
+        isTrue : function (actual /*:Boolean*/, message /*:String*/) /*:Void*/ {
+            if (true !== actual) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be true."), true, actual);
+            }
+    
+        },
+        
+        //-------------------------------------------------------------------------
+        // Special Value Assertion Methods
+        //-------------------------------------------------------------------------    
+        
+        /**
+         * Asserts that a value is not a number.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNaN
+         * @static
+         */
+        isNaN : function (actual /*:Object*/, message /*:String*/) /*:Void*/{
+            if (!isNaN(actual)){
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be NaN."), NaN, actual);
+            }    
+        },
+        
+        /**
+         * Asserts that a value is not the special NaN value.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNotNaN
+         * @static
+         */
+        isNotNaN : function (actual /*:Object*/, message /*:String*/) /*:Void*/{
+            if (isNaN(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Values should not be NaN."), NaN);
+            }    
+        },
+        
+        /**
+         * Asserts that a value is not null. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNotNull
+         * @static
+         */
+        isNotNull : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (Y.Lang.isNull(actual)) {
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Values should not be null."), null);
+            }
+        },
+    
+        /**
+         * Asserts that a value is not undefined. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNotUndefined
+         * @static
+         */
+        isNotUndefined : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (Y.Lang.isUndefined(actual)) {
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should not be undefined."), undefined);
+            }
+        },
+    
+        /**
+         * Asserts that a value is null. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNull
+         * @static
+         */
+        isNull : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isNull(actual)) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be null."), null, actual);
+            }
+        },
+            
+        /**
+         * Asserts that a value is undefined. This uses the triple equals sign
+         * so no type cohersion may occur.
+         * @param {Object} actual The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isUndefined
+         * @static
+         */
+        isUndefined : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isUndefined(actual)) {
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be undefined."), undefined, actual);
+            }
+        },    
+        
+        //--------------------------------------------------------------------------
+        // Instance Assertion Methods
+        //--------------------------------------------------------------------------    
+       
+        /**
+         * Asserts that a value is an array.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isArray
+         * @static
+         */
+        isArray : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isArray(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be an array."), actual);
+            }    
+        },
+       
+        /**
+         * Asserts that a value is a Boolean.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isBoolean
+         * @static
+         */
+        isBoolean : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isBoolean(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be a Boolean."), actual);
+            }    
+        },
+       
+        /**
+         * Asserts that a value is a function.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isFunction
+         * @static
+         */
+        isFunction : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isFunction(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be a function."), actual);
+            }    
+        },
+       
+        /**
+         * Asserts that a value is an instance of a particular object. This may return
+         * incorrect results when comparing objects from one frame to constructors in
+         * another frame. For best results, don't use in a cross-frame manner.
+         * @param {Function} expected The function that the object should be an instance of.
+         * @param {Object} actual The object to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isInstanceOf
+         * @static
+         */
+        isInstanceOf : function (expected /*:Function*/, actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!(actual instanceof expected)){
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value isn't an instance of expected type."), expected, actual);
+            }
+        },
+        
+        /**
+         * Asserts that a value is a number.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNumber
+         * @static
+         */
+        isNumber : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isNumber(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be a number."), actual);
+            }    
+        },    
+        
+        /**
+         * Asserts that a value is an object.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isObject
+         * @static
+         */
+        isObject : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isObject(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be an object."), actual);
+            }
+        },
+        
+        /**
+         * Asserts that a value is a string.
+         * @param {Object} actual The value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isString
+         * @static
+         */
+        isString : function (actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Lang.isString(actual)){
+                throw new Y.Assert.UnexpectedValue(Y.Assert._formatMessage(message, "Value should be a string."), actual);
+            }
+        },
+        
+        /**
+         * Asserts that a value is of a particular type. 
+         * @param {String} expectedType The expected type of the variable.
+         * @param {Object} actualValue The actual value to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isTypeOf
+         * @static
+         */
+        isTypeOf : function (expectedType /*:String*/, actualValue /*:Object*/, message /*:String*/) /*:Void*/{
+            if (typeof actualValue != expectedType){
+                throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Value should be of type " + expectedType + "."), expected, typeof actualValue);
+            }
+        }
+    };
+    
+    //-----------------------------------------------------------------------------
+    // Assertion errors
+    //-----------------------------------------------------------------------------
+    
+    /**
+     * Error is thrown whenever an assertion fails. It provides methods
+     * to more easily get at error information and also provides a base class
+     * from which more specific assertion errors can be derived.
+     *
+     * @param {String} message The message to display when the error occurs.
+     * @namespace Assert
+     * @class Error
+     * @constructor
+     */ 
+    Y.Assert.Error = function (message /*:String*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, message);
+        
+        /*
+         * Error message. Must be duplicated to ensure browser receives it.
+         * @type String
+         * @property message
+         */
+        this.message /*:String*/ = message;
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "Assert Error";
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.Error, Error, {
+    
+        /**
+         * Returns a fully formatted error for an assertion failure. This should
+         * be overridden by all subclasses to provide specific information.
+         * @method getMessage
+         * @return {String} A string describing the error.
+         */
+        getMessage : function () /*:String*/ {
+            return this.message;
+        },
+        
+        /**
+         * Returns a string representation of the error.
+         * @method toString
+         * @return {String} A string representation of the error.
+         */
+        toString : function () /*:String*/ {
+            return this.name + ": " + this.getMessage();
+        },
+        
+        /**
+         * Returns a primitive value version of the error. Same as toString().
+         * @method valueOf
+         * @return {String} A primitive value version of the error.
+         */
+        valueOf : function () /*:String*/ {
+            return this.toString();
+        }
+    
+    });
+    
+    /**
+     * ComparisonFailure is subclass of Error that is thrown whenever
+     * a comparison between two values fails. It provides mechanisms to retrieve
+     * both the expected and actual value.
+     *
+     * @param {String} message The message to display when the error occurs.
+     * @param {Object} expected The expected value.
+     * @param {Object} actual The actual value that caused the assertion to fail.
+     * @namespace Assert 
+     * @extends Assert.Error
+     * @class ComparisonFailure
+     * @constructor
+     */ 
+    Y.Assert.ComparisonFailure = function (message /*:String*/, expected /*:Object*/, actual /*:Object*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, message);
+        
+        /**
+         * The expected value.
+         * @type Object
+         * @property expected
+         */
+        this.expected /*:Object*/ = expected;
+        
+        /**
+         * The actual value.
+         * @type Object
+         * @property actual
+         */
+        this.actual /*:Object*/ = actual;
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "ComparisonFailure";
+        
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.ComparisonFailure, Y.Assert.Error, {
+    
+        /**
+         * Returns a fully formatted error for an assertion failure. This message
+         * provides information about the expected and actual values.
+         * @method toString
+         * @return {String} A string describing the error.
+         */
+        getMessage : function () /*:String*/ {
+            return this.message + "\nExpected: " + this.expected + " (" + (typeof this.expected) + ")"  +
+                "\nActual:" + this.actual + " (" + (typeof this.actual) + ")";
+        }
+    
+    });
+    
+    /**
+     * UnexpectedValue is subclass of Error that is thrown whenever
+     * a value was unexpected in its scope. This typically means that a test
+     * was performed to determine that a value was *not* equal to a certain
+     * value.
+     *
+     * @param {String} message The message to display when the error occurs.
+     * @param {Object} unexpected The unexpected value.
+     * @namespace Assert
+     * @extends Assert.Error
+     * @class UnexpectedValue
+     * @constructor
+     */ 
+    Y.Assert.UnexpectedValue = function (message /*:String*/, unexpected /*:Object*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, message);
+        
+        /**
+         * The unexpected value.
+         * @type Object
+         * @property unexpected
+         */
+        this.unexpected /*:Object*/ = unexpected;
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "UnexpectedValue";
+        
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.UnexpectedValue, Y.Assert.Error, {
+    
+        /**
+         * Returns a fully formatted error for an assertion failure. The message
+         * contains information about the unexpected value that was encountered.
+         * @method getMessage
+         * @return {String} A string describing the error.
+         */
+        getMessage : function () /*:String*/ {
+            return this.message + "\nUnexpected: " + this.unexpected + " (" + (typeof this.unexpected) + ") ";
+        }
+    
+    });
+    
+    /**
+     * ShouldFail is subclass of Error that is thrown whenever
+     * a test was expected to fail but did not.
+     *
+     * @param {String} message The message to display when the error occurs.
+     * @namespace Assert
+     * @extends Assert.Error
+     * @class ShouldFail
+     * @constructor
+     */  
+    Y.Assert.ShouldFail = function (message /*:String*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, message || "This test should fail but didn't.");
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "ShouldFail";
+        
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.ShouldFail, Y.Assert.Error);
+    
+    /**
+     * ShouldError is subclass of Error that is thrown whenever
+     * a test is expected to throw an error but doesn't.
+     *
+     * @param {String} message The message to display when the error occurs.
+     * @namespace Assert
+     * @extends Assert.Error
+     * @class ShouldError
+     * @constructor
+     */  
+    Y.Assert.ShouldError = function (message /*:String*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, message || "This test should have thrown an error but didn't.");
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "ShouldError";
+        
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.ShouldError, Y.Assert.Error);
+    
+    /**
+     * UnexpectedError is subclass of Error that is thrown whenever
+     * an error occurs within the course of a test and the test was not expected
+     * to throw an error.
+     *
+     * @param {Error} cause The unexpected error that caused this error to be 
+     *                      thrown.
+     * @namespace Assert
+     * @extends Assert.Error
+     * @class UnexpectedError
+     * @constructor
+     */  
+    Y.Assert.UnexpectedError = function (cause /*:Object*/){
+    
+        //call superclass
+        arguments.callee.superclass.constructor.call(this, "Unexpected error: " + cause.message);
+        
+        /**
+         * The unexpected error that occurred.
+         * @type Error
+         * @property cause
+         */
+        this.cause /*:Error*/ = cause;
+        
+        /**
+         * The name of the error that occurred.
+         * @type String
+         * @property name
+         */
+        this.name /*:String*/ = "UnexpectedError";
+        
+        /**
+         * Stack information for the error (if provided).
+         * @type String
+         * @property stack
+         */
+        this.stack /*:String*/ = cause.stack;
+        
+    };
+    
+    //inherit methods
+    Y.extend(Y.Assert.UnexpectedError, Y.Assert.Error);
+    
+
+    
+    /**
+     * The ArrayAssert object provides functions to test JavaScript array objects
+     * for a variety of cases.
+     *
+     * @class ArrayAssert
+     * @static
+     */
+     
+    Y.ArrayAssert = {
+    
+        /**
+         * Asserts that a value is present in an array. This uses the triple equals 
+         * sign so no type cohersion may occur.
+         * @param {Object} needle The value that is expected in the array.
+         * @param {Array} haystack An array of values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method contains
+         * @static
+         */
+        contains : function (needle /*:Object*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+            
+            var found /*:Boolean*/ = false;
+            
+            //begin checking values
+            for (var i=0; i < haystack.length && !found; i++){
+                if (haystack[i] === needle) {
+                    found = true;
+                }
+            }
+            
+            if (!found){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Value " + needle + " (" + (typeof needle) + ") not found in array [" + haystack + "]."));
+            }
+        },
+    
+        /**
+         * Asserts that a set of values are present in an array. This uses the triple equals 
+         * sign so no type cohersion may occur. For this assertion to pass, all values must
+         * be found.
+         * @param {Object[]} needles An array of values that are expected in the array.
+         * @param {Array} haystack An array of values to check.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method containsItems
+         * @static
+         */
+        containsItems : function (needles /*:Object[]*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+    
+            //begin checking values
+            for (var i=0; i < needles.length; i++){
+                this.contains(needles[i], haystack, message);
+            }
+        },
+    
+        /**
+         * Asserts that a value matching some condition is present in an array. This uses
+         * a function to determine a match.
+         * @param {Function} matcher A function that returns true if the items matches or false if not.
+         * @param {Array} haystack An array of values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method containsMatch
+         * @static
+         */
+        containsMatch : function (matcher /*:Function*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+            
+            //check for valid matcher
+            if (typeof matcher != "function"){
+                throw new TypeError("ArrayAssert.containsMatch(): First argument must be a function.");
+            }
+            
+            var found /*:Boolean*/ = false;
+            
+            //begin checking values
+            for (var i=0; i < haystack.length && !found; i++){
+                if (matcher(haystack[i])) {
+                    found = true;
+                }
+            }
+            
+            if (!found){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "No match found in array [" + haystack + "]."));
+            }
+        },
+    
+        /**
+         * Asserts that a value is not present in an array. This uses the triple equals 
+         * Asserts that a value is not present in an array. This uses the triple equals 
+         * sign so no type cohersion may occur.
+         * @param {Object} needle The value that is expected in the array.
+         * @param {Array} haystack An array of values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method doesNotContain
+         * @static
+         */
+        doesNotContain : function (needle /*:Object*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+            
+            var found /*:Boolean*/ = false;
+            
+            //begin checking values
+            for (var i=0; i < haystack.length && !found; i++){
+                if (haystack[i] === needle) {
+                    found = true;
+                }
+            }
+            
+            if (found){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Value found in array [" + haystack + "]."));
+            }
+        },
+    
+        /**
+         * Asserts that a set of values are not present in an array. This uses the triple equals 
+         * sign so no type cohersion may occur. For this assertion to pass, all values must
+         * not be found.
+         * @param {Object[]} needles An array of values that are not expected in the array.
+         * @param {Array} haystack An array of values to check.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method doesNotContainItems
+         * @static
+         */
+        doesNotContainItems : function (needles /*:Object[]*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+    
+            for (var i=0; i < needles.length; i++){
+                this.doesNotContain(needles[i], haystack, message);
+            }
+    
+        },
+            
+        /**
+         * Asserts that no values matching a condition are present in an array. This uses
+         * a function to determine a match.
+         * @param {Function} matcher A function that returns true if the items matches or false if not.
+         * @param {Array} haystack An array of values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method doesNotContainMatch
+         * @static
+         */
+        doesNotContainMatch : function (matcher /*:Function*/, haystack /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+            
+            //check for valid matcher
+            if (typeof matcher != "function"){
+                throw new TypeError("ArrayAssert.doesNotContainMatch(): First argument must be a function.");
+            }
+    
+            var found /*:Boolean*/ = false;
+            
+            //begin checking values
+            for (var i=0; i < haystack.length && !found; i++){
+                if (matcher(haystack[i])) {
+                    found = true;
+                }
+            }
+            
+            if (found){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Value found in array [" + haystack + "]."));
+            }
+        },
+            
+        /**
+         * Asserts that the given value is contained in an array at the specified index.
+         * This uses the triple equals sign so no type cohersion will occur.
+         * @param {Object} needle The value to look for.
+         * @param {Array} haystack The array to search in.
+         * @param {int} index The index at which the value should exist.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method indexOf
+         * @static
+         */
+        indexOf : function (needle /*:Object*/, haystack /*:Array*/, index /*:int*/, message /*:String*/) /*:Void*/ {
+        
+            //try to find the value in the array
+            for (var i=0; i < haystack.length; i++){
+                if (haystack[i] === needle){
+                    Y.Assert.areEqual(index, i, message || "Value exists at index " + i + " but should be at index " + index + ".");
+                    return;
+                }
+            }
+            
+            //if it makes it here, it wasn't found at all
+            Y.Assert.fail(Y.Assert._formatMessage(message, "Value doesn't exist in array [" + haystack + "]."));
+        },
+            
+        /**
+         * Asserts that the values in an array are equal, and in the same position,
+         * as values in another array. This uses the double equals sign
+         * so type cohersion may occur. Note that the array objects themselves
+         * need not be the same for this test to pass.
+         * @param {Array} expected An array of the expected values.
+         * @param {Array} actual Any array of the actual values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method itemsAreEqual
+         * @static
+         */
+        itemsAreEqual : function (expected /*:Array*/, actual /*:Array*/, 
+                               message /*:String*/) /*:Void*/ {
+            
+            //one may be longer than the other, so get the maximum length
+            var len /*:int*/ = Math.max(expected.length, actual.length);
+           
+            //begin checking values
+            for (var i=0; i < len; i++){
+                Y.Assert.areEqual(expected[i], actual[i], 
+                    Y.Assert._formatMessage(message, "Values in position " + i + " are not equal."));
+            }
+        },
+        
+        /**
+         * Asserts that the values in an array are equivalent, and in the same position,
+         * as values in another array. This uses a function to determine if the values
+         * are equivalent. Note that the array objects themselves
+         * need not be the same for this test to pass.
+         * @param {Array} expected An array of the expected values.
+         * @param {Array} actual Any array of the actual values.
+         * @param {Function} comparator A function that returns true if the values are equivalent
+         *      or false if not.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @return {Void}
+         * @method itemsAreEquivalent
+         * @static
+         */
+        itemsAreEquivalent : function (expected /*:Array*/, actual /*:Array*/, 
+                               comparator /*:Function*/, message /*:String*/) /*:Void*/ {
+            
+            //make sure the comparator is valid
+            if (typeof comparator != "function"){
+                throw new TypeError("ArrayAssert.itemsAreEquivalent(): Third argument must be a function.");
+            }
+            
+            //one may be longer than the other, so get the maximum length
+            var len /*:int*/ = Math.max(expected.length, actual.length);
+            
+            //begin checking values
+            for (var i=0; i < len; i++){
+                if (!comparator(expected[i], actual[i])){
+                    throw new Y.Assert.ComparisonFailure(Y.Assert._formatMessage(message, "Values in position " + i + " are not equivalent."), expected[i], actual[i]);
+                }
+            }
+        },
+        
+        /**
+         * Asserts that an array is empty.
+         * @param {Array} actual The array to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isEmpty
+         * @static
+         */
+        isEmpty : function (actual /*:Array*/, message /*:String*/) /*:Void*/ {        
+            if (actual.length > 0){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Array should be empty."));
+            }
+        },    
+        
+        /**
+         * Asserts that an array is not empty.
+         * @param {Array} actual The array to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method isNotEmpty
+         * @static
+         */
+        isNotEmpty : function (actual /*:Array*/, message /*:String*/) /*:Void*/ {        
+            if (actual.length === 0){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Array should not be empty."));
+            }
+        },    
+        
+        /**
+         * Asserts that the values in an array are the same, and in the same position,
+         * as values in another array. This uses the triple equals sign
+         * so no type cohersion will occur. Note that the array objects themselves
+         * need not be the same for this test to pass.
+         * @param {Array} expected An array of the expected values.
+         * @param {Array} actual Any array of the actual values.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method itemsAreSame
+         * @static
+         */
+        itemsAreSame : function (expected /*:Array*/, actual /*:Array*/, 
+                              message /*:String*/) /*:Void*/ {
+            
+            //one may be longer than the other, so get the maximum length
+            var len /*:int*/ = Math.max(expected.length, actual.length);
+            
+            //begin checking values
+            for (var i=0; i < len; i++){
+                Y.Assert.areSame(expected[i], actual[i], 
+                    Y.Assert._formatMessage(message, "Values in position " + i + " are not the same."));
+            }
+        },
+        
+        /**
+         * Asserts that the given value is contained in an array at the specified index,
+         * starting from the back of the array.
+         * This uses the triple equals sign so no type cohersion will occur.
+         * @param {Object} needle The value to look for.
+         * @param {Array} haystack The array to search in.
+         * @param {int} index The index at which the value should exist.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method lastIndexOf
+         * @static
+         */
+        lastIndexOf : function (needle /*:Object*/, haystack /*:Array*/, index /*:int*/, message /*:String*/) /*:Void*/ {
+        
+            //try to find the value in the array
+            for (var i=haystack.length; i >= 0; i--){
+                if (haystack[i] === needle){
+                    Y.Assert.areEqual(index, i, Y.Assert._formatMessage(message, "Value exists at index " + i + " but should be at index " + index + "."));
+                    return;
+                }
+            }
+            
+            //if it makes it here, it wasn't found at all
+            Y.Assert.fail(Y.Assert._formatMessage(message, "Value doesn't exist in array."));        
+        }
+        
+    };
+
+
+    /**
+     * The ObjectAssert object provides functions to test JavaScript objects
+     * for a variety of cases.
+     *
+     * @class ObjectAssert
+     * @static
+     */
+    Y.ObjectAssert = {
+    
+        areEqual: function(expected /*:Object*/, actual /*:Object*/, message /*:String*/) /*:Void*/ {
+            Y.Object.each(expected, function(value, name){
+                Y.Assert.areEqual(expected[name], actual[name], Y.Assert._formatMessage(message, "Values should be equal for property " + name));
+            });            
+        },
+        
+        /**
+         * Asserts that an object has a property with the given name.
+         * @param {String} propertyName The name of the property to test.
+         * @param {Object} object The object to search.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method has
+         * @static
+         */    
+        has : function (propertyName /*:String*/, object /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!(propertyName in object)){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Property '" + propertyName + "' not found on object."));
+            }    
+        },
+        
+        /**
+         * Asserts that an object has all properties of a reference object.
+         * @param {Object} refObject The object whose properties should be on the object to test.
+         * @param {Object} object The object to search.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method hasAll
+         * @static
+         */    
+        hasAll : function (refObject /*:Object*/, object /*:Object*/, message /*:String*/) /*:Void*/ {
+            Y.Object.each(refObject, function(value, name){
+                if (!(name in object)){
+                    Y.Assert.fail(Y.Assert._formatMessage(message, "Property '" + name + "' not found on object."));
+                }    
+            });
+        },
+        
+        /**
+         * Asserts that a property with the given name exists on an object instance (not on its prototype).
+         * @param {String} propertyName The name of the property to test.
+         * @param {Object} object The object to search.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method owns
+         * @static
+         */    
+        owns : function (propertyName /*:String*/, object /*:Object*/, message /*:String*/) /*:Void*/ {
+            if (!Y.Object.owns(object, propertyName)){
+                Y.Assert.fail(Y.Assert._formatMessage(message, "Property '" + propertyName + "' not found on object instance."));
+            }     
+        },
+        
+        /**
+         * Asserts that all properties on a given object also exist on an object instance (not on its prototype).
+         * @param {Object} refObject The object whose properties should be owned by the object to test.
+         * @param {Object} object The object to search.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method ownsAll
+         * @static
+         */    
+        ownsAll : function (refObject /*:Object*/, object /*:Object*/, message /*:String*/) /*:Void*/ {
+            Y.Object.each(refObject, function(value, name){
+                if (!Y.Object.owns(object, name)){
+                    Y.Assert.fail(Y.Assert._formatMessage(message, "Property '" + name + "' not found on object instance."));
+                }     
+            });
+        }
+    };
+
+
+    
+    /**
+     * The DateAssert object provides functions to test JavaScript Date objects
+     * for a variety of cases.
+     *
+     * @class DateAssert
+     * @static
+     */
+     
+    Y.DateAssert = {
+    
+        /**
+         * Asserts that a date's month, day, and year are equal to another date's.
+         * @param {Date} expected The expected date.
+         * @param {Date} actual The actual date to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method datesAreEqual
+         * @static
+         */
+        datesAreEqual : function (expected /*:Date*/, actual /*:Date*/, message /*:String*/){
+            if (expected instanceof Date && actual instanceof Date){
+                Y.AssertareEqual(expected.getFullYear(), actual.getFullYear(), Y.Assert_formatMessage(message, "Years should be equal."));
+                Y.AssertareEqual(expected.getMonth(), actual.getMonth(), Y.Assert_formatMessage(message, "Months should be equal."));
+                Y.AssertareEqual(expected.getDate(), actual.getDate(), Y.Assert_formatMessage(message, "Day of month should be equal."));
+            } else {
+                throw new TypeError("DateY.AssertdatesAreEqual(): Expected and actual values must be Date objects.");
+            }
+        },
+    
+        /**
+         * Asserts that a date's hour, minutes, and seconds are equal to another date's.
+         * @param {Date} expected The expected date.
+         * @param {Date} actual The actual date to test.
+         * @param {String} message (Optional) The message to display if the assertion fails.
+         * @method timesAreEqual
+         * @static
+         */
+        timesAreEqual : function (expected /*:Date*/, actual /*:Date*/, message /*:String*/){
+            if (expected instanceof Date && actual instanceof Date){
+                Y.AssertareEqual(expected.getHours(), actual.getHours(), Y.Assert_formatMessage(message, "Hours should be equal."));
+                Y.AssertareEqual(expected.getMinutes(), actual.getMinutes(), Y.Assert_formatMessage(message, "Minutes should be equal."));
+                Y.AssertareEqual(expected.getSeconds(), actual.getSeconds(), Y.Assert_formatMessage(message, "Seconds should be equal."));
+            } else {
+                throw new TypeError("DateY.AsserttimesAreEqual(): Expected and actual values must be Date objects.");
+            }
+        }
+        
+    };
+
+    
+    Y.namespace("Test.Format");
+    
+    /**
+     * Returns test results formatted as a JSON string. Requires JSON utility.
+     * @param {Object} result The results object created by TestRunner.
+     * @return {String} A JSON-formatted string of results.
+     * @namespace Test.Format
+     * @method JSON
+     * @static
+     */
+    Y.Test.Format.JSON = function(results /*:Object*/) /*:String*/ {
+        return Y.JSON.stringify(results);
+    };
+    
+    /**
+     * Returns test results formatted as an XML string.
+     * @param {Object} result The results object created by TestRunner.
+     * @return {String} An XML-formatted string of results.
+     * @namespace Test.Format
+     * @method XML
+     * @static
+     */
+    Y.Test.Format.XML = function(results /*:Object*/) /*:String*/ {
+    
+        var l = Y.Lang;
+        var xml /*:String*/ = "<" + results.type + " name=\"" + results.name.replace(/"/g, "&quot;").replace(/'/g, "&apos;") + "\"";
+        
+        if (results.type == "test"){
+            xml += " result=\"" + results.result + "\" message=\"" + results.message + "\">";
+        } else {
+            xml += " passed=\"" + results.passed + "\" failed=\"" + results.failed + "\" ignored=\"" + results.ignored + "\" total=\"" + results.total + "\">";
+            for (var prop in results) {
+                if (Y.Object.owns(results, prop) && l.isObject(results[prop]) && !l.isArray(results[prop])){
+                    xml += arguments.callee(results[prop]);
+                }
+            }        
+        }
+    
+        xml += "</" + results.type + ">";
+        
+        return xml;
+    
+    };
+
+
+    Y.namespace("Test");
+    
+    /**
+     * An object capable of sending test results to a server.
+     * @param {String} url The URL to submit the results to.
+     * @param {Function} format (Optiona) A function that outputs the results in a specific format.
+     *      Default is Y.Test.Format.XML.
+     * @constructor
+     * @namespace Test
+     * @class Reporter
+     */
+    Y.Test.Reporter = function(url /*:String*/, format /*:Function*/) {
+    
+        /**
+         * The URL to submit the data to.
+         * @type String
+         * @property url
+         */
+        this.url /*:String*/ = url;
+    
+        /**
+         * The formatting function to call when submitting the data.
+         * @type Function
+         * @property format
+         */
+        this.format /*:Function*/ = format || Y.Test.Format.XML;
+    
+        /**
+         * Extra fields to submit with the request.
+         * @type Object
+         * @property _fields
+         * @private
+         */
+        this._fields /*:Object*/ = new Object();
+        
+        /**
+         * The form element used to submit the results.
+         * @type HTMLFormElement
+         * @property _form
+         * @private
+         */
+        this._form /*:HTMLElement*/ = null;
+    
+        /**
+         * Iframe used as a target for form submission.
+         * @type HTMLIFrameElement
+         * @property _iframe
+         * @private
+         */
+        this._iframe /*:HTMLElement*/ = null;
+    };
+    
+    Y.Test.Reporter.prototype = {
+    
+        //restore missing constructor
+        constructor: Y.Test.Reporter,
+    
+        /**
+         * Adds a field to the form that submits the results.
+         * @param {String} name The name of the field.
+         * @param {Variant} value The value of the field.
+         * @return {Void}
+         * @method addField
+         */
+        addField : function (name /*:String*/, value /*:Variant*/) /*:Void*/{
+            this._fields[name] = value;    
+        },
+        
+        /**
+         * Removes all previous defined fields.
+         * @return {Void}
+         * @method addField
+         */
+        clearFields : function() /*:Void*/{
+            this._fields = new Object();
+        },
+    
+        /**
+         * Cleans up the memory associated with the TestReporter, removing DOM elements
+         * that were created.
+         * @return {Void}
+         * @method destroy
+         */
+        destroy : function() /*:Void*/ {
+            if (this._form){
+                this._form.parentNode.removeChild(this._form);
+                this._form = null;
+            }        
+            if (this._iframe){
+                this._iframe.parentNode.removeChild(this._iframe);
+                this._iframe = null;
+            }
+            this._fields = null;
+        },
+    
+        /**
+         * Sends the report to the server.
+         * @param {Object} results The results object created by TestRunner.
+         * @return {Void}
+         * @method report
+         */
+        report : function(results /*:Object*/) /*:Void*/{
+        
+            //if the form hasn't been created yet, create it
+            if (!this._form){
+                this._form = document.createElement("form");
+                this._form.method = "post";
+                this._form.style.visibility = "hidden";
+                this._form.style.position = "absolute";
+                this._form.style.top = 0;
+                document.body.appendChild(this._form);
+            
+                //IE won't let you assign a name using the DOM, must do it the hacky way
+                if (Y.UA.ie){
+                    this._iframe = document.createElement("<iframe name=\"yuiTestTarget\" />");
+                } else {
+                    this._iframe = document.createElement("iframe");
+                    this._iframe.name = "yuiTestTarget";
+                }
+    
+                this._iframe.src = "javascript:false";
+                this._iframe.style.visibility = "hidden";
+                this._iframe.style.position = "absolute";
+                this._iframe.style.top = 0;
+                document.body.appendChild(this._iframe);
+    
+                this._form.target = "yuiTestTarget";
+            }
+    
+            //set the form's action
+            this._form.action = this.url;
+        
+            //remove any existing fields
+            while(this._form.hasChildNodes()){
+                this._form.removeChild(this._form.lastChild);
+            }
+            
+            //create default fields
+            this._fields.results = this.format(results);
+            this._fields.useragent = navigator.userAgent;
+            this._fields.timestamp = (new Date()).toLocaleString();
+    
+            //add fields to the form
+            for (var prop in this._fields){
+                if (Y.Object.owns(this._fields, prop) && typeof this._fields[prop] != "function"){
+                    var input = document.createElement("input");
+                    input.type = "hidden";
+                    input.name = prop;
+                    input.value = this._fields[prop];
+                    this._form.appendChild(input);
+                }
+            }
+    
+            //remove default fields
+            delete this._fields.results;
+            delete this._fields.useragent;
+            delete this._fields.timestamp;
+            
+            if (arguments[1] !== false){
+                this._form.submit();
+            }
+        
+        }
+    
+    };
+
+    /**
+     * Creates a new mock object.
+     * @class Mock
+     * @constructor
+     * @param {Object} template (Optional) An object whose methods
+     *      should be stubbed out on the mock object.
+     */
+    Y.Mock = function(template){
+    
+        //use blank object is nothing is passed in
+        template = template || {};
+        
+        var mock = null;
+        
+        //try to create mock that keeps prototype chain intact
+        try {
+            mock = Y.Object(template);
+        } catch (ex) {
+            mock = {};
+            Y.log("Couldn't create mock with prototype.", "warn", "Mock");
+        }
+        
+        //create new versions of the methods so that they don't actually do anything
+        Y.Object.each(template, function(name){
+            if (Y.Lang.isFunction(template[name])){
+                mock[name] = function(){
+                    Y.Assert.fail("Method " + name + "() was called but was not expected to be.");
+                };
+            }
+        });
+        
+        //return it
+        return mock;    
+    };
+        
+    /**
+     * Assigns an expectation to a mock object. This is used to create
+     * methods and properties on the mock object that are monitored for
+     * calls and changes, respectively.
+     * @param {Object} mock The object to add the expectation to.
+     * @param {Object} expectation An object defining the expectation. For
+     *      a method, the keys "method" and "args" are required with
+     *      an optional "returns" key available. For properties, the keys
+     *      "property" and "value" are required.
+     * @return {void}
+     * @method expect
+     * @static
+     */ 
+    Y.Mock.expect = function(mock /*:Object*/, expectation /*:Object*/){
+
+        //make sure there's a place to store the expectations
+        if (!mock.__expectations) {
+            mock.__expectations = {};
+        }
+
+        //method expectation
+        if (expectation.method){
+            var name = expectation.method,
+                args = expectation.args || expectation.arguments || [],
+                result = expectation.returns,
+                callCount = Y.Lang.isNumber(expectation.callCount) ? expectation.callCount : 1,
+                error = expectation.error,
+                run = expectation.run || function(){};
+                
+            //save expectations
+            mock.__expectations[name] = expectation;
+            expectation.callCount = callCount;
+            expectation.actualCallCount = 0;
+                
+            //process arguments
+            Y.Array.each(args, function(arg, i, array){
+                if (!(array[i] instanceof Y.Mock.Value)){
+                    array[i] = Y.Mock.Value(Y.Assert.areSame, [arg], "Argument " + i + " of " + name + "() is incorrect.");
+                }
+            });
+        
+            //if the method is expected to be called
+            if (callCount > 0){
+                mock[name] = function(){   
+                    expectation.actualCallCount++;
+                    Y.Assert.areEqual(args.length, arguments.length, "Method " + name + "() passed incorrect number of arguments.");
+                    for (var i=0, len=args.length; i < len; i++){
+                        if (args[i]){
+                            args[i].verify(arguments[i]);
+                        } else {
+                            Y.Assert.fail("Argument " + i + " (" + arguments[i] + ") was not expected to be used.");
+                        }
+                        
+                    }                
+
+                    run.apply(this, arguments);
+                    
+                    if (error){
+                        throw error;
+                    }
+                    
+                    return result;
+                };
+            } else {
+            
+                //method should fail if called when not expected
+                mock[name] = function(){
+                    Y.Assert.fail("Method " + name + "() should not have been called.");
+                };
+            }
+        } else if (expectation.property){
+            //save expectations
+            mock.__expectations[name] = expectation;
+        }
+    };
+
+    /**
+     * Verifies that all expectations of a mock object have been met and
+     * throws an assertion error if not.
+     * @param {Object} mock The object to verify..
+     * @return {void}
+     * @method verify
+     * @static
+     */ 
+    Y.Mock.verify = function(mock /*:Object*/){    
+        Y.Object.each(mock.__expectations, function(expectation){
+            if (expectation.method) {
+                Y.Assert.areEqual(expectation.callCount, expectation.actualCallCount, "Method " + expectation.method + "() wasn't called the expected number of times.");
+            } else if (expectation.property){
+                Y.Assert.areEqual(expectation.value, mock[expectation.property], "Property " + expectation.property + " wasn't set to the correct value."); 
+            }
+        });    
+    };
+
+    Y.Mock.Value = function(method, args, message){
+        if (this instanceof Y.Mock.Value){
+            this.verify = function(value){
+                args = [].concat(args);
+                args.push(value);
+                args.push(message);
+                method.apply(null, args);
+            };
+        } else {
+            return new Y.Mock.Value(method, args, message);
+        }
+    };
+    
+    Y.Mock.Value.Any = Y.Mock.Value(function(){},[]);
+    Y.Mock.Value.Boolean = Y.Mock.Value(Y.Assert.isBoolean,[]);
+    Y.Mock.Value.Number = Y.Mock.Value(Y.Assert.isNumber,[]);
+    Y.Mock.Value.String = Y.Mock.Value(Y.Assert.isString,[]);
+    Y.Mock.Value.Object = Y.Mock.Value(Y.Assert.isObject,[]);
+    Y.Mock.Value.Function = Y.Mock.Value(Y.Assert.isFunction,[]);
+
+
+
+}, '3.0.0pr2' ,{requires:['substitute','event-custom','array','oop','event-target','event-simulate']});

=== modified file 'loggerhead/templatefunctions.py'
--- loggerhead/templatefunctions.py	2008-07-26 14:52:44 +0000
+++ loggerhead/templatefunctions.py	2011-09-08 00:33:28 +0000
@@ -13,35 +13,78 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+
 import os
+import urllib
+
+import pkg_resources
+
+import bzrlib
+
+import loggerhead
 from loggerhead.zptsupport import zpt
+from loggerhead.util import html_format
+
 
 templatefunctions = {}
+
+
 def templatefunc(func):
     templatefunctions[func.__name__] = func
     return func
 
 
 _base = os.path.dirname(__file__)
+
+
 def _pt(name):
     return zpt(os.path.join(_base, 'templates', name + '.pt'))
 
 
 templatefunctions['macros'] = _pt('macros').macros
+templatefunctions['breadcrumbs'] = _pt('breadcrumbs').macros
+
 
 @templatefunc
-def file_change_summary(url, entry, modified_file_link):
+def file_change_summary(url, entry, file_changes, style='normal', currently_showing=None):
+    if style == 'fragment':
+        def file_link(filename):
+            if currently_showing and filename == currently_showing:
+                return html_format(
+                    '<b><a href="#%s">%s</a></b>',
+                    urllib.quote(filename.encode('utf-8')), filename)
+            else:
+                return revision_link(
+                    url, entry.revno, filename,
+                    '#' + urllib.quote(filename.encode('utf-8')))
+    else:
+        def file_link(filename):
+            return html_format(
+                '<a href="%s%s" title="View changes to %s in revision %s">'
+                '%s</a>',
+                url(['/revision', entry.revno]),
+                '#' + urllib.quote(filename.encode('utf-8')),
+                filename, entry.revno, filename)
     return _pt('revisionfilechanges').expand(
-        url=url, entry=entry, modified_file_link=modified_file_link,
-        **templatefunctions)
+        entry=entry, file_changes=file_changes, file_link=file_link, **templatefunctions)
+
 
 @templatefunc
-def revisioninfo(url, branch, entry, modified_file_link=None):
+def revisioninfo(url, branch, entry, file_changes=None, currently_showing=None, merged_in=None):
     from loggerhead import util
     return _pt('revisioninfo').expand(
         url=url, change=entry, branch=branch, util=util,
-        modified_file_link=modified_file_link,
-        **templatefunctions)
+        file_changes=file_changes, currently_showing=currently_showing,
+        merged_in=merged_in, **templatefunctions)
+
+
+@templatefunc
+def branchinfo(branch):
+    if branch.served_url is not None:
+        return _pt('branchinfo').expand(branch=branch, **templatefunctions)
+    else:
+        return ''
+
 
 @templatefunc
 def collapse_button(group, name, branch, normal='block'):
@@ -49,28 +92,118 @@
         group=group, name=name, normal=normal, branch=branch,
         **templatefunctions)
 
+
 @templatefunc
 def collapse_all_button(group, branch, normal='block'):
     return _pt('collapse-all-button').expand(
         group=group, normal=normal, branch=branch,
         **templatefunctions)
 
+
 @templatefunc
 def revno_with_nick(entry):
     if entry.branch_nick:
         extra = ' ' + entry.branch_nick
     else:
         extra = ''
-    return '(%s%s)'%(entry.revno, extra)
-
-@templatefunc
-def modified_file_link_rev(url, entry, item):
-    return _pt('modified-file-link-rev').expand(
-        url=url, entry=entry, item=item,
-        **templatefunctions)
-
-@templatefunc
-def modified_file_link_log(url, entry, item):
-    return _pt('modified-file-link-log').expand(
-        url=url, entry=entry, item=item,
-        **templatefunctions)
+    return '(%s%s)' % (entry.revno, extra)
+
+
+@templatefunc
+def search_box(branch, navigation):
+    return _pt('search-box').expand(branch=branch, navigation=navigation,
+        **templatefunctions)
+
+
+@templatefunc
+def feed_link(branch, url):
+    return _pt('feed-link').expand(branch=branch, url=url, **templatefunctions)
+
+
+@templatefunc
+def menu(branch, url, fileview_active=False):
+    return _pt('menu').expand(branch=branch, url=url,
+        fileview_active=fileview_active, **templatefunctions)
+
+
+@templatefunc
+def view_link(url, revno, path):
+    return html_format(
+        '<a href="%s" title="Annotate %s">%s</a>',
+        url(['/view', revno, path]), path, path)
+
+
+@templatefunc
+def revision_link(url, revno, path, frag=''):
+    return html_format(
+        '<a href="%s%s" title="View changes to %s in revision %s">%s</a>',
+        url(['/revision', revno, path]), frag, path, revno, path)
+
+
+@templatefunc
+def loggerhead_version():
+    return loggerhead.__version__
+
+_cached_generator_string = None
+
+@templatefunc
+def generator_string():
+    global _cached_generator_string
+    if _cached_generator_string is None:
+        versions = []
+
+        # TODO: Errors -- e.g. from a missing/invalid __version__ attribute, or
+        # ValueError accessing Distribution.version -- should be non-fatal.
+
+        versions.append(('Loggerhead', loggerhead.__version__))
+
+        import sys
+        python_version = bzrlib._format_version_tuple(sys.version_info)
+        versions.append(('Python', python_version))
+
+        versions.append(('Bazaar', bzrlib.__version__))
+
+        Paste = pkg_resources.get_distribution('Paste')
+        versions.append(('Paste', Paste.version))
+
+        try:
+            PasteDeploy = pkg_resources.get_distribution('PasteDeploy')
+        except pkg_resources.DistributionNotFound:
+            pass
+        else:
+            versions.append(('PasteDeploy', PasteDeploy.version))
+
+        import simpletal
+        versions.append(('SimpleTAL', simpletal.__version__))
+
+        try:
+            import pygments
+        except ImportError:
+            pass
+        else:
+            versions.append(('Pygments', pygments.__version__))
+
+        try:
+            from bzrlib.plugins import search
+        except ImportError:
+            pass
+        else:
+            bzr_search_version = bzrlib._format_version_tuple(
+                search.version_info)
+            versions.append(('bzr-search', bzr_search_version))
+
+        # TODO: On old Python versions, elementtree may be used.
+
+        import simplejson
+        versions.append(('simplejson', simplejson.__version__))
+
+        try:
+            Dozer = pkg_resources.get_distribution('Dozer')
+        except pkg_resources.DistributionNotFound:
+            pass
+        else:
+            versions.append(('Dozer', Dozer.version))
+
+        version_strings = ("%s/%s" % t for t in versions)
+        _cached_generator_string = ' '.join(version_strings)
+    return _cached_generator_string

=== modified file 'loggerhead/templates/atom.pt'
--- loggerhead/templates/atom.pt	2008-06-26 20:42:15 +0000
+++ loggerhead/templates/atom.pt	2010-05-05 18:42:58 +0000
@@ -3,29 +3,31 @@
   <title>
     bazaar changes for <tal:branch-name content="branch/friendly_name">branch name</tal:branch-name>
   </title>
-  <updated tal:content="updated">${updated}</updated>
-  <id tal:content="python:branch.url(['/atom'])">url</id>
-  <link rel="self" tal:attributes="href python:branch.url([''])" />
+  <updated tal:content="string:${updated}Z">${updated}</updated>
+  <id tal:content="python:branch.absolute_url(['/atom'])">url</id>
+  <link rel="self" type="application/atom+xml" tal:attributes="href python:branch.absolute_url(['/atom'])" />
+  <link rel="alternate" type="text/html" tal:attributes="href python:branch.url(['/changes'])" />
 
   <entry tal:repeat="entry changes">
-    <title tal:content="string: ${entry/revno}: ${entry/short_comment}">
+    <title tal:content="string:${entry/revno}: ${entry/short_comment}">
       ${entry/revno}: ${entry/short_comment}
     </title>
-    <updated tal:content="entry/date/isoformat">
-    Z
+    <updated tal:content="string:${entry/utc_date/isoformat}Z">
+      updated
     </updated>
-    <id tal:content="python:branch.url(['/revision', entry.revno])">
+    <!-- TODO: The feed validator will generate warnings because this is URL-encoded -->
+    <id tal:content="python:branch.absolute_url(['/revision', entry.revno])">
       ID
     </id>
-    <author>
-      <name tal:content="python:util.hide_email(entry.author)">
+    <author tal:repeat="author entry/authors">
+      <name tal:content="python:util.hide_email(author)">
         author
       </name>
     </author>
     <content type="text" tal:content="entry/comment">
       comment
     </content>
-    <link rel="alternate"
+    <link rel="alternate" type="text/html"
           tal:attributes="href python:branch.url(['/revision', entry.revno])" />
   </entry>
 </feed>

=== added file 'loggerhead/templates/branchinfo.pt'
--- loggerhead/templates/branchinfo.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/branchinfo.pt	2011-11-25 01:23:32 +0000
@@ -0,0 +1,6 @@
+<div id="branch-info"
+  tal:condition="python:branch.served_url">
+  To get this branch, use: <br/>
+  <code>bzr branch
+  <tal:served-url tal:replace="python:branch.served_url" /></code>
+</div>

=== added file 'loggerhead/templates/breadcrumbs.pt'
--- loggerhead/templates/breadcrumbs.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/breadcrumbs.pt	2012-01-08 21:43:42 +0000
@@ -0,0 +1,22 @@
+<html>
+<body>
+<!--
+    Breadcrumbs macros
+-->
+<!--
+    These are all defined on one line in order to get the spacing looking right
+    in the output
+-->
+
+<!-- Branch breadcrumbs (for the path within the branch) -->
+<span metal:define-macro="branch" class="breadcrumb">
+    <tal:block repeat="crumb branch_breadcrumbs">/<a tal:attributes="href python:url([crumb['suffix'], change.revno, crumb['path']])" tal:content="crumb/dir_name" tal:condition="not:repeat/crumb/end" /><span tal:replace="crumb/dir_name" tal:condition="repeat/crumb/end" /></tal:block>
+</span>
+
+<!-- Directory breadcrumbs (for the path leading up to the branch) -->
+<span metal:define-macro="directory" class="breadcrumb">
+    <tal:block repeat="crumb directory_breadcrumbs"><span tal:condition="not:repeat/crumb/start">/</span><a tal:attributes="href python:static_url('/'+crumb['path'])" tal:content="crumb/dir_name" /></tal:block>
+</span>
+
+</body>
+</html>

=== removed file 'loggerhead/templates/browse.pt'
--- loggerhead/templates/browse.pt	2008-07-22 20:07:08 +0000
+++ loggerhead/templates/browse.pt	1970-01-01 00:00:00 +0000
@@ -1,75 +0,0 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
-  <head>
-    <title metal:fill-slot="title">
-      loggerhead branches
-    </title>
-  </head>
-
-  <body>
-
-    <h1 metal:fill-slot="heading" style="padding-bottom: 1em">
-      <tal:title condition="title" content="title" />
-      <tal:no-title condition="not:title">
-        bazaar branches in loggerhead
-      </tal:no-title>
-    </h1>
-
-    <div metal:fill-slot="content">
-      <div class="browse-project"
-           tal:repeat="project projects">
-        <div class="browse-project-name"
-             tal:content="project/friendly_name"></div>
-
-        <div class="browse-project-description"
-             tal:condition="python:len(project.long_description) > 0"
-             tal:content="structure project/long_description"></div>
-
-        <div class="browse-view">
-          <table>
-            <tr class="heading">
-              <th>Name</th>
-              <th>Description</th>
-              <th>Last change</th>
-              <th />
-            </tr>
-            <tal:block repeat="view python:views_by_project[project]">
-              <tr>
-                <td class="name">
-                  <a tal:attributes="href python:branch.static_url(project.name + '/' +  view.name)"
-                     tal:content="view/friendly_name">
-                    ${view.friendly_name}
-                  </a>
-                </td>
-                <td class="description"
-                    tal:content="view/description">
-                  ${view.description}
-                </td>
-                <td class="last-update"
-                    tal:content="python:view.get_history().has_revisions and util._approximatedate(view.last_updated()) or '(no revisions)'"></td>
-                <td class="feed">
-                  <a tal:attributes="href python:branch.static_url(project.name + '/' +  view.name + '/atom')"
-                     title="atom feed">
-                    <img tal:attributes="src python:branch.static_url('/static/images/feed-icon-16x16.gif')"
-                         alt="atom feed" />
-                  </a>
-                </td>
-              </tr>
-              <tr tal:condition="view/branch_url">
-                <td class="name">
-                </td>
-                <td class="description url" colspan="2">
-                  <a tal:attributes="href view/branch_url"
-                     tal:content="view/branch_url">
-                    ${view.branch_url}
-                  </a>
-                </td>
-              </tr>
-            </tal:block>
-          </table>
-        </div>
-
-      </div>
-    </div>
-  </body>
-</html>

=== modified file 'loggerhead/templates/changelog.pt'
--- loggerhead/templates/changelog.pt	2008-08-04 03:42:01 +0000
+++ loggerhead/templates/changelog.pt	2011-02-23 03:01:15 +0000
@@ -1,164 +1,168 @@
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<tal:block define="onload string:sortCollapseElements()">
-  <html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
-    <head>
-      <title metal:fill-slot="title"
-             tal:content="string:${branch/friendly_name} : changes"></title>
-      <metal:block fill-slot="header_extras">
-        <link rel="alternate" type="application/atom+xml"
-              tal:attributes="href python:url(['/atom']);
-                              title string:RSS feed for ${branch/friendly_name}" />
-      </metal:block>
-    </head>
-
-    <body>
-        <tal:block metal:fill-slot="heading">
-         <h1>
-           <tal:has-link condition="branch/branch_link">
-             <a tal:attributes="href branch/branch_link"
-                tal:content="branch/friendly_name">
-               nice/branch/name
-             </a>
-           </tal:has-link>
-           <tal:no-link condition="not: branch/branch_link">
-             <tal:branch-name replace="branch/friendly_name" />
-           </tal:no-link>
-           : changes
-          <tal:block condition="filter_file_id">to <span tal:content="python:history.get_path(revid, filter_file_id)" /></tal:block>
-          <tal:block condition="start_revid">from revision <tal:block content="python:history.get_revno(start_revid)" /></tal:block>
-          <tal:block condition="query">matching <tal:block content="query" /></tal:block>
-         </h1>
-        </tal:block>
-
-       <div metal:fill-slot="content">
-           <!-- Something nicer-looking should be done with search -->
-        <p tal:condition="search_failed">
-          Sorry, no results found for your search.
-        </p>
-
-        <p tal:condition="not:changes">
-          No revisions!
-        </p>
-
-        <p class="fr revnolink">From Revision <a tal:attributes="href #
-                                                            title python:'Show revision '+history.get_revno(revid)" 
-                                tal:content="python:history.get_revno(revid)"></a>
-          <tal:block tal:condition="python:navigation.last_in_page_revid is not None"> to
-          <a tal:attributes="href # 
+<html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
+  <head>
+    <title metal:fill-slot="title"
+           tal:content="string:${branch/friendly_name} : changes"></title>
+    <metal:block fill-slot="header_extras">
+      <link rel="alternate" type="application/atom+xml"
+            tal:attributes="href python:url(['/atom']);
+                            title string:RSS feed for ${branch/friendly_name}" />
+    <script type="text/javascript">
+      var revids = <tal:block content="data" />;
+    </script>
+      <script type="text/javascript"
+              tal:attributes="src python:branch.static_url('/static/javascript/changelog.js')"></script>
+    </metal:block>
+  </head>
+
+  <body>
+      <tal:block metal:fill-slot="backlink">
+          <tal:has-link condition="branch/branch_link">
+            <div class="black-link">
+                <a tal:attributes="href branch/branch_link">
+                  &#8592; Back to branch summary
+                </a>
+            </div>
+          </tal:has-link>
+      </tal:block>
+    <tal:block metal:fill-slot="branchname" tal:content="string:${branch/friendly_name}" />
+    <tal:block metal:fill-slot="heading">
+        <div id="breadcrumbs">
+            <tal:has-link condition="branch/branch_link">
+              <a tal:attributes="href branch/branch_link"
+                 tal:content="branch/friendly_name">
+                nice/branch/name
+              </a>
+            </tal:has-link>
+            <tal:no-link condition="not: branch/branch_link">
+              <span metal:use-macro="breadcrumbs/directory"></span>
+            </tal:no-link>
+            <tal:block condition="changes">
+              &#187; Changes
+              <tal:block condition="filter_file_id">to <span tal:content="python:history.get_path(revid, filter_file_id)" /></tal:block>
+              <tal:block condition="start_revid">from revision
+                <span tal:content="python:history.get_revno(start_revid)"/>
+              </tal:block>
+              <tal:block condition="query">matching <tal:block content="query" /></tal:block>
+            </tal:block>
+        </div>
+    </tal:block>
+
+    <div metal:fill-slot="content">
+      <tal:branch-info replace="structure python:branchinfo(branch)" />
+
+      <!-- Something nicer-looking should be done with search -->
+      <p tal:condition="search_failed">
+        Sorry, no results found for your search.
+      </p>
+
+      <p tal:condition="not:changes">
+        No revisions!
+      </p>
+
+      <p class="fr revnolink">From Revision <a tal:attributes="href #
+                                                               title python:'Show revision '+history.get_revno(revid)"
+                                               tal:content="python:history.get_revno(revid)"></a>
+        <tal:block tal:condition="python:navigation.last_in_page_revid is not None"> to
+          <a tal:attributes="href #
                              title 'Show revision '+history.get_revno(navigation.last_in_page_revid)"
              tal:content="python:history.get_revno(navigation.last_in_page_revid)"></a>
-         </tal:block></p>
-        <p class="expand" id="expand_all"><a tal:attributes="href string:javascript:toggle_expand_all('open')">
-            <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
-                  alt="expand all" /> expand all</a>
-        </p>
-        <p class="expand" id="collapse_all" style="display:none;"><a tal:attributes="href string:javascript:toggle_expand_all('close')">
-            <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
-                  alt="collapse all" /> collapse all</a>
-        </p>
-        <!-- Table -->        
-        <table id="logentries"
-               tal:define="subcolspan python:4-bool(all_same_author)">
-            <tr class="logheader">
-                <td class="revisionnumber">Rev</td>
-                <td class="expandcell">&nbsp;</td>
-                <td class="summarycell">Summary</td>
-                <td class="authorcell">Author</td>
-                <td class="datecell">Date</td>
-                <td class="diffcell">Diff</td>
-                <td class="downloadcell">Files</td>
-            </tr>
-            <tal:block tal:repeat="entry changes">
-            <a tal:attributes="name string:entry-${entry/revno}"/>
-                <tr tal:attributes="class string:blueRow${entry/parity} revision_log">
-                <td class="revnro revnolink"><a tal:attributes="title python:'Show revision '+entry.revno;
-                                                                href  python:url(['/revision', entry.revno], clear=1)"
-                                                tal:content="python:util.trunc(entry.revno)"></a>
-                </td>            
-                <td class="expcell">
-                    <div class="expand_revisioninfo">
-                        <!-- So, this is interesting. I'm using "alt" to have the correct URL for the image of the expanded icon
-                             and "title" tag for the contracted URL of the image. This is a bit of a hack, but it's better than
-                             other approaches I tried  :)  -->
-                        <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png');
-                                             alt python:branch.static_url('/static/images/treeExpanded.png');
-                                             title python:branch.static_url('/static/images/treeCollapsed.png')" 
-                             class="expand_icon" />
-                    </div>
-                </td>
-                <td class="summcell"><div tal:attributes="class string:short_description">
-                                        <a tal:attributes="title python:'Show revision '+entry.revno;
-                                                           href  python:url(['/revision', entry.revno], clear=1);
-                                                           class string:link"
-                                           tal:content="entry/short_comment"></a>
-                                     </div>
-                                     <div tal:attributes="class string:long_description;
-                                                          style string:display:none">
-                                        <a tal:attributes="title python:'Show revision '+entry.revno;
-                                                           href  python:url(['/revision', entry.revno], clear=1);
-                                                           class string:link"
-                                           tal:content="entry/comment"></a>
-                                     </div>
-                                <div class="revisioninfo" style="display:none;">
-                                    <ul class="expandrev">
-               	                        <li class="mfrom" tal:repeat="parent python:entry.parents[1:]">
-                                            <span class="revnolink">
-                                                <a tal:attributes="href python:url(['/changes', parent.revno])"
-                                                   tal:content="parent/revno"></a>
-                                            </span>
-                                            <a tal:attributes="href python:url(['/changes'], start_revid=parent.revno)"
-                                               tal:content="python:'(' + parent.branch_nick + ')'"
-                                                title="Show history" class="link"></a>
-                                        </li>
-               	                        <li class="mto" tal:repeat="merge_point entry/merge_points">
-                                            <a tal:attributes="href python:url(['/changes'], start_revid=merge_point.revno)"
-                                               tal:content="python:revno_with_nick(merge_point)"
-                                               title="Show history" class="link"></a>
-                                        </li>
-                                        <li class="committerli" tal:content="python:util.hide_email(entry.author)"></li>
-                                        <tal:block content="structure python:file_change_summary(url, entry, modified_file_link_log)" />
-                                    </ul>
-                                </div>
-                </td>
-                <td tal:content="python:util.trunc(util.hide_email(entry.author), 20)"
-                    class="autcell"></td>
-                <td class="date">
-                    <span tal:attributes="title python:util.date_time(entry.date)"
-                          tal:content="python:util._approximatedate(entry.date)"></span>
-                </td>
-                <td class="diffr"><a tal:attributes="title python:'Show diff at revision '+entry.revno;
-                                                     href python:url(['/revision', entry.revno], clear=1)">
-                                  <img tal:attributes="src python:branch.static_url('/static/images/ico_diff.gif')" alt="Diff" /></a></td>
-                <td class="downr"><a tal:attributes="href python:branch.url(['/files', entry.revno]);
-                                                     title string:Files at revision ${entry/revno}">
-                                   <img tal:attributes="src python:branch.static_url('/static/images/ico_file.gif');
-                                                        alt string:Files" /></a>
-                </td>
-            </tr>
-          </tal:block>
-        </table>
-
-        <ul tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
-            id="pages">
-            <li tal:condition="navigation/prev_page_revid" 
-                class="previous">
-                <a tal:attributes="href navigation/prev_page_url">&laquo; Previous</a>
-            </li>
-            <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
-                        so some magic has to be done to just show the previous and next N page numbers
-
-            <li class="active">1</li>
-            <tal:block tal:repeat="page_number python:range(navigation.page_count)">
-            <li><a href="#"
-                   tal:content="page_number"></a></li>
-               </tal:block>-->
-            <li tal:condition="navigation/next_page_revid"
-                class="next">
-                <a tal:attributes="href navigation/next_page_url">Next &raquo;</a>
-            </li>
-        </ul>
-
-      </div>
-    </body>
-  </html>
-</tal:block>
+      </tal:block></p>
+      <p class="expand show_if_js" id="expand_all"><a href="#">
+          <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
+               alt="expand all" /> expand all</a>
+      </p>
+      <p class="expand" id="collapse_all" style="display:none;"><a href="#">
+          <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
+               alt="collapse all" /> collapse all</a>
+      </p>
+      <!-- Table -->
+      <table id="logentries">
+        <tr class="logheader">
+          <th class="revisionnumber">Rev</th>
+          <th class="expandcell show_if_js">&nbsp;</th>
+          <th class="summarycell">Summary</th>
+          <th class="authorcell">Authors</th>
+          <th tal:condition="show_tag_col" class="tagscell">Tags</th>
+          <th class="datecell">Date</th>
+          <th class="diffcell">Diff</th>
+          <th class="downloadcell">Files</th>
+        </tr>
+        <tal:block tal:repeat="entry changes">
+          <a tal:attributes="name string:entry-${entry/revno}"/>
+          <tr tal:attributes="class string:blueRow${entry/parity} revision_log; id string:log-${entry/index}">
+            <td class="revnro revnolink"><a tal:attributes="title python:'Show revision '+entry.revno;
+                                                            href  python:url(['/revision', entry.revno], clear=1)"
+                                            tal:content="python:util.trunc(entry.revno)"></a>
+            </td>
+            <td class="expcell show_if_js">
+              <div class="expand_revisioninfo">
+                <a href="#">
+                  <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
+                       class="expand_icon" />
+                </a>
+              </div>
+            </td>
+            <td class="summcell">
+              <div class="short_description">
+                <img tal:condition="python:entry.parents[1:]"
+                     tal:attributes="src python:branch.static_url('/static/images/ico_mergefrom.gif')" />
+                <a tal:attributes="title python:'Show revision '+entry.revno;
+                                   href  python:url(['/revision', entry.revno], clear=1);
+                                   class string:link"
+                   tal:content="entry/short_comment"></a>
+              </div>
+              <div class="long_description" style="display: none">
+                <img tal:condition="python:entry.parents[1:]"
+                     tal:attributes="src python:branch.static_url('/static/images/ico_mergefrom.gif')" />
+                <a tal:attributes="title python:'Show revision '+entry.revno;
+                                   href  python:url(['/revision', entry.revno], clear=1);
+                                   class string:link"
+                   tal:content="structure python:util.fixed_width(entry.comment)"></a>
+                <div class="loading">
+                  <img tal:attributes="src python:branch.static_url('/static/images/spinner.gif')" />
+                </div>
+              </div>
+            </td>
+            <td tal:content="python:util.trunc(util.hide_email(entry.authors[0]), 20)"
+                class="autcell"></td>
+            <td tal:condition="show_tag_col" tal:content="string:${entry/tags}"
+                class="tagcell"></td>
+            <td class="date">
+              <span tal:attributes="title python:util.date_time(entry.date)"
+                    tal:content="python:util._approximatedate(entry.date)"></span>
+            </td>
+            <td class="diffr"><a tal:attributes="title python:'Show diff at revision '+entry.revno;
+                                                 href python:url(['/revision', entry.revno], clear=1)">
+                <img tal:attributes="src python:branch.static_url('/static/images/ico_diff.gif')" alt="Diff" /></a></td>
+            <td class="downr"><a tal:attributes="href python:branch.url(['/files', entry.revno]);
+                                                 title string:Files at revision ${entry/revno}">
+                <img tal:attributes="src python:branch.static_url('/static/images/ico_file.gif')" alt="Files" /></a>
+            </td>
+          </tr>
+        </tal:block>
+      </table>
+
+      <ul tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
+          id="pages">
+        <li tal:condition="navigation/prev_page_revid"
+            class="previous">
+          <a tal:attributes="href navigation/prev_page_url">&laquo; Newer</a>
+        </li>
+        <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
+             so some magic has to be done to just show the previous and next N page numbers
+
+             <li class="active">1</li>
+             <tal:block tal:repeat="page_number python:range(navigation.page_count)">
+               <li><a href="#"
+                      tal:content="page_number"></a></li>
+             </tal:block>-->
+        <li tal:condition="navigation/next_page_revid"
+            class="next">
+          <a tal:attributes="href navigation/next_page_url">Older &raquo;</a>
+        </li>
+      </ul>
+
+    </div>
+  </body>
+</html>

=== modified file 'loggerhead/templates/directory.pt'
--- loggerhead/templates/directory.pt	2008-08-05 06:12:07 +0000
+++ loggerhead/templates/directory.pt	2011-02-17 19:51:25 +0000
@@ -4,11 +4,14 @@
     <title tal:content="string:Browsing ${name}"></title>
     <link rel="stylesheet"
           tal:attributes="href python:static_url('/static/css/global.css')" />
+    <link rel="shortcut icon"
+          tal:attributes="href python:branch.static_url('/static/images/favicon.ico')" /> 
   </head>
   <body>
     <div id="loggerheadCont">
-      <h1 tal:content="string:Browsing ${name}">
-        Hi.
+      <h1>
+        Browsing
+        <span metal:use-macro="breadcrumbs/directory" />
       </h1>
 
       <div >
@@ -18,13 +21,13 @@
             <th class="datecell">Latest Rev</th>
             <th class="datecell">Last Changed</th>
           </tr>
-          
+
           <tr class="blueRow0" tal:condition="python:name != '/'">
             <td class="icocell">
-                <a href=".."><img tal:attributes="src python:static_url('/static/images/ico_folder_up.gif')" /></a>
+                <a href="../"><img tal:attributes="src python:static_url('/static/images/ico_folder_up.gif')" /></a>
             </td>
             <td class="summcell" colspan="3">
-                <a href="..">..</a>
+                <a href="../">..</a>
             </td>
           </tr>
           <tal:block repeat="dir dirs">
@@ -33,7 +36,7 @@
               <tr tal:attributes="class string:blueRow${dir/parity}">
                 <td class="icocell">
                     <a tal:attributes="href string:${dir/dirname}/files">
-                        <img tal:attributes="src python:static_url('/static/images/ico_branch.gif')" />
+                        <img tal:attributes="src python:static_url('/static/images/ico_branch.gif')" alt="Branch" />
                     </a>
                 </td>
                 <td class="autcell">
@@ -49,12 +52,12 @@
             <tal:non-branch-row tal:condition="not:dir/branch">
               <tr tal:attributes="class string:blueRow${dir/parity}">
                 <td class="icocell">
-                    <a tal:attributes="href string:${dir/dirname}">
-                        <img tal:attributes="src python:static_url('/static/images/ico_folder.gif')" />
+                    <a tal:attributes="href string:${dir/dirname}/">
+                        <img tal:attributes="src python:static_url('/static/images/ico_folder.gif')" alt="Folder" />
                     </a>
                 </td>
                 <td class="autcell">
-                  <a tal:attributes="href string:${dir/dirname}" tal:content="dir/dirname" /></td>
+                  <a tal:attributes="href string:${dir/dirname}/" tal:content="dir/dirname" /></td>
                 <td class="date"></td>
                 <td class="date" tal:content="dir/last_change"></td>
               </tr>

=== added file 'loggerhead/templates/error.pt'
--- loggerhead/templates/error.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/error.pt	2008-09-29 21:32:30 +0000
@@ -0,0 +1,30 @@
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<tal:block define="onload string:load()">
+  <html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
+    <head>
+      <title metal:fill-slot="title"
+             tal:content="string:${branch/friendly_name} : error"></title>
+    </head>
+    <body>
+        <tal:block metal:fill-slot="heading">
+        <h1>
+           <tal:has-link condition="branch/branch_link">
+            <a tal:attributes="href branch/branch_link"
+               tal:content="branch/friendly_name">
+               nice/branch/name
+            </a>
+           </tal:has-link>
+            <tal:no-link condition="not: branch/branch_link">
+                <span metal:use-macro="breadcrumbs/directory"></span>
+            </tal:no-link>
+           : error
+        </h1>
+        <pre>
+            <p tal:content="error_title"/>
+            <p tal:content="error_description"/>
+        </pre>
+        <br/><br/>
+        </tal:block>
+    </body>
+  </html>
+</tal:block>

=== added file 'loggerhead/templates/feed-link.pt'
--- loggerhead/templates/feed-link.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/feed-link.pt	2008-08-13 15:18:17 +0000
@@ -0,0 +1,6 @@
+<tal:feed-link>
+  <a tal:attributes="href python:url(['/atom']);
+                     title string:RSS feed for ${branch/friendly_name}">
+    <img tal:attributes="src python:branch.static_url('/static/images/ico_rss.gif')" alt="RSS" class="rssfeed"/>
+  </a>
+</tal:feed-link>

=== added file 'loggerhead/templates/filediff.pt'
--- loggerhead/templates/filediff.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/filediff.pt	2009-04-01 15:28:21 +0000
@@ -0,0 +1,25 @@
+<div>
+  <div class="pseudotable unified"
+       tal:repeat="chunk chunks">
+
+    <tal:block condition="not:repeat/chunk/start">
+      <div class="pseudorow context-row">
+        <div class="lineNumber separate"></div>
+        <div class="lineNumber second separate"></div>
+        <div class="code separate"></div>
+        <div class="clear"><!-- --></div>
+      </div>
+    </tal:block>
+
+    <div tal:repeat="line chunk/diff"
+         tal:attributes="class string:pseudorow ${line/type}-row">
+      <div class="lineNumber first"
+           tal:content="structure python:util.fill_div(line.old_lineno)"></div>
+      <div class="lineNumber second"
+           tal:content="structure python:util.fill_div(line.new_lineno)"></div>
+      <div tal:attributes="class string:code ${line/type}"
+           tal:content="structure python:util.fill_div(util.html_clean(line.line))"></div>
+      <div class="clear"><!-- --></div>
+    </div>
+  </div>
+</div>

=== modified file 'loggerhead/templates/inventory.pt'
--- loggerhead/templates/inventory.pt	2008-08-05 06:21:09 +0000
+++ loggerhead/templates/inventory.pt	2011-04-22 18:18:02 +0000
@@ -9,133 +9,150 @@
     </metal:block>
   </head>
   <body>
-
-    <h1 metal:fill-slot="heading">
-      <tal:has-link condition="branch/branch_link">
-        <a tal:attributes="href branch/branch_link"
-           tal:content="branch/friendly_name">
-          nice/branch/name
-        </a>
-      </tal:has-link>
-      <tal:no-link condition="not: branch/branch_link">
-        <tal:branch-name replace="branch/friendly_name" />
-      </tal:no-link>
-      : viewing
-      <span tal:content="path" /> for revision <span tal:content="change/revno"/>
-    </h1>
+      <tal:block metal:fill-slot="backlink">
+          <tal:has-link condition="branch/branch_link">
+            <div class="black-link">
+                <a tal:attributes="href branch/branch_link">
+                  &#8592; Back to branch summary
+                </a>
+            </div>
+          </tal:has-link>
+      </tal:block>
+      <tal:block metal:fill-slot="branchname" tal:content="string:${branch/friendly_name}" />
+          <tal:block metal:fill-slot="heading">
+          <div id="breadcrumbs">
+          <tal:has-link condition="branch/branch_link">
+            <a tal:attributes="href branch/branch_link"
+               tal:content="branch/friendly_name">
+              nice/branch/name
+            </a>
+          </tal:has-link>
+          <tal:no-link condition="not: branch/branch_link">
+            <span metal:use-macro="breadcrumbs/directory"></span>
+          </tal:no-link>
+          <span>: <span metal:use-macro="breadcrumbs/branch" /> (revision <tal:revno content="change/revno"></tal:revno>)</span>
+        </div>
+      </tal:block>
 
     <div metal:fill-slot="content">
-        <ul id="submenuTabs">
-            <li id="first">
-                <a tal:attributes="href python:url(['/revision', change.revno], clear=1, start_revid=change.revno)">view revision</a>
-            </li>
-            <li id="last">
-                <a tal:attributes="href python:url(['/changes', change.revno], clear=1, start_revid=change.revno)">view branch changes</a>
-            </li>
-        </ul>
-
-      <tal:revision-info replace="structure python:revisioninfo(url, branch, change)" />
-
-      <table id="logentries">
-          <tr class="logheader">
-            <th class="summarycell"><a tal:attributes="href python:url(['/files', revid], sort='filename')">Filename</a></th>
-            <th class="datecell">Latest Rev</th>
-            <th class="datecell"><a tal:attributes="href python:url(['/files', revid], sort='date')">Last Changed</a></th>
-            <th class="timedate"><a tal:attributes="href python:url(['/files', revid], sort='size')">Size</a></th>
-            <th class="expandcell"></th>
-            <th class="expandcell"></th>
-          </tr>
-
-          <tr class="blueRow0" tal:condition="python:updir">
-              <td class="summcell" colspan="6">
-                  <a tal:attributes="href python:url(['/files', revid], file_id=updir_file_id)" class="link">
-                      <img tal:attributes="src python:branch.static_url('/static/images/ico_folder_up.gif')" />..</a>
-              </td>
-          </tr>
-          
-          <!-- Show this if it's a directory --> 
-          <tal:block repeat="file filelist">
-          <tr tal:attributes="class string:blueRow${file/parity}" tal:condition="python:file.kind=='directory'">
-              <td class="autcell"><a tal:attributes="href python:url(['/files', change.revno], file_id=file.file_id)">
-                      <img tal:attributes="src python:branch.static_url('/static/images/ico_folder.gif');
-                                           title string:Go to ${file/filename}" />
-                  </a>
-
-               <a tal:attributes="href python:url(['/files', change.revno], file_id=file.file_id)" 
-                                      tal:content="file/filename" class="link"></a>
-               </td>
-               <td class="date"><a tal:attributes="href python:url(['/revision', file.change.revno], filter_file_id=file.file_id);
-                                                   title string:Show revision ${file/change/revno}"
-                                   tal:content="file/change/revno"></a>
-               </td>
-               <td class="date" tal:content="python:util.date_time(file.change.date)"></td>
-               <td class="timedate2"></td>
-               <td class="expcell"><a tal:attributes="href python:url(['/changes'], start_revid=start_revid, filter_file_id=file.file_id);
-                                                   title string:Show revision ${file/change/revno}">
-                                    <img tal:attributes="src python:branch.static_url('/static/images/ico_planilla.gif')" alt="Diff" />
-                                   </a>
-            </td>
-              <td class="expcell"></td>
-          </tr>
-          
-          <!-- Show this if it's a symlink --> 
-          <tr tal:attributes="class string:blueRow${file/parity}" tal:condition="python:file.kind=='symlink'">
-              <td class="autcell"><a tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id)">
-                      <img tal:attributes="src python:branch.static_url('/static/images/ico_flecha.gif')" alt="Symlink" />
-                  </a>
-
-               <a tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id)" 
-                                      tal:content="file/filename" class="link"></a>
-               </td>
-               <td class="date"><a tal:attributes="href python:url(['/revision', file.change.revno], filter_file_id=file.file_id);
-                                                   title string:Show revision ${file/change/revno}"
-                                   tal:content="file/change/revno"></a>
-               </td>
-               <td class="date" tal:content="python:util.date_time(file.change.date)"></td>
-               <td class="timedate2">.</td>
-               <td class="expcell"><a tal:attributes="href python:url(['/changes'], start_revid=start_revid, filter_file_id=file.file_id);
-                                                      title string:Show revision ${file/change/revno}">
-                                        <img tal:attributes="src python:branch.static_url('/static/images/ico_planilla.gif');
-                                                             title string:Show revision ${file/change/revno}" />
-                                   </a>
-            </td>
-              <td class="expcell"></td>
-          </tr>
-
-          <!-- Show this if it's a regular file --> 
-          <tr tal:attributes="class string:blueRow${file/parity}" tal:condition="python:file.kind=='file'">
-              <td class="autcell"><a tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id)">
-                      <img tal:attributes="src python:branch.static_url('/static/images/ico_file.gif');
-                                           title string:Annotate ${file/filename}"
-                           tal:condition="python:file.executable is False" />
-                      <!-- Show a different icon id the file executable -->
-                      <img tal:attributes="src python:branch.static_url('/static/images/ico_file_modify.gif'); 
-                                           title string:Annotate ${file/filename}"
-                           tal:condition="python:file.executable is True" alt="File" />
-                  </a>
-
-            <a tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id)"
-                                   tal:content="file/filename" class="link"></a></td>
-            <td class="date"><a tal:attributes="href python:url(['/revision', file.change.revno], filter_file_id=file.file_id);
-                                                title string:Show revision ${file/change/revno}"
-                                tal:content="file/change/revno"></a>
-            </td>
-            <td class="date" tal:content="python:util.date_time(file.change.date)"></td>
-            <td class="timedate2" tal:content="python:util.human_size(file.size)"></td>
-            <td class="expcell"><a tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id);
-                                                   title string:Annotate ${file/filename}">
-                                    <img tal:attributes="src python:branch.static_url('/static/images/ico_planilla.gif')" alt="Diff" />
-                                   </a>
-            </td>
-            <td class="expcell">
-               <a tal:attributes="href python:url(['/download', file.revid, file.file_id, file.filename]);
-                                  title string:Download ${file/filename} at revision ${file/change/revno}">
-                 <img tal:attributes="src python:branch.static_url('/static/images/ico_file_download.gif')" alt="Download File" />
-               </a>
-            </td>
-         </tr>
-        </tal:block>
-      </table>
+        <tal:branch-info replace="structure python:branchinfo(branch)" />
+
+        <p tal:condition="python:not change">
+          No revisions!
+        </p>
+        <p tal:condition="python:change">
+          <ul id="submenuTabs">
+              <li id="first">
+                  <a tal:attributes="href python:url(['/revision', change.revno], clear=1, start_revid=change.revno)">view revision</a>
+              </li>
+              <li id="last">
+                  <a tal:attributes="href python:url(['/changes', change.revno], clear=1, start_revid=change.revno)">view branch changes</a>
+              </li>
+          </ul>
+
+          <tal:revision-info replace="structure python:revisioninfo(url, branch, change)" />
+
+          <table id="logentries">
+            <tr class="logheader">
+              <th class="summarycell"><a tal:attributes="href python:url(['/files', revid], sort='filename')">Filename</a></th>
+              <th class="datecell">Latest Rev</th>
+              <th class="datecell"><a tal:attributes="href python:url(['/files', revid], sort='date')">Last Changed</a></th>
+              <th class="timedate"><a tal:attributes="href python:url(['/files', revid], sort='size')">Size</a></th>
+              <th class="expandcell"></th>
+              <th class="expandcell"></th>
+            </tr>
+
+            <tr class="blueRow0" tal:condition="python:updir is not None">
+                <td class="summcell" colspan="6">
+                    <a tal:attributes="href python:url(['/files', revno_url, updir])" class="link">
+                        <img tal:attributes="src python:branch.static_url('/static/images/ico_folder_up.gif')" />..</a>
+                </td>
+            </tr>
+
+            <!-- Show this if it's a directory -->
+            <tal:block repeat="file filelist">
+            <tr tal:attributes="class string:blueRow${repeat/file/even}" tal:condition="python:file.kind=='directory'">
+                <td class="autcell"><a tal:attributes="href python:url(['/files', revno_url, file.absolutepath])">
+                        <img tal:attributes="src python:branch.static_url('/static/images/ico_folder.gif');
+                                             title string:Go to ${file/filename}" />
+                    </a>
+
+                 <a tal:attributes="href python:url(['/files', revno_url, file.absolutepath])"
+                                        tal:content="file/filename" class="link"></a>
+                 </td>
+                 <td class="date"><a tal:attributes="href python:url(['/revision', file.change.revno]);
+                                                     title string:Show revision ${file/change/revno}"
+                                     tal:content="file/change/revno"></a>
+                 </td>
+                 <td class="date" tal:content="python:util.date_time(file.change.date)"></td>
+                 <td class="timedate2"></td>
+                 <td class="expcell"><a tal:attributes="href python:url(['/changes'], start_revid=start_revid, filter_file_id=file.file_id);
+                                                     title string:Show revision ${file/change/revno}">
+                                      <img tal:attributes="src python:branch.static_url('/static/images/ico_planilla.gif')" alt="Diff" />
+                                     </a>
+              </td>
+                <td class="expcell"></td>
+            </tr>
+
+            <!-- Show this if it's a symlink -->
+            <tr tal:attributes="class string:blueRow${repeat/file/even}" tal:condition="python:file.kind=='symlink'">
+                <td class="autcell"><a tal:attributes="href python:url(['/view', change.revno, file.absolutepath])">
+                        <img tal:attributes="src python:branch.static_url('/static/images/ico_file_flecha.gif')" alt="Symlink" />
+                    </a>
+
+                 <a tal:attributes="href python:url(['/view', revno_url, file.absolutepath])"
+                                        tal:content="file/filename" class="link"></a>
+                 </td>
+                 <td class="date"><a tal:attributes="href python:url(['/revision', file.change.revno]);
+                                                     title string:Show revision ${file/change/revno}"
+                                     tal:content="file/change/revno"></a>
+                 </td>
+                 <td class="date" tal:content="python:util.date_time(file.change.date)"></td>
+                 <td class="timedate2">.</td>
+                 <td class="expcell"><a tal:attributes="href python:url(['/changes'], start_revid=start_revid, filter_file_id=file.file_id);
+                                                        title string:Show revision ${file/change/revno}">
+                                          <img tal:attributes="src python:branch.static_url('/static/images/ico_planilla.gif');
+                                                               title string:Show revision ${file/change/revno}" />
+                                     </a>
+              </td>
+                <td class="expcell"></td>
+            </tr>
+
+            <!-- Show this if it's a regular file -->
+            <tr tal:attributes="class string:blueRow${repeat/file/even}" tal:condition="python:file.kind=='file'">
+                <td class="autcell"><a tal:attributes="href python:url(['/view', revno_url, file.absolutepath])">
+                        <img tal:attributes="src python:branch.static_url('/static/images/ico_file.gif');
+                                             title string:View ${file/filename}"
+                             tal:condition="python:file.executable is False" />
+                        <!-- Show a different icon id the file executable -->
+                        <img tal:attributes="src python:branch.static_url('/static/images/ico_file_modify.gif');
+                                             title string:View ${file/filename}"
+                             tal:condition="python:file.executable is True" alt="File" />
+                    </a>
+
+              <a tal:attributes="href python:url(['/view', revno_url, file.absolutepath])"
+                                     tal:content="file/filename" class="link"></a></td>
+              <td class="date"><a tal:attributes="href python:url(['/revision', file.change.revno]);
+                                                  title string:Show revision ${file/change/revno}"
+                                  tal:content="file/change/revno"></a>
+              </td>
+              <td class="date" tal:content="python:util.date_time(file.change.date)"></td>
+              <td class="timedate2" tal:content="python:util.human_size(file.size)"></td>
+              <td class="expcell"><a tal:attributes="href python:url(['/view', revno_url, file.absolutepath]);
+                                                     title string:View ${file/filename}">
+                                      <img tal:attributes="src python:branch.static_url('/static/images/ico_planilla.gif')" alt="Diff" />
+                                     </a>
+              </td>
+              <td class="expcell">
+                 <a tal:attributes="href python:url(['/download', file.revid, file.file_id, file.filename]);
+                                    title string:Download ${file/filename} at revision ${file/change/revno}">
+                   <img tal:attributes="src python:branch.static_url('/static/images/ico_file_download.gif')" alt="Download File" />
+                 </a>
+              </td>
+           </tr>
+          </tal:block>
+        </table>
+      </p>
     </div>
   </body>
 </html>

=== modified file 'loggerhead/templates/macros.pt'
--- loggerhead/templates/macros.pt	2008-08-04 03:42:01 +0000
+++ loggerhead/templates/macros.pt	2011-11-04 18:16:32 +0000
@@ -3,59 +3,63 @@
 <html xmlns="http://www.w3.org/1999/xhtml" metal:define-macro="main">
   <head>
     <meta content="text/html; charset=utf-8" http-equiv="Content-Type" />
+    <meta name="generator"
+          tal:attributes="content generator_string" />
 
     <title metal:define-slot="title"></title>
     <link rel="stylesheet"
           tal:attributes="href python:branch.static_url('/static/css/global.css')" />
-    <script type="text/javascript"
-            tal:attributes="src python:branch.static_url('/static/javascript/mootools-1.2-core.js')"></script>
-    <script type="text/javascript"
-            tal:attributes="src python:branch.static_url('/static/javascript/mootools-1.2-more.js')"></script>
+    <link rel="shortcut icon"
+          tal:attributes="href python:branch.static_url('/static/images/favicon.png')" />
+    <tal:comment condition="nothing">
+      <script type="text/javascript"
+              src="http://getfirebug.com/releases/lite/1.2/firebug-lite-compressed.js"></script>
+    </tal:comment>
+    <script type="text/javascript">
+      var global_path = <tal:block content="python:'\''+branch.url('/')+'\''" />;
+      var collapsed_icon_path = <tal:block content="python:'\''+branch.static_url('/static/images/treeCollapsed.png')+'\''" />;
+      var expanded_icon_path = <tal:block content="python:'\''+branch.static_url('/static/images/treeExpanded.png')+'\''" />;
+    </script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.yui_url('yui/yui-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.yui_url('oop/oop-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.yui_url('event/event-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.yui_url('attribute/attribute-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.yui_url('base/base-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.yui_url('dom/dom-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.yui_url('node/node-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.yui_url('anim/anim-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.yui_url('io/io-base-min.js')"></script>
     <script type="text/javascript"
             tal:attributes="src python:branch.static_url('/static/javascript/custom.js')"></script>
-      <script language="javascript">
-          var global_path = <tal:block content="python:'\''+branch.url('/')+'\''" />;
-      </script>
     <metal:block metal:define-slot="header_extras" />
   </head>
 
-<body>
+ <body tal:attributes="class python:branch.public_private_css()">
     <!-- Loggerhead Content Area -->
-    <ul id="menuTabs">
-        <form tal:attributes="action python:branch.url('/changes', start_revid=getattr(navigation, 'start_revid', None), 
-                                                                   file_id=getattr(navigation, 'file_id', None))">
-      	  <div id="finderBox">
-            <label>search:</label> <input type="search" name="q" id="q" autocomplete="off" onblur="hide_search();" /> 
-            <div><a tal:attributes="href python:url(['/atom']);
-                                    title string:RSS feed for ${branch/friendly_name}"> 
-                 <img tal:attributes="src python:branch.static_url('/static/images/ico_rss.gif')" alt="RSS" class="rssfeed"/></a>
-            </div>
-          </div>
-        </form>
-
-        <tal:block tal:condition="not:fileview_active">
-        <li><a tal:attributes="href python:url('/changes', clear=1);
-                               title string:Changes;
-                               id string:on">Changes</a></li>
-        <li><a tal:attributes="href python:url('/files', clear=1);
-                               title string:Files">Files</a></li>
-        </tal:block>
-        <tal:block tal:condition="fileview_active">
-        <li><a tal:attributes="href python:url('/changes', clear=1);
-                               title string:Changes">Changes</a></li>
-        <li><a tal:attributes="href python:url('/files', clear=1);
-                               title string:Files;
-                               id string:on">Files</a></li>
-        </tal:block>
-      </ul>
+      
+      <div metal:define-slot="backlink" />
+      
+      <h1 class="branch-name">
+        <span metal:define-slot="branchname" />
+      </h1>
+      <tal:menu define="fileview_active fileview_active"
+                replace="structure python:menu(branch, url, fileview_active)" />
       <div id="loggerheadCont">
 
-         <div id="search_terms"></div>
-
-        <h1 metal:define-slot="heading"></h1>
+        <div id="search_terms"></div>
+        <div metal:define-slot="heading" />
         <div metal:define-slot="content"></div>
 
-        <p class="fl">Loggerhead runs on <a href="http://bazaar-vcs.org/" class="link">Bazaar</a> branches</p>
-    </div>
+        <p id="footer" class="fl">Loggerhead <tal:version content="loggerhead_version" /> is a web-based interface for <a href="http://bazaar-vcs.org/">Bazaar</a> branches</p>
+      </div>
   </body>
 </html>

=== added file 'loggerhead/templates/menu.pt'
--- loggerhead/templates/menu.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/menu.pt	2011-11-24 07:48:58 +0000
@@ -0,0 +1,19 @@
+<tal:menu>
+    <ul id="menuTabs">
+        <tal:changes-active tal:condition="not:fileview_active">
+        <li><a tal:attributes="href python:url('/changes', clear=1);
+                               title string:Changes;
+                               id string:on">Changes</a></li>
+        <li><a tal:attributes="href python:url('/files', clear=1);
+                               title string:Files">Files</a></li>
+        </tal:changes-active>
+        <tal:fileview-active tal:condition="fileview_active">
+        <li><a tal:attributes="href python:url('/changes', clear=1);
+                               title string:Changes">Changes</a></li>
+        <li><a tal:attributes="href python:url('/files', clear=1);
+                               title string:Files;
+                               id string:on">Files</a></li>
+        </tal:fileview-active>
+      </ul>
+</tal:menu>
+

=== removed file 'loggerhead/templates/modified-file-link-rev.pt'
--- loggerhead/templates/modified-file-link-rev.pt	2008-06-19 21:39:15 +0000
+++ loggerhead/templates/modified-file-link-rev.pt	1970-01-01 00:00:00 +0000
@@ -1,7 +0,0 @@
-<tal:block>
-<li class="files"><a 
-     tal:attributes="href  string:#${item/filename}-s;
-                     title string:Jump to ${item/filename} below"
-     tal:content="item/filename" >
-</a></li>
-</tal:block>

=== modified file 'loggerhead/templates/revision.pt'
--- loggerhead/templates/revision.pt	2008-08-04 03:42:01 +0000
+++ loggerhead/templates/revision.pt	2011-11-23 08:33:55 +0000
@@ -9,13 +9,29 @@
       <metal:block fill-slot="header_extras">
         <link rel="stylesheet" type="text/css" media="all"
               tal:attributes="href python:branch.static_url('/static/css/diff.css')"/>
+        <script type="text/javascript"
+                tal:attributes="src python:branch.static_url('/static/javascript/diff.js')"></script>
+        <script type="text/javascript">
+          var link_data = <tal:b content="link_data" />;
+          var specific_path = <tal:b content="json_specific_path" />;
+          var path_to_id = <tal:b content="path_to_id" />;
+        </script>
       </metal:block>
     </head>
 
     <body>
-
+      <tal:block metal:fill-slot="backlink">
+          <tal:has-link condition="branch/branch_link">
+            <div class="black-link">
+                <a tal:attributes="href branch/branch_link">
+                  &#8592; Back to branch summary
+                </a>
+            </div>
+          </tal:has-link>
+      </tal:block>
+      <tal:block metal:fill-slot="branchname" tal:content="string:${branch/friendly_name}" />
       <tal:block metal:fill-slot="heading">
-        <h1>
+        <div id="breadcrumbs">
           <tal:has-link condition="branch/branch_link">
             <a tal:attributes="href branch/branch_link"
                tal:content="branch/friendly_name">
@@ -23,56 +39,88 @@
             </a>
           </tal:has-link>
           <tal:no-link condition="not: branch/branch_link">
-            <tal:branch-name replace="branch/friendly_name" />
+            <span metal:use-macro="breadcrumbs/directory"></span>
           </tal:no-link>
-          <span>: <tal:revno content="change/revno"></tal:revno>
-        <tal:compare-to condition="python:compare_revid is not None">
-          (compared to revision <tal:block content="python:history.get_revno(compare_revid)" />)
-          </tal:compare-to>
-        </span></h1>
+          <span class="breadcrumb">&#187; Revision
+            <tal:revno condition="not:specific_path" content="change/revno"></tal:revno>
+            <a tal:condition="specific_path" tal:content="change/revno"
+               tal:attributes="href python:url(['/revision', change.revno])"
+               title="View changes to all files"></a>
+                      <tal:compare-to condition="python:compare_revid is not None">
+              (compared to revision <tal:block content="python:history.get_revno(compare_revid)" />)
+            </tal:compare-to>
+          </span>
+          <span class="breadcrumb" tal:condition="specific_path">
+            : <tal:annotate content="structure python:view_link(url, change.revno, specific_path)" />
+          </span>
+        </div>
+        <tal:branch-info replace="structure python:branchinfo(branch)" />
+        <h1 tal:condition="not:specific_path">
+          Viewing all changes in revision <tal:revno content="change/revno" />.
+        </h1>
+        <p tal:condition="specific_path">
+          <a tal:attributes="href python:url(['/revision', change.revno])">
+            &#xAB; back to all changes in this revision
+          </a>
+        </p>
+        <p tal:condition="specific_path">
+          Viewing changes to <tal:annotate content="structure python:view_link(url, change.revno, specific_path)" />
+        </p>
         <ul id="submenuTabs">
-            <li id="first"><a tal:attributes="href python:url(['/files', change.revno]); 
-                                               title string:browse files at revision ${change/revno}"
-                               tal:content="string:browse files at revision ${change/revno}"></a></li>
-            <li tal:condition="python:remember != change.revno">
-                <a tal:attributes="href python:url(['/revision', change.revno], remember=change.revno, compare_revid=None); 
-                                   title string:Compare with another revision"
-                   tal:content="string:Compare with another revision"></a></li>       
-            <li tal:condition="python:(remember is not None) and (compare_revid is None) and (change.revno != remember)" >
-                <a tal:attributes="href python:url(['/revision', change.revno], compare_revid=history.get_revno(remember))">
-                compare with revision <tal:b content="python:history.get_revno(remember)" />
-                </a>
-            </li>
-            <li id="last"><a tal:attributes="href python:url(['/changes', change.revno]); 
-                                  title string:view history from revision ${change/revno}"
-                  tal:content="string:view history from revision ${change/revno}"></a></li>
+          <li id="first"><a tal:attributes="href python:url(['/files', change.revno]);
+                                            title string:browse files at revision ${change/revno}"
+                            tal:content="string:browse files at revision ${change/revno}"></a></li>
+          <li tal:condition="python:remember != change.revno">
+            <a tal:attributes="href python:url(['/revision', change.revno], remember=change.revno, compare_revid=None);
+                               title string:compare with another revision"
+               tal:content="string:compare with another revision"></a></li>
+          <li tal:condition="python:(remember is not None) and (compare_revid is None) and (change.revno != remember)" >
+            <a tal:attributes="href python:url(['/revision', change.revno], compare_revid=history.get_revno(remember))">
+              compare with revision <tal:b content="python:history.get_revno(remember)" />
+            </a>
+          </li>
+          <li>
+            <a tal:condition="python:compare_revid is None"
+               tal:attributes="href python:url(['/diff', change.revno], clear=1)">download diff</a>
+            <a tal:condition="python:compare_revid is not None"
+               tal:attributes="href python:url(['/diff', change.revno, history.get_revno(compare_revid)], clear=1)">download diff</a>
+           </li>
+           <li tal:condition="python:can_export">
+            <a tal:attributes="href python:url(['/tarball', change.revno])">download tarball</a>
+           </li>
+          <li id="last"><a tal:attributes="href python:url(['/changes', change.revno]);
+                                           title string:view history from revision ${change/revno}"
+                           tal:content="string:view history from revision ${change/revno}"></a></li>
         </ul>
 
         <tal:we-are-comparing condition="python:compare_revid is not None">
-        <ul id="submenuTabs">
-          <li id="first">
+          <ul id="submenuTabs">
+            <li id="first">
               <a tal:attributes="href python:url([ '/revision', history.get_revno(compare_revid) ], remember=change.revno, compare_revid=change.revno)">
                 reverse the comparison (<tal:b content="change/revno" /> to <tal:b content="python:history.get_revno(compare_revid)" />)
               </a>
-          </li>
-          <li id="last">
+            </li>
+            <li id="last">
               <a tal:attributes="href python:url(['/revision', change.revno], remember=None, compare_revid=None)">
                 stop comparing with revision <tal:b content="python:history.get_revno(compare_revid)" />
               </a>
-          </li>
-        </ul>
+            </li>
+          </ul>
         </tal:we-are-comparing>
-        
-        <tal:revision-info replace="structure python:revisioninfo(url, branch, change, modified_file_link_rev)" />
-        <p class="expand" id="expand_all" style="display:none;"><a tal:attributes="href string:javascript:toggle_expand_all_revisionview('open')">
-            <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
-                  alt="expand all" /> expand all</a>
-        </p>
-        <p class="expand" id="collapse_all"><a tal:attributes="href string:javascript:toggle_expand_all_revisionview('close')">
-            <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
-                  alt="collapse all" /> collapse all</a>
-        </p>
-        <!-- Table -->        
+
+        <tal:revision-info replace="structure python:revisioninfo(url, branch, change, file_changes, specific_path, merged_in)" />
+        <tal:specific-path condition="not:specific_path">
+          <p class="expand show_if_js" id="expand_all"><a href="#">
+              <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
+                   alt="expand all" /> expand all</a>
+          </p>
+          <p class="expand" id="collapse_all" style="display:none;"><a href="#">
+              <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
+                   alt="collapse all" /> collapse all</a>
+          </p>
+        </tal:specific-path>
+        <!-- Table -->
+        <p class="expand show_if_js"><a id="toggle_unified_sbs" href="#">Show diffs side-by-side</a></p>
         <p class="codin"><img tal:attributes="src python:branch.static_url('/static/images/newCode.gif')" alt="added" /> added</p>
         <p class="codin"><img tal:attributes="src python:branch.static_url('/static/images/deleteCode.gif')" alt="removed" /> removed</p>
         <div class="clear"><!-- --></div>
@@ -80,88 +128,94 @@
       </tal:block>
 
       <div metal:fill-slot="content">
-        <div class="diff"
-             tal:condition="change/changes/modified"
-             tal:define="uniqs python:{}">
-          <!-- ! side-by-side diff -->
-          <tal:block repeat="item change/changes/modified">
-
-              <tal:u define="u python:util.uniq(uniqs, item.file_id)">
-                      <div class="diffBox"><img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png');
-                                                                title python:branch.static_url('/static/images/treeCollapsed.png');
-                                                                alt python:branch.static_url('/static/images/treeExpanded.png')"
-                                                                class="expand_diff" />
-                                           <a tal:attributes="href python:url(['/annotate', change.revno], clear=1, file_id=item.file_id);
-                                                              id string:${item/filename}-s;
-                                                              title string:Annotate ${item/filename}"
-                                              tal:content="item/filename"></a></div>
-               <div id="psuedotable" class="diffinfo">
-               <tal:block repeat="chunk item/sbs_chunks">
-
-                <tal:block condition="not:repeat/chunk/start">
-                 <div class="lineNumber separate"></div>
-                 <div class="lineCode separate"></div>
-                 <div class="lineNumber separate"></div>
-                 <div class="lineCode separate"></div>
-                 <div class="clear"><!-- --></div>
-                </tal:block>
-
-                <tal:block repeat="line chunk/diff">
-                    <div id="pseudorow">
-                    <tal:block condition="line/old_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.old_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/old_type}">
-                            <tal:block replace="structure python:util.fill_div(line.old_line)" />
-                        </div>
-                    </tal:block>
-
-                    <tal:block condition="not:line/old_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.old_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/old_type}">
-                            <tal:block replace="structure python:util.fill_div(line.old_line)" />
-                        </div>
-                    </tal:block>
-
-                    <tal:block condition="line/new_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.new_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/new_type}">
-                            <tal:block replace="structure python:util.fill_div(line.new_line)" />
-                        </div>
-                    </tal:block>
-
-                    <tal:block condition="not:line/new_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.new_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/new_type}">
-                            <tal:block replace="structure python:util.fill_div(line.new_line)" />
-                        </div>
-                    </tal:block>
-                    <div class="clear"><!-- --></div>
+        <tal:block condition="specific_path">
+          <div class="diff">
+
+            <div  class="diffBox">
+              <a tal:attributes="href python:url(['/revision', change.revno, specific_path], clear=1);
+                                 id string:${specific_path};
+                                 title string:View changes to ${specific_path} only"
+                 class="the-link">
+                <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
+                     class="expand_diff"/>
+                <tal:b content="specific_path" />
+              </a>
+            </div>
+            <div style="overflow: hidden">
+              <div class="container">
+                <div class="loading" style="display:none">
+                  <img tal:attributes="src python:branch.static_url('/static/images/spinner.gif')" />
+                </div>
+                <div class="diffinfo">
+                  <div class="pseudotable unified"
+                       tal:repeat="chunk diff_chunks">
+
+                    <tal:block condition="not:repeat/chunk/start">
+                      <div class="pseudorow context-row">
+                        <div class="lineNumber separate"></div>
+                        <div class="lineNumber second separate"></div>
+                        <div class="code separate"></div>
+                        <div class="clear"><!-- --></div>
+                      </div>
+                    </tal:block>
+
+                    <div tal:repeat="line chunk/diff"
+                         tal:attributes="class string:pseudorow ${line/type}-row">
+                      <div class="lineNumber first"
+                           tal:content="structure python:util.fill_div(line.old_lineno)"></div>
+                      <div class="lineNumber second"
+                           tal:content="structure python:util.fill_div(line.new_lineno)"></div>
+                      <div tal:attributes="class string:code ${line/type}"
+                           tal:content="structure python:util.fill_div(util.html_clean(line.line))"></div>
+                      <div class="clear"><!-- --></div>
                     </div>
-                   </tal:block>
-                 </tal:block>
-                 </div>
-              </tal:u>
-            </tal:block>
-        </div>
+                  </div>
+                </div>
+              </div>
+            </div>
+          </div>
+        </tal:block>
+
+        <tal:block condition="not:specific_path">
+          <div class="diff"
+               tal:repeat="item file_changes/text_changes" tal:attributes="id string:diff-${item/index}">
+
+            <div  class="diffBox">
+              <a tal:attributes="href python:url(['/revision', change.revno, item.filename], clear=1);
+                                 id string:${item/filename};
+                                 title string:View changes to ${item/filename} only"
+                 class="the-link">
+                <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
+                     class="expand_diff" />
+                <tal:b content="item/filename" />
+              </a>
+            </div>
+            <div class="diffinfo"  style="display:none">
+              <div class="loading">
+                <img tal:attributes="src python:branch.static_url('/static/images/spinner.gif')" />
+              </div>
+            </div>
+          </div>
+        </tal:block>
 
         <ul tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
             id="pages">
-            <li tal:condition="navigation/prev_page_revid" 
-                class="previous">
-                <a tal:attributes="href navigation/prev_page_url">&laquo; Previous</a>
-            </li>
-            <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
-                        so some magic has to be done to just show the previous and next N page numbers
+          <li tal:condition="navigation/prev_page_revid"
+              class="previous">
+            <a tal:attributes="href navigation/prev_page_url">&laquo; Newer</a>
+          </li>
+          <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
+               so some magic has to be done to just show the previous and next N page numbers
 
-            <li class="active">1</li>
-            <tal:block tal:repeat="page_number python:range(navigation.page_count)">
-            <li><a href="#"
-                   tal:content="page_number"></a></li>
+               <li class="active">1</li>
+               <tal:block tal:repeat="page_number python:range(navigation.page_count)">
+                 <li><a href="#"
+                        tal:content="page_number"></a></li>
                </tal:block>-->
-            <li tal:condition="navigation/next_page_revid"
-                class="next">
-                <a tal:attributes="href navigation/next_page_url">Next &raquo;</a>
-            </li>
+          <li tal:condition="navigation/next_page_revid"
+              class="next">
+            <a tal:attributes="href navigation/next_page_url">Older &raquo;</a>
+          </li>
         </ul>
 
       </div>

=== modified file 'loggerhead/templates/revisionfilechanges.pt'
--- loggerhead/templates/revisionfilechanges.pt	2008-07-23 21:31:07 +0000
+++ loggerhead/templates/revisionfilechanges.pt	2012-01-08 23:01:10 +0000
@@ -1,58 +1,53 @@
 <tal:block>
-<ul tal:repeat="added entry/changes/added">
+  <ul tal:repeat="added file_changes/added">
     <tal:block condition="repeat/added/start">
-        <li class="desc">files added:</li>
+      <li class="desc">files added:</li>
     </tal:block>
-    <li class="files"
-        tal:define="filename python:added[0];
-                    file_id  python:added[1]">
-        <a tal:attributes="href  python:url(['/annotate', entry.revno], file_id=file_id);
-                           title string:Annotate ${filename}"
-           tal:content="filename" class="link"></a>
+    <li class="files">
+      <tal:revision condition="python:added.kind == 'file'"
+                    content="structure python:file_link(added.filename)" />
+      <tal:revision condition="python:added.kind != 'file'"
+                    content="added/filename" />
     </li>
-</ul>
+  </ul>
 
-<ul tal:repeat="removed entry/changes/removed">
+  <ul tal:repeat="removed file_changes/removed">
     <tal:block condition="repeat/removed/start">
-        <li class="desc">files removed:</li>
+      <li class="desc">files removed:</li>
     </tal:block>
-    <li class="files"
-        tal:define="filename python:removed[0];
-                    file_id  python:removed[1]">
-      <tal:block content="filename" />
+    <li class="files">
+      <tal:revision condition="python:removed.kind == 'file'"
+                    content="structure python:file_link(removed.filename)" />
+      <tal:revision condition="python:removed.kind != 'file'"
+                    content="removed/filename" />
     </li>
-</ul>
+  </ul>
 
-<ul tal:repeat="renamed entry/changes/renamed">
+  <ul tal:repeat="renamed file_changes/renamed">
     <tal:block condition="repeat/renamed/start">
-        <li class="desc">files renamed:</li>
+      <li class="desc">files renamed:</li>
     </tal:block>
-    <li class="files"
-        tal:define="old_filename python:renamed[0];
-                    new_filename python:renamed[1];
-                    file_id      python:renamed[2]">
-      <a tal:attributes="href  python:url(['/annotate', entry.revno], file_id=file_id);
-                         title string:Annotate ${old_filename}"
-         tal:content="old_filename" class="filename">
+    <li class="files">
+      <tal:old-name content="renamed/old_filename" class="filename">
         old_filename
-      </a>
-      =>
-      <a tal:attributes="href  python:url(['/annotate', entry.revno], file_id=file_id);
-                         title string:Annotate ${new_filename}"
-         tal:content="new_filename">
+      </tal:old-name>
+      =&gt;
+      <tal:revision condition="renamed/text_modified" content="structure python:file_link(renamed.new_filename)" />
+      <tal:old-name condition="not:renamed/text_modified" content="renamed/new_filename" class="filename">
         new_filename
-      </a>
+      </tal:old-name>
+      <tal:prop-change condition="renamed/exe_change" content="string:*" />
     </li>
-</ul>
+  </ul>
 
-<ul tal:repeat="item entry/changes/modified">
+  <ul tal:repeat="item file_changes/modified">
     <tal:block condition="repeat/item/start">
-        <li class="desc">files modified:</li>
+      <li class="desc">files modified:</li>
     </tal:block>
     <li class="files">
-      <a tal:attributes="href  python:url(['/annotate', entry.revno], file_id=item.file_id);
-                         title string:Annotate ${item/filename}"
-                         tal:content="item/filename"/>
+      <tal:revision condition="item/text_modified" content="structure python:file_link(item.filename)" />
+      <tal:revision condition="not:item/text_modified" content="item/filename" />
+      <tal:prop-change condition="item/exe_change" content="string:*" />
     </li>
-</ul>
+  </ul>
 </tal:block>

=== modified file 'loggerhead/templates/revisioninfo.pt'
--- loggerhead/templates/revisioninfo.pt	2008-08-05 19:25:28 +0000
+++ loggerhead/templates/revisioninfo.pt	2011-03-16 12:37:17 +0000
@@ -1,23 +1,58 @@
-<div id="infoContainer" class="revision-info">
+<div class="infoContainer">
     <div id="infTxt">
-        <div class="comiter" tal:content="python:util.hide_email(change.author)"></div>
-        <div class="timer" tal:content="python:util.date_time(change.date)"></div>
-        <div class="mfrom" tal:repeat="parent python:change.parents[1:]">
-            <a tal:attributes="title string:Merged From ${parent/revno};
-                               href python:url(['/revision', parent.revno], clear=1)"
-               tal:content="python:revno_with_nick(parent)"></a>
-        </div>
-        <div class="mto" tal:repeat="merge_point change/merge_points">
-            <a tal:attributes="title string:Merged In ${merge_point/revno};
-                               href python:url(['/revision', merge_point.revno], clear=1)"
-               tal:content="python:revno_with_nick(merge_point)"></a>
-        </div>
-        <div class="revid" tal:content="string:Revision ID: ${change/revid}"></div>
-        <div class="information" tal:content="python:util.fixed_width(change.comment)"></div>
+        <ul>
+            <li class="committer">
+                <strong>Committer:</strong>
+                <span tal:content="python:util.hide_email(change.committer)"></span>
+            </li>
+            <li class="authors" tal:condition="python:len(change.authors) > 1 or change.authors[0] != change.committer">
+                <strong>Author(s):</strong>
+                <span tal:content="python:', '.join(util.hide_emails(change.authors))"></span>
+            </li>
+            <li class="timer">
+                <strong>Date:</strong>
+                <span tal:content="python:util.date_time(change.date)"></span>
+            </li>
+            <li class="mfrom" tal:condition="python:change.parents[1:]">
+                <strong>mfrom:</strong>
+                <span tal:repeat="parent python:change.parents[1:]">
+                    <a tal:attributes="title string:Merged From ${parent/revno};
+                                       href python:url(['/revision', parent.revno], clear=1)"
+                       tal:content="python:revno_with_nick(parent)"></a>
+                </span>
+            </li>
+            <li class="mto" tal:condition="change/merge_points">
+                <strong>mto:</strong>
+                <span tal:repeat="merge_point change/merge_points">
+                    <a tal:attributes="title string:Merged In ${merge_point/revno};
+                                       href python:url(['/revision', merge_point.revno], clear=1)"
+                       tal:content="python:revno_with_nick(merge_point)"></a>
+                </span>
+            </li>
+            <li class="mto" tal:condition="merged_in">
+                <strong>mto:</strong>
+                  This revision was merged to the branch mainline in
+                  <a tal:attributes="href python:url(['/revision', merged_in], clear=1)">revision
+                    <tal:b content="merged_in"/></a>.
+            </li>
+            <li class="revid">
+                <strong>Revision ID:</strong>
+                <span tal:content="change/revid"></span>
+            </li>
+        </ul>
+	<div tal:attributes="class string:foreign-${change/foreign_vcs}"
+	     tal:condition="change/foreign_vcs" 
+	     tal:repeat="revid_part python:change.foreign_revid.keys()"
+	     tal:content="python:'%s: %s' % (revid_part, change.foreign_revid[revid_part])"/>
+        <div class="tags" tal:condition="change/tags" tal:content="string:Tags: ${change/tags}"></div>
+        <div class="clear"><!-- --></div>
+        <div class="bug" tal:repeat="bug change/bugs">
+            <a tal:attributes="href bug" tal:content="bug"></a>
+        </div>
+        <div class="information" tal:content="structure python:util.fixed_width(change.comment)"></div>
     </div>
-    <ul id="list-files">
-        <tal:block condition="nocall:modified_file_link">
-        <tal:block content="structure python:file_change_summary(url, change, modified_file_link)" /></tal:block>
+    <ul id="list-files" tal:condition="file_changes">
+      <tal:block content="structure python:file_change_summary(url, change, file_changes, 'fragment', currently_showing)" />
     </ul>
     <div class="clear"><!-- --></div>
 </div>

=== added file 'loggerhead/templates/revlog.pt'
--- loggerhead/templates/revlog.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/revlog.pt	2009-03-31 15:23:54 +0000
@@ -0,0 +1,17 @@
+<div class="revisioninfo">
+  <ul class="expandrev">
+    <li class="mfrom" tal:repeat="parent python:entry.parents[1:]">
+      <span class="revnolink">
+        <a tal:attributes="href python:url(['/changes', parent.revno])"
+           tal:content="python:revno_with_nick(parent)"></a>
+      </span>
+    </li>
+    <li class="mto" tal:repeat="merge_point entry/merge_points">
+      <a tal:attributes="href python:url(['/changes', merge_point.revno])"
+         tal:content="python:revno_with_nick(merge_point)"
+         title="Show history" class="link"></a>
+    </li>
+    <li class="committerli" tal:content="python:', '.join(util.hide_emails(entry.authors))"></li>
+    <tal:block content="structure python:file_change_summary(url, entry, file_changes)" />
+  </ul>
+</div>

=== added file 'loggerhead/templates/search-box.pt'
--- loggerhead/templates/search-box.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/search-box.pt	2008-08-13 17:24:10 +0000
@@ -0,0 +1,10 @@
+<tal:search-box>
+  <form tal:attributes="action python:branch.url('/changes',
+                            start_revid=getattr(navigation,
+                            'start_revid', None),
+                            file_id=getattr(navigation, 'file_id', None))">
+    <label>search:</label>
+    <input type="search" name="q" id="q" autocomplete="off" onblur="hide_search();" />
+  </form>
+</tal:search-box>
+

=== renamed file 'loggerhead/templates/annotate.pt' => 'loggerhead/templates/view.pt'
--- loggerhead/templates/annotate.pt	2008-08-04 03:42:01 +0000
+++ loggerhead/templates/view.pt	2011-04-22 17:22:26 +0000
@@ -3,65 +3,95 @@
 <html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
   <head>
     <title metal:fill-slot="title"
-           tal:content="string:${branch/friendly_name} : contents of ${path}
+           tal:content="string:${branch/friendly_name} : contents of ${file_path}
                         at revision ${change/revno}">
     </title>
     <metal:block fill-slot="header_extras">
         <link rel="stylesheet" type="text/css" media="all"
-              tal:attributes="href python:branch.static_url('/static/css/annotate.css')"/>
+              tal:attributes="href python:branch.static_url('/static/css/view.css')"/>
+        <link rel="stylesheet" type="text/css" media="all"
+              tal:attributes="href python:branch.static_url('/static/css/highlight.css')"/>
     </metal:block>
   </head>
 
   <body>
-
-    <h1 metal:fill-slot="heading">
-      <tal:has-link condition="branch/branch_link">
-        <a tal:attributes="href branch/branch_link"
-           tal:content="branch/friendly_name">
-          nice/branch/name
-        </a>
-      </tal:has-link>
-      <tal:no-link condition="not: branch/branch_link">
-        <tal:branch-name replace="branch/friendly_name" />
-      </tal:no-link>
-      <span>: <span tal:content="path"></span> (revision <tal:revno content="change/revno"></tal:revno>)</span>
-    </h1>
+      <tal:block metal:fill-slot="backlink">
+          <tal:has-link condition="branch/branch_link">
+            <div class="black-link">
+                <a tal:attributes="href branch/branch_link">
+                  &#8592; Back to branch summary
+                </a>
+            </div>
+          </tal:has-link>
+      </tal:block>
+      <tal:block metal:fill-slot="branchname" tal:content="string:${branch/friendly_name}" />
+          <tal:block metal:fill-slot="heading">
+          <div id="breadcrumbs">
+          <tal:has-link condition="branch/branch_link">
+            <a tal:attributes="href branch/branch_link"
+               tal:content="branch/friendly_name">
+              nice/branch/name
+            </a>
+          </tal:has-link>
+          <tal:no-link condition="not: branch/branch_link">
+            <span metal:use-macro="breadcrumbs/directory"></span>
+          </tal:no-link>
+          <span>: <span metal:use-macro="breadcrumbs/branch" /> (revision <tal:revno content="change/revno"></tal:revno>)</span>
+        </div>
+      </tal:block>
 
     <div metal:fill-slot="content">
+      <tal:branch-info replace="structure python:branchinfo(branch)" />
+
         <ul id="submenuTabs">
             <li id="first">
                 <a tal:attributes="href python:url(['/files', change.revno], clear=1)">browse files</a>
             </li>
-            <li>
-                <a tal:attributes="href python:url(['/revision'], clear=1, start_revid=change.revno)">view revision</a>
-            </li>
-            <li>
-                <a tal:attributes="href python:url(['/changes'], clear=1, start_revid=change.revno, filter_file_id=file_id)">view changes to this file</a>
+            <li tal:condition="not:annotated">
+              <a tal:attributes="href python:url(['/annotate', revno_url, file_path], clear=1)"
+              >view with revision information</a>
+            </li>
+            <li tal:condition="annotated">
+              <a tal:attributes="href python:url(['/view', revno_url, file_path], clear=1)"
+              >view without revision information</a>
+            </li>
+            <li>
+                <a tal:attributes="href python:url(['/revision', change.revno], clear=1)">view revision</a>
+            </li>
+            <li>
+                <a tal:attributes="href python:url(['/changes'], clear=1, filter_file_id=file_id)"
+                >view changes to this file</a>
             </li>
             <li id="last">
-                <a tal:attributes="href python:url(['/download', change.revno, file_id, filename])">download file</a>
+                <a tal:attributes="href python:url(['/download',
+                                    revno_url, file_id, filename])"
+                >download file</a>
             </li>
         </ul>
 
-      <div class="annotate">
+      <div class="view">
         <table id="logentries">
-          <tr class="logheader">
-            <td class="annoLineTit">Line</td>
-            <td class="annoRevTit">Revision</td>            
-            <td class="annoContTit">Contents</td>                    
-          </tr>
+          <tal:rep tal:repeat="line contents">
+            <tr>
+              <td tal:condition="python:path('repeat/line/number') in annotated"
+                  tal:define="anno python:annotated.get(path('repeat/line/number'), None)"
+                  tal:attributes="rowspan python:anno.revspan"
+                  class="viewRev">
+                <a tal:content="python:'%s' % (anno.change.revno,)"
+                   tal:attributes="href python:url(['/revision', anno.change.revno], clear=1);
+                                   title python:'%s by %s, on %s (%s)' % (anno.change.revno, ', '.join(util.hide_emails(anno.change.authors)), anno.change.date.strftime('%d %b %Y %H:%M'), util.date_time(anno.change.date))"></a>
+                <span class="viewAuthors" tal:content="python:'by ' + ', '.join(util.hide_emails(anno.change.authors))" />
+                <br />
 
-          <tr tal:repeat="line contents" 
-              tal:attributes="class string:blueRow${line/parity}">
-            <td class="annoLine" tal:content="line/lineno">1</td>
-            <td class="annoRev">
-              <a tal:condition="python:line.status=='changed'"
-                 tal:content="python:util.trunc(line.change.revno)"
-                 tal:attributes="href python:url(['/revision'], clear=1, start_revid=line.change.revno, filter_file_id=file_id);
-                                 title python:'%s by %s, on %s (%s)'%(line.change.revno, util.hide_email(line.change.author), line.change.date.strftime('%d %b %Y %H:%M'), util.date_time(line.change.date))"></a>
-            </td>
-            <td class="annoCont" tal:content="line/text"></td>
-          </tr>
+                <span tal:content="python:anno.message"></span>
+              </td>
+              <td tal:attributes="class python:path('repeat/line/number') in annotated and 'viewLine first' or 'viewLine'">
+                <a tal:attributes="id string:L${repeat/line/number}; href string:#L${repeat/line/number}"
+                   tal:content="repeat/line/number">1</a>
+              </td>
+              <td class="viewCont"><pre tal:content="structure line"></pre></td>
+            </tr>
+          </tal:rep>
         </table>
       </div>
 

=== modified file 'loggerhead/tests/__init__.py'
--- loggerhead/tests/__init__.py	2006-12-11 06:44:19 +0000
+++ loggerhead/tests/__init__.py	2011-09-08 00:33:28 +0000
@@ -0,0 +1,31 @@
+# Copyright 2006, 2010, 2011 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+def load_tests(standard_tests, module, loader):
+    standard_tests.addTests(loader.loadTestsFromModuleNames([
+        (__name__ + '.' + x) for x in [
+            'test_controllers',
+            'test_corners',
+            'test_history',
+            'test_http_head',
+            'test_load_test',
+            'test_simple',
+            'test_revision_ui',
+            'test_templating',
+            'test_util',
+        ]]))
+    return standard_tests

=== added file 'loggerhead/tests/fixtures.py'
--- loggerhead/tests/fixtures.py	1970-01-01 00:00:00 +0000
+++ loggerhead/tests/fixtures.py	2011-11-25 02:28:56 +0000
@@ -0,0 +1,43 @@
+# Copyright (C) 2007, 2008, 2009, 2011 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+from __future__ import absolute_import
+
+from fixtures import Fixture
+
+
+class SampleBranch(Fixture):
+
+    def __init__(self, testcase):
+        # Must be a bzr TestCase to hook into branch creation, unfortunately.
+        self.testcase = testcase
+
+    def setUp(self):
+        Fixture.setUp(self)
+
+        self.tree = self.testcase.make_branch_and_tree('.')
+
+        self.filecontents = (
+            'some\nmultiline\ndata\n'
+            'with<htmlspecialchars\n')
+        filenames = ['myfilename', 'anotherfile<']
+        self.testcase.build_tree_contents(
+            (filename, self.filecontents) for filename in filenames)
+        for filename in filenames:
+            self.tree.add(filename, '%s-id' % filename)
+        self.fileid = self.tree.path2id('myfilename')
+        self.msg = 'a very exciting commit message <'
+        self.revid = self.tree.commit(message=self.msg)

=== added file 'loggerhead/tests/test_controllers.py'
--- loggerhead/tests/test_controllers.py	1970-01-01 00:00:00 +0000
+++ loggerhead/tests/test_controllers.py	2011-11-25 01:41:07 +0000
@@ -0,0 +1,369 @@
+# Copyright (C) 2008-2011 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+from cStringIO import StringIO
+import logging
+import tarfile
+import tempfile
+
+from paste.fixture import (
+    AppError,
+    )
+from paste.httpexceptions import HTTPServerError
+
+from testtools.matchers import (
+    Matcher,
+    Mismatch,
+    )
+
+from bzrlib import errors
+import simplejson
+
+from loggerhead.apps.branch import BranchWSGIApp
+from loggerhead.controllers.annotate_ui import AnnotateUI
+from loggerhead.controllers.inventory_ui import InventoryUI
+from loggerhead.tests.test_simple import (
+    BasicTests,
+    consume_app,
+    TestWithSimpleTree,
+    )
+
+
+class TestInventoryUI(BasicTests):
+
+    def make_bzrbranch_for_tree_shape(self, shape):
+        tree = self.make_branch_and_tree('.')
+        self.build_tree(shape)
+        tree.smart_add([])
+        tree.commit('')
+        self.addCleanup(tree.branch.lock_read().unlock)
+        return tree.branch
+
+    def make_bzrbranch_and_inventory_ui_for_tree_shape(self, shape):
+        branch = self.make_bzrbranch_for_tree_shape(shape)
+        branch_app = self.make_branch_app(branch)
+        return branch, InventoryUI(branch_app, branch_app.get_history)
+
+    def test_get_filelist(self):
+        bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
+            ['filename'])
+        inv = bzrbranch.repository.get_inventory(bzrbranch.last_revision())
+        self.assertEqual(1, len(inv_ui.get_filelist(inv, '', 'filename', 'head')))
+
+    def test_smoke(self):
+        bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
+            ['filename'])
+        start, content = consume_app(inv_ui,
+            {'SCRIPT_NAME': '/files', 'PATH_INFO': ''})
+        self.assertEqual(('200 OK', [('Content-Type', 'text/html')], None),
+                         start)
+        self.assertContainsRe(content, 'filename')
+
+    def test_no_content_for_HEAD(self):
+        bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
+            ['filename'])
+        start, content = consume_app(inv_ui,
+            {'SCRIPT_NAME': '/files', 'PATH_INFO': '',
+             'REQUEST_METHOD': 'HEAD'})
+        self.assertEqual(('200 OK', [('Content-Type', 'text/html')], None),
+                         start)
+        self.assertEqual('', content)
+
+    def test_get_values_smoke(self):
+        branch = self.make_bzrbranch_for_tree_shape(['a-file'])
+        branch_app = self.make_branch_app(branch)
+        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/files'}
+        inv_ui = branch_app.lookup_app(env)
+        inv_ui.parse_args(env)
+        values = inv_ui.get_values('', {}, {})
+        self.assertEqual('a-file', values['filelist'][0].filename)
+
+    def test_json_render_smoke(self):
+        branch = self.make_bzrbranch_for_tree_shape(['a-file'])
+        branch_app = self.make_branch_app(branch)
+        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/+json/files'}
+        inv_ui = branch_app.lookup_app(env)
+        self.assertOkJsonResponse(inv_ui, env)
+
+
+class TestRevisionUI(BasicTests):
+
+    def make_branch_app_for_revision_ui(self, shape1, shape2):
+        tree = self.make_branch_and_tree('.')
+        self.build_tree_contents(shape1)
+        tree.smart_add([])
+        tree.commit('msg 1', rev_id='rev-1')
+        self.build_tree_contents(shape2)
+        tree.smart_add([])
+        tree.commit('msg 2', rev_id='rev-2')
+        branch = tree.branch
+        self.addCleanup(branch.lock_read().unlock)
+        return self.make_branch_app(branch)
+
+    def test_get_values(self):
+        branch_app = self.make_branch_app_for_revision_ui([], [])
+        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/revision/2'}
+        rev_ui = branch_app.lookup_app(env)
+        rev_ui.parse_args(env)
+        self.assertIsInstance(rev_ui.get_values('', {}, []), dict)
+
+    def test_add_template_values(self):
+        branch_app = self.make_branch_app_for_revision_ui(
+                [('file', 'content\n')], [('file', 'new content\n')])
+        env = {'SCRIPT_NAME': '/',
+               'PATH_INFO': '/revision/1/non-existent-file',
+               'QUERY_STRING':'start_revid=1' }
+        revision_ui = branch_app.lookup_app(env)
+        path = revision_ui.parse_args(env)
+        values = revision_ui.get_values(path, revision_ui.kwargs, {})
+        revision_ui.add_template_values(values)
+        self.assertIs(values['diff_chunks'], None)
+
+    def test_get_values_smoke(self):
+        branch_app = self.make_branch_app_for_revision_ui(
+                [('file', 'content\n'), ('other-file', 'other\n')],
+                [('file', 'new content\n')])
+        env = {'SCRIPT_NAME': '/',
+               'PATH_INFO': '/revision/head:'}
+        revision_ui = branch_app.lookup_app(env)
+        revision_ui.parse_args(env)
+        values = revision_ui.get_values('', {}, {})
+
+        self.assertEqual(values['revid'], 'rev-2')
+        self.assertEqual(values['change'].comment, 'msg 2')
+        self.assertEqual(values['file_changes'].modified[0].filename, 'file')
+        self.assertEqual(values['merged_in'], None)
+
+    def test_json_render_smoke(self):
+        branch_app = self.make_branch_app_for_revision_ui(
+                [('file', 'content\n'), ('other-file', 'other\n')],
+                [('file', 'new content\n')])
+        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/+json/revision/head:'}
+        revision_ui = branch_app.lookup_app(env)
+        self.assertOkJsonResponse(revision_ui, env)
+
+
+
+class TestAnnotateUI(BasicTests):
+
+    def make_annotate_ui_for_file_history(self, file_id, rev_ids_texts):
+        tree = self.make_branch_and_tree('.')
+        self.build_tree_contents([('filename', '')])
+        tree.add(['filename'], [file_id])
+        for rev_id, text, message in rev_ids_texts:
+            self.build_tree_contents([('filename', text)])
+            tree.commit(rev_id=rev_id, message=message)
+        tree.branch.lock_read()
+        self.addCleanup(tree.branch.unlock)
+        branch_app = BranchWSGIApp(tree.branch, friendly_name='test_name')
+        return AnnotateUI(branch_app, branch_app.get_history)
+
+    def test_annotate_file(self):
+        history = [('rev1', 'old\nold\n', '.'), ('rev2', 'new\nold\n', '.')]
+        ann_ui = self.make_annotate_ui_for_file_history('file_id', history)
+        # A lot of this state is set up by __call__, but we'll do it directly
+        # here.
+        ann_ui.args = ['rev2']
+        annotate_info = ann_ui.get_values('filename',
+            kwargs={'file_id': 'file_id'}, headers={})
+        annotated = annotate_info['annotated']
+        self.assertEqual(2, len(annotated))
+        self.assertEqual('2', annotated[1].change.revno)
+        self.assertEqual('1', annotated[2].change.revno)
+
+    def test_annotate_empty_comment(self):
+        # Testing empty comment handling without breaking
+        history = [('rev1', 'old\nold\n', '.'), ('rev2', 'new\nold\n', '')]
+        ann_ui = self.make_annotate_ui_for_file_history('file_id', history)
+        ann_ui.args = ['rev2']
+        annotate_info = ann_ui.get_values('filename',
+            kwargs={'file_id': 'file_id'}, headers={})
+
+    def test_annotate_file_zero_sized(self):
+        # Test against a zero-sized file without breaking. No annotation must be present.
+        history = [('rev1', '' , '.')]
+        ann_ui = self.make_annotate_ui_for_file_history('file_id', history)
+        ann_ui.args = ['rev1']
+        annotate_info = ann_ui.get_values('filename',
+            kwargs={'file_id': 'file_id'}, headers={})
+        annotated = annotate_info['annotated']
+        self.assertEqual(0, len(annotated))
+
+
+class TestFileDiffUI(BasicTests):
+
+    def make_branch_app_for_filediff_ui(self):
+        builder = self.make_branch_builder('branch')
+        builder.start_series()
+        builder.build_snapshot('rev-1-id', None, [
+            ('add', ('', 'root-id', 'directory', '')),
+            ('add', ('filename', 'f-id', 'file', 'content\n'))],
+            message="First commit.")
+        builder.build_snapshot('rev-2-id', None, [
+            ('modify', ('f-id', 'new content\n'))])
+        builder.finish_series()
+        branch = builder.get_branch()
+        self.addCleanup(branch.lock_read().unlock)
+        return self.make_branch_app(branch)
+
+    def test_get_values_smoke(self):
+        branch_app = self.make_branch_app_for_filediff_ui()
+        env = {'SCRIPT_NAME': '/',
+               'PATH_INFO': '/+filediff/rev-2-id/rev-1-id/f-id'}
+        filediff_ui = branch_app.lookup_app(env)
+        filediff_ui.parse_args(env)
+        values = filediff_ui.get_values('', {}, {})
+        chunks = values['chunks']
+        self.assertEqual('insert', chunks[0].diff[1].type)
+        self.assertEqual('new content', chunks[0].diff[1].line)
+
+    def test_json_render_smoke(self):
+        branch_app = self.make_branch_app_for_filediff_ui()
+        env = {'SCRIPT_NAME': '/',
+               'PATH_INFO': '/+json/+filediff/rev-2-id/rev-1-id/f-id'}
+        filediff_ui = branch_app.lookup_app(env)
+        self.assertOkJsonResponse(filediff_ui, env)
+
+
+class TestRevLogUI(BasicTests):
+
+    def make_branch_app_for_revlog_ui(self):
+        builder = self.make_branch_builder('branch')
+        builder.start_series()
+        builder.build_snapshot('rev-id', None, [
+            ('add', ('', 'root-id', 'directory', '')),
+            ('add', ('filename', 'f-id', 'file', 'content\n'))],
+            message="First commit.")
+        builder.finish_series()
+        branch = builder.get_branch()
+        self.addCleanup(branch.lock_read().unlock)
+        return self.make_branch_app(branch)
+
+    def test_get_values_smoke(self):
+        branch_app = self.make_branch_app_for_revlog_ui()
+        env = {'SCRIPT_NAME': '/',
+               'PATH_INFO': '/+revlog/rev-id'}
+        revlog_ui = branch_app.lookup_app(env)
+        revlog_ui.parse_args(env)
+        values = revlog_ui.get_values('', {}, {})
+        self.assertEqual(values['file_changes'].added[1].filename, 'filename')
+        self.assertEqual(values['entry'].comment, "First commit.")
+
+    def test_json_render_smoke(self):
+        branch_app = self.make_branch_app_for_revlog_ui()
+        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/+json/+revlog/rev-id'}
+        revlog_ui = branch_app.lookup_app(env)
+        self.assertOkJsonResponse(revlog_ui, env)
+
+
+class TestControllerHooks(BasicTests):
+
+    def test_dummy_hook(self):
+        return
+        # A hook that returns None doesn't influence the searching for
+        # a controller.
+        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/custom'}
+        myhook = lambda app, environ: None
+        branch = self.make_branch('.')
+        self.addCleanup(branch.lock_read().unlock)
+        app = self.make_branch_app(branch)
+        self.addCleanup(BranchWSGIApp.hooks.uninstall_named_hook, 'controller',
+            'captain hook')
+        BranchWSGIApp.hooks.install_named_hook('controller', myhook, "captain hook")
+        self.assertRaises(KeyError, app.lookup_app, env)
+
+    def test_working_hook(self):
+        # A hook can provide an app to use for a particular request.
+        env = {'SCRIPT_NAME': '', 'PATH_INFO': '/custom'}
+        myhook = lambda app, environ: "I am hooked"
+        branch = self.make_branch('.')
+        self.addCleanup(branch.lock_read().unlock)
+        app = self.make_branch_app(branch)
+        self.addCleanup(BranchWSGIApp.hooks.uninstall_named_hook, 'controller',
+            'captain hook')
+        BranchWSGIApp.hooks.install_named_hook('controller', myhook, "captain hook")
+        self.assertEquals("I am hooked", app.lookup_app(env))
+
+
+class IsTarfile(Matcher):
+
+    def __init__(self, compression):
+        self.compression = compression
+
+    def match(self, content_bytes):
+        f = tempfile.NamedTemporaryFile()
+        try:
+            f.write(content_bytes)
+            f.flush()
+            tarfile.open(f.name, mode='r|' + self.compression)
+        finally:
+            f.close()
+
+
+class MatchesTarballHeaders(Matcher):
+
+    def __init__(self, expect_filename):
+        self.expect_filename = expect_filename
+
+    def match(self, response):
+        # Maybe the c-t should be more specific, but this is probably good for
+        # making sure it gets saved without the client trying to decompress it
+        # or anything.
+        if (response.header('Content-Type') == 'application/octet-stream'
+            and response.header('Content-Disposition') ==
+            "attachment; filename*=utf-8''" + self.expect_filename):
+            pass
+        else:
+            return Mismatch("wrong response headers: %r"
+                % response.headers)
+
+
+class TestDownloadTarballUI(TestWithSimpleTree):
+
+    def setUp(self):
+        super(TestDownloadTarballUI, self).setUp()
+
+    def test_download_tarball(self):
+        # Tarball downloads are enabled by default.
+        app = self.setUpLoggerhead()
+        response = app.get('/tarball')
+        self.assertThat(
+            response.body,
+            IsTarfile('gz'))
+        self.assertThat(
+            response,
+            MatchesTarballHeaders('branch.tgz'))
+
+    def test_download_tarball_of_version(self):
+        app = self.setUpLoggerhead()
+        response = app.get('/tarball/1')
+        self.assertThat(
+            response.body,
+            IsTarfile('gz'))
+        self.assertThat(
+            response,
+            MatchesTarballHeaders('branch-r1.tgz'))
+
+    def test_download_tarball_forbidden(self):
+        app = self.setUpLoggerhead(export_tarballs=False)
+        e = self.assertRaises(
+            AppError, 
+            app.get,
+            '/tarball')
+        self.assertContainsRe(
+            str(e),
+            '(?s).*403 Forbidden'
+            '.*Tarball downloads are not allowed')

=== modified file 'loggerhead/tests/test_corners.py'
--- loggerhead/tests/test_corners.py	2008-06-20 02:20:05 +0000
+++ loggerhead/tests/test_corners.py	2009-04-02 20:32:12 +0000
@@ -12,11 +12,7 @@
         The commit adds a file called 'myfilename' containing the string
         'foo'.
         """
-        f = open(os.path.join(self.bzrbranch, filename), 'w')
-        try:
-            f.write("foo")
-        finally:
-            f.close()
+        self.build_tree_contents([(filename, 'foo')])
         self.tree.add(filename)
         self.tree.commit(message=commit_msg)
 
@@ -30,7 +26,7 @@
         self.addFileAndCommit('myfilename', msg)
 
         # Make a commit that changes the execute bit of 'myfilename'.
-        os.chmod(os.path.join(self.bzrbranch, 'myfilename'), 0755)
+        os.chmod('myfilename', 0755)
         newrevid = self.tree.commit(message='make something executable')
 
         # Check that it didn't break things.
@@ -38,6 +34,16 @@
         res = app.get('/revision/'+newrevid)
         res.mustcontain('executable')
 
+    def test_revision_escapes_commit_message(self):
+        """XXX."""
+        self.createBranch()
+
+        msg = '<b>hi</b>'
+        self.addFileAndCommit('myfilename', msg)
+        app = self.setUpLoggerhead()
+        res = app.get('/revision/1')
+        self.assertFalse(msg in res.body)
+
     def test_empty_commit_message(self):
         """Check that an empty commit message does not break the rendering."""
         self.createBranch()
@@ -50,7 +56,7 @@
         res = app.get('/changes')
         # It's not much of an assertion, but we only really care about
         # "assert not crashed".
-        res.mustcontain('myfilename')
+        res.mustcontain('1')
 
     def test_whitespace_only_commit_message(self):
         """Check that a whitespace-only commit message does not break the
@@ -65,4 +71,4 @@
         res = app.get('/changes')
         # It's not much of an assertion, but we only really care about
         # "assert not crashed".
-        res.mustcontain('myfilename')
+        res.mustcontain('1')

=== removed file 'loggerhead/tests/test_filechangecache.py'
--- loggerhead/tests/test_filechangecache.py	2008-06-25 07:03:06 +0000
+++ loggerhead/tests/test_filechangecache.py	1970-01-01 00:00:00 +0000
@@ -1,95 +0,0 @@
-"""Tests for the FileChangeCache in loggerhead.changecache."""
-
-import shutil
-import tempfile
-
-from loggerhead.changecache import FileChangeCache
-
-class MockEntry(object):
-    def __init__(self, revid):
-        self.revid = revid
-
-
-class MockHistory(object):
-    def __init__(self):
-        self.fetched_revids = set()
-    def get_file_changes_uncached(self, entries):
-        output = []
-        for entry in entries:
-            self.fetched_revids.add(entry.revid)
-            output.append(entry.revid)
-        return output
-
-
-class TestFileChangeCache(object):
-
-    # setup_method and teardown_method are so i can run the tests with
-    # py.test and take advantage of the error reporting.
-    def setup_method(self, meth):
-        self.setUp()
-
-    def teardown_method(self, meth):
-        self.tearDown()
-
-    def setUp(self):
-        self.cache_folders = []
-
-    def tearDown(self):
-        for folder in self.cache_folders:
-            shutil.rmtree(folder)
-
-
-    def makeHistoryAndEntriesForRevids(self, revids, fill_cache_with=[]):
-        cache_folder = tempfile.mkdtemp()
-        self.cache_folders.append(cache_folder)
-        self.history = MockHistory()
-        self.cache = FileChangeCache(self.history, cache_folder)
-
-        self.entries = [MockEntry(revid) for revid in revids]
-
-        self.cache.get_file_changes([entry for entry in self.entries
-                                     if entry.revid in fill_cache_with])
-        self.history.fetched_revids.clear()
-
-
-    def test_empty_cache(self):
-        """An empty cache passes all the revids through to the history object.
-        """
-        revids = ['a', 'b']
-        self.makeHistoryAndEntriesForRevids(revids)
-
-        result = self.cache.get_file_changes(self.entries)
-
-        assert result == revids
-        assert self.history.fetched_revids == set(revids)
-
-    def test_full_cache(self):
-        """A full cache passes none of the revids through to the history
-        object.
-        """
-        revids = ['a', 'b']
-        self.makeHistoryAndEntriesForRevids(revids, fill_cache_with=revids)
-
-        result = self.cache.get_file_changes(self.entries)
-
-        assert result == revids
-        assert self.history.fetched_revids == set()
-
-    def test_partial_cache(self):
-        """A partially full cache passes some of the revids through to the
-        history object, and preserves the ordering of the argument list.
-        """
-        # To test the preservation of argument order code, we put the uncached
-        # revid at the beginning, middle and then end of the list of revids
-        # being asked for.
-        for i in range(3):
-            cached_revids = ['a', 'b']
-            revids = cached_revids[:]
-            revids.insert(i, 'uncached')
-            self.makeHistoryAndEntriesForRevids(
-                revids, fill_cache_with=cached_revids)
-
-            result = self.cache.get_file_changes(self.entries)
-            assert result == revids
-
-            assert self.history.fetched_revids == set(['uncached'])

=== added file 'loggerhead/tests/test_history.py'
--- loggerhead/tests/test_history.py	1970-01-01 00:00:00 +0000
+++ loggerhead/tests/test_history.py	2011-03-25 13:09:10 +0000
@@ -0,0 +1,328 @@
+# Copyright (C) 2011 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+"""Direct tests of the loggerhead/history.py module"""
+
+from bzrlib.foreign import (
+    ForeignRevision,
+    ForeignVcs,
+    VcsMapping,
+    )
+
+from datetime import datetime
+from bzrlib import tag, tests
+
+from loggerhead import history as _mod_history
+
+
+class TestCaseWithExamples(tests.TestCaseWithMemoryTransport):
+
+    def make_linear_ancestry(self):
+        # Time goes up
+        # rev-3
+        #  |
+        # rev-2
+        #  |
+        # rev-1
+        builder = self.make_branch_builder('branch')
+        builder.start_series()
+        builder.build_snapshot('rev-1', None, [
+            ('add', ('', 'root-id', 'directory', None))])
+        builder.build_snapshot('rev-2', ['rev-1'], [])
+        builder.build_snapshot('rev-3', ['rev-2'], [])
+        builder.finish_series()
+        b = builder.get_branch()
+        self.addCleanup(b.lock_read().unlock)
+        return _mod_history.History(b, {})
+
+    def make_long_linear_ancestry(self):
+        builder = self.make_branch_builder('branch')
+        builder.start_series()
+        builder.build_snapshot('A', None, [
+            ('add', ('', 'root-id', 'directory', None))])
+        for r in "BCDEFGHIJKLMNOPQRSTUVWXYZ":
+            builder.build_snapshot(r, None, [])
+        builder.finish_series()
+        b = builder.get_branch()
+        self.addCleanup(b.lock_read().unlock)
+        return _mod_history.History(b, {})
+
+    def make_merged_ancestry(self):
+        # Time goes up
+        # rev-3
+        #  |  \
+        #  |  rev-2
+        #  |  /
+        # rev-1
+        builder = self.make_branch_builder('branch')
+        builder.start_series()
+        builder.build_snapshot('rev-1', None, [
+            ('add', ('', 'root-id', 'directory', None))])
+        builder.build_snapshot('rev-2', ['rev-1'], [])
+        builder.build_snapshot('rev-3', ['rev-1', 'rev-2'], [])
+        builder.finish_series()
+        b = builder.get_branch()
+        self.addCleanup(b.lock_read().unlock)
+        return _mod_history.History(b, {})
+
+    def make_deep_merged_ancestry(self):
+        # Time goes up
+        # F
+        # |\
+        # | E
+        # | |\
+        # | | D
+        # | |/
+        # B C
+        # |/
+        # A
+        builder = self.make_branch_builder('branch')
+        builder.start_series()
+        builder.build_snapshot('A', None, [
+            ('add', ('', 'root-id', 'directory', None))])
+        builder.build_snapshot('B', ['A'], [])
+        builder.build_snapshot('C', ['A'], [])
+        builder.build_snapshot('D', ['C'], [])
+        builder.build_snapshot('E', ['C', 'D'], [])
+        builder.build_snapshot('F', ['B', 'E'], [])
+        builder.finish_series()
+        b = builder.get_branch()
+        self.addCleanup(b.lock_read().unlock)
+        return _mod_history.History(b, {})
+
+    def assertRevidsFrom(self, expected, history, search_revs, tip_rev):
+        self.assertEqual(expected,
+                         list(history.get_revids_from(search_revs, tip_rev)))
+
+
+class _DictProxy(object):
+
+    def __init__(self, d):
+        self._d = d
+        self._accessed = set()
+        self.__setitem__ = d.__setitem__
+
+    def __getitem__(self, name):
+        self._accessed.add(name)
+        return self._d[name]
+
+    def __len__(self):
+        return len(self._d)
+
+
+def track_rev_info_accesses(h):
+    """Track __getitem__ access to History._rev_info,
+
+    :return: set of items accessed
+    """
+    h._rev_info = _DictProxy(h._rev_info)
+    return h._rev_info._accessed
+
+
+class TestHistoryGetRevidsFrom(TestCaseWithExamples):
+
+    def test_get_revids_from_simple_mainline(self):
+        history = self.make_linear_ancestry()
+        self.assertRevidsFrom(['rev-3', 'rev-2', 'rev-1'],
+                              history, None, 'rev-3')
+
+    def test_get_revids_from_merged_mainline(self):
+        history = self.make_merged_ancestry()
+        self.assertRevidsFrom(['rev-3', 'rev-1'],
+                              history, None, 'rev-3')
+
+    def test_get_revids_given_one_rev(self):
+        history = self.make_merged_ancestry()
+        # rev-3 was the first mainline revision to see rev-2.
+        self.assertRevidsFrom(['rev-3'], history, ['rev-2'], 'rev-3')
+
+    def test_get_revids_deep_ancestry(self):
+        history = self.make_deep_merged_ancestry()
+        self.assertRevidsFrom(['F'], history, ['F'], 'F')
+        self.assertRevidsFrom(['F'], history, ['E'], 'F')
+        self.assertRevidsFrom(['F'], history, ['D'], 'F')
+        self.assertRevidsFrom(['F'], history, ['C'], 'F')
+        self.assertRevidsFrom(['B'], history, ['B'], 'F')
+        self.assertRevidsFrom(['A'], history, ['A'], 'F')
+
+    def test_get_revids_doesnt_over_produce_simple_mainline(self):
+        # get_revids_from shouldn't walk the whole ancestry just to get the
+        # answers for the first few revisions.
+        history = self.make_long_linear_ancestry()
+        accessed = track_rev_info_accesses(history)
+        result = history.get_revids_from(None, 'Z')
+        self.assertEqual(set(), accessed)
+        self.assertEqual('Z', result.next())
+        # We already know 'Z' because we passed it in.
+        self.assertEqual(set(), accessed)
+        self.assertEqual('Y', result.next())
+        self.assertEqual(set([history._rev_indices['Z']]), accessed)
+
+    def test_get_revids_doesnt_over_produce_for_merges(self):
+        # get_revids_from shouldn't walk the whole ancestry just to get the
+        # answers for the first few revisions.
+        history = self.make_long_linear_ancestry()
+        accessed = track_rev_info_accesses(history)
+        result = history.get_revids_from(['X', 'V'], 'Z')
+        self.assertEqual(set(), accessed)
+        self.assertEqual('X', result.next())
+        # We access 'W' because we are checking that W wasn't merged into X.
+        # The important bit is that we aren't getting the whole ancestry.
+        self.assertEqual(set([history._rev_indices[x] for x in 'ZYXW']),
+                         accessed)
+        self.assertEqual('V', result.next())
+        self.assertEqual(set([history._rev_indices[x] for x in 'ZYXWVU']),
+                         accessed)
+        self.assertRaises(StopIteration, result.next)
+        self.assertEqual(set([history._rev_indices[x] for x in 'ZYXWVU']),
+                         accessed)
+
+
+
+class TestHistoryChangeFromRevision(tests.TestCaseWithTransport):
+
+    def make_single_commit(self):
+        tree = self.make_branch_and_tree('test')
+        rev_id = tree.commit('Commit Message', timestamp=1299838474.317,
+            timezone=3600, committer='Joe Example <joe@example.com>',
+            revprops={})
+        self.addCleanup(tree.branch.lock_write().unlock)
+        rev = tree.branch.repository.get_revision(rev_id)
+        history = _mod_history.History(tree.branch, {})
+        return history, rev
+
+    def test_simple(self):
+        history, rev = self.make_single_commit()
+        change = history._change_from_revision(rev)
+        self.assertEqual(rev.revision_id, change.revid)
+        self.assertEqual(datetime.fromtimestamp(1299838474.317),
+                         change.date)
+        self.assertEqual(datetime.utcfromtimestamp(1299838474.317),
+                         change.utc_date)
+        self.assertEqual(['Joe Example <joe@example.com>'],
+                         change.authors)
+        self.assertEqual('test', change.branch_nick)
+        self.assertEqual('Commit Message', change.short_comment)
+        self.assertEqual('Commit Message', change.comment)
+        self.assertEqual(['Commit&nbsp;Message'], change.comment_clean)
+        self.assertEqual([], change.parents)
+        self.assertEqual([], change.bugs)
+        self.assertEqual(None, change.tags)
+
+    def test_tags(self):
+        history, rev = self.make_single_commit()
+        b = history._branch
+        b.tags.set_tag('tag-1', rev.revision_id)
+        b.tags.set_tag('tag-2', rev.revision_id)
+        b.tags.set_tag('Tag-10', rev.revision_id)
+        change = history._change_from_revision(rev)
+        # If available, tags are 'naturally' sorted. (sorting numbers in order,
+        # and ignoring case, etc.)
+        if getattr(tag, 'sort_natural', None) is not None:
+            self.assertEqual('tag-1, tag-2, Tag-10', change.tags)
+        else:
+            self.assertEqual('Tag-10, tag-1, tag-2', change.tags)
+
+    def test_committer_vs_authors(self):
+        tree = self.make_branch_and_tree('test')
+        rev_id = tree.commit('Commit Message', timestamp=1299838474.317,
+            timezone=3600, committer='Joe Example <joe@example.com>',
+            revprops={'authors': u'A Author <aauthor@example.com>\n'
+                                 u'B Author <bauthor@example.com>'})
+        self.addCleanup(tree.branch.lock_write().unlock)
+        rev = tree.branch.repository.get_revision(rev_id)
+        history = _mod_history.History(tree.branch, {})
+        change = history._change_from_revision(rev)
+        self.assertEqual(u'Joe Example <joe@example.com>',
+                         change.committer)
+        self.assertEqual([u'A Author <aauthor@example.com>',
+                          u'B Author <bauthor@example.com>'],
+                         change.authors)
+
+
+class TestHistory_IterateSufficiently(tests.TestCase):
+
+    def assertIterate(self, expected, iterable, stop_at, extra_rev_count):
+        self.assertEqual(expected, _mod_history.History._iterate_sufficiently(
+            iterable, stop_at, extra_rev_count))
+
+    def test_iter_no_extra(self):
+        lst = list('abcdefghijklmnopqrstuvwxyz')
+        self.assertIterate(['a', 'b', 'c'], iter(lst), 'c', 0)
+        self.assertIterate(['a', 'b', 'c', 'd'], iter(lst), 'd', 0)
+
+    def test_iter_not_found(self):
+        # If the key in question isn't found, we just exhaust the list
+        lst = list('abcdefghijklmnopqrstuvwxyz')
+        self.assertIterate(lst, iter(lst), 'not-there', 0)
+
+    def test_iter_with_extra(self):
+        lst = list('abcdefghijklmnopqrstuvwxyz')
+        self.assertIterate(['a', 'b', 'c'], iter(lst), 'b', 1)
+        self.assertIterate(['a', 'b', 'c', 'd', 'e'], iter(lst), 'c', 2)
+
+    def test_iter_with_too_many_extra(self):
+        lst = list('abcdefghijklmnopqrstuvwxyz')
+        self.assertIterate(lst, iter(lst), 'y', 10)
+        self.assertIterate(lst, iter(lst), 'z', 10)
+
+    def test_iter_with_extra_None(self):
+        lst = list('abcdefghijklmnopqrstuvwxyz')
+        self.assertIterate(lst, iter(lst), 'z', None)
+
+
+
+class TestHistoryGetView(TestCaseWithExamples):
+
+    def test_get_view_limited_history(self):
+        # get_view should only load enough history to serve the result, not all
+        # history.
+        history = self.make_long_linear_ancestry()
+        accessed = track_rev_info_accesses(history)
+        revid, start_revid, revid_list = history.get_view('Z', 'Z', None,
+                                                      extra_rev_count=5)
+        self.assertEqual(['Z', 'Y', 'X', 'W', 'V', 'U'], revid_list)
+        self.assertEqual('Z', revid)
+        self.assertEqual('Z', start_revid)
+        self.assertEqual(set([history._rev_indices[x] for x in 'ZYXWVU']),
+                         accessed)
+
+
+class TestHistoryGetChangedUncached(TestCaseWithExamples):
+
+    def test_native(self):
+        history = self.make_linear_ancestry()
+        changes = history.get_changes_uncached(['rev-1', 'rev-2'])
+        self.assertEquals(2, len(changes))
+        self.assertEquals('rev-1', changes[0].revid)
+        self.assertEquals('rev-2', changes[1].revid)
+        self.assertIs(None, getattr(changes[0], 'foreign_vcs', None))
+        self.assertIs(None, getattr(changes[0], 'foreign_revid', None))
+
+    def test_foreign(self):
+        # Test with a mocked foreign revision, as it's not possible
+        # to rely on any foreign plugins being installed.
+        history = self.make_linear_ancestry()
+        foreign_vcs = ForeignVcs(None, "vcs")
+        foreign_vcs.show_foreign_revid = repr
+        foreign_rev = ForeignRevision(("uuid", 1234), VcsMapping(foreign_vcs),
+            "revid-in-bzr", message="message",
+            timestamp=234423423.3)
+        change = history._change_from_revision(foreign_rev)
+        self.assertEquals('revid-in-bzr', change.revid)
+        self.assertEquals("('uuid', 1234)", change.foreign_revid)
+        self.assertEquals("vcs", change.foreign_vcs)

=== added file 'loggerhead/tests/test_http_head.py'
--- loggerhead/tests/test_http_head.py	1970-01-01 00:00:00 +0000
+++ loggerhead/tests/test_http_head.py	2011-02-10 02:33:15 +0000
@@ -0,0 +1,92 @@
+# Copyright 2011 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for the HeadMiddleware app."""
+
+from cStringIO import StringIO
+
+from bzrlib import tests
+
+from loggerhead.apps import http_head
+
+
+content = ["<html>",
+           "<head><title>Listed</title></head>",
+           "<body>Content</body>",
+           "</html>",
+          ]
+headers = {'X-Ignored-Header': 'Value'}
+
+def yielding_app(environ, start_response):
+    writer = start_response('200 OK', headers)
+    for chunk in content:
+        yield chunk
+
+
+def list_app(environ, start_response):
+    writer = start_response('200 OK', headers)
+    return content
+
+
+def writer_app(environ, start_response):
+    writer = start_response('200 OK', headers)
+    for chunk in content:
+        writer(chunk)
+    return []
+
+
+class TestHeadMiddleware(tests.TestCase):
+
+    def _trap_start_response(self, status, response_headers, exc_info=None):
+        self._write_buffer = StringIO()
+        self._start_response_passed = (status, response_headers, exc_info)
+        return self._write_buffer.write
+
+    def _consume_app(self, app, request_method):
+        environ = {'REQUEST_METHOD': request_method}
+        value = list(app(environ, self._trap_start_response))
+        self._write_buffer.writelines(value)
+
+    def _verify_get_passthrough(self, app):
+        app = http_head.HeadMiddleware(app)
+        self._consume_app(app, 'GET')
+        self.assertEqual(('200 OK', headers, None), self._start_response_passed)
+        self.assertEqualDiff(''.join(content), self._write_buffer.getvalue())
+
+    def _verify_head_no_body(self, app):
+        app = http_head.HeadMiddleware(app)
+        self._consume_app(app, 'HEAD')
+        self.assertEqual(('200 OK', headers, None), self._start_response_passed)
+        self.assertEqualDiff('', self._write_buffer.getvalue())
+
+    def test_get_passthrough_yielding(self):
+        self._verify_get_passthrough(yielding_app)
+
+    def test_head_passthrough_yielding(self):
+        self._verify_head_no_body(yielding_app)
+
+    def test_get_passthrough_list(self):
+        self._verify_get_passthrough(list_app)
+
+    def test_head_passthrough_list(self):
+        self._verify_head_no_body(list_app)
+
+    def test_get_passthrough_writer(self):
+        self._verify_get_passthrough(writer_app)
+
+    def test_head_passthrough_writer(self):
+        self._verify_head_no_body(writer_app)
+

=== added file 'loggerhead/tests/test_load_test.py'
--- loggerhead/tests/test_load_test.py	1970-01-01 00:00:00 +0000
+++ loggerhead/tests/test_load_test.py	2011-04-14 14:10:04 +0000
@@ -0,0 +1,337 @@
+# Copyright 2011 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#
+
+"""Tests for the load testing code."""
+
+import socket
+import time
+import threading
+import Queue
+
+from bzrlib import tests
+from bzrlib.tests import http_server
+
+from loggerhead import load_test
+
+
+empty_script = """{
+    "parameters": {},
+    "requests": []
+}"""
+
+class TestRequestDescription(tests.TestCase):
+
+    def test_init_from_dict(self):
+        rd = load_test.RequestDescription({'thread': '10', 'relpath': '/foo'})
+        self.assertEqual('10', rd.thread)
+        self.assertEqual('/foo', rd.relpath)
+
+    def test_default_thread_is_1(self):
+        rd = load_test.RequestDescription({'relpath': '/bar'})
+        self.assertEqual('1', rd.thread)
+        self.assertEqual('/bar', rd.relpath)
+
+
+_cur_time = time.time()
+def one_sec_timer():
+    """Every time this timer is called, it increments by 1 second."""
+    global _cur_time
+    _cur_time += 1.0
+    return _cur_time
+
+
+class NoopRequestWorker(load_test.RequestWorker):
+
+    # Every call to _timer will increment by one
+    _timer = staticmethod(one_sec_timer)
+
+    # Ensure that process never does anything
+    def process(self, url):
+        return True
+
+
+class TestRequestWorkerInfrastructure(tests.TestCase):
+    """Tests various infrastructure bits, without doing actual requests."""
+
+    def test_step_next_tracks_time(self):
+        rt = NoopRequestWorker('id')
+        rt.queue.put('item')
+        rt.step_next()
+        self.assertTrue(rt.queue.empty())
+        self.assertEqual([('item', True, 1.0)], rt.stats)
+
+    def test_step_multiple_items(self):
+        rt = NoopRequestWorker('id')
+        rt.queue.put('item')
+        rt.step_next()
+        rt.queue.put('next-item')
+        rt.step_next()
+        self.assertTrue(rt.queue.empty())
+        self.assertEqual([('item', True, 1.0), ('next-item', True, 1.0)],
+                         rt.stats)
+
+    def test_step_next_does_nothing_for_noop(self):
+        rt = NoopRequestWorker('id')
+        rt.queue.put('item')
+        rt.step_next()
+        rt.queue.put('<noop>')
+        rt.step_next()
+        self.assertEqual([('item', True, 1.0)], rt.stats)
+
+    def test_step_next_will_timeout(self):
+        # We don't want step_next to block forever
+        rt = NoopRequestWorker('id', blocking_time=0.001)
+        self.assertRaises(Queue.Empty, rt.step_next)
+
+    def test_run_stops_for_stop_event(self):
+        rt = NoopRequestWorker('id', blocking_time=0.001, _queue_size=2)
+        rt.queue.put('item1')
+        rt.queue.put('item2')
+        event = threading.Event()
+        t = threading.Thread(target=rt.run, args=(event,))
+        t.start()
+        # Wait for the queue to be processed
+        rt.queue.join()
+        # Now we can queue up another one, and wait for it
+        rt.queue.put('item3')
+        rt.queue.join()
+        # Now set the stopping event
+        event.set()
+        # Add another item to the queue, which might get processed, but the
+        # next item won't
+        rt.queue.put('item4')
+        rt.queue.put('item5')
+        t.join()
+        self.assertEqual([('item1', True, 1.0), ('item2', True, 1.0),
+                          ('item3', True, 1.0)],
+                         rt.stats[:3])
+        # The last event might be item4 or might be item3, the important thing
+        # is that even though there are still queued events, we won't
+        # process anything past the first
+        self.assertNotEqual('item5', rt.stats[-1][0])
+
+
+class TestRequestWorker(tests.TestCaseWithTransport):
+
+    def setUp(self):
+        super(TestRequestWorker, self).setUp()
+        self.transport_readonly_server = http_server.HttpServer
+
+    def test_request_items(self):
+        rt = load_test.RequestWorker('id', blocking_time=0.01, _queue_size=2)
+        self.build_tree(['file1', 'file2'])
+        readonly_url1 = self.get_readonly_url('file1')
+        self.assertStartsWith(readonly_url1, 'http://')
+        readonly_url2 = self.get_readonly_url('file2')
+        rt.queue.put(readonly_url1)
+        rt.queue.put(readonly_url2)
+        rt.step_next()
+        rt.step_next()
+        self.assertEqual(readonly_url1, rt.stats[0][0])
+        self.assertEqual(readonly_url2, rt.stats[1][0])
+
+    def test_request_nonexistant_items(self):
+        rt = load_test.RequestWorker('id', blocking_time=0.01, _queue_size=2)
+        readonly_url1 = self.get_readonly_url('no-file1')
+        rt.queue.put(readonly_url1)
+        rt.step_next()
+        self.assertEqual(readonly_url1, rt.stats[0][0])
+        self.assertEqual(False, rt.stats[0][1])
+
+    def test_no_server(self):
+        s = socket.socket()
+        # Bind to a port, but don't listen on it
+        s.bind(('localhost', 0))
+        url = 'http://%s:%s/path' % s.getsockname()
+        rt = load_test.RequestWorker('id', blocking_time=0.01, _queue_size=2)
+        rt.queue.put(url)
+        rt.step_next()
+        self.assertEqual((url, False), rt.stats[0][:2])
+
+
+class NoActionScript(load_test.ActionScript):
+
+    _thread_class = NoopRequestWorker
+    _default_blocking_timeout = 0.01
+
+
+class TestActionScriptInfrastructure(tests.TestCase):
+
+    def test_parse_requires_parameters_and_requests(self):
+        self.assertRaises(ValueError,
+            load_test.ActionScript.parse, '')
+        self.assertRaises(ValueError,
+            load_test.ActionScript.parse, '{}')
+        self.assertRaises(ValueError,
+            load_test.ActionScript.parse, '{"parameters": {}}')
+        self.assertRaises(ValueError,
+            load_test.ActionScript.parse, '{"requests": []}')
+        load_test.ActionScript.parse(
+            '{"parameters": {}, "requests": [], "comment": "section"}')
+        script = load_test.ActionScript.parse(
+            empty_script)
+        self.assertIsNot(None, script)
+
+    def test_parse_default_base_url(self):
+        script = load_test.ActionScript.parse(empty_script)
+        self.assertEqual('http://localhost:8080', script.base_url)
+
+    def test_parse_find_base_url(self):
+        script = load_test.ActionScript.parse(
+            '{"parameters": {"base_url": "http://example.com"},'
+            ' "requests": []}')
+        self.assertEqual('http://example.com', script.base_url)
+
+    def test_parse_default_blocking_timeout(self):
+        script = load_test.ActionScript.parse(empty_script)
+        self.assertEqual(60.0, script.blocking_timeout)
+
+    def test_parse_find_blocking_timeout(self):
+        script = load_test.ActionScript.parse(
+            '{"parameters": {"blocking_timeout": 10.0},'
+            ' "requests": []}'
+        )
+        self.assertEqual(10.0, script.blocking_timeout)
+
+    def test_parse_finds_requests(self):
+        script = load_test.ActionScript.parse(
+            '{"parameters": {}, "requests": ['
+            ' {"relpath": "/foo"},'
+            ' {"relpath": "/bar"}'
+            ' ]}')
+        self.assertEqual(2, len(script._requests))
+        self.assertEqual("/foo", script._requests[0].relpath)
+        self.assertEqual("/bar", script._requests[1].relpath)
+
+    def test__get_worker(self):
+        script = NoActionScript()
+        # If an id is found, then we should create it
+        self.assertEqual({}, script._threads)
+        worker = script._get_worker('id')
+        self.assertTrue('id' in script._threads)
+        # We should have set the blocking timeout
+        self.assertEqual(script.blocking_timeout / 10.0,
+                         worker.blocking_time)
+
+        # Another request will return the identical object
+        self.assertIs(worker, script._get_worker('id'))
+
+        # And the stop event will stop the thread
+        script.stop_and_join()
+
+    def test__full_url(self):
+        script = NoActionScript()
+        self.assertEqual('http://localhost:8080/path',
+                         script._full_url('/path'))
+        self.assertEqual('http://localhost:8080/path/to/foo',
+                         script._full_url('/path/to/foo'))
+        script.base_url = 'http://example.com'
+        self.assertEqual('http://example.com/path/to/foo',
+                         script._full_url('/path/to/foo'))
+        script.base_url = 'http://example.com/base'
+        self.assertEqual('http://example.com/base/path/to/foo',
+                         script._full_url('/path/to/foo'))
+        script.base_url = 'http://example.com'
+        self.assertEqual('http://example.com:8080/path',
+                         script._full_url(':8080/path'))
+
+    def test_single_threaded(self):
+        script = NoActionScript.parse("""{
+            "parameters": {"base_url": ""},
+            "requests": [
+                {"thread": "1", "relpath": "first"},
+                {"thread": "1", "relpath": "second"},
+                {"thread": "1", "relpath": "third"},
+                {"thread": "1", "relpath": "fourth"}
+            ]}""")
+        script.run()
+        worker = script._get_worker("1")
+        self.assertEqual(["first", "second", "third", "fourth"],
+                         [s[0] for s in worker.stats])
+
+    def test_two_threads(self):
+        script = NoActionScript.parse("""{
+            "parameters": {"base_url": ""},
+            "requests": [
+                {"thread": "1", "relpath": "first"},
+                {"thread": "2", "relpath": "second"},
+                {"thread": "1", "relpath": "third"},
+                {"thread": "2", "relpath": "fourth"}
+            ]}""")
+        script.run()
+        worker = script._get_worker("1")
+        self.assertEqual(["first", "third"],
+                         [s[0] for s in worker.stats])
+        worker = script._get_worker("2")
+        self.assertEqual(["second", "fourth"],
+                         [s[0] for s in worker.stats])
+
+
+class TestActionScriptIntegration(tests.TestCaseWithTransport):
+
+    def setUp(self):
+        super(TestActionScriptIntegration, self).setUp()
+        self.transport_readonly_server = http_server.HttpServer
+
+    def test_full_integration(self):
+        self.build_tree(['first', 'second', 'third', 'fourth'])
+        url = self.get_readonly_url()
+        script = load_test.ActionScript.parse("""{
+            "parameters": {"base_url": "%s", "blocking_timeout": 2.0},
+            "requests": [
+                {"thread": "1", "relpath": "first"},
+                {"thread": "2", "relpath": "second"},
+                {"thread": "1", "relpath": "no-this"},
+                {"thread": "2", "relpath": "or-this"},
+                {"thread": "1", "relpath": "third"},
+                {"thread": "2", "relpath": "fourth"}
+            ]}""" % (url,))
+        script.run()
+        worker = script._get_worker("1")
+        self.assertEqual([("first", True), ('no-this', False),
+                          ("third", True)],
+                         [(s[0].rsplit('/', 1)[1], s[1])
+                          for s in worker.stats])
+        worker = script._get_worker("2")
+        self.assertEqual([("second", True), ('or-this', False),
+                          ("fourth", True)],
+                         [(s[0].rsplit('/', 1)[1], s[1])
+                          for s in worker.stats])
+
+
+class TestRunScript(tests.TestCaseWithTransport):
+
+    def setUp(self):
+        super(TestRunScript, self).setUp()
+        self.transport_readonly_server = http_server.HttpServer
+
+    def test_run_script(self):
+        self.build_tree(['file1', 'file2', 'file3', 'file4'])
+        url = self.get_readonly_url()
+        self.build_tree_contents([('localhost.script', """{
+    "parameters": {"base_url": "%s", "blocking_timeout": 0.1},
+    "requests": [
+        {"thread": "1", "relpath": "file1"},
+        {"thread": "2", "relpath": "file2"},
+        {"thread": "1", "relpath": "file3"},
+        {"thread": "2", "relpath": "file4"}
+    ]
+}""" % (url,))])
+        script = load_test.run_script('localhost.script')
+        worker = script._threads["1"][0]
+        self.assertEqual([("file1", True), ('file3', True)],
+                         [(s[0].rsplit('/', 1)[1], s[1])
+                          for s in worker.stats])
+        worker = script._threads["2"][0]
+        self.assertEqual([("file2", True), ("file4", True)],
+                         [(s[0].rsplit('/', 1)[1], s[1])
+                          for s in worker.stats])

=== added file 'loggerhead/tests/test_revision_ui.py'
--- loggerhead/tests/test_revision_ui.py	1970-01-01 00:00:00 +0000
+++ loggerhead/tests/test_revision_ui.py	2011-03-16 12:37:17 +0000
@@ -0,0 +1,46 @@
+# Copyright (C) 2011 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+
+from loggerhead.tests.test_simple import BasicTests
+
+
+class TestRevisionUI(BasicTests):
+
+    def test_authors_vs_committer(self):
+        self.createBranch()
+        self.tree.commit('First', committer="Joe Example <joe@example.com>",
+            revprops={'authors': u'A Author <aauthor@example.com>\n'
+                                 u'B Author <bauthor@example.com>'})
+        app = self.setUpLoggerhead()
+        res = app.get('/revision/1')
+        # We would like to assert that Joe Example is connected to Committer,
+        # and the Authors are connected. However, that requires asserting the
+        # exact HTML connections, which I wanted to avoid.
+        res.mustcontain('Committer', 'Joe Example',
+                        'Author(s)', 'A Author, B Author')
+
+    def test_author_is_committer(self):
+        self.createBranch()
+        self.tree.commit('First', committer="Joe Example <joe@example.com>")
+        app = self.setUpLoggerhead()
+        res = app.get('/revision/1')
+        # We would like to assert that Joe Example is connected to Committer,
+        # and the Authors are connected. However, that requires asserting the
+        # exact HTML connections, which I wanted to avoid.
+        res.mustcontain('Committer', 'Joe Example')
+        self.assertFalse('Author(s)' in res.body)

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2008-07-01 04:01:31 +0000
+++ loggerhead/tests/test_simple.py	2011-11-25 02:28:56 +0000
@@ -1,90 +1,116 @@
+# Copyright (C) 2007, 2008, 2009, 2011 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
 import cgi
-import unittest
-import os
-import tempfile
-import shutil
 import logging
-
-import bzrlib.bzrdir
-import bzrlib.osutils
-from configobj import ConfigObj
-
-from loggerhead.history import History
+import re
+import simplejson
+from cStringIO import StringIO
+
+from bzrlib.tests import TestCaseWithTransport
+try:
+    from bzrlib.util.configobj.configobj import ConfigObj
+except ImportError:
+    from configobj import ConfigObj
+from bzrlib import config
+
 from loggerhead.apps.branch import BranchWSGIApp
+from loggerhead.apps.http_head import HeadMiddleware
 from paste.fixture import TestApp
-
-
-def test_config_root():
-    from loggerhead.apps.config import Root
-    config = ConfigObj()
-    app = TestApp(Root(config))
-    res = app.get('/')
-    res.mustcontain('loggerhead branches')
-
-
-class BasicTests(object):
-
-    # setup_method and teardown_method are so i can run the tests with
-    # py.test and take advantage of the error reporting.
-    def setup_method(self, meth):
-        self.setUp()
-
-    def teardown_method(self, meth):
-        self.tearDown()
+from paste.httpexceptions import HTTPExceptionHandler, HTTPMovedPermanently
+
+from loggerhead.tests.fixtures import (
+    SampleBranch,
+    )
+
+
+class BasicTests(TestCaseWithTransport):
 
     def setUp(self):
-        logging.basicConfig(level=logging.DEBUG)
-        self.bzrbranch = None
-        self.old_bzrhome = None
+        TestCaseWithTransport.setUp(self)
+        logging.basicConfig(level=logging.ERROR)
+        logging.getLogger('bzr').setLevel(logging.CRITICAL)
 
     def createBranch(self):
-        self.old_bzrhome = bzrlib.osutils.set_or_unset_env('BZR_HOME', '')
-        self.bzrbranch = tempfile.mkdtemp()
-        self.branch = bzrlib.bzrdir.BzrDir.create_branch_convenience(
-            self.bzrbranch, force_new_tree=True)
-        self.tree = self.branch.bzrdir.open_workingtree()
-
-    config_template = """
-    [project]
-        [[branch]]
-            branch_name = 'branch'
-            folder = '%(branch)s'
-    """
-
-    def setUpLoggerhead(self):
-        app = TestApp(BranchWSGIApp(self.branch).app)
-        return app
-
-    def tearDown(self):
-        if self.bzrbranch is not None:
-            shutil.rmtree(self.bzrbranch)
-        bzrlib.osutils.set_or_unset_env('BZR_HOME', self.old_bzrhome)
+        self.tree = self.make_branch_and_tree('.')
+
+    def setUpLoggerhead(self, **kw):
+        branch_app = BranchWSGIApp(self.tree.branch, '', **kw).app
+        return TestApp(HTTPExceptionHandler(branch_app))
+
+    def assertOkJsonResponse(self, app, env):
+        start, content = consume_app(app, env)
+        self.assertEqual('200 OK', start[0])
+        self.assertEqual('application/json', dict(start[1])['Content-Type'])
+        self.assertEqual(None, start[2])
+        simplejson.loads(content)
+
+    def make_branch_app(self, branch, **kw):
+        branch_app = BranchWSGIApp(branch, friendly_name='friendly-name', **kw)
+        branch_app._environ = {
+            'wsgi.url_scheme':'',
+            'SERVER_NAME':'',
+            'SERVER_PORT':'80',
+            }
+        branch_app._url_base = ''
+        return branch_app
 
 
 class TestWithSimpleTree(BasicTests):
 
     def setUp(self):
         BasicTests.setUp(self)
-        self.createBranch()
-
-        f = open(os.path.join(self.bzrbranch, 'myfilename'), 'w')
-        self.filecontents = ('some\nmultiline\ndata\n'
-                             'with<htmlspecialchars\n')
-        try:
-            f.write(self.filecontents)
-        finally:
-            f.close()
-        self.tree.add('myfilename')
-        self.fileid = self.tree.path2id('myfilename')
-        self.msg = 'a very exciting commit message <'
-        self.revid = self.tree.commit(message=self.msg)
-
+        self.sample_branch_fixture = SampleBranch(self)
+
+        # XXX: This could be cleaned up more... -- mbp 2011-11-25
+        self.useFixture(self.sample_branch_fixture)
+        self.tree = self.sample_branch_fixture.tree
+        self.fileid = self.sample_branch_fixture.fileid
+        self.filecontents = self.sample_branch_fixture.filecontents
+        self.msg = self.sample_branch_fixture.msg
+
+    def test_public_private(self):
+        app = self.make_branch_app(self.tree.branch, private=True)
+        self.assertEqual(app.public_private_css(), 'private')
+        app = self.make_branch_app(self.tree.branch)
+        self.assertEqual(app.public_private_css(), 'public')
 
     def test_changes(self):
         app = self.setUpLoggerhead()
         res = app.get('/changes')
         res.mustcontain(cgi.escape(self.msg))
 
+    def test_changes_for_file(self):
+        app = self.setUpLoggerhead()
+        res = app.get('/changes?filter_file_id=myfilename-id')
+        res.mustcontain(cgi.escape(self.msg))
+
+    def test_changes_branch_from(self):
+        app = self.setUpLoggerhead(served_url="lp:loggerhead")
+        res = app.get('/changes')
+        self.failUnless("To get this branch, use:" in res)
+        self.failUnless("lp:loggerhead" in res)
+
+    def test_no_empty_download_location(self):
+        """With no served_url, no instructions how to get it"""
+        app = self.setUpLoggerhead()
+        res = app.get('/changes')
+        self.failIf("To get this branch, use:" in res)
+
     def test_changes_search(self):
         app = self.setUpLoggerhead()
         res = app.get('/changes', params={'q': 'foo'})
@@ -92,22 +118,55 @@
 
     def test_annotate(self):
         app = self.setUpLoggerhead()
-        res = app.get('/annotate', params={'file_id':self.fileid})
+        res = app.get('/annotate', params={'file_id': self.fileid})
+        # If pygments is installed, it inserts <span class="pyg" content into
+        # the output, to trigger highlighting. And it specifically highlights
+        # the &lt; that we are interested in seeing in the output.
+        # Without pygments we have a simple: 'with&lt;htmlspecialchars'
+        # With it, we have
+        # '<span class='pyg-n'>with</span><span class='pyg-o'>&lt;</span>'
+        # '<span class='pyg-n'>htmlspecialchars</span>
+        # So we pre-filter the body, to make sure remove spans of that type.
+        body_no_span = re.sub(r'<span class="pyg-.">', '', res.body)
+        body_no_span = body_no_span.replace('</span>', '')
         for line in self.filecontents.splitlines():
-            res.mustcontain(cgi.escape(line))
+            escaped = cgi.escape(line)
+            self.assertTrue(escaped in body_no_span,
+                            "did not find %r in %r" % (escaped, body_no_span))
 
     def test_inventory(self):
         app = self.setUpLoggerhead()
         res = app.get('/files')
         res.mustcontain('myfilename')
+        res = app.get('/files/')
+        res.mustcontain('myfilename')
+        res = app.get('/files/1')
+        res.mustcontain('myfilename')
+        res = app.get('/files/1/')
+        res.mustcontain('myfilename')
+        res = app.get('/files/1/?file_id=' + self.tree.path2id(''))
+        res.mustcontain('myfilename')
+
+    def test_inventory_bad_rev_404(self):
+        app = self.setUpLoggerhead()
+        res = app.get('/files/200', status=404)
+        res = app.get('/files/invalid-revid', status=404)
+
+    def test_inventory_bad_path_404(self):
+        app = self.setUpLoggerhead()
+        res = app.get('/files/1/hooha', status=404)
+        res = app.get('/files/1?file_id=dssadsada', status=404)
 
     def test_revision(self):
         app = self.setUpLoggerhead()
         res = app.get('/revision/1')
+        res.mustcontain(no=['anotherfile<'])
+        res.mustcontain('anotherfile&lt;')
         res.mustcontain('myfilename')
 
 
 class TestEmptyBranch(BasicTests):
+    """Test that an empty branch doesn't break"""
 
     def setUp(self):
         BasicTests.setUp(self)
@@ -118,3 +177,107 @@
         res = app.get('/changes')
         res.mustcontain('No revisions!')
 
+    def test_inventory(self):
+        app = self.setUpLoggerhead()
+        res = app.get('/files')
+        res.mustcontain('No revisions!')
+
+
+class TestHiddenBranch(BasicTests):
+    """
+    Test that hidden branches aren't shown
+    FIXME: not tested that it doesn't show up on listings
+    """
+
+    def setUp(self):
+        BasicTests.setUp(self)
+        self.createBranch()
+        locations = config.locations_config_filename()
+        config.ensure_config_dir_exists()
+        open(locations, 'wb').write('[%s]\nhttp_serve = False'
+                                    % (self.tree.branch.base,))
+
+    def test_no_access(self):
+        app = self.setUpLoggerhead()
+        res = app.get('/changes', status=404)
+
+
+class TestControllerRedirects(BasicTests):
+    """
+    Test that a file under /files redirects to /view,
+    and a directory under /view redirects to /files.
+    """
+
+    def setUp(self):
+        BasicTests.setUp(self)
+        self.createBranch()
+        self.build_tree(('file', 'folder/', 'folder/file'))
+        self.tree.smart_add([])
+        self.tree.commit('')
+
+    def test_view_folder(self):
+        app = TestApp(BranchWSGIApp(self.tree.branch, '').app)
+
+        e = self.assertRaises(HTTPMovedPermanently, app.get, '/view/head:/folder')
+        self.assertEqual(e.location(), '/files/head:/folder')
+
+    def test_files_file(self):
+        app = TestApp(BranchWSGIApp(self.tree.branch, '').app)
+
+        e = self.assertRaises(HTTPMovedPermanently, app.get, '/files/head:/folder/file')
+        self.assertEqual(e.location(), '/view/head:/folder/file')
+        e = self.assertRaises(HTTPMovedPermanently, app.get, '/files/head:/file')
+        self.assertEqual(e.location(), '/view/head:/file')
+
+
+class TestHeadMiddleware(BasicTests):
+
+    def setUp(self):
+        BasicTests.setUp(self)
+        self.createBranch()
+        self.msg = 'trivial commit message'
+        self.revid = self.tree.commit(message=self.msg)
+
+    def setUpLoggerhead(self, **kw):
+        branch_app = BranchWSGIApp(self.tree.branch, '', **kw).app
+        return TestApp(HTTPExceptionHandler(HeadMiddleware(branch_app)))
+
+    def test_get(self):
+        app = self.setUpLoggerhead()
+        res = app.get('/changes')
+        res.mustcontain(self.msg)
+        self.assertEqual('text/html', res.header('Content-Type'))
+
+    def test_head(self):
+        app = self.setUpLoggerhead()
+        res = app.get('/changes', extra_environ={'REQUEST_METHOD': 'HEAD'})
+        self.assertEqual('text/html', res.header('Content-Type'))
+        self.assertEqualDiff('', res.body)
+
+
+def consume_app(app, env):
+    body = StringIO()
+    start = []
+    def start_response(status, headers, exc_info=None):
+        start.append((status, headers, exc_info))
+        return body.write
+    extra_content = list(app(env, start_response))
+    body.writelines(extra_content)
+    return start[0], body.getvalue()
+
+
+
+#class TestGlobalConfig(BasicTests):
+#    """
+#    Test that global config settings are respected
+#    """
+
+#    def setUp(self):
+#        BasicTests.setUp(self)
+#        self.createBranch()
+#        config.GlobalConfig().set_user_option('http_version', 'True')
+
+#    def test_setting_respected(self):
+        #FIXME: Figure out how to test this properly
+#        app = self.setUpLoggerhead()
+#        res = app.get('/changes', status=200)

=== modified file 'loggerhead/tests/test_templating.py'
--- loggerhead/tests/test_templating.py	2008-06-18 06:34:10 +0000
+++ loggerhead/tests/test_templating.py	2008-10-24 02:26:05 +0000
@@ -1,6 +1,8 @@
 from loggerhead.zptsupport import load_template
 
-RENDERED = u"<html>\n<head>\n<title>%s</title>\n</head>\n<body>\n<div>Hello, %s</div>\n</body>\n</html>"
+RENDERED = u"<html>\n<head>\n<title>%s</title>\n</head>\n\
+<body>\n<div>Hello, %s</div>\n</body>\n</html>"
+
 
 def test_template_lookup():
     template = load_template("loggerhead.tests.simple")

=== added file 'loggerhead/tests/test_util.py'
--- loggerhead/tests/test_util.py	1970-01-01 00:00:00 +0000
+++ loggerhead/tests/test_util.py	2011-09-08 00:33:28 +0000
@@ -0,0 +1,33 @@
+# Copyright 2011 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+from bzrlib import tests
+
+from loggerhead.util import html_escape, html_format
+
+
+class TestHTMLEscaping(tests.TestCase):
+
+    def test_html_escape(self):
+        self.assertEqual(
+            "foo &quot;&#39;&lt;&gt;&amp;",
+            html_escape("foo \"'<>&"))
+
+    def test_html_format(self):
+        self.assertEqual(
+            '<foo bar="baz&quot;&#39;">&lt;baz&gt;&amp;</foo>',
+            html_format(
+                '<foo bar="%s">%s</foo>', "baz\"'", "<baz>&"))

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2008-07-26 17:53:10 +0000
+++ loggerhead/util.py	2012-01-08 21:48:52 +0000
@@ -19,23 +19,29 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-try:
-    from xml.etree import ElementTree as ET
-except ImportError:
-    from elementtree import ElementTree as ET
-
 import base64
-import cgi
 import datetime
 import logging
 import re
 import struct
 import threading
 import time
-import types
+import sys
+import os
+import subprocess
+
+try:
+    from xml.etree import ElementTree as ET
+except ImportError:
+    from elementtree import ElementTree as ET
+
+from bzrlib import urlutils
+
+from simpletal.simpleTALUtils import HTMLStructureCleaner
 
 log = logging.getLogger("loggerhead.controllers")
 
+
 def fix_year(year):
     if year < 70:
         year += 2000
@@ -54,12 +60,16 @@
 # displaydate and approximatedate return an elementtree <span> Element
 # with the full date in a tooltip.
 
+
 def date_day(value):
     return value.strftime('%Y-%m-%d')
 
 
 def date_time(value):
-    return value.strftime('%Y-%m-%d %T')
+    if value is not None:
+        return value.strftime('%Y-%m-%d %H:%M:%S')
+    else:
+        return 'N/A'
 
 
 def _displaydate(date):
@@ -120,11 +130,13 @@
     return _wrap_with_date_time_title(date, _displaydate(date))
 
 
-class Container (object):
+class Container(object):
     """
     Convert a dict into an object with attributes.
     """
+
     def __init__(self, _dict=None, **kw):
+        self._properties = {}
         if _dict is not None:
             for key, value in _dict.iteritems():
                 setattr(self, key, value)
@@ -134,12 +146,31 @@
     def __repr__(self):
         out = '{ '
         for key, value in self.__dict__.iteritems():
-            if key.startswith('_') or (getattr(self.__dict__[key], '__call__', None) is not None):
+            if key.startswith('_') or (getattr(self.__dict__[key],
+                                       '__call__', None) is not None):
                 continue
             out += '%r => %r, ' % (key, value)
         out += '}'
         return out
 
+    def __getattr__(self, attr):
+        """Used for handling things that aren't already available."""
+        if attr.startswith('_') or attr not in self._properties:
+            raise AttributeError('No attribute: %s' % (attr,))
+        val = self._properties[attr](self, attr)
+        setattr(self, attr, val)
+        return val
+
+    def _set_property(self, attr, prop_func):
+        """Set a function that will be called when an attribute is desired.
+
+        We will cache the return value, so the function call should be
+        idempotent. We will pass 'self' and the 'attr' name when triggered.
+        """
+        if attr.startswith('_'):
+            raise ValueError("Cannot create properties that start with _")
+        self._properties[attr] = prop_func
+
 
 def trunc(text, limit=10):
     if len(text) <= limit:
@@ -150,6 +181,7 @@
 STANDARD_PATTERN = re.compile(r'^(.*?)\s*<(.*?)>\s*$')
 EMAIL_PATTERN = re.compile(r'[-\w\d\+_!%\.]+@[-\w\d\+_!%\.]+')
 
+
 def hide_email(email):
     """
     try to obsure any email address in a bazaar committer's name.
@@ -169,23 +201,66 @@
         return '%s at %s' % (username, domains[-2])
     return '%s at %s' % (username, domains[0])
 
+def hide_emails(emails):
+    """
+    try to obscure any email address in a list of bazaar committers' names.
+    """
+    result = []
+    for email in emails:
+        result.append(hide_email(email))
+    return result
 
 # only do this if unicode turns out to be a problem
 #_BADCHARS_RE = re.compile(ur'[\u007f-\uffff]')
 
+# Can't be a dict; &amp; needs to be done first.
+html_entity_subs = [
+    ("&", "&amp;"),
+    ('"', "&quot;"),
+    ("'", "&#39;"), # &apos; is defined in XML, but not HTML.
+    (">", "&gt;"),
+    ("<", "&lt;"),
+    ]
+
+
+def html_escape(s):
+    """Transform dangerous (X)HTML characters into entities.
+
+    Like cgi.escape, except also escaping \" and '. This makes it safe to use
+    in both attribute and element content.
+
+    If you want to safely fill a format string with escaped values, use
+    html_format instead
+    """
+    for char, repl in html_entity_subs:
+        s = s.replace(char, repl)
+    return s
+
+
+def html_format(template, *args):
+    """Safely format an HTML template string, escaping the arguments.
+
+    The template string must not be user-controlled; it will not be escaped.
+    """
+    return template % tuple(html_escape(arg) for arg in args)
+
+
 # FIXME: get rid of this method; use fixed_width() and avoid XML().
+
 def html_clean(s):
     """
     clean up a string for html display.  expand any tabs, encode any html
     entities, and replace spaces with '&nbsp;'.  this is primarily for use
     in displaying monospace text.
     """
-    s = cgi.escape(s.expandtabs())
+    s = html_escape(s.expandtabs())
     s = s.replace(' ', '&nbsp;')
     return s
 
+
 NONBREAKING_SPACE = u'\N{NO-BREAK SPACE}'
 
+
 def fill_div(s):
     """
     CSS is stupid. In some cases we need to replace an empty value with
@@ -193,8 +268,6 @@
 
     return: the same value recieved if not empty, and a '&nbsp;' if it is.
     """
-    
-
     if s is None:
         return '&nbsp;'
     elif isinstance(s, int):
@@ -208,6 +281,7 @@
             s = s.decode('iso-8859-15')
         return s
 
+HSC = HTMLStructureCleaner()
 
 def fixed_width(s):
     """
@@ -224,7 +298,10 @@
             s = s.decode('utf-8')
         except UnicodeDecodeError:
             s = s.decode('iso-8859-15')
-    return s.expandtabs().replace(' ', NONBREAKING_SPACE)
+
+    s = html_escape(s).expandtabs().replace(' ', NONBREAKING_SPACE)
+
+    return HSC.clean(s).replace('\n', '<br/>')
 
 
 def fake_permissions(kind, executable):
@@ -263,6 +340,7 @@
 P95_MEG = int(0.9 * MEG)
 P95_GIG = int(0.9 * GIG)
 
+
 def human_size(size, min_divisor=0):
     size = int(size)
     if (size == 0) and (min_divisor == 0):
@@ -297,6 +375,14 @@
     return out
 
 
+def local_path_from_url(url):
+    """Convert Bazaar URL to local path, ignoring readonly+ prefix"""
+    readonly_prefix = 'readonly+'
+    if url.startswith(readonly_prefix):
+        url = url[len(readonly_prefix):]
+    return urlutils.local_path_from_url(url)
+
+
 def fill_in_navigation(navigation):
     """
     given a navigation block (used by the template for the page header), fill
@@ -308,10 +394,12 @@
         navigation.position = 0
     navigation.count = len(navigation.revid_list)
     navigation.page_position = navigation.position // navigation.pagesize + 1
-    navigation.page_count = (len(navigation.revid_list) + (navigation.pagesize - 1)) // navigation.pagesize
+    navigation.page_count = (len(navigation.revid_list) + (navigation.pagesize\
+ - 1)) // navigation.pagesize
 
     def get_offset(offset):
-        if (navigation.position + offset < 0) or (navigation.position + offset > navigation.count - 1):
+        if (navigation.position + offset < 0) or (
+           navigation.position + offset > navigation.count - 1):
             return None
         return navigation.revid_list[navigation.position + offset]
 
@@ -324,7 +412,7 @@
             navigation.next_page_revid)
     start_revno = navigation.history.get_revno(navigation.start_revid)
 
-    params = { 'filter_file_id': navigation.filter_file_id }
+    params = {'filter_file_id': navigation.filter_file_id}
     if getattr(navigation, 'query', None) is not None:
         params['q'] = navigation.query
 
@@ -339,7 +427,71 @@
             [navigation.scan_url, next_page_revno], **params)
 
 
+def directory_breadcrumbs(path, is_root, view):
+    """
+    Generate breadcrumb information from the directory path given
+
+    The path given should be a path up to any branch that is currently being
+    served
+
+    Arguments:
+    path -- The path to convert into breadcrumbs
+    is_root -- Whether or not loggerhead is serving a branch at its root
+    view -- The type of view we are showing (files, changes etc)
+    """
+    # Is our root directory itself a branch?
+    if is_root:
+        breadcrumbs = [{
+            'dir_name': path,
+            'path': '',
+            'suffix': view,
+        }]
+    else:
+        # Create breadcrumb trail for the path leading up to the branch
+        breadcrumbs = [{
+            'dir_name': "(root)",
+            'path': '',
+            'suffix': '',
+        }]
+        if path != '/':
+            dir_parts = path.strip('/').split('/')
+            for index, dir_name in enumerate(dir_parts):
+                breadcrumbs.append({
+                    'dir_name': dir_name,
+                    'path': '/'.join(dir_parts[:index + 1]),
+                    'suffix': '',
+                })
+            # If we are not in the directory view, the last crumb is a branch,
+            # so we need to specify a view
+            if view != 'directory':
+                breadcrumbs[-1]['suffix'] = '/' + view
+    return breadcrumbs
+
+
+def branch_breadcrumbs(path, inv, view):
+    """
+    Generate breadcrumb information from the branch path given
+
+    The path given should be a path that exists within a branch
+
+    Arguments:
+    path -- The path to convert into breadcrumbs
+    inv -- Inventory to get file information from
+    view -- The type of view we are showing (files, changes etc)
+    """
+    dir_parts = path.strip('/').split('/')
+    inner_breadcrumbs = []
+    for index, dir_name in enumerate(dir_parts):
+        inner_breadcrumbs.append({
+            'dir_name': dir_name,
+            'path': '/'.join(dir_parts[:index + 1]),
+            'suffix': '/' + view,
+        })
+    return inner_breadcrumbs
+
+
 def decorator(unbound):
+
     def new_decorator(f):
         g = unbound(f)
         g.__name__ = f.__name__
@@ -352,35 +504,23 @@
     return new_decorator
 
 
-# common threading-lock decorator
-def with_lock(lockname, debug_name=None):
-    if debug_name is None:
-        debug_name = lockname
-    @decorator
-    def _decorator(unbound):
-        def locked(self, *args, **kw):
-            getattr(self, lockname).acquire()
-            try:
-                return unbound(self, *args, **kw)
-            finally:
-                getattr(self, lockname).release()
-        return locked
-    return _decorator
-
 
 @decorator
 def lsprof(f):
+
     def _f(*a, **kw):
         from loggerhead.lsprof import profile
         import cPickle
         z = time.time()
         ret, stats = profile(f, *a, **kw)
-        log.debug('Finished profiled %s in %d msec.' % (f.__name__, int((time.time() - z) * 1000)))
+        log.debug('Finished profiled %s in %d msec.' % (f.__name__,
+            int((time.time() - z) * 1000)))
         stats.sort()
         stats.freeze()
         now = time.time()
         msec = int(now * 1000) % 1000
-        timestr = time.strftime('%Y%m%d%H%M%S', time.localtime(now)) + ('%03d' % msec)
+        timestr = time.strftime('%Y%m%d%H%M%S',
+                                time.localtime(now)) + ('%03d' % (msec,))
         filename = f.__name__ + '-' + timestr + '.lsprof'
         cPickle.dump(stats, open(filename, 'w'), 2)
         return ret
@@ -415,8 +555,8 @@
 #         for re-ordering an existing page by different sort
 
 t_context = threading.local()
-_valid = ('start_revid', 'file_id', 'filter_file_id', 'q', 'remember',
-          'compare_revid', 'sort')
+_valid = (
+    'start_revid', 'filter_file_id', 'q', 'remember', 'compare_revid', 'sort')
 
 
 def set_context(map):
@@ -442,3 +582,94 @@
     overrides = dict((k, v) for (k, v) in overrides.iteritems() if k in _valid)
     map.update(overrides)
     return map
+
+
+class Reloader(object):
+    """
+    This class wraps all paste.reloader logic. All methods are @classmethod.
+    """
+
+    _reloader_environ_key = 'PYTHON_RELOADER_SHOULD_RUN'
+
+    @classmethod
+    def _turn_sigterm_into_systemexit(cls):
+        """
+        Attempts to turn a SIGTERM exception into a SystemExit exception.
+        """
+        try:
+            import signal
+        except ImportError:
+            return
+
+        def handle_term(signo, frame):
+            raise SystemExit
+        signal.signal(signal.SIGTERM, handle_term)
+
+    @classmethod
+    def is_installed(cls):
+        return os.environ.get(cls._reloader_environ_key)
+
+    @classmethod
+    def install(cls):
+        from paste import reloader
+        reloader.install(int(1))
+
+    @classmethod
+    def restart_with_reloader(cls):
+        """Based on restart_with_monitor from paste.script.serve."""
+        print 'Starting subprocess with file monitor'
+        while True:
+            args = [sys.executable] + sys.argv
+            new_environ = os.environ.copy()
+            new_environ[cls._reloader_environ_key] = 'true'
+            proc = None
+            try:
+                try:
+                    cls._turn_sigterm_into_systemexit()
+                    proc = subprocess.Popen(args, env=new_environ)
+                    exit_code = proc.wait()
+                    proc = None
+                except KeyboardInterrupt:
+                    print '^C caught in monitor process'
+                    return 1
+            finally:
+                if (proc is not None
+                    and getattr(os, 'kill', None) is not None):
+                    import signal
+                    try:
+                        os.kill(proc.pid, signal.SIGTERM)
+                    except (OSError, IOError):
+                        pass
+
+            # Reloader always exits with code 3; but if we are
+            # a monitor, any exit code will restart
+            if exit_code != 3:
+                return exit_code
+            print '-'*20, 'Restarting', '-'*20
+
+
+def convert_file_errors(application):
+    """WSGI wrapper to convert some file errors to Paste exceptions"""
+    def new_application(environ, start_response):
+        try:
+            return application(environ, start_response)
+        except (IOError, OSError), e:
+            import errno
+            from paste import httpexceptions
+            if e.errno == errno.ENOENT:
+                raise httpexceptions.HTTPNotFound()
+            elif e.errno == errno.EACCES:
+                raise httpexceptions.HTTPForbidden()
+            else:
+                raise
+    return new_application
+
+
+def convert_to_json_ready(obj):
+    if isinstance(obj, Container):
+        d = obj.__dict__.copy()
+        del d['_properties']
+        return d
+    elif isinstance(obj, datetime.datetime):
+        return tuple(obj.utctimetuple())
+    raise TypeError(repr(obj) + " is not JSON serializable")

=== modified file 'loggerhead/wholehistory.py'
--- loggerhead/wholehistory.py	2008-07-26 14:52:44 +0000
+++ loggerhead/wholehistory.py	2010-04-26 19:37:26 +0000
@@ -1,4 +1,5 @@
-# Cache the whole history data needed by loggerhead about a branch.
+#
+# Copyright (C) 2008, 2009 Canonical Ltd.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,6 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+"""Cache the whole history data needed by loggerhead about a branch."""
 
 import logging
 import time
@@ -30,49 +32,54 @@
     # Filter ghosts, and null:
     if NULL_REVISION in revision_graph:
         del revision_graph[NULL_REVISION]
-    for key, parents in revision_graph.items():
+    for key, parents in revision_graph.iteritems():
         revision_graph[key] = tuple(parent for parent in parents if parent
             in revision_graph)
     return revision_graph
 
 
 def compute_whole_history_data(branch):
+    """Compute _rev_info and _rev_indices for a branch.
+
+    See History.__doc__ for what these data structures mean.
+    """
     z = time.time()
 
     last_revid = branch.last_revision()
 
-    log = logging.getLogger('loggerhead.%s' % (branch.nick,))
+    log = logging.getLogger('loggerhead.%s' %
+                            (branch.get_config().get_nickname(),))
 
     graph = branch.repository.get_graph()
-    parent_map = dict(((key, value) for key, value in
-         graph.iter_ancestry([last_revid]) if value is not None))
+    parent_map = dict((key, value) for key, value in
+        graph.iter_ancestry([last_revid]) if value is not None)
 
     _revision_graph = _strip_NULL_ghosts(parent_map)
-    _full_history = []
-    _revision_info = {}
-    _revno_revid = {}
+
+    _rev_info = []
+    _rev_indices = {}
+
     if is_null(last_revid):
         _merge_sort = []
     else:
         _merge_sort = merge_sort(
             _revision_graph, last_revid, generate_revno=True)
 
-    for (seq, revid, merge_depth, revno, end_of_merge) in _merge_sort:
-        _full_history.append(revid)
+    for info in _merge_sort:
+        seq, revid, merge_depth, revno, end_of_merge = info
         revno_str = '.'.join(str(n) for n in revno)
-        _revno_revid[revno_str] = revid
-        _revision_info[revid] = (
-            seq, revid, merge_depth, revno_str, end_of_merge)
-
-    _where_merged = {}
-
-    for revid in _revision_graph.keys():
-        if _revision_info[revid][2] == 0:
+        parents = _revision_graph[revid]
+        _rev_indices[revid] = len(_rev_info)
+        _rev_info.append([(seq, revid, merge_depth, revno_str, end_of_merge), (), parents])
+
+    for revid in _revision_graph.iterkeys():
+        if _rev_info[_rev_indices[revid]][0][2] == 0:
             continue
         for parent in _revision_graph[revid]:
-            _where_merged.setdefault(parent, set()).add(revid)
-
-    log.info('built revision graph cache: %r secs' % (time.time() - z,))
-
-    return (_revision_graph, _full_history, _revision_info,
-            _revno_revid, _merge_sort, _where_merged)
+            c = _rev_info[_rev_indices[parent]]
+            if revid not in c[1]:
+                c[1] = c[1] + (revid,)
+
+    log.info('built revision graph cache: %.3f secs' % (time.time() - z,))
+
+    return (_rev_info, _rev_indices)

=== modified file 'loggerhead/zptsupport.py'
--- loggerhead/zptsupport.py	2008-07-26 14:52:44 +0000
+++ loggerhead/zptsupport.py	2010-05-12 15:01:44 +0000
@@ -18,21 +18,23 @@
 import logging
 import os
 import pkg_resources
+import re
 import StringIO
 
 from simpletal import simpleTAL, simpleTALES
 
-logging.getLogger("simpleTAL").setLevel(logging.INFO)
-logging.getLogger("simpleTALES").setLevel(logging.INFO)
-
-
 _zpt_cache = {}
+
+
 def zpt(tfile):
     tinstance = _zpt_cache.get(tfile)
     stat = os.stat(tfile)
     if tinstance is None or tinstance.stat != stat:
+        text = open(tfile).read()
+        text = re.sub(r'\s*\n\s*', '\n', text)
+        text = re.sub(r'[ \t]+', ' ', text)
         tinstance = _zpt_cache[tfile] = TemplateWrapper(
-            simpleTAL.compileXMLTemplate(open(tfile)), tfile, stat)
+            simpleTAL.compileXMLTemplate(text), tfile, stat)
     return tinstance
 
 
@@ -74,7 +76,7 @@
         package = classname[0:divider]
         basename = classname[divider+1:]
     else:
-        raise ValueError, "All templates must be in a package"
+        raise ValueError("All templates must be in a package")
 
     tfile = pkg_resources.resource_filename(
         package, "%s.%s" % (basename, "pt"))

=== added file 'loggerheadd'
--- loggerheadd	1970-01-01 00:00:00 +0000
+++ loggerheadd	2009-04-30 10:39:05 +0000
@@ -0,0 +1,112 @@
+#!/bin/sh
+### BEGIN INIT INFO
+# Required-Start:       $local_fs $remote_fs $network
+# Default-Start:        3 5
+# Default-Stop:         0 1 2 6
+# Short-Description:    Loggerhead
+# Description:          Manage Loggerhead (a web viewer for projects in bazaar)
+### END INIT INFO
+
+
+#
+# Configure this please:
+# (Please stop loggerhead before changing the configuration, otherwise this
+#   script might not be able to kill loggerhead)
+#
+
+LHUSER=loggerhead
+
+if [ `whoami` = "$LHUSER" ]; then
+    SUDO=""
+else
+    SUDO="sudo -H -u $LHUSER"
+fi
+
+# If serve-branches is not in your path, you will need to specify the full path:
+SERVE_BRANCHES_CMD=serve-branches
+
+LOG_FOLDER=/var/log/loggerhead
+LOG_FILE=$LOG_FOLDER/loggerheadd.log
+URL_PREFIX=/loggerhead
+PORT=8080
+
+#please specify the base directory to serve:
+BZRROOT=/bzrroot
+
+# You can add additional options to serve-branches here:
+START_CMD="$SERVE_BRANCHES_CMD --prefix=$URL_PREFIX --log-folder=$LOG_FOLDER --port=$PORT $BZRROOT"
+
+
+#
+# main part
+#
+
+loggerhead_process(){
+    $SUDO pgrep -fl "$START_CMD"
+}
+
+loggerhead_status(){
+    proccess=`loggerhead_process`
+    #echo "$proccess"
+    listening=`netstat -nl |grep -e ":$PORT "`
+    #echo "$listening"
+    if [ -z "$proccess" ]; then
+        echo "Loggerhead is *not* running."
+    else
+        echo "Loggerhead is running."
+        if [ -z "$listening" ]; then
+            echo "This server is *not* listening on port $PORT."
+        else
+            echo "This server is listening on port $PORT."
+        fi
+    fi
+}
+
+start_loggerhead(){
+    echo "Starting loggerhead.   (See $LOG_FOLDER for details.)"
+
+    # make sure the log folder is created
+    if [ ! -d $LOG_FOLDER ]
+    then
+        $SUDO mkdir -p $LOG_FOLDER
+    fi
+    echo "" > $LOG_FILE
+    $SUDO python $START_CMD > $LOG_FILE 2>&1 &
+
+    #wait a little while of some logging to appear
+    log=""
+    for i in $(seq 1 3 30); do
+        log=`cat $LOG_FILE`
+        if [ -n "$log" ]; then
+            break
+        fi
+        sleep 0.3
+    done
+    tail $LOG_FILE
+    loggerhead_status
+}
+
+stop_loggerhead(){
+    echo "Stopping loggerhead."
+    $SUDO pkill -f "$START_CMD"
+    loggerhead_status
+}
+
+case "$1" in
+    start)
+        start_loggerhead
+    ;;
+    stop)
+        stop_loggerhead
+    ;;
+    status)
+        loggerhead_status
+    ;;
+    restart)
+        stop_loggerhead
+        start_loggerhead
+    ;;
+    *)
+        echo "Usage: loggerheadd { start | stop | status | restart }"
+        exit 1
+esac

=== added file 'serve-branches'
--- serve-branches	1970-01-01 00:00:00 +0000
+++ serve-branches	2009-06-26 09:42:43 +0000
@@ -0,0 +1,27 @@
+#!/usr/bin/env python
+#
+# Copyright (C) 2008, 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Search for branches underneath a directory and serve them all."""
+
+import sys
+
+from loggerhead.main import main
+
+
+if __name__ == "__main__":
+    main(sys.argv[1:])

=== modified file 'serve-branches.1'
--- serve-branches.1	2008-08-05 16:07:16 +0000
+++ serve-branches.1	2008-09-10 23:12:59 +0000
@@ -21,8 +21,23 @@
 \fB\-\-trunk\-dir\fR=\fIDIR\fR
 The directory that contains the trunk branches.
 .TP
+\fB\-\-port\fR
+Port Loggerhead should listen on (defaults to 8080).
+.TP
+\fB\-\-host\fR
+Host Loggerhead should listen on.
+.TP
+\fB\-\-prefix\fR
+Specify host prefix.
+.TP
+\fB\-\-reload\fR
+Restarts the application when changing python files. Only used for development purposes.
+.TP
+\fB\-\-log\-folder\fR=\fILOG_FOLDER\fR
+The directory to place log files
+.TP
 \fB\-\-version\fR
-Print the software version and exit
+Print the software version and exit.
 .SH "LICENSE"
 GNU GPLv2 or later.
 .SH "SEE ALSO"

=== modified file 'setup.py' (properties changed: -x to +x)
--- setup.py	2008-08-05 16:02:23 +0000
+++ setup.py	2012-02-02 04:58:46 +0000
@@ -18,8 +18,8 @@
 
 """Loggerhead is a web viewer for projects in bazaar"""
 
-
 from distutils.core import setup
+
 import loggerhead
 
 
@@ -30,18 +30,46 @@
     license = "GNU GPL v2 or later",
     maintainer = "Michael Hudson",
     maintainer_email = "michael.hudson@canonical.com",
-    scripts = ["start-loggerhead", "stop-loggerhead", "serve-branches"],
-    packages = ["loggerhead", 
-                "loggerhead/apps", 
-                "loggerhead/controllers", 
-                "loggerhead/templates"],
-    package_data = {"loggerhead":["templates/*.pt", 
-                                  "static/css/*.css", 
-                                  "static/javascript/*", 
-                                  "static/images/*"]},
+    scripts = [
+        "serve-branches",
+        "loggerhead.wsgi",
+        ],
+    packages = ["loggerhead",
+                "loggerhead/apps",
+                "loggerhead/controllers",
+                "loggerhead/templates",
+                "bzrlib.plugins.loggerhead"],
+    package_dir={'bzrlib.plugins.loggerhead':'.'},
+    package_data = {"loggerhead": ["templates/*.pt",
+                                   "static/css/*.css",
+                                   "static/javascript/*.js",
+                                   "static/javascript/yui/build/anim/*",
+                                   "static/javascript/yui/build/base/*",
+                                   "static/javascript/yui/build/cssbase/*",
+                                   "static/javascript/yui/build/cssgrids/*",
+                                   "static/javascript/yui/build/dd/*",
+                                   "static/javascript/yui/build/dump/*",
+                                   "static/javascript/yui/build/get/*",
+                                   "static/javascript/yui/build/json/*",
+                                   "static/javascript/yui/build/node/*",
+                                   "static/javascript/yui/build/queue/*",
+                                   "static/javascript/yui/build/yui/*",
+                                   "static/javascript/yui/build/attribute/*",
+                                   "static/javascript/yui/build/cookie/*",
+                                   "static/javascript/yui/build/cssfonts/*",
+                                   "static/javascript/yui/build/cssreset/*",
+                                   "static/javascript/yui/build/dom/*",
+                                   "static/javascript/yui/build/event/*",
+                                   "static/javascript/yui/build/io/*",
+                                   "static/javascript/yui/build/loader/*",
+                                   "static/javascript/yui/build/oop/*",
+                                   "static/javascript/yui/build/substitute/*",
+                                   "static/javascript/yui/build/yui-base/*",
+                                   "static/images/*"]},
     data_files = [
-        ('share/man/man1',['start-loggerhead.1', 'stop-loggerhead.1', 
-                           'serve-branches.1']),
-        ('share/doc/loggerhead', ['loggerhead.conf.example']),
+        ('share/man/man1', ['serve-branches.1']),
+        ('share/doc/loggerhead', ['loggerhead.conf.example',
+                                  'apache-loggerhead.conf',
+                                  'bazaar.conf']),
         ],
     )

=== removed file 'start-loggerhead'
--- start-loggerhead	2008-08-06 18:33:20 +0000
+++ start-loggerhead	1970-01-01 00:00:00 +0000
@@ -1,165 +0,0 @@
-#!/usr/bin/env python
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-"""A script for starting the loggerhead process."""
-
-
-import logging
-import logging.handlers
-from optparse import OptionParser
-import os
-import sys
-import urlparse
-
-from configobj import ConfigObj
-
-from paste import httpserver
-from paste.httpexceptions import make_middleware
-from paste.translogger import make_filter
-
-from loggerhead import daemon, release
-from loggerhead.apps.config import Root
-
-
-def make_handler(config, filename):
-    roll = config.get('log.roll', 'never')
-    if roll == 'daily':
-        h = logging.handlers.TimedRotatingFileHandler(filename, 'midnight', 0, 100)
-    elif roll == 'weekly':
-        h = logging.handlers.TimedRotatingFileHandler(filename, 'W0', 0, 100)
-    else:
-        h = logging.FileHandler(filename)
-    return h
-
-
-def setup_logging(logdir, config, foreground):
-    # i hate that stupid logging config format, so just set up logging here.
-
-    if not os.path.exists(log_folder):
-        os.mkdir(log_folder)
-
-    f = logging.Formatter('%(levelname)-.3s [%(asctime)s.%(msecs)03d] %(name)s: %(message)s',
-                          '%Y%m%d-%H:%M:%S')
-    debug_log = make_handler(config, os.path.join(log_folder, 'debug.log'))
-    debug_log.setLevel(logging.DEBUG)
-    debug_log.setFormatter(f)
-    if foreground:
-        stdout_log = logging.StreamHandler(sys.stdout)
-        stdout_log.setLevel(logging.DEBUG)
-        stdout_log.setFormatter(f)
-    f = logging.Formatter('[%(asctime)s.%(msecs)03d] %(message)s',
-                          '%Y%m%d-%H:%M:%S')
-    access_log = make_handler(config, os.path.join(log_folder, 'access.log'))
-    access_log.setLevel(logging.INFO)
-    access_log.setFormatter(f)
-
-    logging.getLogger('').setLevel(logging.DEBUG)
-    logging.getLogger('').addHandler(debug_log)
-    logging.getLogger('wsgi').addHandler(access_log)
-
-    if foreground:
-        logging.getLogger('').addHandler(stdout_log)
-
-
-
-def main():
-    home = os.path.realpath(os.path.dirname(__file__))
-    default_pidfile = os.path.join(home, 'loggerhead.pid')
-    default_configfile = os.path.join(home, 'loggerhead.conf')
-    default_log_folder = os.path.join(home, 'logs')
-    parser = OptionParser(usage='usage: %prog [options]', version='%prog ' + release.version)
-    parser.add_option('-f', '--foreground', action='store_true', dest='foreground', default=False,
-                      help="run in the foreground; don't daemonize")
-    parser.add_option('-C', '--check', action='store_true', dest='check', default=False,
-                      help="only start if not already running (useful for cron jobs)")
-    parser.add_option('-p', '--pidfile', dest="pidfile", default=default_pidfile,
-                      help="override pidfile location")
-    parser.add_option('-c', '--config-file', dest="configfile", default=default_configfile,
-                      help="override configuration file location")
-    parser.add_option('-L', '--log-folder', dest="log-folder", default=default_log_folder,
-                      help="override log file directory")
-    options, args = parser.parse_args()
-    if len(args) > 0:
-        parser.error('No filename arguments are used, only options.')
-
-    if options.check:
-        if daemon.is_running(options.pidfile):
-            sys.exit(0)
-        sys.stderr.write('Did not find loggerhead running in %r; restarting...\n' % (options.pidfile,))
-
-    # read loggerhead config
-
-    config = ConfigObj(options.configfile, encoding='utf-8')
-    extra_path = config.get('bzrpath', None)
-    if extra_path:
-        sys.path.insert(0, extra_path)
-
-    #turbogears.update_config(configfile="dev.cfg", modulename="loggerhead.config")
-
-    potential_overrides = [ ('server.socket_port', int),
-                            ('server.webpath', str),
-                            ('server.thread_pool', int),
-                            ('server.socket_host' ,str) ]
-    server_port = int(config.get('server.socket_port', 8080))
-    nworkers = int(config.get('server.thread_pool', 10))
-    server_host = config.get('server.socket_host', '0.0.0.0')
-    webpath = config.get('server.webpath', None)
-
-    for key, keytype in potential_overrides:
-        value = config.get(key, None)
-        if value is not None:
-            value = keytype(value)
-            #turbogears.config.update({ key: value })
-
-    if not options.foreground:
-        sys.stderr.write('\n')
-        sys.stderr.write('Launching loggerhead into the background.\n')
-        sys.stderr.write('PID file: %s\n' % (options.pidfile,))
-        sys.stderr.write('\n')
-
-        daemon.daemonize(options.pidfile, home)
-
-    setup_logging(options.log_folder, config, foreground=options.foreground)
-
-    log = logging.getLogger('loggerhead')
-    log.info('Starting up...')
-
-    app = Root(config)
-
-    app = app
-    app = make_middleware(app)
-    app = make_filter(app, None)
-
-    if webpath:
-        scheme, netloc, path, blah, blah, blah = urlparse.urlparse(webpath)
-        def app(environ, start_response, orig=app):
-            environ['SCRIPT_NAME'] = path
-            environ['HTTP_HOST'] = netloc
-            return orig(environ, start_response)
-
-    try:
-        httpserver.serve(
-            app, host=server_host, port=server_port,
-            threadpool_workers=nworkers)
-    finally:
-        log.info('Shutdown.')
-        try:
-            os.remove(options.pidfile)
-        except OSError:
-            pass
-
-
-if __name__ == '__main__':
-    main()

=== removed file 'start-loggerhead.1'
--- start-loggerhead.1	2008-08-06 18:33:20 +0000
+++ start-loggerhead.1	1970-01-01 00:00:00 +0000
@@ -1,38 +0,0 @@
-.TH START-LOGGERHEAD "1" "July 2008" "start-loggerhead 1.2.1" "User Commands"
-.SH NAME
-start-loggerhead \- start a loggerhead server
-.SH SYNOPSIS
-.B start-loggerhead
-[\fIoptions\fR]
-.SH DESCRIPTION
-Loggerhead is a web viewer for projects in bazaar. It can be used to navigate 
-a branch history, annotate files, view patches, perform searches, etc. It's 
-heavily based on bazaar-webserve, which is itself based on hgweb for Mercurial.
-.PP
-The start-loggerhead command starts a new standalone loggerhead server.
-.SH OPTIONS
-.TP
-\fB\-\-version\fR
-show program's version number and exit
-.TP
-\fB\-h\fR, \fB\-\-help\fR
-show this help message and exit
-.TP
-\fB\-f\fR, \fB\-\-foreground\fR
-run in the foreground; don't daemonize
-.TP
-\fB\-C\fR, \fB\-\-check\fR
-only start if not already running (useful for cron jobs)
-.TP
-\fB\-p\fR, \fB\-\-pidfile=PIDFILE\fR
-override pid file location
-.TP
-\fB\-c\fR, \fB\-\-config-file=CONFIGFILE\fR
-override configuration file location
-.TP
-\fB\-L\fR, \fB\-\-log-folder=LOG-FOLDER\fR
-override log directory
-.SH "LICENSE"
-GNU GPLv2 or later.
-.SH "SEE ALSO"
-https://launchpad.net/loggerhead

=== removed file 'stop-loggerhead'
--- stop-loggerhead	2008-08-04 23:46:37 +0000
+++ stop-loggerhead	1970-01-01 00:00:00 +0000
@@ -1,43 +0,0 @@
-#!/usr/bin/env python
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-"""A script for stopping the loggerhead process."""
-
-import os
-import sys
-
-home = os.path.realpath(os.path.dirname(__file__))
-pidfile = os.path.join(home, 'loggerhead.pid')
-
-try:
-    f = open(pidfile, 'r')
-except IOError, e:
-    print 'No pid file found.'
-    sys.exit(1)
-
-pid = int(f.readline())
-
-try:
-    os.kill(pid, 0)
-except OSError, e:
-    print 'Stale pid file; server is not running.'
-    sys.exit(1)
-
-print
-print 'Shutting down previous server @ pid %d.' % (pid,)
-print
-
-import signal
-os.kill(pid, signal.SIGINT)

=== removed file 'stop-loggerhead.1'
--- stop-loggerhead.1	2008-07-26 14:09:59 +0000
+++ stop-loggerhead.1	1970-01-01 00:00:00 +0000
@@ -1,15 +0,0 @@
-.TH STOP-LOGGERHEAD "1" "July 2008" "stop-loggerhead 1.2.1" "User Commands"
-.SH NAME
-stop-loggerhead \- stop a loggerhead server
-.SH SYNOPSIS
-.B stop-loggerhead
-.SH DESCRIPTION
-Loggerhead is a web viewer for projects in bazaar. It can be used to navigate 
-a branch history, annotate files, view patches, perform searches, etc. It's 
-heavily based on bazaar-webserve, which is itself based on hgweb for Mercurial.
-.PP
-The stop-loggerhead command stops the currently running loggerhead server.
-.SH "LICENSE"
-GNU GPLv2 or later.
-.SH "SEE ALSO"
-https://launchpad.net/loggerhead

